@@ -6,16 +6,14 @@ set -ev
 ADD_PKG_LIST=""
 
 if [ "${GITHUB_JOB}" = "clang_tidy" ]; then
-  ADD_PKG_LIST="
-    clang-tidy  \
-    python-yaml"
+  pip install pyyaml
+  ADD_PKG_LIST="clang-tidy"
 fi
 
 if [ "${GITHUB_JOB}" = "testsuite" ]; then
   ADD_PKG_LIST="
     ${CXX} \
     libwayland-egl1-mesa  \
-    linux-generic \
     mesa-utils  \
     xserver-xorg  \
     xserver-xorg-core \
@@ -29,7 +27,6 @@ if [ "${GITHUB_JOB}" = "appimage" ]; then
 fi
 
 sudo apt-get update
-sudo apt-get upgrade
 
 # This script handles the common dependencies
 ./install-dependencies.sh debian -y ${ADD_PKG_LIST}
