@@ -1,6 +1,6 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_productionsite_type {
    name = "empire_fishers_house",
@@ -42,6 +42,10 @@ wl.Descriptions():new_productionsite_type {
          -- TRANSLATORS: Completed/Skipped/Did not start fishing because ...
          descname = _("fishing"),
          actions = {
+            -- time of worker: 17.2-46 sec, min+max average 31.6 sec
+            -- min. time total: 17.2 + 10 = 27.2 sec
+            -- max. time total: 46 + 10 = 56 sec
+            -- avg. time total: 31.6 + 10 = 41.6 sec
             "callworker=fish",
             "sleep=duration:10s"
          }
