@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2022 by the Widelands Development Team
+ * Copyright (C) 2009-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -134,14 +134,14 @@ constexpr uint16_t kWhFarButReachable = 250;
 constexpr uint16_t kWhNotReachable = 500;
 
 struct CheckStepRoadAI {
-	CheckStepRoadAI(Widelands::Player* const pl, uint8_t const mc, bool const oe);
+	CheckStepRoadAI(Widelands::Player* pl, uint8_t mc, bool oe);
 
-	bool allowed(const Widelands::Map&,
-	             Widelands::FCoords start,
-	             Widelands::FCoords end,
-	             int32_t dir,
-	             Widelands::CheckStep::StepId) const;
-	bool reachable_dest(const Widelands::Map&, const Widelands::FCoords& dest) const;
+	[[nodiscard]] bool allowed(const Widelands::Map&,
+	                           Widelands::FCoords start,
+	                           Widelands::FCoords end,
+	                           int32_t dir,
+	                           Widelands::CheckStep::StepId) const;
+	[[nodiscard]] bool reachable_dest(const Widelands::Map&, const Widelands::FCoords& dest) const;
 
 	Widelands::Player* player;
 	uint8_t movecaps;
@@ -152,14 +152,14 @@ struct CheckStepRoadAI {
 // plus one step more to a field with own immovable. So that also flags and buildings are
 // included in resulting list
 struct CheckStepOwnTerritory {
-	CheckStepOwnTerritory(Widelands::Player* const pl, uint8_t const mc, bool const oe);
+	CheckStepOwnTerritory(Widelands::Player* pl, uint8_t mc, bool oe);
 
-	bool allowed(const Widelands::Map&,
-	             Widelands::FCoords start,
-	             Widelands::FCoords end,
-	             int32_t dir,
-	             Widelands::CheckStep::StepId) const;
-	bool reachable_dest(const Widelands::Map&, const Widelands::FCoords& dest) const;
+	[[nodiscard]] bool allowed(const Widelands::Map&,
+	                           Widelands::FCoords start,
+	                           Widelands::FCoords end,
+	                           int32_t dir,
+	                           Widelands::CheckStep::StepId) const;
+	[[nodiscard]] bool reachable_dest(const Widelands::Map&, const Widelands::FCoords& dest) const;
 
 	Widelands::Player* player;
 	uint8_t movecaps;
@@ -171,7 +171,7 @@ struct CheckStepOwnTerritory {
 struct FindNodeEnemy {
 	FindNodeEnemy(Widelands::Player* p, Widelands::Game& g);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -184,7 +184,7 @@ struct FindNodeEnemy {
 struct FindNodeEnemiesBuilding {
 	FindNodeEnemiesBuilding(Widelands::Player* p, Widelands::Game& g);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -194,7 +194,7 @@ struct FindNodeEnemiesBuilding {
 struct FindEnemyNodeWalkable {
 	FindEnemyNodeWalkable(Widelands::Player* p, Widelands::Game& g);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -204,7 +204,7 @@ struct FindEnemyNodeWalkable {
 struct FindNodeAllyOwned {
 	FindNodeAllyOwned(Widelands::Player* p, Widelands::Game& g, Widelands::PlayerNumber n);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -219,7 +219,7 @@ struct FindNodeUnownedMineable {
 	                        Widelands::Game& g,
 	                        int32_t t = Widelands::INVALID_INDEX);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -231,7 +231,7 @@ struct FindNodeUnownedMineable {
 struct FindNodeUnownedBuildable {
 	FindNodeUnownedBuildable(Widelands::Player* p, Widelands::Game& g);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -241,7 +241,7 @@ struct FindNodeUnownedBuildable {
 struct FindNodeUnownedWalkable {
 	FindNodeUnownedWalkable(Widelands::Player* p, Widelands::Game& g);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Player* player;
 	Widelands::Game& game;
@@ -252,7 +252,7 @@ struct FindNodeUnownedWalkable {
 struct FindNodeMineable {
 	FindNodeMineable(Widelands::Game& g, Widelands::DescriptionIndex r);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& fc) const;
 
 	Widelands::Game& game;
 	int32_t res;
@@ -262,7 +262,8 @@ struct FindNodeMineable {
 struct FindNodeWater {
 	explicit FindNodeWater(const Widelands::Descriptions& descriptions);
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& coord) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&,
+	                          const Widelands::FCoords& coord) const;
 
 private:
 	const Widelands::Descriptions& descriptions_;
@@ -275,16 +276,17 @@ struct FindNodeOpenWater {
 	explicit FindNodeOpenWater(const Widelands::Descriptions& /* descriptions */) {
 	}
 
-	bool accept(const Widelands::EditorGameBase&, const Widelands::FCoords& coord) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&,
+	                          const Widelands::FCoords& coord) const;
 };
 
 struct FindNodeWithFlagOrRoad {
-	bool accept(const Widelands::EditorGameBase&, Widelands::FCoords) const;
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, Widelands::FCoords) const;
 };
 
 // Accepts any field
 struct FindNodeAcceptAll {
-	bool accept(const Widelands::EditorGameBase&, Widelands::FCoords) const {
+	[[nodiscard]] bool accept(const Widelands::EditorGameBase&, Widelands::FCoords) const {
 		return true;
 	}
 };
@@ -297,7 +299,7 @@ struct NearFlag {
 		}
 	};
 	NearFlag();
-	NearFlag(const Widelands::Flag* f, int32_t const c);
+	NearFlag(const Widelands::Flag* f, int32_t c);
 
 	bool operator<(const NearFlag& f) const {
 		return current_road_distance > f.current_road_distance;
@@ -368,71 +370,71 @@ struct BuildableField {
 
 	Time field_info_expiration;
 
-	bool preferred;
-	bool enemy_nearby;
-	bool enemy_accessible_;
+	bool preferred{false};
+	bool enemy_nearby{false};
+	bool enemy_accessible_{false};
 
-	bool invalidated;
+	bool invalidated{false};
 
-	bool enemy_wh_nearby;
-	uint16_t unowned_land_nearby;
-	uint16_t enemy_owned_land_nearby;
-	uint16_t unowned_buildable_spots_nearby;
-	uint16_t unowned_portspace_vicinity_nearby;
-	uint16_t nearest_buildable_spot_nearby;
+	bool enemy_wh_nearby{false};
+	uint16_t unowned_land_nearby{0U};
+	uint16_t enemy_owned_land_nearby{0U};
+	uint16_t unowned_buildable_spots_nearby{0U};
+	uint16_t unowned_portspace_vicinity_nearby{0U};
+	uint16_t nearest_buildable_spot_nearby{0U};
 	// to identify that field is too close to border and no production building should be built there
-	bool near_border;
-	uint16_t unowned_mines_spots_nearby;
-	uint16_t unowned_iron_mines_nearby;
+	bool near_border{false};
+	uint16_t unowned_mines_spots_nearby{0U};
+	uint16_t unowned_iron_mines_nearby{0u};
 	// Immovables categorized by building name, so we can have multiple lumberjack/ranger types
 	std::map<std::string, uint8_t> immovables_by_name_nearby;
 	// Immovables categorized by building attribute, so other buildings can access the information
 	// (e.g. space consumers). Also used for the neurons.
 	std::map<BuildingAttribute, uint8_t> immovables_by_attribute_nearby;
-	int16_t water_nearby;
-	int16_t open_water_nearby;
-	int16_t distant_water;
-	int16_t fish_nearby;
-	int8_t critters_nearby;
-	Widelands::ResourceAmount ground_water;  // used by wells
-	uint8_t space_consumers_nearby;
-	uint8_t rangers_nearby;
+	int16_t water_nearby{-1};
+	int16_t open_water_nearby{-1};
+	int16_t distant_water{0};
+	int16_t fish_nearby{-1};
+	int8_t critters_nearby{-1};
+	Widelands::ResourceAmount ground_water{1};  // used by wells
+	uint8_t space_consumers_nearby{0U};
+	uint8_t rangers_nearby{0U};
 	// to manage the military better following variables exists:
 	// future soldier capacity of own nearby militarysites:
-	int16_t area_military_capacity;
-	int16_t future_area_military_capacity;
+	int16_t area_military_capacity{0};
+	int16_t future_area_military_capacity{0};
 	// distance to near buldings:
-	int16_t military_loneliness;
-	int16_t future_military_loneliness;
+	int16_t military_loneliness{1000};
+	int16_t future_military_loneliness{1000};
 	// count of military buildings in construction
 	// when making decision on new mulitary buildings it considers also
 	// unowned fields and mines, but this information is not quite correct as there
 	// are construction sites that will change this once they are built
-	int16_t military_in_constr_nearby;
+	int16_t military_in_constr_nearby{0};
 	// actual count of soldiers in nearby buldings
-	int16_t own_military_presence;
-	int16_t enemy_military_presence;
-	int16_t enemy_military_sites;  // Including unfinished
-	int16_t ally_military_presence;
+	int16_t own_military_presence{0};
+	int16_t enemy_military_presence{0};
+	int16_t enemy_military_sites{0};  // Including unfinished
+	int16_t ally_military_presence{0};
 	// stationed (manned) military buildings nearby
-	int16_t military_stationed;
+	int16_t military_stationed{0};
 	uint32_t average_flag_dist_to_wh;
-	int16_t military_unstationed;
-	int16_t own_non_military_nearby;
-	bool defense_msite_allowed;
-	ExtendedBool is_portspace;
-	bool port_nearby;  // to increase priority if a port is nearby,
+	int16_t military_unstationed{0};
+	int16_t own_non_military_nearby{0};
+	bool defense_msite_allowed{false};
+	ExtendedBool is_portspace{ExtendedBool::kUnset};
+	bool port_nearby{false};  // to increase priority if a port is nearby,
 	// especially for new colonies
-	ExtendedBool portspace_nearby;    // special fields intended for ports
-	ExtendedBool shipyard_preferred;  // special fields intended for shipyards
-	int32_t max_buildcap_nearby;
+	ExtendedBool portspace_nearby{ExtendedBool::kUnset};  // special fields intended for ports
+	ExtendedBool shipyard_preferred;                      // special fields intended for shipyards
+	int32_t max_buildcap_nearby{0};
 	// It is not necessary to check resources (stones, fish...) too frequently as they do not change
 	// fast. This stores the time of the last check.
 	Time last_resources_check_time;
-	int32_t military_score_;
-	bool inland;
-	uint16_t local_soldier_capacity;
-	bool is_militarysite;
+	int32_t military_score_{0};
+	bool inland{false};
+	uint16_t local_soldier_capacity{0U};
+	bool is_militarysite{false};
 
 	std::vector<uint8_t> consumers_nearby;
 	std::vector<uint8_t> producers_nearby;
@@ -449,10 +451,10 @@ struct MineableField {
 
 	Widelands::FCoords coords;
 	Time field_info_expiration;
-	bool preferred;
-	int32_t mines_nearby;
+	bool preferred{false};
+	int32_t mines_nearby{0};
 	// this is to provide that a mine is not built on the edge of mine area
-	int32_t same_mine_fields_nearby;
+	int32_t same_mine_fields_nearby{0};
 };
 
 struct EconomyObserver {
@@ -476,7 +478,7 @@ struct BuildingObserver {
 		kMine
 	};
 
-	int32_t total_count() const;
+	[[nodiscard]] uint32_t total_count() const;
 	AiModeBuildings aimode_limit_status() const;
 	bool buildable(const Widelands::Player& p) const;
 
@@ -529,12 +531,12 @@ struct BuildingObserver {
 	int16_t initial_preciousness;
 	int16_t max_preciousness;
 	int16_t max_needed_preciousness;
-	int32_t cnt_built;
-	int32_t cnt_under_construction;
-	int32_t cnt_target;           // number of buildings as target
-	int32_t cnt_limit_by_aimode;  // limit imposed by weak or normal AI mode
+	uint32_t cnt_built;
+	uint32_t cnt_under_construction;
+	uint32_t cnt_target;           // number of buildings as target
+	uint32_t cnt_limit_by_aimode;  // limit imposed by weak or normal AI mode
 
-	int32_t cnt_upgrade_pending;  // number of buildings that are to be upgraded
+	uint32_t cnt_upgrade_pending;  // number of buildings that are to be upgraded
 
 	// used to track amount of wares produced by building
 	uint32_t stocklevel_count;
@@ -575,10 +577,14 @@ struct TrainingSiteObserver {
 };
 
 struct WarehouseSiteObserver {
-
 	Widelands::Warehouse* site;
 	BuildingObserver* bo;
-	uint32_t flag_distances_last_update;
+};
+
+struct PortSiteObserver {
+	Widelands::Warehouse* site;
+	BuildingObserver* bo;
+	uint32_t ships_assigned;
 };
 
 struct ShipObserver {
@@ -587,6 +593,11 @@ struct ShipObserver {
 	Time last_command_time = Time(0);
 	bool escape_mode = false;
 
+	// Used for warships, stores whether the ship is assigned to a port.
+	// has_destination() cannot be used alone, because newly refitted warships
+	// keep the refitting port as destination.
+	bool guarding = false;
+
 	// direction by which the ship circumvents an island
 	// this is the last circle-island command's direction
 	Widelands::IslandExploreDirection island_circ_direction =
@@ -596,6 +607,8 @@ struct ShipObserver {
 struct WareObserver {
 	bool refined_build_material = false;
 	uint8_t preciousness;
+	// all buildings of the tribe which produce the given ware
+	std::vector<Widelands::DescriptionIndex> producers;
 };
 
 // Computer player does not get notification messages about enemy militarysites
@@ -623,14 +636,14 @@ struct EnemySiteObserver {
 // as all mines have 3 levels, AI does not know total count of mines per mined material
 // so this observer will be used for this
 struct MineTypesObserver {
-	MineTypesObserver();
+	MineTypesObserver() = default;
 
-	uint16_t total_count() const;
+	[[nodiscard]] uint16_t total_count() const;
 
-	uint16_t in_construction;
-	uint16_t finished;
-	bool is_critical;
-	uint16_t unoccupied;
+	uint16_t in_construction{0U};
+	uint16_t finished{0U};
+	bool is_critical{false};
+	uint16_t unoccupied{0U};
 };
 
 // This struct contains count of mineable fields grouped by ore/resource type
@@ -676,16 +689,16 @@ struct Neuron {
 	Neuron(int8_t, uint8_t, uint16_t);
 	void recalculate();
 	void set_weight(int8_t w);
-	int8_t get_weight() {
+	[[nodiscard]] int8_t get_weight() const {
 		return weight;
 	}
 	int8_t get_result(size_t);
 	int8_t get_result_safe(int32_t, bool = false);
 	void set_type(uint8_t);
-	uint8_t get_type() {
+	[[nodiscard]] uint8_t get_type() const {
 		return type;
 	}
-	uint16_t get_id() {
+	[[nodiscard]] uint16_t get_id() const {
 		return id;
 	}
 
@@ -703,7 +716,7 @@ struct FNeuron {
 	bool get_result(bool, bool, bool, bool bool4 = true, bool bool5 = true);
 	bool get_position(uint8_t);
 	uint32_t get_int();
-	uint16_t get_id() {
+	[[nodiscard]] uint16_t get_id() const {
 		return id;
 	}
 
@@ -760,7 +773,7 @@ struct ManagementData {
 		ai_training_mode_ = true;
 	}
 
-	int16_t get_military_number_at(uint8_t) const;
+	[[nodiscard]] int16_t get_military_number_at(uint8_t) const;
 	void set_military_number_at(uint8_t, int16_t) const;
 	MutatingIntensity do_mutate(bool, int16_t);
 	int8_t shift_weight_value(int8_t, bool = true);
@@ -786,15 +799,15 @@ private:
 
 // this is used to count militarysites by their size
 struct MilitarySiteSizeObserver {
-	MilitarySiteSizeObserver();
+	MilitarySiteSizeObserver() = default;
 
-	uint16_t in_construction;
-	uint16_t finished;
+	uint16_t in_construction{0U};
+	uint16_t finished{0U};
 };
 
 // this represents a scheduler task
 struct SchedulerTask {
-	SchedulerTask(const Time& time, const SchedulerTaskId t, const uint8_t p, const char* d);
+	SchedulerTask(const Time& time, SchedulerTaskId t, uint8_t p, const char* d);
 
 	bool operator<(const SchedulerTask& other) const;
 
@@ -834,17 +847,24 @@ private:
 		           uint32_t cs,
 		           uint32_t land,
 		           uint32_t oland,
-		           uint32_t o60l);
+		           uint32_t o60l,
+		           int32_t ds,
+		           uint32_t bld,
+		           bool def);
 
 		Widelands::TeamNumber team_number = 0U;
 		uint32_t players_power = 0U;
 		uint32_t old_players_power = 0U;
 		uint32_t old60_players_power = 0U;
 		uint32_t players_casualities = 0U;
-		Time last_time_seen = Time();  // never seen
+		Time last_time_seen = Time();       // never seen
+		Time last_time_requested = Time();  // never sent a diplo request
 		uint32_t players_land = 0U;
 		uint32_t old_players_land = 0U;
 		uint32_t old60_players_land = 0U;
+		int32_t players_diplomacy_score = 0U;
+		uint32_t players_buildings = 0U;
+		bool defeated = false;
 	};
 
 public:
@@ -860,44 +880,80 @@ public:
 	         uint32_t cs,
 	         uint32_t land,
 	         uint32_t oland,
-	         uint32_t o60l);
+	         uint32_t o60l,
+	         int32_t ds,
+	         uint32_t bld,
+	         bool def);
 	void remove_stat(Widelands::PlayerNumber pn);
 	void recalculate_team_power();
 
 	// This is strength of player plus third of strength of other members of his team
-	uint32_t get_modified_player_power(Widelands::PlayerNumber pn);
-	uint32_t get_player_power(Widelands::PlayerNumber pn);
-	uint32_t get_old_player_power(Widelands::PlayerNumber pn);
-	uint32_t get_old60_player_power(Widelands::PlayerNumber pn);
-	uint32_t get_player_land(Widelands::PlayerNumber pn);
-	uint32_t get_old_player_land(Widelands::PlayerNumber pn);
-	uint32_t get_old60_player_land(Widelands::PlayerNumber pn);
-	uint32_t get_visible_enemies_power(const Time&);
-	uint32_t get_enemies_average_power();
-	uint32_t get_enemies_average_land();
-	uint32_t get_enemies_max_power();
-	uint32_t get_enemies_max_land();
-	uint32_t get_old_visible_enemies_power(const Time&);
-	bool players_in_same_team(Widelands::PlayerNumber pl1, Widelands::PlayerNumber pl2);
-	bool strong_enough(Widelands::PlayerNumber pl);
+	[[nodiscard]] uint32_t get_modified_player_power(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_player_power(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_old_player_power(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_old60_player_power(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_player_land(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_old_player_land(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_old60_player_land(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_player_buildings(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_visible_enemies_power(const Time&);
+	[[nodiscard]] uint32_t get_enemies_average_power();
+	[[nodiscard]] uint32_t get_enemies_average_land();
+	[[nodiscard]] uint32_t get_enemies_max_power();
+	[[nodiscard]] uint32_t get_max_power();
+	[[nodiscard]] uint32_t get_enemies_max_land();
+	[[nodiscard]] uint32_t get_max_land();
+	[[nodiscard]] uint32_t get_max_buildings();
+	[[nodiscard]] Widelands::TeamNumber get_team_number(Widelands::PlayerNumber pn);
+	[[nodiscard]] int32_t get_diplo_score(Widelands::PlayerNumber pn);
+	[[nodiscard]] uint32_t get_old_visible_enemies_power(const Time&);
+	[[nodiscard]] bool players_in_same_team(Widelands::PlayerNumber pl1,
+	                                        Widelands::PlayerNumber pl2);
+	[[nodiscard]] bool strong_enough(Widelands::PlayerNumber pl);
 	void set_last_time_seen(const Time&, Widelands::PlayerNumber);
-	bool player_seen_lately(Widelands::PlayerNumber, const Time&);
-	bool get_is_enemy(Widelands::PlayerNumber);
-	uint8_t enemies_seen_lately_count(const Time&);
-	bool any_enemy_seen_lately(const Time&);
+	void set_last_time_requested(const Time&, Widelands::PlayerNumber);
+	[[nodiscard]] bool player_seen_lately(Widelands::PlayerNumber, const Time&);
+	[[nodiscard]] bool player_diplo_requested_lately(Widelands::PlayerNumber, const Time&);
+	[[nodiscard]] bool get_is_enemy(Widelands::PlayerNumber);
+	[[nodiscard]] uint8_t enemies_seen_lately_count(const Time&);
+	[[nodiscard]] uint8_t members_in_team(Widelands::TeamNumber tn);
+	[[nodiscard]] bool get_is_alone(Widelands::PlayerNumber pn);
+	[[nodiscard]] int32_t get_team_average_score(Widelands::TeamNumber tn,
+	                                             Widelands::PlayerNumber exclude_pn = 0);
+	[[nodiscard]] uint32_t team_power(Widelands::TeamNumber tn);
+	[[nodiscard]] uint8_t players_active() const;
+	[[nodiscard]] Widelands::PlayerNumber get_worst_ally() const;
+	[[nodiscard]] int32_t get_worst_ally_score() const;
+	[[nodiscard]] bool any_enemy_seen_lately(const Time&);
 	void set_update_time(const Time&);
 	const Time& get_update_time();
 
+	// Decide which of inviting or requesting to join is both possible and desirable, and do the
+	// chosen action. May choose to do nothing, if neither is possible, or the possible action is
+	// not desirable.
+	void join_or_invite(Widelands::PlayerNumber pn, Widelands::Game& game, const Time& gametime);
+
 private:
 	// This is the core part of this struct
-	std::map<Widelands::PlayerNumber, PlayerStat> all_stats;
+	std::map<Widelands::PlayerNumber, PlayerStat> all_stats_;
 
 	// Number of team, sum of players' strength
-	std::map<Widelands::TeamNumber, uint32_t> team_powers;
+	std::map<Widelands::TeamNumber, uint32_t> team_powers_;
+	// Number of team, sum of players' diploscores
+	std::map<Widelands::TeamNumber, uint32_t> team_scores_sum_;
+	// Number of team, number of members
+	std::map<Widelands::TeamNumber, uint8_t> team_members_;
+	// number of active players (not defeated)
+	uint8_t active_players_;
 
 	Time update_time;
 	Widelands::PlayerNumber this_player_number;
 	Widelands::PlayerNumber this_player_team;
+
+	// Member of own team with lowest diploscore
+	Widelands::PlayerNumber worst_ally_;
+	// Lowest member diploscore in own team
+	int32_t worst_ally_score_;
 };
 
 // This is a wrapper around map of <Flag coords hash:distance from flag to nearest warehouse>
@@ -927,7 +983,7 @@ private:
 		// Saying the road was built and when
 		void set_road_built(const Time&);
 		// Asking if road can be built from this flag (providing current gametime)
-		bool is_road_prohibited(const Time&) const;
+		[[nodiscard]] bool is_road_prohibited(const Time&) const;
 		// get current distance (providing current gametime)
 		uint16_t get(const Time&, uint32_t*) const;
 	};
@@ -942,7 +998,7 @@ public:
 	int16_t get_wh_distance(uint32_t flag_coords, const Time& gametime, uint32_t* nw);
 	void set_road_built(uint32_t coords_hash, const Time& gametime);
 	bool is_road_prohibited(uint32_t coords_hash, const Time& gametime);
-	uint16_t count() const;
+	[[nodiscard]] uint16_t count() const;
 	bool remove_old_flag(const Time& gametime);
 };
 
@@ -965,8 +1021,8 @@ struct FlagCandidates {
 		uint16_t possible_road_distance;
 		uint16_t cand_flag_distance_to_wh;
 		// Scoring is considering multiple things
-		int16_t score() const;
-		bool is_buildable() {
+		[[nodiscard]] int16_t score() const;
+		[[nodiscard]] bool is_buildable() const {
 			return possible_road_distance > 0;
 		}
 		bool operator<(const Candidate& other) const {
@@ -979,10 +1035,10 @@ private:
 	uint16_t start_flag_dist_to_wh;
 
 public:
-	const std::vector<Candidate>& flags() const {
+	[[nodiscard]] const std::vector<Candidate>& flags() const {
 		return flags_;
 	}
-	bool has_candidate(uint32_t) const;
+	[[nodiscard]] bool has_candidate(uint32_t) const;
 	void add_flag(uint32_t, bool, uint16_t, uint16_t);
 	bool set_cur_road_distance(uint32_t, uint16_t);
 	bool set_road_possible(uint32_t, uint16_t);
@@ -991,7 +1047,7 @@ public:
 	uint32_t count() {
 		return flags_.size();
 	}
-	FlagCandidates::Candidate* get_winner(const int16_t = 0);
+	FlagCandidates::Candidate* get_winner(int16_t = 0);
 };
 }  // namespace AI
 
