@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -46,15 +46,15 @@ namespace AI {
  * \ref Implementation interface.
  */
 struct ComputerPlayer {
-	ComputerPlayer(Widelands::Game&, const Widelands::PlayerNumber);
+	ComputerPlayer(Widelands::Game&, Widelands::PlayerNumber);
 	virtual ~ComputerPlayer() = default;
 
 	virtual void think() = 0;
 
-	Widelands::Game& game() const {
+	[[nodiscard]] Widelands::Game& game() const {
 		return game_;
 	}
-	Widelands::PlayerNumber player_number() {
+	[[nodiscard]] Widelands::PlayerNumber player_number() const {
 		return player_number_;
 	}
 
@@ -81,8 +81,7 @@ struct ComputerPlayer {
 			assert(!contains(name, as_string(kAiNameSeparator)));
 		}
 
-		virtual ~Implementation() {
-		}
+		virtual ~Implementation() = default;
 		virtual ComputerPlayer* instantiate(Widelands::Game&, Widelands::PlayerNumber) const = 0;
 	};
 	using ImplementationVector = std::vector<ComputerPlayer::Implementation const*>;
