@@ -533,7 +533,13 @@ bool DefaultAI::check_ships(const Time& gametime) {
 		// if ship is waiting for command
 		if (so.waiting_for_command_) {
 			if (so.ship->get_ship_type() == Widelands::ShipType::kTransport) {
-				expedition_management(so);
+				// so.waiting_for_command_ can still be true right after a warship is backfitted to
+				// transport.
+				if (so.ship->is_expedition_or_warship()) {
+					expedition_management(so);
+				} else {
+					so.waiting_for_command_ = false;
+				}
 			} else {
 				warship_management(so);
 			}
@@ -695,7 +701,7 @@ void DefaultAI::gain_ship(Widelands::Ship& ship, NewShip type) {
 
 Widelands::IslandExploreDirection DefaultAI::randomExploreDirection() {
 	return RNG::static_rand(20) < 10 ? Widelands::IslandExploreDirection::kClockwise :
-                                      Widelands::IslandExploreDirection::kCounterClockwise;
+	                                   Widelands::IslandExploreDirection::kCounterClockwise;
 }
 
 // this is called whenever a transport ship received a notification that requires
@@ -950,8 +956,8 @@ bool DefaultAI::attempt_escape(ShipObserver& so) {
 	if (!possible_directions.empty() || !new_teritory_directions.empty()) {
 		const Widelands::Direction direction =
 		   !new_teritory_directions.empty() ?
-            new_teritory_directions.at(RNG::static_rand(new_teritory_directions.size())) :
-            possible_directions.at(RNG::static_rand(possible_directions.size()));
+		      new_teritory_directions.at(RNG::static_rand(new_teritory_directions.size())) :
+		      possible_directions.at(RNG::static_rand(possible_directions.size()));
 		game().send_player_ship_scouting_direction(
 		   *so.ship, static_cast<Widelands::WalkingDir>(direction));
 
