@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,7 +28,8 @@ bool g_fail_on_lua_error(false);
  * class WException implementation
  */
 #undef wexception
-WException::WException(char const* const file, uint32_t const line, char const* const fmt, ...) {
+WException::WException(char const* const file, uint32_t const line, char const* const fmt, ...)
+   : file_(file), line_(line) {
 	char buffer[512];
 	{
 		va_list va;
@@ -41,10 +42,6 @@ WException::WException(char const* const file, uint32_t const line, char const*
 	what_ = ost.str();
 }
 
-char const* WException::what() const noexcept {
-	return what_.c_str();
-}
-
 /*
  * class warning implementation
  */
