@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 #include <vector>
 
 #include "base/macros.h"
-#include "base/multithreading.h"
+#include "base/mutex.h"
 #include "config.h"
 #include "third_party/gettext/gettext.h"  // For ngettext and pgettext.
 
@@ -40,6 +40,7 @@
 #endif
 
 /// Some macros to make i18n more readable and aid in tagging strings for translation
+// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 #define _(str) i18n::translate(str)
 
 #undef pgettext
@@ -112,6 +113,15 @@ std::string localize_list(const std::vector<std::string>& items, ConcatenateWith
  */
 std::string join_sentences(const std::string& sentence1, const std::string& sentence2);
 
+/**
+ * Checks whether 'input' is the translation of 'base'. Also returns true if
+ * 'input' is the same as 'base'. If 'textdomain_name' is given, then uses that
+ * textdomain, otherwise the current one.
+ */
+bool is_translation_of(const std::string& input,
+                       const std::string& base,
+                       const std::string& textdomain_name = "");
+
 }  // namespace i18n
 
 #endif  // end of include guard: WL_BASE_I18N_H
