@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -78,11 +78,8 @@ public:
 		SDL_LogSetOutputFunction(sdl_logging_func, this);
 		std::cout << "Log output will be written to: " << stdout_filename_ << std::endl;
 
-		// Configure redirection
-		std::cout.rdbuf(stdout_.rdbuf());
-		std::cerr.rdbuf(stderr_.rdbuf());
 		// Repeat version info so that we'll have it available in the log file too
-		std::cout << "This is Widelands version " << build_ver_details() << std::endl;
+		stdout_ << "This is Widelands version " << build_ver_details() << std::endl;
 		stdout_.flush();
 	}
 
