@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,8 @@
 
 #include <cassert>
 #include <ctime>
+#include <iomanip>
+#include <sstream>
 
 #include "base/i18n.h"
 
@@ -194,3 +196,11 @@ std::string gametimestring(uint32_t gametime, bool show_seconds) {
 
 	return result.substr(i);
 }
+
+std::string realtimestring() {
+	std::time_t t = std::time(nullptr);
+	std::tm tm = *std::localtime(&t);
+	std::ostringstream oss("");
+	oss << std::put_time(&tm, "%X");
+	return oss.str();
+}
