@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,7 @@
 #ifndef WL_BASE_TIME_STRING_H
 #define WL_BASE_TIME_STRING_H
 
+#include <cstdint>
 #include <string>
 
 /// Get a string representation conforming to ISO 8601 of the current time (in
@@ -40,4 +41,6 @@ char* gamestring_with_leading_zeros(uint32_t gametime);
 /// If Time represents more than 999 hours, it wraps around
 std::string gametimestring(uint32_t gametime, bool show_seconds = false);
 
+std::string realtimestring();
+
 #endif  // end of include guard: WL_BASE_TIME_STRING_H
