@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,12 +39,11 @@ struct WLWarning : public std::exception {
 
 	/// The target of the returned pointer remains valid during the lifetime of
 	/// the warning object.
-	virtual const char* title() const;
-	const char* what() const noexcept override;
+	[[nodiscard]] virtual const char* title() const;
+	[[nodiscard]] const char* what() const noexcept override;
 
 protected:
-	WLWarning() {
-	}
+	WLWarning() = default;
 	std::string what_;
 	std::string title_;
 };
