@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,8 +31,7 @@ public:
 	explicit RoadDescr(char const* const init_name, char const* const init_descname)
 	   : RoadBaseDescr(init_name, init_descname, MapObjectType::ROAD) {
 	}
-	~RoadDescr() override {
-	}
+	~RoadDescr() override = default;
 
 private:
 	DISALLOW_COPY_AND_ASSIGN(RoadDescr);
@@ -63,11 +62,11 @@ struct Road : public RoadBase {
 
 	// A CarrierSlot can store a carrier.
 	struct CarrierSlot {
-		CarrierSlot();
+		CarrierSlot() = default;
 
 		OPtr<Carrier> carrier;
-		Request* carrier_request;
-		uint8_t carrier_type_id;
+		Request* carrier_request{nullptr};
+		uint8_t carrier_type_id{std::numeric_limits<uint8_t>::max()};
 	};
 
 	void postsplit(Game&, Flag&) override;
@@ -104,13 +103,13 @@ private:
 
 	void link_into_flags(EditorGameBase&, bool = false) override;
 
-	bool busy_;
+	bool busy_{false};
 	/// Counter that is incremented when a ware does not get a carrier for this
 	/// road immediately and decremented over time.
-	int32_t wallet_;
+	int32_t wallet_{0};
 
 	/// holds the gametime when wallet_ was last charged
-	Time last_wallet_charge_;
+	Time last_wallet_charge_{0U};
 
 	void request_carrier(CarrierSlot&);
 	static void
