@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2022 by the Widelands Development Team
+ * Copyright (C) 2011-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,20 +32,36 @@ namespace Widelands {
 
 class Economy;
 struct Flag;
+class ProductionSite;
 struct RoutingNodeNeighbour;
+class ShipFleetYardInterface;
 
 class ShipFleetDescr : public MapObjectDescr {
 public:
 	ShipFleetDescr(char const* const init_name, char const* const init_descname)
 	   : MapObjectDescr(MapObjectType::SHIP_FLEET, init_name, init_descname) {
 	}
-	~ShipFleetDescr() override {
-	}
+	~ShipFleetDescr() override = default;
 
 private:
 	DISALLOW_COPY_AND_ASSIGN(ShipFleetDescr);
 };
 
+class ShipFleetYardInterfaceDescr : public BobDescr {
+public:
+	ShipFleetYardInterfaceDescr(char const* const init_name, char const* const init_descname)
+	   : BobDescr(init_name,
+	              init_descname,
+	              MapObjectType::SHIP_FLEET_YARD_INTERFACE,
+	              MapObjectDescr::OwnerType::kTribe) {
+	}
+	~ShipFleetYardInterfaceDescr() override = default;
+	[[nodiscard]] Bob& create_object() const override;
+
+private:
+	DISALLOW_COPY_AND_ASSIGN(ShipFleetYardInterfaceDescr);
+};
+
 constexpr Duration kFleetInterval(4000);
 constexpr uint32_t kRouteNotCalculated = std::numeric_limits<uint32_t>::max();
 
@@ -69,11 +85,10 @@ constexpr uint32_t kRouteNotCalculated = std::numeric_limits<uint32_t>::max();
  */
 struct ShipFleet : MapObject {
 	struct PortPath {
-		int32_t cost;
+		int32_t cost{-1};
 		std::shared_ptr<Path> path;
 
-		PortPath() : cost(-1) {
-		}
+		PortPath() = default;
 	};
 
 	const ShipFleetDescr& descr() const;
@@ -85,7 +100,7 @@ struct ShipFleet : MapObject {
 	PortDock* get_arbitrary_dock() const;
 	void set_economy(Economy* e, WareWorker);
 
-	bool active() const;
+	[[nodiscard]] bool active() const;
 
 	bool init(EditorGameBase&) override;
 	void cleanup(EditorGameBase&) override;
@@ -95,30 +110,39 @@ struct ShipFleet : MapObject {
 	void remove_ship(EditorGameBase& egbase, Ship* ship);
 	void add_port(EditorGameBase& egbase, PortDock* port);
 	void remove_port(EditorGameBase& egbase, PortDock* port);
-	bool has_ports() const;
+	[[nodiscard]] bool has_ports() const;
+
+	void add_interface(ShipFleetYardInterface* i);
+	void remove_interface(EditorGameBase& egbase, ShipFleetYardInterface* i);
 
 	void log_general_info(const EditorGameBase&) const override;
 
 	bool get_path(const PortDock& start, const PortDock& end, Path& path);
 	void add_neighbours(PortDock& pd, std::vector<RoutingNodeNeighbour>& neighbours);
 
-	uint32_t count_ships() const;
-	uint32_t count_ports() const;
-	bool get_act_pending() const;
+	[[nodiscard]] uint32_t count_ships() const;
+	[[nodiscard]] uint32_t count_ports() const;
+	[[nodiscard]] bool get_act_pending() const;
 
-	bool empty() const;
+	[[nodiscard]] bool empty() const;
+	[[nodiscard]] bool lacks_ship() const;
 
-	ShippingSchedule& get_schedule() {
+	[[nodiscard]] ShippingSchedule& get_schedule() {
 		return schedule_;
 	}
 
-	const std::vector<Ship*>& get_ships() const {
+	[[nodiscard]] const std::vector<Ship*>& get_ships() const {
 		return ships_;
 	}
-	std::vector<PortDock*>& get_ports() {
+	[[nodiscard]] std::vector<PortDock*>& get_ports() {
 		return ports_;
 	}
 
+	[[nodiscard]] Quantity get_ships_target() const {
+		return ships_target_;
+	}
+	void set_ships_target(EditorGameBase& egbase, Quantity t);
+
 protected:
 	void act(Game&, uint32_t data) override;
 
@@ -134,9 +158,12 @@ private:
 	const PortPath& portpath_bidir(uint32_t i, uint32_t j, bool& reverse) const;
 
 	std::vector<Ship*> ships_;
+	std::vector<ShipFleetYardInterface*> interfaces_;
 	std::vector<PortDock*> ports_;
 
-	bool act_pending_;
+	Quantity ships_target_{kEconomyTargetInfinity};
+	Time target_last_modified_{0U};
+	bool act_pending_{false};
 
 	std::map<std::pair<Serial, Serial>, PortPath> port_paths_;
 
@@ -147,12 +174,13 @@ protected:
 	struct Loader : MapObject::Loader {
 		Loader() = default;
 
-		void load(FileRead&);
+		void load(FileRead& fr, uint8_t packet_version);
 		void load_pointers() override;
 		void load_finish() override;
 
 	private:
 		std::vector<uint32_t> ships_;
+		std::vector<uint32_t> interfaces_;
 		std::vector<uint32_t> ports_;
 	};
 
@@ -165,6 +193,46 @@ public:
 	static MapObject::Loader* load(EditorGameBase&, MapObjectLoader&, FileRead&);
 };
 
+class ShipFleetYardInterface : public Bob {
+public:
+	ShipFleetYardInterface();
+	static ShipFleetYardInterface*
+	create(EditorGameBase& egbase, ProductionSite& ps, const Coords& pos);
+
+	const ShipFleetYardInterfaceDescr& descr() const;
+	void init_auto_task(Game& game) override;
+	void cleanup(EditorGameBase&) override;
+	void log_general_info(const EditorGameBase&) const override;
+
+	[[nodiscard]] ProductionSite* get_building() const {
+		return building_;
+	}
+	[[nodiscard]] ShipFleet* get_fleet() const {
+		return fleet_;
+	}
+	void set_fleet(ShipFleet* fleet) {
+		fleet_ = fleet;
+	}
+
+	void save(EditorGameBase&, MapObjectSaver&, FileWrite&) override;
+	static Loader* load(EditorGameBase&, MapObjectLoader&, FileRead&);
+
+private:
+	ProductionSite* building_{nullptr};
+	ShipFleet* fleet_{nullptr};
+
+protected:
+	struct Loader : Bob::Loader {
+		Loader() = default;
+
+		void load(FileRead& fr);
+		void load_pointers() override;
+
+	private:
+		Serial building_;
+	};
+};
+
 }  // namespace Widelands
 
 #endif  // end of include guard: WL_ECONOMY_SHIP_FLEET_H
