@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,11 +42,11 @@ class Trackable {
 	friend class BaseTrackPtr;
 
 	class Tracker {
-		uint32_t refcount_;
+		uint32_t refcount_{0};
 		Trackable* ptr_;
 
 	public:
-		explicit Tracker(Trackable* const p) : refcount_(0), ptr_(p) {
+		explicit Tracker(Trackable* const p) : ptr_(p) {
 		}
 
 		void addref() {
@@ -56,13 +56,15 @@ class Trackable {
 		void deref() {
 			assert(refcount_ > 0);
 			--refcount_;
-			if (!refcount_ && !ptr_)
+			if ((refcount_ == 0u) && (ptr_ == nullptr)) {
 				delete this;
+			}
 		}
 		void clear() {
 			ptr_ = nullptr;
-			if (!refcount_)
+			if (refcount_ == 0u) {
 				delete this;
+			}
 		}
 
 		Trackable* get() {
@@ -72,8 +74,7 @@ class Trackable {
 		//  Putting "private:" here causes a compiler warning, even though we use
 		//  delete this.
 	protected:
-		~Tracker() {
-		}
+		~Tracker() = default;
 	};
 
 public:
@@ -98,52 +99,59 @@ TrackPtr is a template that derives from BaseTrackPtr and provides a
 type-safe interface.
 */
 class BaseTrackPtr {
-	mutable Trackable::Tracker* tracker_;
+	mutable Trackable::Tracker* tracker_{nullptr};
 
 protected:
-	BaseTrackPtr() : tracker_(nullptr) {
-	}
+	BaseTrackPtr() = default;
 	~BaseTrackPtr() {
-		if (tracker_)
+		if (tracker_ != nullptr) {
 			tracker_->deref();
+		}
 	}
 	explicit BaseTrackPtr(Trackable* const t) {
-		if (t) {
+		if (t != nullptr) {
 			tracker_ = t->tracker_;
 			tracker_->addref();
-		} else
+		} else {
 			tracker_ = nullptr;
+		}
 	}
 	BaseTrackPtr(const BaseTrackPtr& o) {
 		tracker_ = o.tracker_;
-		if (tracker_)
+		if (tracker_ != nullptr) {
 			tracker_->addref();
+		}
 	}
 
 	void set(const BaseTrackPtr& o) {
-		if (tracker_)
+		if (tracker_ != nullptr) {
 			tracker_->deref();
+		}
 
 		tracker_ = o.tracker_;
-		if (tracker_)
+		if (tracker_ != nullptr) {
 			tracker_->addref();
+		}
 	}
 
 	void set(Trackable* const t) {
-		if (tracker_)
+		if (tracker_ != nullptr) {
 			tracker_->deref();
+		}
 
-		if (t) {
+		if (t != nullptr) {
 			tracker_ = t->tracker_;
 			tracker_->addref();
-		} else
+		} else {
 			tracker_ = nullptr;
+		}
 	}
 
 	Trackable* get() const {
-		if (tracker_) {
-			if (Trackable* const t = tracker_->get())
+		if (tracker_ != nullptr) {
+			if (Trackable* const t = tracker_->get()) {
 				return t;
+			}
 
 			tracker_->deref();
 			tracker_ = nullptr;
@@ -164,10 +172,13 @@ template <class T> struct TrackPtr : BaseTrackPtr {
 
 	explicit TrackPtr(T* ptr) : BaseTrackPtr(ptr) {
 	}
-	explicit TrackPtr(const TrackPtr<T>& o) : BaseTrackPtr(o) {
+	TrackPtr(const TrackPtr<T>& o) : BaseTrackPtr(o) {
 	}
 
 	TrackPtr& operator=(const TrackPtr<T>& o) {
+		if (&o == this) {
+			return *this;
+		}
 		set(o);
 		return *this;
 	}
@@ -176,7 +187,7 @@ template <class T> struct TrackPtr : BaseTrackPtr {
 		return *this;
 	}
 
-	operator T*() const {
+	operator T*() const {  // NOLINT allow implicit conversion
 		return static_cast<T*>(get());
 	}
 	T* operator->() const {
