@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,8 +32,7 @@ public:
 	WaterwayDescr(char const* const init_name, char const* const init_descname)
 	   : RoadBaseDescr(init_name, init_descname, MapObjectType::WATERWAY) {
 	}
-	~WaterwayDescr() override {
-	}
+	~WaterwayDescr() override = default;
 
 private:
 	DISALLOW_COPY_AND_ASSIGN(WaterwayDescr);
