@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@
 
 class EditorTool;
 
-std::string editor_splash_image();
+extern const std::string kEditorSplashImage;
 
 /**
  * This is the EditorInteractive. It is like the InteractivePlayer class,
@@ -55,7 +55,7 @@ public:
 	struct Tools {
 		explicit Tools(EditorInteractive& parent, const Widelands::Map& map)
 		   : current_pointer(&info),
-		     use_tool(EditorTool::First),
+
 		     info(parent),
 		     set_height(parent),
 		     decrease_height(parent),
@@ -76,12 +76,12 @@ public:
 		     resize(parent, map.get_width(), map.get_height()),
 		     tool_history(parent) {
 		}
-		EditorTool& current() const {
+		[[nodiscard]] EditorTool& current() const {
 			return *current_pointer;
 		}
 		using ToolVector = std::vector<EditorTool*>;
 		EditorTool* current_pointer;
-		EditorTool::ToolIndex use_tool;
+		EditorTool::ToolIndex use_tool{EditorTool::First};
 		EditorInfoTool info;
 		EditorSetHeightTool set_height;
 		EditorDecreaseHeightTool decrease_height;
@@ -111,7 +111,9 @@ public:
 		kRandom,           // show Random Map window
 		kLoad              // show Load Map window
 	};
-	static void run_editor(UI::Panel* error_message_parent,
+
+	// Returns true on clean exit, false if an exception was caught by the wrapper
+	static bool run_editor(UI::Panel* error_message_parent,
 	                       EditorInteractive::Init,
 	                       const std::string& filename = "",
 	                       const std::string& script_to_run = "");
@@ -125,8 +127,8 @@ public:
 
 	void map_clicked(const Widelands::NodeAndTriangle<>& node_and_triangle, bool draw);
 	void set_sel_pos(Widelands::NodeAndTriangle<>) override;
-	void set_sel_radius(uint32_t) override;
-	void set_sel_radius_and_update_menu(uint32_t);
+	void set_sel_radius(uint32_t radius, uint16_t gap);
+	void set_sel_radius_and_update_menu(uint32_t radius, uint16_t gap);
 	void stop_painting();
 
 	//  Handle UI elements.
@@ -147,7 +149,7 @@ public:
 	}
 
 	// action functions
-	void exit();
+	void exit(bool force = false);
 
 	void set_need_save(bool const t) {
 		need_save_ = t;
@@ -186,6 +188,7 @@ private:
 		kLoadMap,
 		kSaveMap,
 		kMapOptions,
+		kUploadAsAddOn,
 		kExitEditor,
 	};
 
@@ -246,10 +249,12 @@ private:
 
 	void update_tool_history_window();
 
+	void publish_map();
+
 	//  state variables
-	bool need_save_;
+	bool need_save_{false};
 	uint32_t realtime_;
-	bool is_painting_;
+	bool is_painting_{false};
 
 	// All unique menu windows
 	struct EditorMenuWindows {
@@ -287,8 +292,8 @@ private:
 	// Show / Hide menu on the toolbar
 	UI::Dropdown<ShowHideEntry> showhidemenu_;
 
-	UI::Button* undo_;
-	UI::Button* redo_;
+	UI::Button* undo_{nullptr};
+	UI::Button* redo_{nullptr};
 
 	std::unique_ptr<Tools> tools_;
 	std::unique_ptr<EditorHistory> history_;
