@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2022 by the Widelands Development Team
+ * Copyright (C) 2012-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,11 +45,12 @@ struct EditorActionArgs {
 	~EditorActionArgs();
 
 	uint32_t sel_radius;
+	std::vector<bool> selection_gaps;
 
-	int32_t change_by;                                     // resources, change height tools
+	int32_t change_by{0};                                  // resources, change height tools
 	std::list<Widelands::Field::Height> original_heights;  // change height tool
-	Widelands::DescriptionIndex current_resource;          // resources change tools
-	Widelands::ResourceAmount set_to;                      // resources change tools
+	Widelands::DescriptionIndex current_resource{0U};      // resources change tools
+	Widelands::ResourceAmount set_to{0U};                  // resources change tools
 	Widelands::Extent new_map_size;                        // resize tool
 
 	struct ResourceState {
@@ -68,7 +69,7 @@ struct EditorActionArgs {
 
 	std::list<EditorToolAction*> draw_actions;  // draw tool
 
-	uint32_t refcount;
+	uint32_t refcount{0U};
 
 	WindowID window_id;
 };
