@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
 
 ///  Ensures that the height of a node is within an interval.
 struct EditorSetHeightTool : public EditorTool {
-	EditorSetHeightTool(EditorInteractive& parent)
+	explicit EditorSetHeightTool(EditorInteractive& parent)
 	   : EditorTool(parent, *this, *this), interval_(10, 10) {
 	}
 
@@ -39,11 +39,11 @@ struct EditorSetHeightTool : public EditorTool {
 
 	EditorActionArgs format_args_impl() override;
 
-	const Image* get_sel_impl() const override {
+	[[nodiscard]] const Image* get_sel_impl() const override {
 		return g_image_cache->get("images/wui/editor/fsel_editor_set_height.png");
 	}
 
-	Widelands::HeightInterval get_interval() const {
+	[[nodiscard]] Widelands::HeightInterval get_interval() const {
 		return interval_;
 	}
 	void set_interval(const Widelands::HeightInterval& i) {
