@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,8 +27,7 @@ Widelands::NodeCaps resource_tools_nodecaps(const Widelands::FCoords& fcoords,
 
 ///  Decreases the resources of a node by a value.
 struct EditorSetResourcesTool : public EditorTool {
-	EditorSetResourcesTool(EditorInteractive& parent)
-	   : EditorTool(parent, *this, *this), cur_res_(0), set_to_(0) {
+	explicit EditorSetResourcesTool(EditorInteractive& parent) : EditorTool(parent, *this, *this) {
 	}
 
 	/**
@@ -44,7 +43,7 @@ struct EditorSetResourcesTool : public EditorTool {
 
 	EditorActionArgs format_args_impl() override;
 
-	const Image* get_sel_impl() const override {
+	[[nodiscard]] const Image* get_sel_impl() const override {
 		return g_image_cache->get("images/wui/editor/fsel_editor_set_resources.png");
 	}
 
@@ -53,13 +52,13 @@ struct EditorSetResourcesTool : public EditorTool {
 		return resource_tools_nodecaps(fcoords, egbase, cur_res_);
 	}
 
-	Widelands::ResourceAmount get_set_to() const {
+	[[nodiscard]] Widelands::ResourceAmount get_set_to() const {
 		return set_to_;
 	}
 	void set_set_to(Widelands::ResourceAmount const n) {
 		set_to_ = n;
 	}
-	Widelands::DescriptionIndex get_cur_res() const {
+	[[nodiscard]] Widelands::DescriptionIndex get_cur_res() const {
 		return cur_res_;
 	}
 	void set_cur_res(Widelands::DescriptionIndex const res) {
@@ -81,8 +80,8 @@ struct EditorSetResourcesTool : public EditorTool {
 	}
 
 private:
-	Widelands::DescriptionIndex cur_res_;
-	Widelands::ResourceAmount set_to_;
+	Widelands::DescriptionIndex cur_res_{0U};
+	Widelands::ResourceAmount set_to_{0U};
 };
 
 #endif  // end of include guard: WL_EDITOR_TOOLS_SET_RESOURCES_TOOL_H
