@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,13 +28,13 @@ struct EditorSetStartingPosTool : public EditorTool {
 	int32_t handle_click_impl(const Widelands::NodeAndTriangle<>&,
 	                          EditorActionArgs*,
 	                          Widelands::Map*) override;
-	const Image* get_sel_impl() const override {
+	[[nodiscard]] const Image* get_sel_impl() const override {
 		return playercolor_image(get_current_player() - 1, "images/players/player_position_menu.png");
 	}
 
-	Widelands::PlayerNumber get_current_player() const;
+	[[nodiscard]] Widelands::PlayerNumber get_current_player() const;
 	void set_current_player(int32_t);
-	bool has_size_one() const override {
+	[[nodiscard]] bool has_size_one() const override {
 		return true;
 	}
 	Widelands::NodeCaps nodecaps_for_buildhelp(const Widelands::FCoords& fcoords,
