@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
 
 #include "editor/editorinteractive.h"
 
-ToolConf::ToolConf() : primary(nullptr), change_by(0), set_to(0), interval(0, 0), resource(0) {
+ToolConf::ToolConf() : interval(0, 0) {
 }
 
 std::string ToolConf::to_key() const {
