@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,7 +31,7 @@ struct MainMenuLoadMap : public MainMenuLoadOrSaveMap {
 protected:
 	void clicked_ok() override;
 	// Sets the current dir and updates labels.
-	void set_current_directory(const std::string& filename) override;
+	void set_current_directory(const std::vector<std::string>& filenames) override;
 
 private:
 	void entry_selected();
