@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ protected:
 	virtual void clicked_ok() = 0;
 	void toggle_mapnames();
 	// Sets the current dir and updates labels.
-	virtual void set_current_directory(const std::string& filename) = 0;
+	virtual void set_current_directory(const std::vector<std::string>& filenames) = 0;
 	void layout() override;
 	void fill_table();
 
@@ -54,7 +54,7 @@ protected:
 	// Private variables first, because compiler would complain about initialization order otherwise
 private:
 	// Common padding between panels
-	int32_t const padding_;
+	int32_t const padding_{4};
 
 	// Whether to list empty directories
 	bool const show_empty_dirs_;
@@ -89,7 +89,7 @@ protected:
 
 	// Settings data
 	const std::string basedir_;
-	std::string curdir_;
+	std::vector<std::string> curdir_;
 	bool include_addon_maps_;
 };
 
