@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -43,7 +43,7 @@ private:
 	void clicked_cancel();
 	void fill_list();
 
-	int32_t margin_;
+	int32_t margin_{4};
 	int32_t box_width_;
 	UI::Box box_;
 	MapSizeBox map_size_box_;
