@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,21 +29,32 @@ EditorToolChangeHeightOptionsMenu::EditorToolChangeHeightOptionsMenu(
    EditorIncreaseHeightTool& increase_tool,
    UI::UniqueWindow::Registry& registry)
    : EditorToolOptionsMenu(parent, registry, 350, 100, _("Height Tools Options"), increase_tool),
+     eia_(parent),
      increase_tool_(increase_tool),
-     box_(this, UI::PanelStyle::kWui, hmargin(), vmargin(), UI::Box::Vertical, 0, 0, vspacing()),
+     box_(this,
+          UI::PanelStyle::kWui,
+          "main_box",
+          hmargin(),
+          vmargin(),
+          UI::Box::Vertical,
+          0,
+          0,
+          vspacing()),
      change_by_(&box_,
+                "change_by",
                 0,
                 0,
                 get_inner_w() - 2 * hmargin(),
                 80,
                 increase_tool_.get_change_by(),
                 1,
-                MAX_FIELD_HEIGHT_DIFF,
+                eia_.egbase().map().max_field_height_diff(),
                 UI::PanelStyle::kWui,
                 _("Increase/Decrease height by:"),
                 UI::SpinBox::Units::kNone,
                 UI::SpinBox::Type::kSmall),
      set_to_(&box_,
+             "set_to",
              0,
              0,
              get_inner_w() - 2 * hmargin(),
@@ -76,7 +87,7 @@ EditorToolChangeHeightOptionsMenu::EditorToolChangeHeightOptionsMenu(
 void EditorToolChangeHeightOptionsMenu::update_change_by() {
 	int32_t change_by = change_by_.get_value();
 	assert(change_by > 0);
-	assert(change_by <= MAX_FIELD_HEIGHT_DIFF);
+	assert(change_by <= eia_.egbase().map().max_field_height_diff());
 
 	increase_tool_.set_change_by(change_by);
 	increase_tool_.decrease_tool().set_change_by(change_by);
