@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,8 +31,17 @@ EditorToolNoiseHeightOptionsMenu::EditorToolNoiseHeightOptionsMenu(
    UI::UniqueWindow::Registry& registry)
    : EditorToolOptionsMenu(parent, registry, 300, 120, _("Random Height Options"), noise_tool),
      noise_tool_(noise_tool),
-     box_(this, UI::PanelStyle::kWui, hmargin(), vmargin(), UI::Box::Vertical, 0, 0, vspacing()),
+     box_(this,
+          UI::PanelStyle::kWui,
+          "main_box",
+          hmargin(),
+          vmargin(),
+          UI::Box::Vertical,
+          0,
+          0,
+          vspacing()),
      lower_(&box_,
+            "lower",
             0,
             0,
             get_inner_w() - 2 * hmargin(),
@@ -45,6 +54,7 @@ EditorToolNoiseHeightOptionsMenu::EditorToolNoiseHeightOptionsMenu(
             UI::SpinBox::Units::kNone,
             UI::SpinBox::Type::kSmall),
      upper_(&box_,
+            "upper",
             0,
             0,
             get_inner_w() - 2 * hmargin(),
@@ -57,6 +67,7 @@ EditorToolNoiseHeightOptionsMenu::EditorToolNoiseHeightOptionsMenu(
             UI::SpinBox::Units::kNone,
             UI::SpinBox::Type::kSmall),
      set_to_(&box_,
+             "set_to",
              0,
              0,
              get_inner_w() - 2 * hmargin(),
@@ -82,16 +93,17 @@ EditorToolNoiseHeightOptionsMenu::EditorToolNoiseHeightOptionsMenu(
 	upper_.changed.connect([this]() { update_upper(); });
 	set_to_.changed.connect([this]() { update_set_to(); });
 
-	UI::Textarea* label = new UI::Textarea(&box_, UI::PanelStyle::kWui, UI::FontStyle::kWuiLabel, 0,
-	                                       0, 0, 0, _("Random height"), UI::Align::kCenter);
+	UI::Textarea* label =
+	   new UI::Textarea(&box_, UI::PanelStyle::kWui, "label_random", UI::FontStyle::kWuiLabel, 0, 0,
+	                    0, 0, _("Random height"), UI::Align::kCenter);
 	label->set_fixed_width(get_inner_w() - 2 * hmargin());
 	box_.add(label);
 	box_.add(&upper_);
 	box_.add(&lower_);
 
 	box_.add_space(2 * vspacing());
-	label = new UI::Textarea(&box_, UI::PanelStyle::kWui, UI::FontStyle::kWuiLabel, 0, 0, 0, 0,
-	                         _("Fixed height"), UI::Align::kCenter);
+	label = new UI::Textarea(&box_, UI::PanelStyle::kWui, "label_fixed", UI::FontStyle::kWuiLabel, 0,
+	                         0, 0, 0, _("Fixed height"), UI::Align::kCenter);
 	label->set_fixed_width(get_inner_w() - 2 * hmargin());
 	box_.add(label);
 	box_.add(&set_to_);
