@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,8 +26,8 @@
 struct EditorToolOptionsMenu : public UI::UniqueWindow {
 	EditorToolOptionsMenu(EditorInteractive& parent,
 	                      UI::UniqueWindow::Registry&,
-	                      const uint32_t width,
-	                      const uint32_t height,
+	                      uint32_t width,
+	                      uint32_t height,
 	                      const std::string& title,
 	                      EditorTool& tool);
 
@@ -59,7 +59,7 @@ struct EditorToolOptionsMenu : public UI::UniqueWindow {
 	virtual void update_window() {
 	}
 
-private:
+protected:
 	EditorInteractive& parent_;
 	EditorTool& current_tool_;
 };
