@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,11 +34,13 @@ struct EditorToolPlaceImmovableOptionsMenu : public EditorToolOptionsMenu {
 	~EditorToolPlaceImmovableOptionsMenu() override = default;
 
 	void update_window() override;
+	void think() override;
 
 private:
 	std::unique_ptr<
 	   CategorizedItemSelectionMenu<Widelands::ImmovableDescr, EditorPlaceImmovableTool>>
 	   multi_select_menu_;
+	UI::Button* auto_trees_button_{nullptr};
 };
 
 #endif  // end of include guard: WL_EDITOR_UI_MENUS_TOOL_PLACE_IMMOVABLE_OPTIONS_MENU_H
