@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,18 +27,27 @@ class EditorInteractive;
 /// The tool size window/menu.
 struct EditorToolsizeMenu : public UI::UniqueWindow {
 	EditorToolsizeMenu(EditorInteractive&, UI::UniqueWindow::Registry&);
-	void update(uint32_t);
+	void update(uint32_t radius, uint32_t gap);
 	void set_buttons_enabled(bool enable);
-	uint32_t value() {
-		return value_;
+	[[nodiscard]] uint32_t radius() const {
+		return radius_;
+	}
+	[[nodiscard]] uint32_t gap_percent() const {
+		return gap_percent_;
 	}
 
 private:
 	EditorInteractive& eia() const;
-	UI::SpinBox spinbox_;
-	uint32_t value_;
+
+	UI::Box box_;
+	UI::SpinBox spinbox_radius_;
+	UI::SpinBox spinbox_gap_;
+
+	uint32_t radius_{0U};
+	uint16_t gap_percent_{0U};
+
 	void changed();
-	static constexpr uint32_t kMargin = 5;
+	bool is_updating_{false};
 };
 
 #endif  // end of include guard: WL_EDITOR_UI_MENUS_TOOLSIZE_MENU_H
