@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,14 +23,14 @@
 
 /// Manages a set of 6 animations, one for each possible direction.
 struct DirAnimations {
-	DirAnimations(uint32_t dir1 = 0,
-	              uint32_t dir2 = 0,
-	              uint32_t dir3 = 0,
-	              uint32_t dir4 = 0,
-	              uint32_t dir5 = 0,
-	              uint32_t dir6 = 0);
+	explicit DirAnimations(uint32_t dir1 = 0,
+	                       uint32_t dir2 = 0,
+	                       uint32_t dir3 = 0,
+	                       uint32_t dir4 = 0,
+	                       uint32_t dir5 = 0,
+	                       uint32_t dir6 = 0);
 
-	uint32_t get_animation(Widelands::Direction const dir) const {
+	[[nodiscard]] uint32_t get_animation(Widelands::Direction const dir) const {
 		return animations_[dir - 1];
 	}
 	void set_animation(const Widelands::Direction dir, const uint32_t anim) {
@@ -41,8 +41,8 @@ struct DirAnimations {
 		return DirAnimations(0);  // Since real animation IDs are positive, this is safe
 	}
 
-	operator bool() const {
-		return animations_[0];
+	explicit operator bool() const {
+		return animations_[0] != 0u;
 	}
 
 private:
