@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,10 +32,10 @@ struct RGBColor {
 	RGBColor();
 
 	// Returns this color in hex format.
-	std::string hex_value() const;
+	[[nodiscard]] std::string hex_value() const;
 
 	// Map this color to the given 'fmt'
-	uint32_t map(const SDL_PixelFormat& fmt) const;
+	[[nodiscard]] uint32_t map(const SDL_PixelFormat& fmt) const;
 
 	// Set it to the given 'clr' which is interpretes through 'fmt'.
 	void set(SDL_PixelFormat* fmt, uint32_t clr);
@@ -56,13 +56,13 @@ struct RGBAColor {
 	RGBAColor();
 
 	// Initializes to opaque color.
-	RGBAColor(const RGBColor& c);
+	RGBAColor(const RGBColor& c);  // NOLINT allow implicit conversion
 
 	// Returns this color in hex format.
-	std::string hex_value() const;
+	[[nodiscard]] std::string hex_value() const;
 
 	// Map this color to the given 'fmt'
-	uint32_t map(const SDL_PixelFormat& fmt) const;
+	[[nodiscard]] uint32_t map(const SDL_PixelFormat& fmt) const;
 
 	// Set it to the given 'clr' which is interpretes through 'fmt'.
 	void set(const SDL_PixelFormat& fmt, uint32_t clr);
