@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
 
 #include "graphic/gl/fields_to_draw.h"
 
+#include <cstddef>
 #include <cstdlib>
 
 #include "base/log.h"
@@ -111,7 +112,7 @@ void FieldsToDraw::reset(const Widelands::EditorGameBase& egbase,
 	assert(h_ > 0);
 
 	// Ensure that there is enough memory for the resize operation
-	size_t dimension = w_ * h_;
+	size_t dimension = static_cast<size_t>(w_) * h_;
 	const size_t max_dimension = fields_.max_size();
 	if (dimension > max_dimension) {
 		log_warn_time(egbase.get_gametime(),
@@ -129,6 +130,7 @@ void FieldsToDraw::reset(const Widelands::EditorGameBase& egbase,
 			FieldsToDraw::Field& f = fields_[calculate_index(fx, fy)];
 
 			f.geometric_coords = Widelands::Coords(fx, fy);
+			f.obscured_by_slope = false;
 
 			f.ln_index = calculate_index(fx - 1, fy);
 			f.rn_index = calculate_index(fx + 1, fy);
@@ -169,4 +171,33 @@ void FieldsToDraw::reset(const Widelands::EditorGameBase& egbase,
 			f.road_sw = f.fcoords.field->get_road(Widelands::WALK_SW);
 		}
 	}
+
+	// Check which slopes may obscure fields behind them
+	for (int32_t fy = min_fy_; fy <= max_fy_; ++fy) {
+		for (int32_t fx = min_fx_; fx <= max_fx_; ++fx) {
+			FieldsToDraw::Field& f = fields_[calculate_index(fx, fy)];
+			FieldsToDraw::Field* f0 = &f;
+			for (;;) {
+				if (!f0->all_neighbors_valid()) {
+					break;
+				}
+
+				FieldsToDraw::Field* f2 = &fields_[f0->trn_index];
+				FieldsToDraw::Field* f1 = &fields_[f2->ln_index];
+				f1->obscured_by_slope |= f.surface_pixel.y < f1->surface_pixel.y;
+				f2->obscured_by_slope |= f.surface_pixel.y < f2->surface_pixel.y;
+
+				if (!f1->all_neighbors_valid() || !f2->all_neighbors_valid()) {
+					break;
+				}
+
+				f0 = &fields_[f1->trn_index];
+				if (f.surface_pixel.y < f0->surface_pixel.y) {
+					f0->obscured_by_slope = true;
+				} else {
+					break;
+				}
+			}
+		}
+	}
 }
