@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,8 +18,10 @@
 #include "graphic/gl/utils.h"
 
 #include <cassert>
+#include <cstddef>
 #include <memory>
 
+#include "base/multithreading.h"
 #include "base/wexception.h"
 #include "io/fileread.h"
 #include "io/filesystem/layered_filesystem.h"
@@ -81,7 +83,7 @@ public:
 	explicit Shader(GLenum type);
 	~Shader();
 
-	GLuint object() const {
+	[[nodiscard]] GLuint object() const {
 		return shader_object_;
 	}
 
@@ -174,8 +176,7 @@ void Program::build(const std::string& program_name) {
 	}
 }
 
-State::State()
-   : last_active_texture_(NONE), current_framebuffer_(0), current_framebuffer_texture_(0) {
+State::State() : last_active_texture_(NONE) {
 }
 
 void State::bind(const GLenum target, const GLuint texture) {
@@ -256,6 +257,7 @@ void State::enable_vertex_attrib_array(std::unordered_set<GLint> entries) {
 
 // static
 State& State::instance() {
+	assert(is_initializer_thread());
 	static State binder;
 	return binder;
 }
@@ -267,7 +269,7 @@ void vertex_attrib_pointer(int vertex_index, int num_items, int stride, size_t o
 
 void swap_rows(const int width, const int height, const int pitch, const int bpp, uint8_t* pixels) {
 	uint8_t* begin_row = pixels;
-	uint8_t* end_row = pixels + pitch * (height - 1);
+	uint8_t* end_row = pixels + static_cast<ptrdiff_t>(pitch) * (height - 1);
 	while (begin_row < end_row) {
 		for (int x = 0; x < width * bpp; ++x) {
 			std::swap(begin_row[x], end_row[x]);
