@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
 
 #include "graphic/image_io.h"
 
+#include <cstddef>
 #include <memory>
 
 #include <SDL_image.h>
@@ -130,7 +131,7 @@ bool save_to_png(Texture* texture, StreamWrite* sw, ColorType color_type) {
 			for (uint32_t y = 0; y < surf_h; ++y) {
 				for (uint32_t x = 0; x < surf_w; ++x) {
 					color = texture->get_pixel(x, y);
-					row[3 * x] = color.r;
+					row[static_cast<std::size_t>(3) * x] = color.r;
 					row[3 * x + 1] = color.g;
 					row[3 * x + 2] = color.b;
 				}
@@ -140,7 +141,7 @@ bool save_to_png(Texture* texture, StreamWrite* sw, ColorType color_type) {
 			for (uint32_t y = 0; y < surf_h; ++y) {
 				for (uint32_t x = 0; x < surf_w; ++x) {
 					color = texture->get_pixel(x, y);
-					row[4 * x] = color.r;
+					row[static_cast<std::size_t>(4) * x] = color.r;
 					row[4 * x + 1] = color.g;
 					row[4 * x + 2] = color.b;
 					row[4 * x + 3] = color.a;
