@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2022 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,15 +30,18 @@
 
 // Layers for selecting what do display on the minimap.
 enum class MiniMapLayer {
-	Terrain = 1,
-	Owner = 2,
-	Flag = 4,
-	Road = 8,
-	Building = 16,
-	Zoom2 = 32,
-	ViewWindow = 64,
-	StartingPositions = 128,
-	Ship = 256,
+	Terrain = 1 << 0,
+	Owner = 1 << 1,
+	Flag = 1 << 2,
+	Road = 1 << 3,
+	Building = 1 << 4,
+	Zoom2 = 1 << 5,
+	ViewWindow = 1 << 6,
+	StartingPositions = 1 << 7,
+	Ship = 1 << 8,
+	Traffic = 1 << 9,
+	Artifacts = 1 << 10,
+	Attack = 1 << 11,
 };
 
 // A bunch of operators that turn MiniMapLayer into a bitwise combinable flag class.
@@ -66,7 +69,7 @@ Vector2f minimap_pixel_to_mappixel(const Widelands::Map& map,
                                    const Vector2i& minimap_pixel,
                                    const Rectf& view_area,
                                    MiniMapType minimap_type,
-                                   const bool zoom);
+                                   bool zoom);
 
 // Render the minimap. If player is not nullptr, it renders from that player's
 // point of view. The 'view_area' designates the currently visible area in the
@@ -96,7 +99,7 @@ void draw_minimap_static(Texture& texture,
                          const Widelands::EditorGameBase& egbase,
                          const Widelands::Player* player,
                          MiniMapLayer layers,
-                         const bool draw_full = true,
+                         bool draw_full = true,
                          uint16_t* rows_drawn = nullptr);
 
 // Blit the static texture from the previous step onto a new texture.
