@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2022 by the Widelands Development Team
+ * Copyright (C) 2018-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,23 +36,23 @@ struct ProgressbarStyleInfo {
 	     medium_color_(init_medium_color),
 	     high_color_(init_high_color) {
 	}
-	explicit ProgressbarStyleInfo(const ProgressbarStyleInfo& other)
+	ProgressbarStyleInfo(const ProgressbarStyleInfo& other)
 	   : font_(new UI::FontStyleInfo(other.font())),
 	     low_color_(other.low_color()),
 	     medium_color_(other.medium_color()),
 	     high_color_(other.high_color()) {
 	}
 
-	const UI::FontStyleInfo& font() const {
-		return *font_.get();
+	[[nodiscard]] const UI::FontStyleInfo& font() const {
+		return *font_;
 	}
-	const RGBColor& low_color() const {
+	[[nodiscard]] const RGBColor& low_color() const {
 		return low_color_;
 	}
-	const RGBColor& medium_color() const {
+	[[nodiscard]] const RGBColor& medium_color() const {
 		return medium_color_;
 	}
-	const RGBColor& high_color() const {
+	[[nodiscard]] const RGBColor& high_color() const {
 		return high_color_;
 	}
 
