@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,19 +31,15 @@
 class Surface {
 public:
 	Surface() = default;
-	virtual ~Surface() {
-	}
+	virtual ~Surface() = default;
 
 	/// Dimensions.
-	virtual int width() const = 0;
-	virtual int height() const = 0;
+	[[nodiscard]] virtual int width() const = 0;
+	[[nodiscard]] virtual int height() const = 0;
 
 	/// This draws a part of 'texture'.
-	void blit(const Rectf& dst,
-	          const Image&,
-	          const Rectf& src_rect,
-	          const float opacity,
-	          BlendMode blend_mode);
+	void
+	blit(const Rectf& dst, const Image&, const Rectf& src_rect, float opacity, BlendMode blend_mode);
 
 	/// This draws a playercolor blended image.
 	void blit_blended(const Rectf& dst,
