@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
 
 #include <cstdlib>
 #include <memory>
+#include <regex>
 
 #include "base/string.h"
 #include "graphic/text/rt_errors_impl.h"
@@ -141,7 +142,37 @@ void Tag::parse_content(TextStream& ts, TagConstraints& tcs, const TagSet& allow
 				throw SyntaxErrorImpl(
 				   line, col, "no text, as only tags are allowed here", text, ts.peek(100));
 			}
-			children_.push_back(new Child(text));
+
+			// Regex taken from https://stackoverflow.com/a/3809435
+			static std::regex kLinkRegex("https?:\\/\\/"
+			                             "(www\\.)?[-a-zA-Z0-9@:%._\\+~#=]{1,256}\\.[a-zA-Z0-9()]{1,6}"
+			                             "\\b([-a-zA-Z0-9()@:%_\\+.~#?&//=]*)");
+			static thread_local bool autolink_protection(false);
+			while (!text.empty()) {
+				std::smatch match;
+				if (autolink_protection || !std::regex_search(text, match, kLinkRegex)) {
+					children_.push_back(new Child(text));
+					break;
+				}
+				autolink_protection = true;
+
+				size_t match_start = match.position();
+				size_t match_len = match.length();
+				if (match_start > 0) {
+					children_.push_back(new Child(text.substr(0, match_start)));
+				}
+
+				Tag* child = new Tag();
+				std::string url = text.substr(match_start, match_len);
+				TextStream linktext(format(
+				   "<link type=url target=%1$s mouseover=\"%2$s\"><font underline=1>%3$s</font></link>",
+				   url, url, url));
+				child->parse(linktext, tcs, allowed_tags);
+				children_.push_back(new Child(child));
+
+				text = text.substr(match_start + match_len);
+				autolink_protection = false;
+			}
 		}
 
 		if (ts.peek(2 + name_.size()) == ("</" + name_)) {
@@ -180,14 +211,15 @@ void Tag::parse(TextStream& ts, TagConstraints& tcs, const TagSet& allowed_tags)
 The Richtext Tags
 =================
 
-- :ref:`rt_tags_rt`
-- :ref:`rt_tags_div`
-- :ref:`rt_tags_br`
-- :ref:`rt_tags_space`
-- :ref:`rt_tags_vspace`
-- :ref:`rt_tags_p`
-- :ref:`rt_tags_font`
-- :ref:`rt_tags_img`
+* :ref:`rt_tags_rt`
+* :ref:`rt_tags_div`
+* :ref:`rt_tags_br`
+* :ref:`rt_tags_space`
+* :ref:`rt_tags_vspace`
+* :ref:`rt_tags_p`
+* :ref:`rt_tags_font`
+* :ref:`rt_tags_img`
+* :ref:`rt_tags_link`
 
 For an introduction to our richtext system including a code example, see :ref:`wlrichtext`.
 
@@ -231,6 +263,7 @@ Sub-tags
 * :ref:`rt_tags_font`
 * :ref:`rt_tags_p`
 * :ref:`rt_tags_vspace`
+* :ref:`rt_tags_link`
 
 :ref:`Return to tag index<rt_tags>`
 		*/
@@ -248,6 +281,7 @@ Sub-tags
 		tc.allowed_children.insert("vspace");
 		tc.allowed_children.insert("font");
 		tc.allowed_children.insert("div");
+		tc.allowed_children.insert("link");
 		tc.text_allowed = false;
 		tc.has_closing_tag = true;
 		tag_constraints_["rt"] = tc;
@@ -282,6 +316,7 @@ Sub-tags
 * :ref:`rt_tags_font`
 * :ref:`rt_tags_p`
 * :ref:`rt_tags_vspace`
+* :ref:`rt_tags_link`
 
 :ref:`Return to tag index<rt_tags>`
 		*/
@@ -301,6 +336,7 @@ Sub-tags
 		tc.allowed_children.insert("vspace");
 		tc.allowed_children.insert("font");
 		tc.allowed_children.insert("div");
+		tc.allowed_children.insert("link");
 
 		tc.text_allowed = false;
 		tc.has_closing_tag = true;
@@ -397,6 +433,7 @@ Sub-tags
 * :ref:`rt_tags_img`
 * :ref:`rt_tags_space`
 * :ref:`rt_tags_vspace`
+* :ref:`rt_tags_link`
 
 :ref:`Return to tag index<rt_tags>`
 		*/
@@ -412,6 +449,7 @@ Sub-tags
 		tc.allowed_children.insert("br");
 		tc.allowed_children.insert("img");
 		tc.allowed_children.insert("div");
+		tc.allowed_children.insert("link");
 		tc.text_allowed = true;
 		tc.has_closing_tag = true;
 		tag_constraints_["p"] = tc;
@@ -447,6 +485,7 @@ Sub-tags
 * :ref:`rt_tags_p`
 * :ref:`rt_tags_space`
 * :ref:`rt_tags_vspace`
+* :ref:`rt_tags_link`
 
 :ref:`Return to tag index<rt_tags>`
 		*/
@@ -466,6 +505,7 @@ Sub-tags
 		tc.allowed_children.insert("p");
 		tc.allowed_children.insert("font");
 		tc.allowed_children.insert("div");
+		tc.allowed_children.insert("link");
 		tc.allowed_children.insert("img");
 		tc.text_allowed = true;
 		tc.has_closing_tag = true;
@@ -473,6 +513,55 @@ Sub-tags
 	}
 	{
 		/* RST
+.. _rt_tags_link:
+
+Link -- <link>
+--------------
+
+This tag defines a clickable hyperlink.
+
+Attributes
+^^^^^^^^^^
+
+* **type**: Mandatory. What kind of link. Can be "url" or "ui".
+* **target**: Mandatory. The URL to open or the UI widget to reference.
+* **action**: Mandatory for UI links: the action to perform. Not allowed for URLs.
+* **mouseover**: Optional. The mouseover text to show.
+
+Sub-tags
+^^^^^^^^
+
+* :ref:`rt_tags_br`
+* :ref:`rt_tags_div`
+* :ref:`rt_tags_font`
+* :ref:`rt_tags_img`
+* :ref:`rt_tags_p`
+* :ref:`rt_tags_space`
+* :ref:`rt_tags_vspace`
+* :ref:`rt_tags_link`
+
+:ref:`Return to tag index<rt_tags>`
+		*/
+		TagConstraint tc;
+		tc.allowed_attrs.insert("type");
+		tc.allowed_attrs.insert("target");
+		tc.allowed_attrs.insert("action");
+		tc.allowed_attrs.insert("mouseover");
+
+		tc.allowed_children.insert("br");
+		tc.allowed_children.insert("space");
+		tc.allowed_children.insert("vspace");
+		tc.allowed_children.insert("p");
+		tc.allowed_children.insert("font");
+		tc.allowed_children.insert("div");
+		tc.allowed_children.insert("link");
+		tc.allowed_children.insert("img");
+		tc.text_allowed = true;
+		tc.has_closing_tag = true;
+		tag_constraints_["link"] = tc;
+	}
+	{
+		/* RST
 .. _rt_tags_img:
 
 Image -- <img>
@@ -487,8 +576,9 @@ Attributes
 * **object**: Show the representative image of a map object instead of using ``src``.
 * **ref**: To be implemented
 * **color**: Player color for the image as a hex value
-* **width**: Width of the image as a pixel amount.
+* **width**: Maximum width of the image as a pixel amount.
   The corresponding height will be matched automatically.
+  The image may only be scaled down, never up.
   Not supported in conjunction with the ``object`` parameter.
 
 :ref:`Return to tag index<rt_tags>`
