@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,11 +37,11 @@ class Attr {
 public:
 	Attr(const std::string& gname, const std::string& value);
 
-	const std::string& name() const;
-	int64_t get_int(int64_t max_value) const;
-	bool get_bool() const;
-	std::string get_string() const;
-	RGBColor get_color() const;
+	[[nodiscard]] const std::string& name() const;
+	[[nodiscard]] int64_t get_int(int64_t max_value) const;
+	[[nodiscard]] bool get_bool() const;
+	[[nodiscard]] std::string get_string() const;
+	[[nodiscard]] RGBColor get_color() const;
 
 private:
 	const std::string name_, value_;
@@ -57,7 +57,7 @@ public:
 	const Attr& operator[](const std::string& s) const;
 
 	// Returns true if 'name' is a known attribute.
-	bool has(const std::string& s) const;
+	[[nodiscard]] bool has(const std::string& s) const;
 
 private:
 	std::map<std::string, std::unique_ptr<Attr>> attrs_;
@@ -78,9 +78,9 @@ public:
 
 	~Tag();
 
-	const std::string& name() const;
-	const AttrMap& attrs() const;
-	const ChildList& children() const;
+	[[nodiscard]] const std::string& name() const;
+	[[nodiscard]] const AttrMap& attrs() const;
+	[[nodiscard]] const ChildList& children() const;
 	void parse(TextStream& ts, TagConstraints& tcs, const TagSet&);
 
 private:
@@ -95,17 +95,16 @@ private:
 };
 
 struct Child {
-	Child() : tag(nullptr), text() {
-	}
+	Child() = default;
 	explicit Child(Tag* t) : tag(t) {
 	}
 	explicit Child(const std::string& t) : tag(nullptr), text(t) {
 	}
 	~Child() {
-		if (tag)
-			delete tag;
+
+		delete tag;
 	}
-	Tag* tag;
+	Tag* tag{nullptr};
 	std::string text;
 };
 
