@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,8 +58,8 @@ public:
 	                                        std::shared_ptr<const T> entry) = 0;
 
 protected:
-	/// Inserts this entry of type T into the cache. asserts() that there is no entry with this hash
-	/// already cached. Returns the given T for convenience.
+	/// Inserts this entry of type T into the cache if there is no entry with this hash already
+	/// cached. Returns the given T for convenience.
 	std::shared_ptr<const T> insert(const std::string& hash,
 	                                std::shared_ptr<const T> entry,
 	                                uint32_t entry_size_in_size_unit);
@@ -77,7 +77,7 @@ private:
 	};
 
 	uint32_t max_size_in_size_unit_;
-	uint32_t size_in_size_unit_;
+	uint32_t size_in_size_unit_{0U};
 	std::map<std::string, Entry> entries_;
 	AccessHistory access_history_;
 
@@ -88,7 +88,7 @@ private:
 
 template <typename T>
 TransientCache<T>::TransientCache(uint32_t max_size_in_arbitrary_unit)
-   : max_size_in_size_unit_(max_size_in_arbitrary_unit), size_in_size_unit_(0) {
+   : max_size_in_size_unit_(max_size_in_arbitrary_unit) {
 }
 template <typename T> TransientCache<T>::~TransientCache() {
 	flush();
@@ -118,7 +118,9 @@ template <typename T>
 std::shared_ptr<const T> TransientCache<T>::insert(const std::string& hash,
                                                    std::shared_ptr<const T> entry,
                                                    uint32_t entry_size_in_size_unit) {
-	assert(entries_.find(hash) == entries_.end());
+	if (entries_.find(hash) != entries_.end()) {  // Should happen only in race conditions
+		return entry;
+	}
 
 	while (!entries_.empty() &&
 	       size_in_size_unit_ + entry_size_in_size_unit > max_size_in_size_unit_) {
