@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,12 +21,17 @@
 
 #include <memory>
 
+#include <SDL.h>
+
 #include "graphic/align.h"
 #include "graphic/color.h"
 #include "graphic/styles/font_style.h"
 #include "graphic/styles/panel_styles.h"
+#include "graphic/styles/paragraph_style.h"
 #include "graphic/text/rendered_text.h"
 
+#define HAS_PRIMARY_SELECTION_BUFFER SDL_VERSION_ATLEAST(2, 26, 0)
+
 /**
  * Returns the exact width of the text rendered as editorfont for the given font size.
  * This function is inefficient; only call when we need the exact width.
@@ -41,7 +46,7 @@ int text_height(const UI::FontStyleInfo& style, float scale = 1.0f);
 int text_height(UI::FontStyle style, float scale = 1.0f);
 
 /**
- * Checks it the given string is RichText or not. Does not do validity checking.
+ * Checks if the given string is RichText or not. Does not do validity checking.
  */
 inline bool is_richtext(const std::string& text) {
 	return text.compare(0, 3, "<rt") == 0;
@@ -66,6 +71,9 @@ std::string as_richtext_paragraph(const std::string& text,
                                   UI::Align align = UI::Align::kLeft);
 std::string as_editor_richtext_paragraph(const std::string& text, const UI::FontStyleInfo& style);
 
+std::string as_font_tag(UI::FontStyle style, const std::string& text);
+std::string as_font_tag(const std::string& text, UI::FontStyle style);
+
 std::string as_listitem(const std::string&, UI::FontStyle style);
 
 std::string as_game_tip(const std::string&);
@@ -76,6 +84,12 @@ std::string as_mapobject_message(const std::string& image,
                                  const RGBColor* player_color = nullptr);
 std::string as_message(const std::string& heading, const std::string& body);
 
+std::string
+as_url_hyperlink(const std::string& url, const std::string& text, const std::string& mouseover);
+inline std::string as_url_hyperlink(const std::string& url) {
+	return as_url_hyperlink(url, url, url);
+}
+
 void newlines_to_richtext(std::string&);
 
 /**
@@ -108,4 +122,27 @@ std::string as_content(const std::string& txt, UI::PanelStyle style);
 std::string
 as_tooltip_text_with_hotkey(const std::string& text, const std::string& hotkey, UI::PanelStyle);
 
+/// Insert vertical space. Returns an empty string if gap is zero or negative.
+[[nodiscard]] std::string as_vspace(int gap);
+
+/// Format 'text' with paragraph style 'style'
+std::string as_paragraph_style(UI::ParagraphStyle style, const std::string& text);
+
+/// Format 'text' with paragraph style 'style' with optional 'attributes' to be included
+/// in the paragraph tag. (Font attributes can be changed in a nested font tag.)
+std::string as_paragraph_style(UI::ParagraphStyle style,
+                               const std::string& attributes,
+                               const std::string& text);
+
+/// Return opening paragraph and font tags for formatting with paragraph style 'style'.
+/// The optional 'attributes' will be included in the paragraph tag.
+std::string open_paragraph_style(UI::ParagraphStyle style, const std::string& attributes = "");
+
+/// Return closing font and paragraph tags for formatting as plain paragraph.
+std::string close_paragraph_style(UI::ParagraphStyle style);
+
+/// Return 'term' and 'description' formatted as a definition list entry.
+/// (a paragraph with 'term' in bold and 'description' as normal text)
+std::string as_definition_line(const std::string& term, const std::string& description);
+
 #endif  // end of include guard: WL_GRAPHIC_TEXT_LAYOUT_H
