@@ -1,5 +1,5 @@
 /*
- * Copyright 2010 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
 #include "graphic/texture.h"
 
 #include <cassert>
+#include <cstddef>
 
 #include <SDL_surface.h>
 
@@ -73,7 +74,7 @@ public:
 		glDeleteFramebuffers(1, &gl_framebuffer_id_);
 	}
 
-	GLuint id() const {
+	[[nodiscard]] GLuint id() const {
 		return gl_framebuffer_id_;
 	}
 
@@ -116,9 +117,11 @@ Texture::Texture(SDL_Surface* surface, bool intensity) : owns_texture_(false) {
 	uint8_t bpp = surface->format->BytesPerPixel;
 
 	if ((surface->format->palette != nullptr) || width() != surface->w || height() != surface->h ||
-	    (bpp != 3 && bpp != 4) || is_bgr_surface(*surface->format)) {
+	    (bpp != 4) || is_bgr_surface(*surface->format)) {
 		SDL_Surface* converted = empty_sdl_surface(width(), height());
-		assert(converted);
+		if (converted == nullptr) {
+			throw wexception("Failed to create SDL_Surface");
+		}
 		SDL_SetSurfaceAlphaMod(converted, SDL_ALPHA_OPAQUE);
 		SDL_SetSurfaceBlendMode(converted, SDL_BLENDMODE_NONE);
 		SDL_SetSurfaceAlphaMod(surface, SDL_ALPHA_OPAQUE);
@@ -127,16 +130,15 @@ Texture::Texture(SDL_Surface* surface, bool intensity) : owns_texture_(false) {
 		SDL_FreeSurface(surface);
 		surface = converted;
 		bpp = surface->format->BytesPerPixel;
+		assert(bpp == 4);
 	}
 
-	const GLenum pixels_format = bpp == 4 ? GL_RGBA : GL_RGB;
-
 	SDL_LockSurface(surface);
 
 	Gl::swap_rows(width(), height(), surface->pitch, bpp, static_cast<uint8_t*>(surface->pixels));
 
 	glTexImage2D(GL_TEXTURE_2D, 0, static_cast<GLint>(intensity ? GL_INTENSITY : GL_RGBA), width(),
-	             height(), 0, pixels_format, GL_UNSIGNED_BYTE, surface->pixels);
+	             height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, surface->pixels);
 
 	SDL_UnlockSurface(surface);
 	SDL_FreeSurface(surface);
@@ -212,7 +214,7 @@ void Texture::lock() {
 		throw wexception("A surface that does not own its pixels can not be locked..");
 	}
 
-	pixels_.reset(new uint8_t[width() * height() * 4]);
+	pixels_.reset(new uint8_t[4ULL * width() * height()]);
 
 	Gl::State::instance().bind(GL_TEXTURE0, blit_data_.texture_id);
 	glGetTexImage(GL_TEXTURE_2D, 0, GL_RGBA, GL_UNSIGNED_BYTE, pixels_.get());
