@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +33,7 @@ constexpr int kPadding = 1;
 
 }  // namespace
 
-TextureAtlas::Node::Node(const Recti& init_r) : used(false), r(init_r) {
+TextureAtlas::Node::Node(const Recti& init_r) : r(init_r) {
 }
 
 void TextureAtlas::Node::split(int item_w, int item_h) {
@@ -48,9 +48,6 @@ void TextureAtlas::Node::split(int item_w, int item_h) {
 	// size of the full canvas.
 }
 
-TextureAtlas::TextureAtlas() : next_index_(0) {
-}
-
 void TextureAtlas::add(const Image& texture) {
 	blocks_.emplace_back(next_index_++, &texture);
 }
