@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2022 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,7 @@
 #define WL_GRAPHIC_WORDWRAP_H
 
 #include <memory>
+#include <optional>
 
 #include <base/scoped_timer.h>
 #include <unicode/uchar.h>
@@ -42,36 +43,39 @@ struct WordWrap {
 
 	void set_wrapwidth(uint32_t wrapwidth);
 
-	uint32_t wrapwidth() const;
+	[[nodiscard]] uint32_t wrapwidth() const;
 
 	void wrap(const std::string& text);
 
-	uint32_t width() const;
-	uint32_t height() const;
+	[[nodiscard]] uint32_t width() const;
+	[[nodiscard]] uint32_t height() const;
 	void set_draw_caret(bool draw_it) {
 		draw_caret_ = draw_it;
 	}
 
 	void draw(RenderTarget& dst,
 	          Vector2i where,
-	          Align align = UI::Align::kLeft,
-	          uint32_t caret = std::numeric_limits<uint32_t>::max(),
-	          bool with_selection = false,
-	          uint32_t selection_start = 0,
-	          uint32_t selection_end = 0,
-	          uint32_t scrollbar_position = 0,
-	          const std::string& caret_image_path = std::string());
+	          UI::Align align,
+	          uint32_t caret,
+	          bool with_selection,
+	          std::optional<std::pair<int32_t, int32_t>> expand_selection_y,
+	          uint32_t selection_start,
+	          uint32_t selection_end,
+	          uint32_t scrollbar_position,
+	          const std::string& caret_image_path);
 
 	void calc_wrapped_pos(uint32_t caret, uint32_t& line, uint32_t& pos) const;
-	uint32_t nrlines() const {
+	[[nodiscard]] uint32_t nrlines() const {
 		return lines_.size();
 	}
-	uint32_t line_offset(uint32_t line) const;
-	uint32_t offset_of_line_at(int32_t y) const;
-	std::string text_of_line_at(int32_t y) const;
+	[[nodiscard]] uint32_t line_offset(uint32_t line) const;
+	[[nodiscard]] uint32_t offset_of_line_at(int32_t y) const;
+	[[nodiscard]] std::string text_of_line_at(int32_t y) const;
 	int text_width_of(std::string& text) const;
+	[[nodiscard]] uint32_t lineheight() const;
 
 	void focus();
+	void enter_cursor_movement_mode();
 
 private:
 	struct LineData {
@@ -88,13 +92,13 @@ private:
 	                         std::string::size_type& next_line_start,
 	                         uint32_t safety_margin);
 
-	bool line_fits(const std::string& text, uint32_t safety_margin) const;
+	[[nodiscard]] bool line_fits(const std::string& text, uint32_t safety_margin) const;
 
-	uint32_t quick_width(const UChar& c) const;
-	uint32_t quick_width(const std::string& text) const;
+	[[nodiscard]] uint32_t quick_width(const UChar& c) const;
+	[[nodiscard]] uint32_t quick_width(const std::string& text) const;
 
 	uint32_t wrapwidth_;
-	bool draw_caret_;
+	bool draw_caret_{false};
 
 	// TODO(GunChleoc): We can tie these to constexpr once the old font renderer is gone.
 	const int fontsize_;
@@ -110,12 +114,16 @@ private:
 	                         uint32_t selection_start_x,
 	                         uint32_t selection_end_line,
 	                         uint32_t selection_end_x,
-	                         const int fontheight,
+	                         std::optional<std::pair<int32_t, int32_t>> expand_selection_y,
+	                         int fontheight,
 	                         uint32_t line,
 	                         const Vector2i& point) const;
-	uint32_t line_index(int32_t y) const;
+	[[nodiscard]] uint32_t line_index(int32_t y) const;
 	ScopedTimer caret_timer_;
-	uint32_t caret_ms;
+	uint32_t caret_ms_;
+	ScopedTimer cursor_movement_timer_;
+	uint32_t cursor_ms_;
+	bool cursor_movement_active_ = false;
 };
 
 }  // namespace UI
