@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 by the Widelands Development Team
+ * Copyright (C) 2020-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,10 +40,12 @@ enum class AddOnCategory {
 	kTribes,
 	kScript,
 	kMaps,
+	kMapGenerator,
 	kCampaign,
 	kWinCondition,
 	kStartingCondition,
-	kTheme
+	kTheme,
+	kUIPlugin,
 };
 
 // Note: Below you will see some lines like `std::function<std::string()> descname`.
@@ -56,6 +58,7 @@ struct AddOnCategoryInfo {
 	std::string internal_name;
 	std::function<std::string()> descname;
 	std::string icon;
+	bool network_relevant;
 };
 
 using AddOnVersion = std::vector<uint32_t>;
@@ -63,6 +66,9 @@ std::string version_to_string(const AddOnVersion&, bool localize = true);
 AddOnVersion string_to_version(std::string);
 // Returns true if and only if version `compare` is newer than version `base`
 bool is_newer_version(const AddOnVersion& base, const AddOnVersion& compare);
+bool matches_widelands_version(const std::string& min_wl_version,
+                               const std::string& max_wl_version,
+                               const std::string& warn_future_name = std::string());
 
 // Required add-ons for an add-on, map, or savegame with the recommended version
 using AddOnRequirements = std::vector<std::pair<std::string, AddOnVersion>>;
@@ -122,10 +128,14 @@ struct AddOnInfo {
 	uint32_t votes[kMaxRating] = {0};  ///< Total number of votes for each of the ratings 1-10.
 	std::map<size_t, AddOnComment> user_comments;
 
-	bool matches_widelands_version() const;
-	uint32_t number_of_votes() const;
-	double average_rating() const;
-	bool requires_texture_atlas_rebuild() const;
+	// Development builds (version 1.x~n) are treated as the next stable version (version 1.x)
+	// `warn_future` enables logging of the match in development versions if the addon requires
+	// the next stable version.
+	[[nodiscard]] bool matches_widelands_version(bool warn_future = false) const;
+
+	[[nodiscard]] uint32_t number_of_votes() const;
+	[[nodiscard]] double average_rating() const;
+	[[nodiscard]] bool requires_texture_atlas_rebuild() const;
 };
 
 using AddOnsList = std::vector<std::shared_ptr<AddOns::AddOnInfo>>;
@@ -141,6 +151,7 @@ inline static std::string theme_addon_template_dir(const std::string& name) {
 // Sorted list of all add-ons mapped to whether they are currently enabled
 using AddOnState = std::pair<std::shared_ptr<AddOnInfo>, bool>;
 extern std::vector<AddOnState> g_addons;
+const AddOnInfo* find_addon(const std::string& name);
 
 extern const std::unordered_map<std::string, std::string> kDifficultyIcons;
 extern const std::map<AddOnCategory, AddOnCategoryInfo> kAddOnCategories;
@@ -152,11 +163,14 @@ AddOnConflict check_requirements(const AddOnRequirements&);
 
 unsigned count_all_dependencies(const std::string&, const std::map<std::string, AddOnState>&);
 
+std::string list_game_relevant_addons();
+
 /**
  * If an add-on of type `base` requires an add-on of type `dependency`, this function
  * tells whether the dependency must necessarily be listed after the requiring add-on.
  */
 bool order_matters(AddOnCategory base, AddOnCategory dependency);
+bool require_enabled(AddOnCategory base, AddOnCategory dependency);
 
 std::shared_ptr<AddOnInfo> preload_addon(const std::string&);
 
