@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2022 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,11 +37,10 @@ template <typename CT> struct CookiePriorityQueueBase {
 	struct Cookie {
 		Cookie() : pos(bad_pos()) {
 		}
-		~Cookie() {
-		}
+		~Cookie() = default;
 
 		/** Returns \c true if the cookie is currently managed by a queue */
-		bool is_active() const {
+		[[nodiscard]] bool is_active() const {
 			return pos != bad_pos();
 		}
 
@@ -96,16 +95,16 @@ struct CookiePriorityQueue : CookiePriorityQueueBase<CPQType> {
 	                             const CookieAccessor& accessor = CookieAccessor());
 	~CookiePriorityQueue();
 
-	CookieSizeType size() const;
-	bool empty() const;
-	CookieType* top() const;
+	[[nodiscard]] CookieSizeType size() const;
+	[[nodiscard]] bool empty() const;
+	[[nodiscard]] CookieType* top() const;
 
 	void push(CookieType* elt);
 	void pop(CookieType* elt);
 	void decrease_key(CookieType* elt);
 	void increase_key(CookieType* elt);
 
-	Widelands::WareWorker type() const {
+	[[nodiscard]] Widelands::WareWorker type() const {
 		return type_;
 	}
 
@@ -154,8 +153,9 @@ CookiePriorityQueue<t_T, t_Cw, t_CA>::CookiePriorityQueue(
 
 template <typename t_T, typename t_Cw, typename t_CA>
 CookiePriorityQueue<t_T, t_Cw, t_CA>::~CookiePriorityQueue() {
-	for (typename CookieTypeVector::iterator it = d.begin(); it != d.end(); ++it)
+	for (typename CookieTypeVector::iterator it = d.begin(); it != d.end(); ++it) {
 		cookie_pos(ca(*it, type_)) = bad_pos();
+	}
 }
 
 template <typename t_T, typename t_Cw, typename t_CA>
@@ -207,8 +207,9 @@ void CookiePriorityQueue<t_T, t_Cw, t_CA>::pop(
 	d.pop_back();
 	cookie_pos(elt_cookie) = BaseType::bad_pos();
 
-	if (!d.empty())
+	if (!d.empty()) {
 		increase_key(*d.begin());
+	}
 }
 
 template <typename t_T, typename t_Cw, typename t_CA>
@@ -221,8 +222,9 @@ void CookiePriorityQueue<t_T, t_Cw, t_CA>::decrease_key(
 	while (cookie_pos(elt_cookie) != 0) {
 		CookieSizeType parent = parent_pos(cookie_pos(elt_cookie));
 
-		if (!c(*elt, *d[parent], type_))
+		if (!c(*elt, *d[parent], type_)) {
 			break;
+		}
 
 		Cookie& parent_cookie(ca(d[parent], type_));
 
@@ -247,8 +249,9 @@ void CookiePriorityQueue<t_T, t_Cw, t_CA>::increase_key(
 		CookieSizeType left_child = left_child_pos(cookie_pos(elt_cookie));
 		CookieSizeType right_child = right_child_pos(cookie_pos(elt_cookie));
 
-		if (left_child >= d.size())
+		if (left_child >= d.size()) {
 			break;
+		}
 
 		Cookie& left_cookie(ca(d[left_child], type_));
 
@@ -261,8 +264,9 @@ void CookiePriorityQueue<t_T, t_Cw, t_CA>::increase_key(
 			}
 		}
 
-		if (right_child >= d.size())
+		if (right_child >= d.size()) {
 			break;
+		}
 
 		Cookie& right_cookie(ca(d[right_child], type_));
 
