@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,10 +35,10 @@
 
 namespace UI {
 struct ProgressWindow;
-}
+}  // namespace UI
 namespace FsMenu {
 class LaunchGame;
-}
+}  // namespace FsMenu
 class InteractiveBase;
 class InteractiveGameBase;  // TODO(GunChleoc): Get rid
 
@@ -110,7 +110,7 @@ public:
 
 	// loading stuff
 	void load_all_tribes();
-	void allocate_player_maps();
+	void allocate_player_maps() const;
 	virtual void postload();
 	void postload_addons();
 	void postload_tribes();
@@ -127,6 +127,7 @@ public:
 	                                     bool show_game_tips,
 	                                     const std::string& theme,
 	                                     const std::string& background,
+	                                     bool crop,
 	                                     UI::Panel* parent = nullptr);
 
 	/// Set step text for the current loader UI if it's not nullptr.
@@ -141,7 +142,7 @@ public:
 	void remove_loader_ui();
 	UI::ProgressWindow* release_loader_ui();
 
-	void set_road(const FCoords&, uint8_t direction, RoadSegment roadtype);
+	void set_road(const FCoords&, uint8_t direction, RoadSegment roadtype) const;
 
 	// warping stuff. instantly creating map_objects
 	Building& warp_building(const Coords&,
@@ -169,7 +170,7 @@ public:
 	                                      const std::string& name,
 	                                      Player* owner,
 	                                      const BuildingDescr* former_building);
-	Bob& create_ship(const Coords&, const DescriptionIndex ship_type_idx, Player* owner = nullptr);
+	Bob& create_ship(const Coords&, DescriptionIndex ship_type_idx, Player* owner = nullptr);
 	Bob& create_ship(const Coords&, const std::string& name, Player* owner = nullptr);
 	Bob& create_worker(const Coords&, DescriptionIndex worker, Player* owner);
 
@@ -181,14 +182,14 @@ public:
 		return ibase_.get();
 	}
 
-	void inform_players_about_ownership(MapIndex, PlayerNumber);
-	void inform_players_about_immovable(MapIndex, MapObjectDescr const*);
+	void inform_players_about_ownership(MapIndex, PlayerNumber) const;
+	void inform_players_about_immovable(MapIndex, MapObjectDescr const*) const;
 	void inform_players_about_road(FCoords, MapObjectDescr const*);
 	void inform_players_about_waterway(FCoords, MapObjectDescr const*);
 
 	void unconquer_area(PlayerArea<Area<FCoords>>, PlayerNumber destroying_player = 0);
 	void conquer_area(PlayerArea<Area<FCoords>>, bool conquer_guarded_location = false);
-	void conquer_area_no_building(PlayerArea<Area<FCoords>> const);
+	void conquer_area_no_building(PlayerArea<Area<FCoords>>);
 
 	void cleanup_objects() {
 		objects().cleanup(*this);
@@ -199,7 +200,7 @@ public:
 	Time& get_gametime_pointer() {
 		return gametime_;
 	}
-	void set_ibase(InteractiveBase* const b);
+	void set_ibase(InteractiveBase* b);
 
 	/// Lua frontend, used to run Lua scripts
 	virtual LuaInterface& lua() {
@@ -229,8 +230,8 @@ public:
 	const AllTribes& all_tribes() const;
 
 protected:
-	bool did_postload_addons_;
-	bool did_postload_tribes_;
+	bool did_postload_addons_{false};
+	bool did_postload_tribes_{false};
 
 private:
 	/// Common function for create_critter and create_ship.
@@ -270,14 +271,14 @@ private:
 
 	// Changes the owner of 'fc' from the current player to the new player and
 	// sends notifications about this.
-	void change_field_owner(const FCoords& fc, PlayerNumber new_owner);
+	void change_field_owner(const FCoords& fc, PlayerNumber new_owner) const;
 
 	Immovable& do_create_immovable(const Coords& c,
-	                               DescriptionIndex const idx,
+	                               DescriptionIndex idx,
 	                               Player* owner,
 	                               const BuildingDescr* former_building_descr);
 
-	Time gametime_;
+	Time gametime_{0U};
 	ObjectManager objects_;
 
 	std::unique_ptr<LuaInterface> lua_;
