@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,6 +60,15 @@ BobDescr::BobDescr(const std::string& init_descname,
 	}
 }
 
+BobDescr::BobDescr(const std::string& init_name,
+                   const std::string& init_descname,
+                   const MapObjectType init_type,
+                   MapObjectDescr::OwnerType owner_type)
+   : MapObjectDescr(init_type, init_name, init_descname),
+     owner_type_(owner_type),
+     vision_range_(0) {
+}
+
 /**
  * Only tribe bobs (workers, ships) have a vision range, since it would be irrelevant
  * for world bobs (critters).
@@ -82,19 +91,7 @@ Bob& BobDescr::create(EditorGameBase& egbase, Player* const owner, const Coords&
 	return bob;
 }
 
-Bob::Bob(const BobDescr& init_descr)
-   : MapObject(&init_descr),
-     position_(FCoords(Coords(0, 0), nullptr)),  // not linked anywhere
-     linknext_(nullptr),
-     linkpprev_(nullptr),
-     anim_(0),
-     animstart_(0),
-     walking_(IDLE),
-     walkstart_(0),
-     walkend_(0),
-     actid_(0),
-     actscheduled_(false),
-     in_act_(false) {
+Bob::Bob(const BobDescr& init_descr) : MapObject(&init_descr) {
 }
 
 /**
@@ -497,17 +494,17 @@ struct CheckStepBlocked {
 	explicit CheckStepBlocked(BlockedTracker& tracker) : tracker_(tracker) {
 	}
 
-	bool allowed(const Map& /* map */,
-	             FCoords /* start */,
-	             FCoords end,
-	             int32_t /* dir */,
-	             CheckStep::StepId /* id */) const {
+	[[nodiscard]] bool allowed(const Map& /* map */,
+	                           FCoords /* start */,
+	                           FCoords end,
+	                           int32_t /* dir */,
+	                           CheckStep::StepId /* id */) const {
 		if (end == tracker_.finaldest_) {
 			return true;
 		}
 		return !tracker_.is_blocked(end);
 	}
-	bool reachable_dest(const Map& /* map */, FCoords /* pos */) const {
+	[[nodiscard]] bool reachable_dest(const Map& /* map */, FCoords /* pos */) const {
 		return true;
 	}
 
@@ -827,8 +824,10 @@ void Bob::draw(const EditorGameBase& egbase,
  * Set a looping animation, starting now.
  */
 void Bob::set_animation(const EditorGameBase& egbase, uint32_t const anim) {
-	anim_ = anim;
-	animstart_ = egbase.get_gametime();
+	if (anim_ != anim) {
+		anim_ = anim;
+		animstart_ = egbase.get_gametime();
+	}
 }
 
 /**
@@ -897,13 +896,19 @@ bool Bob::check_node_blocked(Game& game, const FCoords& field, bool /* commit */
  * This will update the owner's viewing area.
  */
 void Bob::set_owner(Player* const player) {
-	if ((owner_ != nullptr) && (position_.field != nullptr)) {
-		owner_.load()->unsee_area(Area<FCoords>(get_position(), descr().vision_range()));
+	Player* old_owner = owner_.load();
+
+	if (old_owner != nullptr && position_.field != nullptr) {
+		old_owner->unsee_area(Area<FCoords>(get_position(), descr().vision_range()));
 	}
+
 	owner_ = player;
-	if ((owner_ != nullptr) && (position_.field != nullptr)) {
-		owner_.load()->see_area(Area<FCoords>(get_position(), descr().vision_range()));
+
+	if (player != nullptr && position_.field != nullptr) {
+		player->see_area(Area<FCoords>(get_position(), descr().vision_range()));
 	}
+
+	owner_changed(old_owner, player);
 }
 
 /**
@@ -911,6 +916,8 @@ void Bob::set_owner(Player* const player) {
  *
  * Performs the necessary (un)linking in the \ref Field structures and
  * updates the owner's viewing area, if the bob has an owner.
+ *
+ * Overriding implementations must always call this function!
  */
 void Bob::set_position(EditorGameBase& egbase, const Coords& coords) {
 	FCoords oldposition = position_;
@@ -959,7 +966,7 @@ void Bob::log_general_info(const EditorGameBase& egbase) const {
 	FORMAT_WARNINGS_OFF
 	molog(egbase.get_gametime(), "Owner: %p\n", owner_.load());
 	FORMAT_WARNINGS_ON
-	molog(egbase.get_gametime(), "Postition: (%i, %i)\n", position_.x, position_.y);
+	molog(egbase.get_gametime(), "Position: (%i, %i)\n", position_.x, position_.y);
 	molog(egbase.get_gametime(), "ActID: %i\n", actid_);
 	molog(egbase.get_gametime(), "ActScheduled: %s\n", actscheduled_ ? "true" : "false");
 	molog(egbase.get_gametime(), "Animation: %s\n",
