@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,24 +40,23 @@ struct CheckStep {
 
 private:
 	struct BaseCapsule {
-		virtual ~BaseCapsule() {
-		}
-		virtual bool allowed(
+		virtual ~BaseCapsule() = default;
+		[[nodiscard]] virtual bool allowed(
 		   const Map&, const FCoords& start, const FCoords& end, int32_t dir, StepId id) const = 0;
-		virtual bool reachable_dest(const Map&, const FCoords& dest) const = 0;
+		[[nodiscard]] virtual bool reachable_dest(const Map&, const FCoords& dest) const = 0;
 	};
 	template <typename T> struct Capsule : public BaseCapsule {
-		Capsule(const T& init_op) : op(init_op) {
+		Capsule(const T& init_op) : op(init_op) {  // NOLINT allow implicit conversion
 		}
 
-		bool allowed(const Map& map,
-		             const FCoords& start,
-		             const FCoords& end,
-		             int32_t const dir,
-		             StepId const id) const override {
+		[[nodiscard]] bool allowed(const Map& map,
+		                           const FCoords& start,
+		                           const FCoords& end,
+		                           int32_t const dir,
+		                           StepId const id) const override {
 			return op.allowed(map, start, end, dir, id);
 		}
-		bool reachable_dest(const Map& map, const FCoords& dest) const override {
+		[[nodiscard]] bool reachable_dest(const Map& map, const FCoords& dest) const override {
 			return op.reachable_dest(map, dest);
 		}
 
@@ -71,18 +70,20 @@ private:
 public:
 	CheckStep();
 
-	template <typename T> CheckStep(const T& op) : capsule(new Capsule<T>(op)) {
+	template <typename T>
+	CheckStep(const T& op)  // NOLINT allow implicit conversion
+	   : capsule(new Capsule<T>(op)) {
 	}
 
 	/**
 	 * \return \c true true if moving from start to end (single step in the given
 	 * direction) is allowed.
 	 */
-	bool allowed(const Map& map,
-	             const FCoords& start,
-	             const FCoords& end,
-	             int32_t const dir,
-	             StepId const id) const {
+	[[nodiscard]] bool allowed(const Map& map,
+	                           const FCoords& start,
+	                           const FCoords& end,
+	                           int32_t const dir,
+	                           StepId const id) const {
 		return capsule->allowed(map, start, end, dir, id);
 	}
 
@@ -90,11 +91,24 @@ public:
 	 * \return \c true if the destination field can be reached at all
 	 * (e.g. return false for land-based bobs when dest is in water).
 	 */
-	bool reachable_dest(const Map& map, const FCoords& dest) const {
+	[[nodiscard]] bool reachable_dest(const Map& map, const FCoords& dest) const {
 		return capsule->reachable_dest(map, dest);
 	}
 };
 
+struct CheckStepAlwaysTrue {
+	[[nodiscard]] bool allowed(const Map& /* map */,
+	                           const FCoords& /* start */,
+	                           const FCoords& /* end */,
+	                           int32_t /* dir */,
+	                           CheckStep::StepId /* id */) const {
+		return true;
+	}
+	[[nodiscard]] bool reachable_dest(const Map& /* map */, const FCoords& /* dest */) const {
+		return true;
+	}
+};
+
 /**
  * CheckStep implementation that returns the logic and of all
  * sub-implementations that have been added via \ref add().
@@ -102,12 +116,12 @@ public:
 struct CheckStepAnd {
 	void add(const CheckStep& sub);
 
-	bool allowed(const Map&,
-	             const FCoords& start,
-	             const FCoords& end,
-	             int32_t dir,
-	             CheckStep::StepId id) const;
-	bool reachable_dest(const Map&, const FCoords& dest) const;
+	[[nodiscard]] bool allowed(const Map&,
+	                           const FCoords& start,
+	                           const FCoords& end,
+	                           int32_t dir,
+	                           CheckStep::StepId id) const;
+	[[nodiscard]] bool reachable_dest(const Map&, const FCoords& dest) const;
 
 private:
 	std::vector<CheckStep> subs;
@@ -124,9 +138,9 @@ struct CheckStepDefault {
 	explicit CheckStepDefault(uint8_t const movecaps) : movecaps_(movecaps) {
 	}
 
-	bool allowed(
+	[[nodiscard]] bool allowed(
 	   const Map&, const FCoords& start, const FCoords& end, int32_t dir, CheckStep::StepId) const;
-	bool reachable_dest(const Map&, const FCoords& dest) const;
+	[[nodiscard]] bool reachable_dest(const Map&, const FCoords& dest) const;
 
 private:
 	uint8_t movecaps_;
@@ -141,9 +155,9 @@ struct CheckStepFerry {
 	explicit CheckStepFerry(const EditorGameBase& egbase) : egbase_(egbase) {
 	}
 
-	bool allowed(
+	[[nodiscard]] bool allowed(
 	   const Map&, const FCoords& from, const FCoords& to, int32_t dir, CheckStep::StepId) const;
-	bool reachable_dest(const Map&, const FCoords& dest) const;
+	[[nodiscard]] bool reachable_dest(const Map&, const FCoords& dest) const;
 
 private:
 	const EditorGameBase& egbase_;
@@ -159,9 +173,9 @@ struct CheckStepWalkOn {
 	   : movecaps_(movecaps), onlyend_(onlyend) {
 	}
 
-	bool allowed(
+	[[nodiscard]] bool allowed(
 	   const Map&, const FCoords& start, const FCoords& end, int32_t dir, CheckStep::StepId) const;
-	bool reachable_dest(const Map&, FCoords dest) const;
+	[[nodiscard]] bool reachable_dest(const Map&, FCoords dest) const;
 
 private:
 	uint8_t movecaps_;
@@ -180,9 +194,9 @@ struct CheckStepRoad {
 	   : player_(player), movecaps_(movecaps) {
 	}
 
-	bool allowed(
+	[[nodiscard]] bool allowed(
 	   const Map&, const FCoords& start, const FCoords& end, int32_t dir, CheckStep::StepId) const;
-	bool reachable_dest(const Map&, const FCoords& dest) const;
+	[[nodiscard]] bool reachable_dest(const Map&, const FCoords& dest) const;
 
 private:
 	const Player& player_;
@@ -197,9 +211,9 @@ struct CheckStepLimited {
 	void add_allowed_location(const Coords& c) {
 		allowed_locations_.insert(c);
 	}
-	bool allowed(
+	[[nodiscard]] bool allowed(
 	   const Map&, const FCoords& start, const FCoords& end, int32_t dir, CheckStep::StepId) const;
-	bool reachable_dest(const Map&, FCoords dest) const;
+	[[nodiscard]] bool reachable_dest(const Map&, FCoords dest) const;
 
 private:
 	// The ordering of the set does not matter, as long as it is system
