@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -66,9 +66,7 @@ Descriptions::Descriptions(LuaInterface* lua, const AddOns::AddOnsList& addons)
      workers_(new DescriptionMaintainer<WorkerDescr>()),
      tribes_(new DescriptionMaintainer<TribeDescr>()),
      compatibility_table_(new PostOneWorldLegacyLookupTable()),
-     largest_workarea_(0),
-     scenario_tribes_(nullptr),
-     tribes_have_been_registered_(false),
+
      subscriber_(Notifications::subscribe<DescriptionManager::NoteMapObjectDescriptionTypeCheck>(
         [this](DescriptionManager::NoteMapObjectDescriptionTypeCheck note) { check(note); })),
      lua_(lua),
@@ -195,6 +193,9 @@ bool Descriptions::building_exists(const std::string& buildingname) const {
 bool Descriptions::building_exists(DescriptionIndex index) const {
 	return buildings_->get_mutable(index) != nullptr;
 }
+bool Descriptions::immovable_exists(const std::string& immoname) const {
+	return immovables_->exists(immoname) != nullptr;
+}
 bool Descriptions::immovable_exists(DescriptionIndex index) const {
 	return immovables_->get_mutable(index) != nullptr;
 }
@@ -207,6 +208,12 @@ bool Descriptions::tribe_exists(const std::string& tribename) const {
 bool Descriptions::tribe_exists(DescriptionIndex index) const {
 	return tribes_->get_mutable(index) != nullptr;
 }
+bool Descriptions::terrain_exists(const std::string& terrainname) const {
+	return terrains_->exists(terrainname) != nullptr;
+}
+bool Descriptions::terrain_exists(DescriptionIndex index) const {
+	return terrains_->get_mutable(index) != nullptr;
+}
 
 DescriptionIndex Descriptions::safe_building_index(const std::string& buildingname) const {
 	DescriptionIndex result = building_index(buildingname);
@@ -412,12 +419,6 @@ void Descriptions::add_object_description(const LuaTable& table, MapObjectType t
 	const std::string& type_name = table.get_string("name");
 	const std::string& type_descname = table.get_string("descname");
 
-	// TODO(GunChleoc): Compatibility, remove after v1.0
-	if (table.has_key<std::string>("msgctxt")) {
-		log_warn(
-		   "The 'msgctxt' entry is no longer needed in '%s', please remove it", type_name.c_str());
-	}
-
 	description_manager_->mark_loading_in_progress(type_name);
 
 	// Add
