@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,6 +19,8 @@
 #ifndef WL_LOGIC_MAP_OBJECTS_FINDIMMOVABLE_H
 #define WL_LOGIC_MAP_OBJECTS_FINDIMMOVABLE_H
 
+#include <vector>
+
 #include "logic/map_objects/map_object_type.h"
 
 namespace Widelands {
@@ -30,26 +32,25 @@ class Player;
 struct FindImmovable {
 private:
 	struct BaseCapsule {
-		BaseCapsule() : refcount(1) {
-		}
-		virtual ~BaseCapsule() {
-		}
+		BaseCapsule() = default;
+		virtual ~BaseCapsule() = default;
 
 		void addref() {
 			++refcount;
 		}
 		void deref() {
-			if (--refcount == 0)
+			if (--refcount == 0) {
 				delete this;
+			}
 		}
-		virtual bool accept(const BaseImmovable&) const = 0;
+		[[nodiscard]] virtual bool accept(const BaseImmovable&) const = 0;
 
-		int refcount;
+		int refcount{1};
 	};
 	template <typename T> struct Capsule : public BaseCapsule {
-		explicit Capsule(const T& init_op) : op(init_op) {
+		Capsule(const T& init_op) : op(init_op) {  // NOLINT allow implicit conversion
 		}
-		bool accept(const BaseImmovable& imm) const override {
+		[[nodiscard]] bool accept(const BaseImmovable& imm) const override {
 			return op.accept(imm);
 		}
 
@@ -59,7 +60,7 @@ private:
 	BaseCapsule* capsule;
 
 public:
-	explicit FindImmovable(const FindImmovable& o) {
+	FindImmovable(const FindImmovable& o) {
 		capsule = o.capsule;
 		capsule->addref();
 	}
@@ -68,18 +69,21 @@ public:
 		capsule = nullptr;
 	}
 	FindImmovable& operator=(const FindImmovable& o) {
+		if (&o == this) {
+			return *this;
+		}
 		capsule->deref();
 		capsule = o.capsule;
 		capsule->addref();
 		return *this;
 	}
 
-	template <typename T> FindImmovable(const T& op) {
+	template <typename T> FindImmovable(const T& op) {  // NOLINT allow implicit conversion
 		capsule = new Capsule<T>(op);
 	}
 
 	// Return true if this node should be returned by find_fields()
-	bool accept(const BaseImmovable& imm) const {
+	[[nodiscard]] bool accept(const BaseImmovable& imm) const {
 		return capsule->accept(imm);
 	}
 };
@@ -87,58 +91,88 @@ public:
 const FindImmovable& find_immovable_always_true();
 
 // FindImmovable functor
+struct FindImmovableAnd {
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
+
+	void add(FindImmovable f) {
+		functors_.emplace_back(f);
+	}
+
+private:
+	std::vector<FindImmovable> functors_;
+};
+
+struct FindImmovableOr {
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
+
+	void add(FindImmovable f) {
+		functors_.emplace_back(f);
+	}
+
+private:
+	std::vector<FindImmovable> functors_;
+};
+
 struct FindImmovableSize {
 	FindImmovableSize(int32_t const init_min, int32_t const init_max)
 	   : min(init_min), max(init_max) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
 private:
 	int32_t min, max;
 };
+
 struct FindImmovableType {
 	explicit FindImmovableType(MapObjectType const init_type) : type(init_type) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
 private:
 	MapObjectType type;
 };
+
 struct FindImmovableAttribute {
 	explicit FindImmovableAttribute(uint32_t const init_attrib) : attrib(init_attrib) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
 private:
 	int32_t attrib;
 };
-struct FindImmovablePlayerImmovable {
-	FindImmovablePlayerImmovable() {
-	}
 
-	bool accept(const BaseImmovable&) const;
+struct FindImmovablePlayerImmovable {
+	FindImmovablePlayerImmovable() = default;
+
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 };
+
 struct FindImmovablePlayerMilitarySite {
 	explicit FindImmovablePlayerMilitarySite(const Player& init_player) : player(init_player) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
+private:
 	const Player& player;
 };
-struct FindImmovableAttackTarget {
-	FindImmovableAttackTarget() {
-	}
 
-	bool accept(const BaseImmovable&) const;
+struct FindImmovableAttackTarget {
+	FindImmovableAttackTarget() = default;
+
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 };
+
 struct FindForeignMilitarysite {
 	explicit FindForeignMilitarysite(const Player& init_player) : player(init_player) {
 	}
-	bool accept(const BaseImmovable&) const;
+
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
+
+private:
 	const Player& player;
 };
 
@@ -146,19 +180,36 @@ struct FindImmovableByDescr {
 	explicit FindImmovableByDescr(const ImmovableDescr& init_descr) : descr(init_descr) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
+private:
 	const ImmovableDescr& descr;
 };
+
+struct FindImmovableNotReserved {
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
+};
+
 struct FindFlagOf {
 	explicit FindFlagOf(const FindImmovable& init_finder) : finder(init_finder) {
 	}
 
-	bool accept(const BaseImmovable&) const;
+	[[nodiscard]] bool accept(const BaseImmovable&) const;
 
+private:
 	const FindImmovable finder;
 };
 
+struct FindFlagWithPlayersWarehouse {
+	explicit FindFlagWithPlayersWarehouse(const Player& owner) : owner_(owner) {
+	}
+
+	[[nodiscard]] bool accept(const BaseImmovable& imm) const;
+
+private:
+	const Player& owner_;
+};
+
 }  // namespace Widelands
 
 #endif  // end of include guard: WL_LOGIC_MAP_OBJECTS_FINDIMMOVABLE_H
