@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,12 +19,15 @@
 #include "logic/map_objects/findnode.h"
 
 #include "base/wexception.h"
+#include "economy/ferry_fleet.h"
 #include "logic/editor_game_base.h"
 #include "logic/field.h"
 #include "logic/map.h"
+#include "logic/map_objects/checkstep.h"
 #include "logic/map_objects/descriptions.h"
 #include "logic/map_objects/immovable.h"
 #include "logic/map_objects/world/terrain_description.h"
+#include "logic/player.h"
 
 namespace Widelands {
 
@@ -37,12 +40,10 @@ void FindNodeAnd::add(const FindNode& findfield, bool const negate) {
 }
 
 bool FindNodeAnd::accept(const EditorGameBase& egbase, const FCoords& coord) const {
-	for (const Subfunctor& subfunctor : subfunctors) {
-		if (subfunctor.findfield.accept(egbase, coord) == subfunctor.negate) {
-			return false;
-		}
-	}
-	return true;
+	return std::all_of(
+	   subfunctors.begin(), subfunctors.end(), [&egbase, &coord](const Subfunctor& subfunctor) {
+		   return subfunctor.findfield.accept(egbase, coord) != subfunctor.negate;
+	   });
 }
 
 bool FindNodeCaps::accept(const EditorGameBase& /* egbase */, const FCoords& coord) const {
@@ -193,6 +194,25 @@ bool FindNodeResourceBreedable::accept(const EditorGameBase& egbase, const FCoor
 	return false;
 }
 
+bool FindNodeFerry::accept(const EditorGameBase& egbase, const FCoords& coords) const {
+	CheckStepFerry csf(egbase);
+	if (!csf.reachable_dest(egbase.map(), coords)) {
+		return false;
+	}
+	if (player_who_needs_ferry_ == 0) {
+		return true;
+	}
+
+	for (Bob* bob = coords.field->get_first_bob(); bob != nullptr; bob = bob->get_next_bob()) {
+		if (bob->descr().type() == MapObjectType::FERRY_FLEET_YARD_INTERFACE &&
+		    bob->owner().player_number() == player_who_needs_ferry_ &&
+		    dynamic_cast<FerryFleetYardInterface*>(bob)->get_fleet()->lacks_ferry()) {
+			return true;
+		}
+	}
+	return false;
+}
+
 bool FindNodeShore::accept(const EditorGameBase& egbase, const FCoords& coords) const {
 	if ((coords.field->nodecaps() & MOVECAPS_WALK) == 0) {
 		return false;
