@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -95,7 +95,8 @@ void BaseImmovable::set_position(EditorGameBase& egbase, const Coords& c) {
 
 	// Needed so players can update partially visible buildings' vision.
 	if (get_size() >= BIG) {
-		Notifications::publish(NoteFieldTerrainChanged{f, map->get_index(f)});
+		Notifications::publish(NoteFieldTerrainChanged{
+		   f, map->get_index(f), NoteFieldTerrainChanged::Change::kImmovable});
 	}
 }
 
@@ -121,7 +122,8 @@ void BaseImmovable::unset_position(EditorGameBase& egbase, const Coords& c) {
 
 	// Needed so players can update partially visible buildings' vision.
 	if (get_size() >= BIG) {
-		Notifications::publish(NoteFieldTerrainChanged{f, map->get_index(f)});
+		Notifications::publish(NoteFieldTerrainChanged{
+		   f, map->get_index(f), NoteFieldTerrainChanged::Change::kImmovable});
 	}
 
 	f.field->immovable = nullptr;
@@ -148,8 +150,7 @@ ImmovableDescr::ImmovableDescr(const std::string& init_descname,
                                const std::vector<std::string>& attribs,
                                Descriptions& descriptions)
    : MapObjectDescr(MapObjectType::IMMOVABLE, table.get_string("name"), init_descname, table),
-     descriptions_(descriptions),
-     size_(BaseImmovable::NONE) {
+     descriptions_(descriptions) {
 	if (!is_animation_known("idle")) {
 		throw GameDataError("Immovable %s has no idle animation", name().c_str());
 	}
@@ -204,22 +205,8 @@ ImmovableDescr::ImmovableDescr(const std::string& init_descname,
 			                    program_name.c_str(), name().c_str());
 		}
 		try {
-			// TODO(GunChleoc): Compatibility, remove after v1.0
-			if (program_name == "program") {
-				log_warn("The main program for the immovable %s should be renamed from 'program' "
-				         "to 'main'\n",
-				         name().c_str());
-				if (programs->keys<std::string>().count(MapObjectProgram::kMainProgram) != 0u) {
-					log_err("         This also clashes with an already existing 'main' program\n");
-				}
-				programs_[MapObjectProgram::kMainProgram] = new ImmovableProgram(
-				   MapObjectProgram::kMainProgram,
-				   programs->get_table(program_name)->array_entries<std::string>(), *this);
-			} else {
-				programs_[program_name] = new ImmovableProgram(
-				   program_name, programs->get_table(program_name)->array_entries<std::string>(),
-				   *this);
-			}
+			programs_[program_name] = new ImmovableProgram(
+			   program_name, programs->get_table(program_name)->array_entries<std::string>(), *this);
 		} catch (const std::exception& e) {
 			throw GameDataError("%s: Error in immovable program %s: %s", name().c_str(),
 			                    program_name.c_str(), e.what());
@@ -328,16 +315,7 @@ IMPLEMENTATION
 
 Immovable::Immovable(const ImmovableDescr& imm_descr,
                      const Widelands::BuildingDescr* former_building_descr)
-   : BaseImmovable(imm_descr),
-     former_building_descr_(former_building_descr),
-     anim_(0),
-     animstart_(0),
-     program_(nullptr),
-     program_ptr_(0),
-     anim_construction_total_(0),
-     anim_construction_done_(0),
-     program_step_(0),
-     growth_delay_(0) {
+   : BaseImmovable(imm_descr), former_building_descr_(former_building_descr) {
 }
 
 BaseImmovable::PositionList Immovable::get_positions(const EditorGameBase& /* egbase */) const {
@@ -732,7 +710,7 @@ MapObject::Loader* Immovable::load(EditorGameBase& egbase, MapObjectLoader& mol,
  *
  * If the immovable is not currently in construction mode, return \c false.
  */
-bool Immovable::construct_remaining_buildcost(Game& /* game */, Buildcost* buildcost) {
+bool Immovable::construct_remaining_buildcost(Buildcost* buildcost) {
 	ActConstructData* d = get_action_data<ActConstructData>();
 	if (d == nullptr) {
 		return false;
@@ -785,7 +763,7 @@ bool Immovable::construct_ware(Game& game, DescriptionIndex index) {
 	molog(game.get_gametime(), "construct_ware: total %u delivered: %u", index, d->delivered[index]);
 
 	Buildcost remaining;
-	construct_remaining_buildcost(game, &remaining);
+	construct_remaining_buildcost(&remaining);
 
 	const ImmovableProgram::ActConstruct* action =
 	   dynamic_cast<const ImmovableProgram::ActConstruct*>(&(*program_)[program_ptr_]);
@@ -812,8 +790,7 @@ PlayerImmovable IMPLEMENTATION
 /**
  * Zero-initialize
  */
-PlayerImmovable::PlayerImmovable(const MapObjectDescr& mo_descr)
-   : BaseImmovable(mo_descr), ware_economy_(nullptr), worker_economy_(nullptr) {
+PlayerImmovable::PlayerImmovable(const MapObjectDescr& mo_descr) : BaseImmovable(mo_descr) {
 }
 
 /**
