@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -129,39 +129,39 @@ public:
 	               Descriptions& descriptions);
 	~ImmovableDescr() override;
 
-	int32_t get_size() const {
+	[[nodiscard]] int32_t get_size() const {
 		return size_;
 	}
-	ImmovableProgram const* get_program(const std::string&) const;
+	[[nodiscard]] ImmovableProgram const* get_program(const std::string&) const;
 
 	Immovable& create(EditorGameBase&,
 	                  const Coords&,
 	                  const Widelands::BuildingDescr* former_building_descr) const;
 
-	const Buildcost& buildcost() const {
+	[[nodiscard]] const Buildcost& buildcost() const {
 		return buildcost_;
 	}
 
 	// A basic localized name for the immovable, used by trees
-	const std::string& species() const {
+	[[nodiscard]] const std::string& species() const {
 		return species_;
 	}
 
 	// Every immovable that can 'grow' needs to have terrain affinity defined,
 	// all others do not. Returns true if this one has it defined.
-	bool has_terrain_affinity() const;
+	[[nodiscard]] bool has_terrain_affinity() const;
 
 	// Returns the terrain affinity. If !has_terrain_affinity() this will return
 	// an undefined value.
-	const TerrainAffinity& terrain_affinity() const;
+	[[nodiscard]] const TerrainAffinity& terrain_affinity() const;
 
 	// Map object names that the immovable can transform/grow into
-	const std::set<std::pair<MapObjectType, std::string>>& becomes() const {
+	[[nodiscard]] const std::set<std::pair<MapObjectType, std::string>>& becomes() const {
 		return becomes_;
 	}
 
 	// A set of all productionsites that gather this immovable or any of its future types
-	const std::set<std::string> collected_by() const {
+	[[nodiscard]] const std::set<std::string> collected_by() const {
 		return collected_by_;
 	}
 	void add_collected_by(const Descriptions& descriptions,
@@ -173,7 +173,7 @@ public:
 
 protected:
 	Descriptions& descriptions_;
-	int32_t size_;
+	int32_t size_{BaseImmovable::NONE};
 	Programs programs_;
 
 	/// Buildcost for externally constructible immovables (for ship construction)
@@ -236,14 +236,16 @@ public:
 
 	void switch_program(Game& game, const std::string& program_name);
 	bool construct_ware(Game& game, DescriptionIndex index);
-	bool construct_remaining_buildcost(Game& game, Buildcost* buildcost);
+	bool construct_remaining_buildcost(Buildcost* buildcost);
 
 	void set_action_data(ImmovableActionData* data);
 	template <typename T> T* get_action_data() {
-		if (!action_data_)
+		if (action_data_ == nullptr) {
 			return nullptr;
-		if (T* data = dynamic_cast<T*>(action_data_.get()))
+		}
+		if (T* data = dynamic_cast<T*>(action_data_.get()); data != nullptr) {
 			return data;
+		}
 		set_action_data(nullptr);
 		return nullptr;
 	}
@@ -265,11 +267,11 @@ protected:
 
 	Coords position_;
 
-	std::atomic<uint32_t> anim_;
-	Time animstart_;
+	std::atomic<uint32_t> anim_{0U};
+	Time animstart_{0U};
 
-	const ImmovableProgram* program_;
-	uint32_t program_ptr_;  ///< index of next instruction to execute
+	const ImmovableProgram* program_{nullptr};
+	uint32_t program_ptr_{0U};  ///< index of next instruction to execute
 
 	// Whether a worker was told to remove this object ASAP.
 	// A set of all players who want this object gone.
@@ -284,15 +286,15 @@ protected:
  */
 #if (__GNUC__ == 4) && (__GNUC_MINOR__ == 0)
 public:
-	uint32_t anim_construction_total_;
-	uint32_t anim_construction_done_;
-	Time program_step_;
+	uint32_t anim_construction_total_{0U};
+	uint32_t anim_construction_done_{0U};
+	Time program_step_{0U};
 
 protected:
 #else
-	std::atomic<uint32_t> anim_construction_total_;
-	std::atomic<uint32_t> anim_construction_done_;
-	Time program_step_;  ///< time of next step
+	std::atomic<uint32_t> anim_construction_total_{0U};
+	std::atomic<uint32_t> anim_construction_done_{0U};
+	Time program_step_{0U};  ///< time of next step
 #endif
 
 	/**
@@ -303,7 +305,7 @@ protected:
 	std::unique_ptr<ImmovableActionData> action_data_;
 
 private:
-	Duration growth_delay_;
+	Duration growth_delay_{0U};
 
 	// Load/save support
 protected:
@@ -397,8 +399,8 @@ protected:
 	void cleanup(EditorGameBase&) override;
 
 private:
-	Economy* ware_economy_;
-	Economy* worker_economy_;
+	Economy* ware_economy_{nullptr};
+	Economy* worker_economy_{nullptr};
 
 	Workers workers_;
 
