@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,6 +37,14 @@ std::string to_string(const MapObjectType type) {
 		return "critter";
 	case MapObjectType::SHIP:
 		return "ship";
+	case MapObjectType::PINNED_NOTE:
+		return "pinned_note";
+	case MapObjectType::SHIP_FLEET_YARD_INTERFACE:
+		return "ship_fleet_yard_interface";
+	case MapObjectType::FERRY_FLEET_YARD_INTERFACE:
+		return "ferry_fleet_yard_interface";
+	case MapObjectType::NAVAL_INVASION_BASE:
+		return "naval_invasion_base";
 	case MapObjectType::WORKER:
 		return "worker";
 	case MapObjectType::CARRIER:
