@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,15 +39,7 @@ const BattleDescr& Battle::descr() const {
 	return g_battle_descr;
 }
 
-Battle::Battle()
-   : MapObject(&g_battle_descr),
-     first_(nullptr),
-     second_(nullptr),
-     creationtime_(0),
-     readyflags_(0),
-     damage_(0),
-     first_strikes_(true),
-     last_attack_hits_(false) {
+Battle::Battle() : MapObject(&g_battle_descr) {
 }
 
 Battle::Battle(Game& game, Soldier* first_soldier, Soldier* second_soldier)
