@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,11 +38,12 @@ namespace Widelands {
 class InputQueue;
 class Request;
 
+constexpr Duration kSoldierSwapTime(20000);
 constexpr float kBuildingSilhouetteOpacity = 0.3f;
 
 /* The value 'true' means that the DescriptionIndex is a normal building, as
  * happens e.g. when enhancing a building. The value 'false' means that the
- * DescriptionIndex refers to an immovable, as happens e.g. with amazon treetop sentry. This
+ * DescriptionIndex refers to an immovable, as happens e.g. with Amazon treetop sentry. This
  * immovable should therefore always be painted below the building image.
  */
 using FormerBuildings = std::vector<std::pair<DescriptionIndex, bool>>;
@@ -56,26 +57,25 @@ public:
 	              MapObjectType type,
 	              const LuaTable& t,
 	              Descriptions& descriptions);
-	~BuildingDescr() override {
-	}
+	~BuildingDescr() override = default;
 
-	bool is_buildable() const {
+	[[nodiscard]] bool is_buildable() const {
 		return buildable_;
 	}
-	bool can_be_dismantled() const {
+	[[nodiscard]] bool can_be_dismantled() const {
 		return can_be_dismantled_;
 	}
-	bool is_destructible() const {
+	[[nodiscard]] bool is_destructible() const {
 		return destructible_;
 	}
-	bool is_enhanced() const {
+	[[nodiscard]] bool is_enhanced() const {
 		return enhanced_building_;
 	}
 
 	/**
 	 * The build cost for direct construction
 	 */
-	const Buildcost& buildcost() const {
+	[[nodiscard]] const Buildcost& buildcost() const {
 		return buildcost_;
 	}
 	Buildcost& mutable_buildcost() {
@@ -85,7 +85,7 @@ public:
 	/**
 	 * Returned wares for dismantling
 	 */
-	const Buildcost& returns_on_dismantle() const {
+	[[nodiscard]] const Buildcost& returns_on_dismantle() const {
 		return returns_on_dismantle_;
 	}
 	Buildcost& mutable_returns_on_dismantle() {
@@ -95,7 +95,7 @@ public:
 	/**
 	 * The build cost for enhancing a previous building
 	 */
-	const Buildcost& enhancement_cost() const {
+	[[nodiscard]] const Buildcost& enhancement_cost() const {
 		return enhancement_cost_;
 	}
 	Buildcost& mutable_enhancement_cost() {
@@ -105,39 +105,39 @@ public:
 	/**
 	 * The returned wares for a enhaced building
 	 */
-	const Buildcost& enhancement_returns_on_dismantle() const {
+	[[nodiscard]] const Buildcost& enhancement_returns_on_dismantle() const {
 		return enhancement_returns_on_dismantle_;
 	}
 	Buildcost& mutable_enhancement_returns_on_dismantle() {
 		return enhancement_returns_on_dismantle_;
 	}
 
-	int32_t get_size() const {
+	[[nodiscard]] int32_t get_size() const {
 		return size_;
 	}
-	bool get_ismine() const {
+	[[nodiscard]] bool get_ismine() const {
 		return mine_;
 	}
-	bool get_isport() const {
+	[[nodiscard]] bool get_isport() const {
 		return port_;
 	}
-	bool needs_seafaring() const {
+	[[nodiscard]] bool needs_seafaring() const {
 		return needs_seafaring_;
 	}
-	bool needs_waterways() const {
+	[[nodiscard]] bool needs_waterways() const {
 		return needs_waterways_;
 	}
 
-	bool is_useful_on_map(bool seafaring_allowed, bool waterways_allowed) const;
+	[[nodiscard]] bool is_useful_on_map(bool seafaring_allowed, bool waterways_allowed) const;
 
 	// Returns the enhancement this building can become or
 	// INVALID_INDEX if it cannot be enhanced.
-	const DescriptionIndex& enhancement() const {
+	[[nodiscard]] const DescriptionIndex& enhancement() const {
 		return enhancement_;
 	}
 	// Returns the building from which this building can be enhanced or
 	// INVALID_INDEX if it cannot be built as an enhanced building.
-	const DescriptionIndex& enhanced_from() const {
+	[[nodiscard]] const DescriptionIndex& enhanced_from() const {
 		return enhanced_from_;
 	}
 	void set_enhanced_from(const DescriptionIndex& index) {
@@ -161,10 +161,10 @@ public:
 	                 bool loading = false,
 	                 const FormerBuildings& former_buildings = FormerBuildings()) const;
 
-	virtual uint32_t get_conquers() const;
-	virtual uint32_t vision_range() const;
+	[[nodiscard]] virtual uint32_t get_conquers() const;
+	[[nodiscard]] virtual uint32_t vision_range() const;
 
-	const WorkareaInfo& workarea_info() const {
+	[[nodiscard]] const WorkareaInfo& workarea_info() const {
 		return workarea_info_;
 	}
 
@@ -172,17 +172,17 @@ public:
 	// in many places.
 	WorkareaInfo workarea_info_;
 
-	bool suitability(const Map&, const FCoords&) const;
-	const AI::BuildingHints& hints() const;
+	[[nodiscard]] bool suitability(const Map&, const FCoords&) const;
+	[[nodiscard]] const AI::BuildingHints& hints() const;
 	void set_hints_trainingsites_max_percent(int percent);
 
-	uint32_t get_unoccupied_animation() const;
+	[[nodiscard]] uint32_t get_unoccupied_animation() const;
 
-	DescriptionIndex get_built_over_immovable() const {
+	[[nodiscard]] DescriptionIndex get_built_over_immovable() const {
 		return built_over_immovable_;
 	}
 
-	const std::string& get_owning_tribe() const {
+	[[nodiscard]] const std::string& get_owning_tribe() const {
 		return owning_tribe_;
 	}
 	void set_owning_tribe(const std::string&);
@@ -190,8 +190,8 @@ public:
 	void set_enhancement(Descriptions&, LuaTable&);
 
 protected:
-	virtual Building& create_object() const = 0;
-	Building& create_constructionsite() const;
+	[[nodiscard]] virtual Building& create_object() const = 0;
+	[[nodiscard]] Building& create_constructionsite() const;
 
 private:
 	void set_enhancement_cost(const Buildcost& enhance_cost, const Buildcost& return_enhanced);
@@ -205,24 +205,24 @@ private:
 	Buildcost enhancement_cost_;      // cost for enhancing
 	Buildcost
 	   enhancement_returns_on_dismantle_;  // Returned ware for dismantling an enhanced building
-	int32_t size_;                         // size of the building
-	bool mine_;
-	bool port_;
+	int32_t size_{BaseImmovable::SMALL};   // size of the building
+	bool mine_{false};
+	bool port_{false};
 	bool needs_seafaring_;  // This building should only be built on seafaring maps.
 	bool needs_waterways_;  // This building should only be built on maps with waterways/ferries
 	                        // enabled
-	DescriptionIndex enhancement_;
-	DescriptionIndex
-	   enhanced_from_;         // The building this building was enhanced from, or INVALID_INDEX
-	bool enhanced_building_;   // if it is one, it is bulldozable
-	AI::BuildingHints hints_;  // hints (knowledge) for computer players
+	DescriptionIndex enhancement_{INVALID_INDEX};
+	DescriptionIndex enhanced_from_{
+	   INVALID_INDEX};  // The building this building was enhanced from, or INVALID_INDEX
+	bool enhanced_building_{false};          // if it is one, it is bulldozable
+	AI::BuildingHints hints_;                // hints (knowledge) for computer players
 	DescriptionIndex built_over_immovable_;  // can be built only on nodes where an immovable with
 	                                         // this attribute stands
 
 	std::string owning_tribe_;
 
 	// for migration, 0 is the default, meaning get_conquers() + 4
-	uint32_t vision_range_;
+	uint32_t vision_range_{0U};
 	DISALLOW_COPY_AND_ASSIGN(BuildingDescr);
 };
 
@@ -253,7 +253,6 @@ public:
 		PCap_Enhancable = 1 << 2,  // can be enhanced to something
 	};
 
-public:
 	enum class InfoStringFormat { kCensus, kStatistics, kTooltip };
 
 	explicit Building(const BuildingDescr&);
@@ -360,8 +359,10 @@ public:
 		return soldier_control_;
 	}
 
+	virtual bool is_present(Worker& worker) const;
+
 	void send_message(Game& game,
-	                  const Message::Type msgtype,
+	                  Message::Type msgtype,
 	                  const std::string& title,
 	                  const std::string& icon_filename,
 	                  const std::string& heading,
@@ -415,37 +416,38 @@ protected:
 	void set_soldier_control(SoldierControl* new_soldier_control);
 
 	Coords position_;
-	Flag* flag_;
+	Flag* flag_{nullptr};
 
-	uint32_t anim_;
-	Time animstart_;
+	uint32_t anim_{0U};
+	Time animstart_{0U};
 
 	using LeaveQueue = std::vector<OPtr<Worker>>;
 	LeaveQueue leave_queue_;     //  FIFO queue of workers leaving the building
-	Time leave_time_;            //  when to wake the next one from leave queue
+	Time leave_time_{0U};        //  when to wake the next one from leave queue
 	ObjectPointer leave_allow_;  //  worker that is allowed to leave now
 
 	Time worker_evicted_;  // The time when a worker was last evicted by the player.
 
 	//  The player who has defeated this building.
-	PlayerNumber defeating_player_;
+	PlayerNumber defeating_player_{0U};
 
 	std::map<DescriptionIndex, WarePriority> ware_priorities_;
 
 	/// Whether we see our vision_range area based on workers in the building
-	bool seeing_;
+	bool seeing_{false};
 
 	// The former buildings names, with the current one in last position.
 	FormerBuildings old_buildings_;
-	const MapObjectDescr* was_immovable_;
+	const MapObjectDescr* was_immovable_{nullptr};
 
 private:
 	std::string statistics_string_;
-	AttackTarget* attack_target_;      // owned by the base classes, set by 'set_attack_target'.
-	SoldierControl* soldier_control_;  // owned by the base classes, set by 'set_soldier_control'.
+	AttackTarget* attack_target_{nullptr};  // owned by the base classes, set by 'set_attack_target'.
+	SoldierControl* soldier_control_{
+	   nullptr};  // owned by the base classes, set by 'set_soldier_control'.
 
-	bool mute_messages_;
-	bool is_destruction_blocked_;
+	bool mute_messages_{false};
+	bool is_destruction_blocked_{false};
 };
 }  // namespace Widelands
 
