@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ namespace Widelands {
 
 ProductionsiteSettings::ProductionsiteSettings(const ProductionSiteDescr& descr,
                                                const TribeDescr& tribe)
-   : BuildingSettings(descr.name(), tribe), stopped(false) {
+   : BuildingSettings(descr.name(), tribe) {
 	for (const auto& pair : descr.input_wares()) {
 		ware_queues.insert(std::make_pair(
 		   pair.first, InputQueueSetting{pair.second, pair.second, WarePriority::kNormal}));
@@ -47,7 +47,8 @@ MilitarysiteSettings::MilitarysiteSettings(const MilitarySiteDescr& descr, const
    : BuildingSettings(descr.name(), tribe),
      max_capacity(descr.get_max_number_of_soldiers()),
      desired_capacity(descr.get_max_number_of_soldiers()),
-     prefer_heroes(descr.prefers_heroes_at_start_) {
+     soldier_preference(descr.prefers_heroes_at_start_ ? SoldierPreference::kHeroes :
+                                                         SoldierPreference::kRookies) {
 }
 
 TrainingsiteSettings::TrainingsiteSettings(const TrainingSiteDescr& descr, const TribeDescr& tribe)
@@ -59,7 +60,7 @@ TrainingsiteSettings::TrainingsiteSettings(const TrainingSiteDescr& descr, const
 WarehouseSettings::WarehouseSettings(const WarehouseDescr& wh, const TribeDescr& tribe)
    : BuildingSettings(wh.name(), tribe),
      launch_expedition_allowed(wh.get_isport()),
-     launch_expedition(false) {
+     max_garrison(wh.get_max_garrison()) {
 	for (const DescriptionIndex di : tribe.wares()) {
 		ware_preferences.emplace(di, StockPolicy::kNormal);
 	}
@@ -115,7 +116,7 @@ void MilitarysiteSettings::apply(const BuildingSettings& bs) {
 	if (upcast(const MilitarysiteSettings, s, &bs)) {
 		desired_capacity =
 		   new_desired_capacity(s->max_capacity, s->desired_capacity, desired_capacity);
-		prefer_heroes = s->prefer_heroes;
+		soldier_preference = s->soldier_preference;
 	}
 }
 
@@ -135,16 +136,27 @@ void WarehouseSettings::apply(const BuildingSettings& bs) {
 			}
 		}
 		launch_expedition = launch_expedition_allowed && s->launch_expedition;
+		desired_capacity =
+		   new_desired_capacity(s->max_garrison, s->desired_capacity, desired_capacity);
+		soldier_preference = s->soldier_preference;
 	}
 }
 
 // Saveloading
 
+/* Versions changelogs:
+ * Global: 2: v1.1
+ * Militarysite: 1: v1.1
+ * Productionsite: 2: v1.1
+ * Trainingsite: 1: v1.1
+ * Warehouse: 2: v1.1
+ *   - 3: Added soldier preference and capacity
+ */
 constexpr uint8_t kCurrentPacketVersion = 2;
 constexpr uint8_t kCurrentPacketVersionMilitarysite = 1;
 constexpr uint8_t kCurrentPacketVersionProductionsite = 2;
 constexpr uint8_t kCurrentPacketVersionTrainingsite = 1;
-constexpr uint8_t kCurrentPacketVersionWarehouse = 2;
+constexpr uint8_t kCurrentPacketVersionWarehouse = 3;
 
 // static
 BuildingSettings* BuildingSettings::load(const Game& game, const TribeDescr& tribe, FileRead& fr) {
@@ -204,7 +216,7 @@ void MilitarysiteSettings::read(const Game& game, FileRead& fr) {
 		const uint8_t packet_version = fr.unsigned_8();
 		if (packet_version == kCurrentPacketVersionMilitarysite) {
 			desired_capacity = fr.unsigned_32();
-			prefer_heroes = (fr.unsigned_8() != 0u);
+			soldier_preference = static_cast<SoldierPreference>(fr.unsigned_8());
 		} else {
 			throw UnhandledVersionError(
 			   "MilitarysiteSettings", packet_version, kCurrentPacketVersionMilitarysite);
@@ -219,7 +231,7 @@ void MilitarysiteSettings::save(const Game& game, FileWrite& fw) const {
 	fw.unsigned_8(kCurrentPacketVersionMilitarysite);
 
 	fw.unsigned_32(desired_capacity);
-	fw.unsigned_8(prefer_heroes ? 1 : 0);
+	fw.unsigned_8(static_cast<uint8_t>(soldier_preference));
 }
 
 void ProductionsiteSettings::read(const Game& game, FileRead& fr) {
@@ -311,8 +323,13 @@ void WarehouseSettings::read(const Game& game, FileRead& fr) {
 	BuildingSettings::read(game, fr);
 	try {
 		const uint8_t packet_version = fr.unsigned_8();
-		if (packet_version == kCurrentPacketVersionWarehouse) {
+		if (packet_version >= 2 && packet_version <= kCurrentPacketVersionWarehouse) {
 			launch_expedition = (fr.unsigned_8() != 0u);
+			// TODO(Nordfriese): Savegame compatibility v1.1
+			if (packet_version >= 3) {
+				desired_capacity = fr.unsigned_32();
+				soldier_preference = static_cast<SoldierPreference>(fr.unsigned_8());
+			}
 			const uint32_t nr_wares = fr.unsigned_32();
 			const uint32_t nr_workers = fr.unsigned_32();
 			for (uint32_t i = 0; i < nr_wares; ++i) {
@@ -345,6 +362,9 @@ void WarehouseSettings::save(const Game& game, FileWrite& fw) const {
 	fw.unsigned_8(kCurrentPacketVersionWarehouse);
 
 	fw.unsigned_8(launch_expedition ? 1 : 0);
+	fw.unsigned_32(desired_capacity);
+	fw.unsigned_8(static_cast<uint8_t>(soldier_preference));
+
 	fw.unsigned_32(ware_preferences.size());
 	fw.unsigned_32(worker_preferences.size());
 	for (const auto& pair : ware_preferences) {
