@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,13 +33,12 @@ struct Coords;
 class FerryDescr : public CarrierDescr {
 public:
 	FerryDescr(const std::string& init_descname, const LuaTable& table, Descriptions& descriptions);
-	~FerryDescr() override {
-	}
+	~FerryDescr() override = default;
 
-	uint32_t movecaps() const override;
+	[[nodiscard]] uint32_t movecaps() const override;
 
 protected:
-	Bob& create_object() const override;
+	[[nodiscard]] Bob& create_object() const override;
 
 private:
 	DISALLOW_COPY_AND_ASSIGN(FerryDescr);
@@ -55,8 +54,7 @@ struct Ferry : public Carrier {
 	MO_DESCR(FerryDescr)
 
 	explicit Ferry(const FerryDescr& ferry_descr);
-	~Ferry() override {
-	}
+	~Ferry() override = default;
 
 	bool init(EditorGameBase&) override;
 	void set_economy(Game&, Economy*, WareWorker);
@@ -74,7 +72,7 @@ struct Ferry : public Carrier {
 
 private:
 	friend struct FerryFleet;
-	FerryFleet* fleet_;
+	FerryFleet* fleet_{nullptr};
 
 	std::unique_ptr<Coords> destination_;
 
@@ -86,15 +84,14 @@ private:
 	void unemployed_update(Game&, State&);
 	void row_update(Game&, State&);
 
-	Time unemployed_since_;
+	Time unemployed_since_{0U};
 
 protected:
 	void cleanup(EditorGameBase&) override;
 
 	struct Loader : public Carrier::Loader {
 	public:
-		Loader() {
-		}
+		Loader() = default;
 		void load(FileRead&) override;
 
 	protected:
