@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,43 +22,35 @@
 #include <memory>
 
 #include "base/macros.h"
-#include "economy/request.h"
+#include "economy/soldier_request.h"
 #include "logic/map_objects/tribes/building.h"
-#include "logic/map_objects/tribes/requirements.h"
 #include "logic/map_objects/tribes/soldiercontrol.h"
 #include "scripting/lua_table.h"
 
 namespace Widelands {
 
-// I assume elsewhere, that enum SoldierPreference fits to uint8_t.
-enum class SoldierPreference : uint8_t {
-	kRookies,
-	kHeroes,
-};
-
 class MilitarySiteDescr : public BuildingDescr {
 public:
 	MilitarySiteDescr(const std::string& init_descname,
 	                  const LuaTable& t,
 	                  Descriptions& descriptions);
-	~MilitarySiteDescr() override {
-	}
+	~MilitarySiteDescr() override = default;
 
-	Building& create_object() const override;
+	[[nodiscard]] Building& create_object() const override;
 
-	uint32_t get_conquers() const override {
+	[[nodiscard]] uint32_t get_conquers() const override {
 		return conquer_radius_;
 	}
 	void set_conquers(uint32_t c) {
 		conquer_radius_ = c;
 	}
-	Quantity get_max_number_of_soldiers() const {
+	[[nodiscard]] Quantity get_max_number_of_soldiers() const {
 		return num_soldiers_;
 	}
 	void set_max_number_of_soldiers(Quantity q) {
 		num_soldiers_ = q;
 	}
-	uint32_t get_heal_per_second() const {
+	[[nodiscard]] uint32_t get_heal_per_second() const {
 		return heal_per_second_;
 	}
 	void set_heal_per_second(uint32_t h) {
@@ -73,9 +65,9 @@ public:
 	std::string defeated_you_str_;
 
 private:
-	uint32_t conquer_radius_;
-	Quantity num_soldiers_;
-	uint32_t heal_per_second_;
+	uint32_t conquer_radius_{0U};
+	Quantity num_soldiers_{0U};
+	uint32_t heal_per_second_{0U};
 	DISALLOW_COPY_AND_ASSIGN(MilitarySiteDescr);
 };
 
@@ -99,20 +91,13 @@ public:
 	/// target building.
 	void send_attacker(Soldier&, Building&);
 
-	/// This methods are helper for use at configure this site.
-	void set_requirements(const Requirements&);
-	void clear_requirements();
-	const Requirements& get_requirements() const {
-		return soldier_requirements_;
-	}
-
 	void reinit_after_conqueration(Game&);
 
 	void update_soldier_request(bool i = false);
 
 	void set_soldier_preference(SoldierPreference);
-	SoldierPreference get_soldier_preference() const {
-		return soldier_preference_;
+	[[nodiscard]] SoldierPreference get_soldier_preference() const {
+		return soldier_request_.get_preference();
 	}
 
 	std::unique_ptr<const BuildingSettings> create_building_settings() const override;
@@ -123,7 +108,6 @@ protected:
 private:
 	void update_statistics_string(std::string*) override;
 
-	bool is_present(Soldier&) const;
 	static void
 	request_soldier_callback(Game&, Request&, DescriptionIndex, Worker*, PlayerImmovable&);
 
@@ -131,14 +115,10 @@ private:
 	bool has_soldier_job(Soldier&);
 	bool military_presence_kept(Game&);
 	void notify_player(Game&, bool discovered = false);
-	bool update_upgrade_requirements();
-	void update_normal_soldier_request();
-	void update_upgrade_soldier_request();
 	bool incorporate_upgraded_soldier(EditorGameBase& egbase, Soldier& s);
 	Soldier* find_least_suited_soldier();
 	bool drop_least_suited_soldier(bool new_soldier_has_arrived, Soldier* newguy);
 
-private:
 	// We can be attacked if we have stationed soldiers.
 	class AttackTarget : public Widelands::AttackTarget {
 	public:
@@ -168,11 +148,12 @@ private:
 		explicit SoldierControl(MilitarySite* military_site) : military_site_(military_site) {
 		}
 
-		std::vector<Soldier*> present_soldiers() const override;
-		std::vector<Soldier*> stationed_soldiers() const override;
-		Quantity min_soldier_capacity() const override;
-		Quantity max_soldier_capacity() const override;
-		Quantity soldier_capacity() const override;
+		[[nodiscard]] std::vector<Soldier*> present_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> stationed_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> associated_soldiers() const override;
+		[[nodiscard]] Quantity min_soldier_capacity() const override;
+		[[nodiscard]] Quantity max_soldier_capacity() const override;
+		[[nodiscard]] Quantity soldier_capacity() const override;
 		void set_soldier_capacity(Quantity capacity) override;
 		void drop_soldier(Soldier&) override;
 		int incorporate_soldier(EditorGameBase& egbase, Soldier& s) override;
@@ -183,17 +164,13 @@ private:
 
 	AttackTarget attack_target_;
 	SoldierControl soldier_control_;
-	Requirements soldier_requirements_;  // This is used to grab a bunch of soldiers: Anything goes
-	RequireAttribute soldier_upgrade_requirements_;     // This is used when exchanging soldiers.
-	std::unique_ptr<Request> normal_soldier_request_;   // filling the site
-	std::unique_ptr<Request> upgrade_soldier_request_;  // seeking for better soldiers
-	bool didconquer_;
+	bool didconquer_{false};
 	Quantity capacity_;
 
 	/**
 	 * Next gametime where we should heal something.
 	 */
-	Time nexthealtime_;
+	Time nexthealtime_{0U};
 
 	struct SoldierJob {
 		Soldier* soldier;
@@ -201,11 +178,12 @@ private:
 		bool stayhome;
 	};
 	std::vector<SoldierJob> soldierjobs_;
-	SoldierPreference soldier_preference_;
-	Time next_swap_soldiers_time_;
-	bool soldier_upgrade_try_;  // optimization -- if everybody is zero-level, do not downgrade
-	bool doing_upgrade_request_;
-	std::vector<std::map<std::tuple<int, int, int>, std::string>> statistics_string_cache_;
+	Time next_swap_soldiers_time_{0U};
+	SoldierRequest soldier_request_;
+
+	static constexpr size_t kNoOfStatisticsStringCases = 4U;
+	std::vector<std::map<std::tuple<int, int, int>, std::string>> statistics_string_cache_{
+	   kNoOfStatisticsStringCases};
 };
 }  // namespace Widelands
 
