@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -86,9 +86,9 @@ private:
 	virtual const Duration& build_step_time() const = 0;
 
 protected:
-	const BuildingDescr* building_;  // type of building that was or will become
+	const BuildingDescr* building_{nullptr};  // type of building that was or will become
 
-	Request* builder_request_;
+	Request* builder_request_{nullptr};
 	OPtr<Worker> builder_;
 
 	using Wares = std::vector<WaresQueue*>;
@@ -96,10 +96,10 @@ protected:
 	                       // (dismantlesites)
 	Wares dropout_wares_;  // additional items to drop out immediately
 
-	bool working_;             // true if the builder is currently working
-	Time work_steptime_;       // time when next step is completed
-	uint32_t work_completed_;  // how many steps have we done so far?
-	uint32_t work_steps_;      // how many steps (= wares) until we're done?
+	bool working_{false};          // true if the builder is currently working
+	Time work_steptime_{0U};       // time when next step is completed
+	uint32_t work_completed_{0U};  // how many steps have we done so far?
+	uint32_t work_steps_{0U};      // how many steps (= wares) until we're done?
 };
 }  // namespace Widelands
 
