@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,13 +48,12 @@ struct ProductionProgram : public MapObjectProgram {
 	/// Can be executed on a ProductionSite.
 	struct Action {
 		struct TrainingParameters {
-			TrainingParameters() : attribute(TrainingAttribute::kTotal), level(INVALID_INDEX) {
-			}
-			static TrainingParameters parse(const std::vector<std::string>& arguments,
-			                                const std::string& action_name);
+			TrainingParameters() = default;
+			TrainingParameters(const std::vector<std::string>& arguments,
+			                   const std::string& action_name);
 
-			TrainingAttribute attribute;
-			unsigned level;
+			TrainingAttribute attribute{TrainingAttribute::kTotal};
+			unsigned level{INVALID_INDEX};
 		};
 
 		Action() = default;
@@ -76,13 +75,13 @@ struct ProductionProgram : public MapObjectProgram {
 		 */
 		virtual void building_work_failed(Game&, ProductionSite&, Worker&) const;
 
-		const Groups& consumed_wares_workers() const {
+		[[nodiscard]] const Groups& consumed_wares_workers() const {
 			return consumed_wares_workers_;
 		}
-		const BillOfMaterials& produced_wares() const {
+		[[nodiscard]] const BillOfMaterials& produced_wares() const {
 			return produced_wares_;
 		}
-		const BillOfMaterials& recruited_workers() const {
+		[[nodiscard]] const BillOfMaterials& recruited_workers() const {
 			return recruited_workers_;
 		}
 
@@ -158,35 +157,35 @@ struct ProductionProgram : public MapObjectProgram {
 	/// is implicitly set to Completed.
 	struct ActReturn : public Action {
 		ActReturn(const std::vector<std::string>& arguments,
-		          const ProductionSiteDescr&,
+		          ProductionSiteDescr&,
 		          const Descriptions& descriptions);
 		~ActReturn() override;
 		void execute(Game&, ProductionSite&) const override;
 
 		struct Condition {
 			virtual ~Condition() = default;
-			virtual bool evaluate(const ProductionSite&) const = 0;
-			virtual std::string description(const Descriptions&) const = 0;
-			virtual std::string description_negation(const Descriptions&) const = 0;
+			[[nodiscard]] virtual bool evaluate(const ProductionSite&) const = 0;
+			[[nodiscard]] virtual std::string description(const Descriptions&) const = 0;
+			[[nodiscard]] virtual std::string description_negation(const Descriptions&) const = 0;
 		};
 		static Condition* create_condition(const std::vector<std::string>& arguments,
 		                                   std::vector<std::string>::const_iterator& begin,
 		                                   std::vector<std::string>::const_iterator& end,
-		                                   const ProductionSiteDescr&,
+		                                   ProductionSiteDescr&,
 		                                   const Descriptions& descriptions);
 
 		struct Negation : public Condition {
 			Negation(const std::vector<std::string>& arguments,
 			         std::vector<std::string>::const_iterator& begin,
 			         std::vector<std::string>::const_iterator& end,
-			         const ProductionSiteDescr& descr,
+			         ProductionSiteDescr& descr,
 			         const Descriptions& descriptions);
 			~Negation() override;
-			bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
 			// Just a dummy to satisfy the superclass interface. Do not use.
-			std::string description(const Descriptions&) const override;
+			[[nodiscard]] std::string description(const Descriptions&) const override;
 			// Just a dummy to satisfy the superclass interface. Do not use.
-			std::string description_negation(const Descriptions&) const override;
+			[[nodiscard]] std::string description_negation(const Descriptions&) const override;
 
 		private:
 			Condition* const operand;
@@ -196,9 +195,10 @@ struct ProductionProgram : public MapObjectProgram {
 		struct EconomyNeedsWare : public Condition {
 			explicit EconomyNeedsWare(const DescriptionIndex& i) : ware_type(i) {
 			}
-			bool evaluate(const ProductionSite&) const override;
-			std::string description(const Descriptions& descriptions) const override;
-			std::string description_negation(const Descriptions& descriptions) const override;
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] std::string description(const Descriptions& descriptions) const override;
+			[[nodiscard]] std::string
+			description_negation(const Descriptions& descriptions) const override;
 
 		private:
 			DescriptionIndex ware_type;
@@ -208,9 +208,10 @@ struct ProductionProgram : public MapObjectProgram {
 		struct EconomyNeedsWorker : public Condition {
 			explicit EconomyNeedsWorker(const DescriptionIndex& i) : worker_type(i) {
 			}
-			bool evaluate(const ProductionSite&) const override;
-			std::string description(const Descriptions& descriptions) const override;
-			std::string description_negation(const Descriptions& descriptions) const override;
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] std::string description(const Descriptions& descriptions) const override;
+			[[nodiscard]] std::string
+			description_negation(const Descriptions& descriptions) const override;
 
 		private:
 			DescriptionIndex worker_type;
@@ -224,9 +225,10 @@ struct ProductionProgram : public MapObjectProgram {
 			        std::vector<std::string>::const_iterator end,
 			        const ProductionSiteDescr& descr,
 			        const Descriptions& descriptions);
-			bool evaluate(const ProductionSite&) const override;
-			std::string description(const Descriptions& descriptions) const override;
-			std::string description_negation(const Descriptions& descriptions) const override;
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] std::string description(const Descriptions& descriptions) const override;
+			[[nodiscard]] std::string
+			description_negation(const Descriptions& descriptions) const override;
 
 		private:
 			WareTypeGroup group;
@@ -235,9 +237,23 @@ struct ProductionProgram : public MapObjectProgram {
 		/// Tests whether any of the workers at the site needs experience to
 		/// become upgraded.
 		struct WorkersNeedExperience : public Condition {
-			bool evaluate(const ProductionSite&) const override;
-			std::string description(const Descriptions&) const override;
-			std::string description_negation(const Descriptions&) const override;
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] std::string description(const Descriptions&) const override;
+			[[nodiscard]] std::string description_negation(const Descriptions&) const override;
+		};
+
+		/// Tests whether a nearby fleet needs a ship or ferry.
+		struct FleetNeeds : public Condition {
+			enum class Type { kShip, kFerry };
+			explicit FleetNeeds(Type t) : type_(t) {
+			}
+
+			[[nodiscard]] bool evaluate(const ProductionSite&) const override;
+			[[nodiscard]] std::string description(const Descriptions&) const override;
+			[[nodiscard]] std::string description_negation(const Descriptions&) const override;
+
+		private:
+			Type type_;
 		};
 
 		using Conditions = std::vector<Condition*>;
@@ -282,7 +298,7 @@ struct ProductionProgram : public MapObjectProgram {
 		explicit ActCall(const std::vector<std::string>& arguments);
 		void execute(Game&, ProductionSite&) const override;
 
-		const std::string& program_name() const {
+		[[nodiscard]] const std::string& program_name() const {
 			return program_name_;
 		}
 
@@ -306,13 +322,13 @@ struct ProductionProgram : public MapObjectProgram {
 		void execute(Game&, ProductionSite&) const override;
 		bool get_building_work(Game&, ProductionSite&, Worker&) const override;
 		void building_work_failed(Game&, ProductionSite&, Worker&) const override;
-		const std::string& program() const {
+		[[nodiscard]] const std::string& program() const {
 			return program_;
 		}
 
 	private:
 		std::string program_;
-		ProgramResult on_failure_;
+		ProgramResult on_failure_{ProgramResult::kFailed};
 	};
 
 	/// Does nothing.
@@ -326,8 +342,7 @@ struct ProductionProgram : public MapObjectProgram {
 	///
 	/// Blocks the execution of the program for the specified duration.
 	struct ActSleep : public Action {
-		explicit ActSleep(const std::vector<std::string>& arguments,
-		                  const ProductionSiteDescr& psite);
+		explicit ActSleep(const std::vector<std::string>& arguments);
 		void execute(Game&, ProductionSite&) const override;
 
 	private:
@@ -462,12 +477,12 @@ struct ProductionProgram : public MapObjectProgram {
 		void execute(Game&, ProductionSite&) const override;
 
 	private:
-		DescriptionIndex resource_;
-		uint8_t workarea_;            // width/radius of mine
-		unsigned max_resources_;      // Can work up to this percent (of total mountain resources)
-		unsigned depleted_chance_;    // odds of finding resources from empty mine
-		unsigned experience_chance_;  // probability of training in _empty_ mines
-		bool notify_on_failure_;      // Send a message if no resources could be found.
+		DescriptionIndex resource_{INVALID_INDEX};
+		uint8_t workarea_;              // width/radius of mine
+		unsigned max_resources_;        // Can work up to this percent (of total mountain resources)
+		unsigned depleted_chance_;      // odds of finding resources from empty mine
+		unsigned experience_chance_;    // probability of training in _empty_ mines
+		bool notify_on_failure_{true};  // Send a message if no resources could be found.
 	};
 
 	struct ActCheckSoldier : public Action {
@@ -475,7 +490,7 @@ struct ProductionProgram : public MapObjectProgram {
 		                         const ProductionSiteDescr& descr);
 		void execute(Game&, ProductionSite& ps) const override;
 
-		TrainingParameters training() const {
+		[[nodiscard]] TrainingParameters training() const {
 			return training_;
 		}
 
@@ -488,7 +503,7 @@ struct ProductionProgram : public MapObjectProgram {
 		                  const ProductionSiteDescr& descr);
 		void execute(Game&, ProductionSite& ps) const override;
 
-		TrainingParameters training() const {
+		[[nodiscard]] TrainingParameters training() const {
 			return training_;
 		}
 
@@ -511,8 +526,7 @@ struct ProductionProgram : public MapObjectProgram {
 	/// Plays the specified sound effect with the specified priority. Whether the
 	/// sound effect is actually played is determined by the sound handler.
 	struct ActPlaySound : public Action {
-		explicit ActPlaySound(const std::vector<std::string>& arguments,
-		                      const ProductionSiteDescr& descr);
+		explicit ActPlaySound(const std::vector<std::string>& arguments);
 		void execute(Game&, ProductionSite&) const override;
 
 	private:
@@ -540,7 +554,8 @@ struct ProductionProgram : public MapObjectProgram {
 		bool get_building_work(Game&, ProductionSite&, Worker&) const override;
 		void building_work_failed(Game&, ProductionSite&, Worker&) const override;
 
-		const ImmovableDescr& get_construction_descr(const Descriptions& descriptions) const;
+		[[nodiscard]] const ImmovableDescr&
+		get_construction_descr(const Descriptions& descriptions) const;
 
 	private:
 		std::string objectname;
@@ -553,14 +568,23 @@ struct ProductionProgram : public MapObjectProgram {
 	                  Descriptions& descriptions,
 	                  ProductionSiteDescr* building);
 
-	const std::string& descname() const;
+	[[nodiscard]] const std::string& descname() const;
 
-	size_t size() const;
-	const ProductionProgram::Action& operator[](size_t const idx) const;
+	[[nodiscard]] size_t size() const;
+	const ProductionProgram::Action& operator[](size_t idx) const;
 
-	const ProductionProgram::Groups& consumed_wares_workers() const;
-	const Buildcost& produced_wares() const;
-	const Buildcost& recruited_workers() const;
+	[[nodiscard]] const ProductionProgram::Groups& consumed_wares_workers() const;
+	[[nodiscard]] const Buildcost& produced_wares() const;
+	[[nodiscard]] const Buildcost& recruited_workers() const;
+	[[nodiscard]] const std::string& trained_attribute() const {
+		return trained_attribute_;
+	}
+	[[nodiscard]] uint8_t train_from_level() const {
+		return train_from_level_;
+	}
+	[[nodiscard]] uint8_t train_to_level() const {
+		return train_to_level_;
+	}
 	// Throws a GameDataError if we're trying to call an unknown program
 	void validate_calls(const ProductionSiteDescr& descr) const;
 
@@ -570,6 +594,9 @@ private:
 	ProductionProgram::Groups consumed_wares_workers_;
 	Buildcost produced_wares_;
 	Buildcost recruited_workers_;
+	std::string trained_attribute_;
+	uint8_t train_from_level_;
+	uint8_t train_to_level_;
 };
 }  // namespace Widelands
 
