@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,124 +35,82 @@ public:
 	TrainingSiteDescr(const std::string& init_descname,
 	                  const LuaTable& table,
 	                  Descriptions& descriptions);
-	~TrainingSiteDescr() override {
-	}
+	~TrainingSiteDescr() override = default;
 
-	Building& create_object() const override;
+	[[nodiscard]] Building& create_object() const override;
 
-	Quantity get_max_number_of_soldiers() const {
+	[[nodiscard]] Quantity get_max_number_of_soldiers() const {
 		return num_soldiers_;
 	}
 	void set_max_number_of_soldiers(Quantity q) {
 		num_soldiers_ = q;
 	}
-	bool get_train_health() const {
+	[[nodiscard]] bool get_train_health() const {
 		return train_health_;
 	}
-	bool get_train_attack() const {
+	[[nodiscard]] bool get_train_attack() const {
 		return train_attack_;
 	}
-	bool get_train_defense() const {
+	[[nodiscard]] bool get_train_defense() const {
 		return train_defense_;
 	}
-	bool get_train_evade() const {
+	[[nodiscard]] bool get_train_evade() const {
 		return train_evade_;
 	}
 
-	unsigned get_min_level(TrainingAttribute) const;
-	unsigned get_max_level(TrainingAttribute) const;
-	int32_t get_max_stall() const {
+	[[nodiscard]] unsigned get_min_level(TrainingAttribute) const;
+	[[nodiscard]] unsigned get_max_level(TrainingAttribute) const;
+	[[nodiscard]] int32_t get_max_stall() const {
 		return max_stall_;
 	}
 	void set_max_stall(int32_t trainer_patience) {
 		max_stall_ = trainer_patience;
 	}
 
-	const std::vector<std::vector<std::string>>& get_food_health() const {
-		return food_health_;
-	}
-	const std::vector<std::vector<std::string>>& get_food_attack() const {
-		return food_attack_;
-	}
-	const std::vector<std::vector<std::string>>& get_food_defense() const {
-		return food_defense_;
-	}
-	const std::vector<std::vector<std::string>>& get_food_evade() const {
-		return food_evade_;
-	}
-	const std::vector<std::string>& get_weapons_health() const {
-		return weapons_health_;
-	}
-	const std::vector<std::string>& get_weapons_attack() const {
-		return weapons_attack_;
-	}
-	const std::vector<std::string>& get_weapons_defense() const {
-		return weapons_defense_;
-	}
-	const std::vector<std::string>& get_weapons_evade() const {
-		return weapons_evade_;
-	}
-
-	const std::string& no_soldier_to_train_message() const {
+	[[nodiscard]] const std::string& no_soldier_to_train_message() const {
 		return no_soldier_to_train_message_;
 	}
 
-	const std::string& no_soldier_for_training_level_message() const {
+	[[nodiscard]] const std::string& no_soldier_for_training_level_message() const {
 		return no_soldier_for_training_level_message_;
 	}
 
 private:
-	// Read the table to add needed food and weapons for training a property.
-	// Properties are health, attack, defense, and evade.
-	void add_training_inputs(const LuaTable& table,
-	                         std::vector<std::vector<std::string>>* food,
-	                         std::vector<std::string>* weapons);
-
-	void update_level(TrainingAttribute attrib, unsigned level);
+	void update_level(TrainingAttribute attrib, unsigned from_level, unsigned to_level);
 
 	//  TODO(unknown): These variables should be per soldier type. They should be in a
 	//  struct and there should be a vector, indexed by Soldier_Index,
 	//  with that struct structs as element type.
-	/** Maximum number of soldiers for a training site*/
+	/** Maximum number of soldiers for a training site */
 	Quantity num_soldiers_;
-	/** Number of rounds w/o successful training, after which a soldier is kicked out.**/
+	/** Number of rounds w/o successful training, after which a soldier is kicked out. */
 	uint32_t max_stall_;
-	/** Whether this site can train health*/
-	bool train_health_;
-	/** Whether this site can train attack*/
-	bool train_attack_;
-	/** Whether this site can train defense*/
-	bool train_defense_;
-	/** Whether this site can train evasion*/
-	bool train_evade_;
+	/** Whether this site can train health */
+	bool train_health_{false};
+	/** Whether this site can train attack */
+	bool train_attack_{false};
+	/** Whether this site can train defense */
+	bool train_defense_{false};
+	/** Whether this site can train evasion */
+	bool train_evade_{false};
 
-	/** Minimum health to which a soldier can drop at this site*/
-	unsigned min_health_;
-	/** Minimum attacks to which a soldier can drop at this site*/
-	unsigned min_attack_;
-	/** Minimum defense to which a soldier can drop at this site*/
-	unsigned min_defense_;
-	/** Minimum evasion to which a soldier can drop at this site*/
-	unsigned min_evade_;
+	/** Minimum health a soldier needs to train at this site */
+	unsigned min_health_{std::numeric_limits<uint32_t>::max()};
+	/** Minimum attack a soldier needs to train at this site */
+	unsigned min_attack_{std::numeric_limits<uint32_t>::max()};
+	/** Minimum defense a soldier needs to train at this site */
+	unsigned min_defense_{std::numeric_limits<uint32_t>::max()};
+	/** Minimum evade a soldier needs to train at this site */
+	unsigned min_evade_{std::numeric_limits<uint32_t>::max()};
 
-	/** Maximum health a soldier can acquire at this site*/
-	unsigned max_health_;
-	/** Maximum attack a soldier can acquire at this site*/
-	unsigned max_attack_;
-	/** Maximum defense a soldier can acquire at this site*/
-	unsigned max_defense_;
-	/** Maximum evasion a soldier can acquire at this site*/
-	unsigned max_evade_;
-
-	// For building help
-	std::vector<std::vector<std::string>> food_health_;
-	std::vector<std::vector<std::string>> food_attack_;
-	std::vector<std::vector<std::string>> food_defense_;
-	std::vector<std::vector<std::string>> food_evade_;
-	std::vector<std::string> weapons_health_;
-	std::vector<std::string> weapons_attack_;
-	std::vector<std::string> weapons_defense_;
-	std::vector<std::string> weapons_evade_;
+	/** Maximum health a soldier can acquire at this site */
+	unsigned max_health_{0U};
+	/** Maximum attack a soldier can acquire at this site */
+	unsigned max_attack_{0U};
+	/** Maximum defense a soldier can acquire at this site */
+	unsigned max_defense_{0U};
+	/** Maximum evasion a soldier can acquire at this site */
+	unsigned max_evade_{0U};
 
 	std::string no_soldier_to_train_message_;
 	std::string no_soldier_for_training_level_message_;
@@ -195,8 +153,9 @@ public:
 
 	void add_worker(Worker&) override;
 	void remove_worker(Worker&) override;
+	bool is_present(Worker& worker) const override;
 
-	bool get_build_heroes() {
+	bool get_build_heroes() const {
 		return build_heroes_;
 	}
 	void set_build_heroes(bool b_heroes) {
@@ -226,11 +185,12 @@ private:
 		explicit SoldierControl(TrainingSite* training_site) : training_site_(training_site) {
 		}
 
-		std::vector<Soldier*> present_soldiers() const override;
-		std::vector<Soldier*> stationed_soldiers() const override;
-		Quantity min_soldier_capacity() const override;
-		Quantity max_soldier_capacity() const override;
-		Quantity soldier_capacity() const override;
+		[[nodiscard]] std::vector<Soldier*> present_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> stationed_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> associated_soldiers() const override;
+		[[nodiscard]] Quantity min_soldier_capacity() const override;
+		[[nodiscard]] Quantity max_soldier_capacity() const override;
+		[[nodiscard]] Quantity soldier_capacity() const override;
 		void set_soldier_capacity(Quantity capacity) override;
 		void drop_soldier(Soldier&) override;
 		int incorporate_soldier(EditorGameBase& egbase, Soldier& s) override;
@@ -254,7 +214,7 @@ private:
 
 	SoldierControl soldier_control_;
 	/// Open requests for soldiers. The soldiers can be under way or unavailable
-	Request* soldier_request_;
+	Request* soldier_request_{nullptr};
 
 	/** The soldiers currently at the training site*/
 	std::vector<Soldier*> soldiers_;
@@ -268,12 +228,12 @@ private:
 
 	/** True, \b always upgrade already experienced soldiers first, when possible
 	 * False, \b always upgrade inexperienced soldiers first, when possible */
-	bool build_heroes_;
+	bool build_heroes_{false};
 
 	std::vector<Upgrade> upgrades_;
 	Upgrade* current_upgrade_;
 
-	ProgramResult result_;  /// The result of the last training program.
+	ProgramResult result_{ProgramResult::kFailed};  /// The result of the last training program.
 
 	// These are used for kicking out soldiers prematurely
 	static const uint32_t training_state_multiplier_;
