@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 
 #include "base/macros.h"
 #include "economy/request.h"
+#include "economy/soldier_request.h"
 #include "economy/ware_instance.h"
 #include "logic/map_objects/tribes/building.h"
 #include "logic/map_objects/tribes/soldiercontrol.h"
@@ -41,28 +42,36 @@ struct WarehouseSupply;
 class WarehouseDescr : public BuildingDescr {
 public:
 	WarehouseDescr(const std::string& init_descname, const LuaTable& t, Descriptions& descriptions);
-	~WarehouseDescr() override {
-	}
+	~WarehouseDescr() override = default;
 
-	Building& create_object() const override;
+	[[nodiscard]] Building& create_object() const override;
 
-	uint32_t get_conquers() const override {
+	[[nodiscard]] uint32_t get_conquers() const override {
 		return conquers_;
 	}
 	void set_conquers(uint32_t c) {
 		conquers_ = c;
 	}
 
-	unsigned get_heal_per_second() const {
+	[[nodiscard]] unsigned get_heal_per_second() const {
 		return heal_per_second_;
 	}
 	void set_heal_per_second(unsigned h) {
 		heal_per_second_ = h;
 	}
 
+	[[nodiscard]] Quantity get_max_garrison() const {
+		return max_garrison_;
+	}
+	void set_max_garrison(Quantity g) {
+		max_garrison_ = g;
+	}
+
 private:
-	int32_t conquers_;
-	unsigned heal_per_second_;
+	int32_t conquers_{0};
+	unsigned heal_per_second_{0U};
+	Quantity max_garrison_{0U};
+
 	DISALLOW_COPY_AND_ASSIGN(WarehouseDescr);
 };
 
@@ -205,6 +214,7 @@ public:
 	PortDock* get_portdock() const {
 		return portdock_;
 	}
+	void update_statistics_string(std::string* str) override;
 
 	// Returns the first matching not completely filled waresqueue of the expedition if this is a
 	// port.
@@ -215,6 +225,21 @@ public:
 	// Will throw an exception otherwise.
 	InputQueue& inputqueue(DescriptionIndex, WareWorker, const Request*) override;
 
+	[[nodiscard]] const std::string& get_warehouse_name() const {
+		return warehouse_name_;
+	}
+	void set_warehouse_name(const std::string& name);
+
+	[[nodiscard]] Quantity get_desired_soldier_count() const {
+		return desired_soldier_count_;
+	}
+	void set_desired_soldier_count(Quantity q);
+
+	void set_soldier_preference(SoldierPreference);
+	[[nodiscard]] SoldierPreference get_soldier_preference() const {
+		return soldier_request_.get_preference();
+	}
+
 	void log_general_info(const EditorGameBase&) const override;
 
 private:
@@ -223,11 +248,12 @@ private:
 		explicit SoldierControl(Warehouse* warehouse) : warehouse_(warehouse) {
 		}
 
-		std::vector<Soldier*> present_soldiers() const override;
-		std::vector<Soldier*> stationed_soldiers() const override;
-		Quantity min_soldier_capacity() const override;
-		Quantity max_soldier_capacity() const override;
-		Quantity soldier_capacity() const override;
+		[[nodiscard]] std::vector<Soldier*> present_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> stationed_soldiers() const override;
+		[[nodiscard]] std::vector<Soldier*> associated_soldiers() const override;
+		[[nodiscard]] Quantity min_soldier_capacity() const override;
+		[[nodiscard]] Quantity max_soldier_capacity() const override;
+		[[nodiscard]] Quantity soldier_capacity() const override;
 		void set_soldier_capacity(Quantity capacity) override;
 		void drop_soldier(Soldier&) override;
 		int incorporate_soldier(EditorGameBase& egbase, Soldier& s) override;
@@ -243,13 +269,13 @@ private:
 		explicit AttackTarget(Warehouse* warehouse) : warehouse_(warehouse) {
 		}
 
-		bool can_be_attacked() const override;
+		[[nodiscard]] bool can_be_attacked() const override;
 		void enemy_soldier_approaches(const Soldier&) const override;
 		Widelands::AttackTarget::AttackResult attack(Soldier*) const override;
 		void set_allow_conquer(PlayerNumber, bool) const override {
 			// Warehouses can never be conquered
 		}
-		bool get_allow_conquer(PlayerNumber) const override {
+		[[nodiscard]] bool get_allow_conquer(PlayerNumber) const override {
 			return false;
 		}
 
@@ -287,24 +313,31 @@ private:
 	void update_planned_workers(Game&, PlannedWorkers& pw);
 	void update_all_planned_workers(Game&);
 
+	static void
+	request_soldier_callback(Game&, Request&, DescriptionIndex, Worker*, PlayerImmovable&);
+	Quantity desired_soldier_count_{0U};
 	AttackTarget attack_target_;
 	SoldierControl soldier_control_;
+	SoldierRequest soldier_request_;
+	Time next_swap_soldiers_time_{0U};
+
 	WarehouseSupply* supply_;
 
 	std::vector<StockPolicy> ware_policy_;
 	std::vector<StockPolicy> worker_policy_;
+	std::string warehouse_name_;
 
 	// Workers who live here at the moment
 	using WorkerList = std::vector<OPtr<Worker>>;
 	using IncorporatedWorkers = std::map<DescriptionIndex, WorkerList>;
 	IncorporatedWorkers incorporated_workers_;
 	std::vector<Time> next_worker_without_cost_spawn_;
-	Time next_military_act_;
-	Time next_stock_remove_act_;
+	Time next_military_act_{0U};
+	Time next_stock_remove_act_{0U};
 
 	std::vector<PlannedWorkers> planned_workers_;
 
-	PortDock* portdock_;
+	PortDock* portdock_{nullptr};
 
 	// This is information for portdock, to know whether it should
 	// try to recreate itself
