@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,6 +53,7 @@ class Worker : public Bob {
 		enum {
 			walkObject = 1,  //  walk to objvar1
 			walkCoords = 2,  //  walk to coords
+			walkDir = 4,     //  walk in direction iparam2
 		};
 
 		enum { plantAlways, plantUnlessObject };
@@ -151,7 +152,13 @@ public:
 
 	void start_task_shipping(Game&, PortDock*);
 	void end_shipping(Game&);
-	bool is_shipping();
+	bool is_shipping() const;
+	void set_ship_serial(Serial s) {
+		ship_serial_ = s;
+	}
+	Serial get_ship_serial() const {
+		return ship_serial_;
+	}
 
 	void start_task_buildingwork(Game&);
 	void update_task_buildingwork(Game&);
@@ -179,10 +186,11 @@ public:
 
 protected:
 	virtual bool is_evict_allowed();
+	virtual bool is_employed();
 	virtual void draw_inner(const EditorGameBase& game,
 	                        const Vector2f& point_on_dst,
 	                        const Widelands::Coords& coords,
-	                        const float scale,
+	                        float scale,
 	                        RenderTarget* dst) const;
 	void draw(const EditorGameBase&,
 	          const InfoToDraw& info_to_draw,
@@ -252,7 +260,6 @@ private:
 	bool run_callobject(Game&, State&, const Action&);
 	bool run_plant(Game&, State&, const Action&);
 	bool run_createbob(Game&, State&, const Action&);
-	bool run_buildferry(Game&, State&, const Action&);
 	bool run_removeobject(Game&, State&, const Action&);
 	bool run_repeatsearch(Game&, State&, const Action&);
 	bool run_findresources(Game&, State&, const Action&);
@@ -271,10 +278,9 @@ private:
 		}
 		// The variable scoutme should not be accessed when randomwalk is true.
 		// Initializing the scoutme variable with an obviously-wrong value.
-		PlaceToScout() : randomwalk(true), scoutme(-32100, -32100) {
-		}
-		const bool randomwalk;
-		const Coords scoutme;
+		PlaceToScout() = default;
+		const bool randomwalk = true;
+		const Coords scoutme{-32100, -32100};
 	};
 	std::vector<PlaceToScout> scouts_worklist;
 
@@ -288,19 +294,20 @@ private:
 	bool scout_random_walk(Game& game, const Map& map, const State& state);
 	bool scout_lurk_around(Game& game, const Map& map, struct Worker::PlaceToScout& scoutat);
 
-	OPtr<PlayerImmovable> location_;   ///< meta location of the worker
-	Economy* worker_economy_;          ///< economy this worker is registered in
-	Economy* ware_economy_;            ///< economy this worker's wares are registered in
-	OPtr<WareInstance> carried_ware_;  ///< ware we are carrying
-	IdleWorkerSupply* supply_;         ///< supply while gowarehouse and not transfer
-	Transfer* transfer_;               ///< where we are currently being sent
-	int32_t current_exp_;              ///< current experience
+	OPtr<PlayerImmovable> location_;     ///< meta location of the worker
+	Economy* worker_economy_{nullptr};   ///< economy this worker is registered in
+	Economy* ware_economy_{nullptr};     ///< economy this worker's wares are registered in
+	OPtr<WareInstance> carried_ware_;    ///< ware we are carrying
+	IdleWorkerSupply* supply_{nullptr};  ///< supply while gowarehouse and not transfer
+	Transfer* transfer_{nullptr};        ///< where we are currently being sent
+	int32_t current_exp_{0};             ///< current experience
+	Serial ship_serial_{0};              ///< Ship the worker is currently on, if any
 
 	// saving and loading
 protected:
 	struct Loader : public Bob::Loader {
 	public:
-		Loader();
+		Loader() = default;
 
 		virtual void load(FileRead&);
 		void load_pointers() override;
@@ -311,8 +318,8 @@ protected:
 		const MapObjectProgram* get_program(const std::string& name) override;
 
 	private:
-		uint32_t location_;
-		uint32_t carried_ware_;
+		uint32_t location_{0U};
+		uint32_t carried_ware_{0U};
 		Transfer::ReadData transfer_;
 	};
 
