@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,6 @@
 
 #include "logic/map_objects/tribes/worker_program.h"
 
-#include "base/log.h"
 #include "logic/game_data_error.h"
 #include "logic/map_objects/findnode.h"
 #include "sound/sound_handler.h"
@@ -67,7 +66,6 @@ Available actions are:
 - `callobject`_
 - `plant`_
 - `createbob`_
-- `buildferry`_
 - `removeobject`_
 - `repeatsearch`_
 - `findresources`_
@@ -89,7 +87,6 @@ const WorkerProgram::ParseMap WorkerProgram::parsemap_[] = {
    {"callobject", &WorkerProgram::parse_callobject},
    {"plant", &WorkerProgram::parse_plant},
    {"createbob", &WorkerProgram::parse_createbob},
-   {"buildferry", &WorkerProgram::parse_buildferry},
    {"removeobject", &WorkerProgram::parse_removeobject},
    {"repeatsearch", &WorkerProgram::parse_repeatsearch},
    {"findresources", &WorkerProgram::parse_findresources},
@@ -214,27 +211,18 @@ void WorkerProgram::parse_mine(Worker::Action* act, const std::vector<std::strin
 
 	act->function = &Worker::run_mine;
 
-	if (read_key_value_pair(cmd[1], ':').second.empty()) {
-		// TODO(GunChleoc): Compatibility, remove this option after v1.0
-		log_warn("'mine' program without parameter names is deprecated, please use "
-		         "'mine=<resource_name> radius:<number>' in %s\n",
-		         worker_.name().c_str());
-		act->sparam1 = cmd[0];
-		act->iparam1 = read_positive(cmd[1]);
-	} else {
-		for (const std::string& argument : cmd) {
-			const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
-			if (item.first == "radius") {
-				act->iparam1 = read_positive(item.second);
-			} else if (item.second.empty()) {
-				act->sparam1 = item.first;
-			} else {
-				throw GameDataError(
-				   "Unknown parameter '%s'. Usage: mine=<resource_name> radius:<number>",
-				   item.first.c_str());
-			}
+	for (const std::string& argument : cmd) {
+		const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
+		if (item.first == "radius") {
+			act->iparam1 = read_positive(item.second);
+		} else if (item.second.empty()) {
+			act->sparam1 = item.first;
+		} else {
+			throw GameDataError("Unknown parameter '%s'. Usage: mine=<resource_name> radius:<number>",
+			                    item.first.c_str());
 		}
 	}
+
 	Notifications::publish(
 	   NoteMapObjectDescription(act->sparam1, NoteMapObjectDescription::LoadType::kObject));
 }
@@ -271,27 +259,18 @@ void WorkerProgram::parse_breed(Worker::Action* act, const std::vector<std::stri
 
 	act->function = &Worker::run_breed;
 
-	if (read_key_value_pair(cmd[1], ':').second.empty()) {
-		// TODO(GunChleoc): Compatibility, remove this option after v1.0
-		log_warn("'breed' program without parameter names is deprecated, please use "
-		         "'breed=<resource_name> radius:<number>' in %s\n",
-		         worker_.name().c_str());
-		act->sparam1 = cmd[0];
-		act->iparam1 = read_positive(cmd[1]);
-	} else {
-		for (const std::string& argument : cmd) {
-			const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
-			if (item.first == "radius") {
-				act->iparam1 = read_positive(item.second);
-			} else if (item.second.empty()) {
-				act->sparam1 = item.first;
-			} else {
-				throw GameDataError(
-				   "Unknown parameter '%s'. Usage: breed=<resource_name> radius:<number>",
-				   item.first.c_str());
-			}
+	for (const std::string& argument : cmd) {
+		const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
+		if (item.first == "radius") {
+			act->iparam1 = read_positive(item.second);
+		} else if (item.second.empty()) {
+			act->sparam1 = item.first;
+		} else {
+			throw GameDataError("Unknown parameter '%s'. Usage: breed=<resource_name> radius:<number>",
+			                    item.first.c_str());
 		}
 	}
+
 	Notifications::publish(
 	   NoteMapObjectDescription(act->sparam1, NoteMapObjectDescription::LoadType::kObject));
 }
@@ -551,6 +530,8 @@ walk
       * ``coords``: Walk to a previously found and selected field/coordinate.
       * ``object-or-coords``: Walk to a previously found and selected object if present;
         otherwise to previously found and selected field/coordinate.
+      * ``ne|e|se|sw|w|nw``: New in version 1.2. Orders the worker to move one field in the
+        specified direction. The worker program exits with "fail" if the movement is not possible.
 
    Walk to a previously selected destination. Examples::
 
@@ -589,7 +570,7 @@ walk
  */
 void WorkerProgram::parse_walk(Worker::Action* act, const std::vector<std::string>& cmd) {
 	if (cmd.size() != 1) {
-		throw GameDataError("Usage: walk=object|coords|object-or-coords");
+		throw GameDataError("Usage: walk=object|coords|object-or-coords|<direction>");
 	}
 
 	act->function = &Worker::run_walk;
@@ -600,6 +581,24 @@ void WorkerProgram::parse_walk(Worker::Action* act, const std::vector<std::strin
 		act->iparam1 = Worker::Action::walkCoords;
 	} else if (cmd[0] == "object-or-coords") {
 		act->iparam1 = Worker::Action::walkObject | Worker::Action::walkCoords;
+	} else if (cmd[0] == "ne") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_NE;
+	} else if (cmd[0] == "e") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_E;
+	} else if (cmd[0] == "se") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_SE;
+	} else if (cmd[0] == "sw") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_SW;
+	} else if (cmd[0] == "w") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_W;
+	} else if (cmd[0] == "nw") {
+		act->iparam1 = Worker::Action::walkDir;
+		act->iparam2 = WALK_NW;
 	} else {
 		throw GameDataError("Bad walk destination '%s'", cmd[0].c_str());
 	}
@@ -815,23 +814,6 @@ void WorkerProgram::parse_createbob(Worker::Action* act, const std::vector<std::
 	}
 }
 
-/* RST
-buildferry
-^^^^^^^^^^
-.. function:: buildferry
-
-   **DEPRECATED** use ``createbob=TRIBENAME_ferry`` instead.
-*/
-void WorkerProgram::parse_buildferry(Worker::Action* act, const std::vector<std::string>& cmd) {
-	if (cmd.size() > 1) {
-		throw wexception("buildferry takes no arguments");
-	}
-	// TODO(GunChleoc): API compatibility - remove after v1.0
-	log_warn("%s: Worker program 'buildferry' is deprecated. Use createbob=TRIBENAME_ferry instead.",
-	         worker_.name().c_str());
-	act->function = &Worker::run_buildferry;
-}
-
 /* RST
 terraform
 ^^^^^^^^^
@@ -912,28 +894,18 @@ void WorkerProgram::parse_repeatsearch(Worker::Action* act, const std::vector<st
 
 	act->function = &Worker::run_repeatsearch;
 
-	if (read_key_value_pair(cmd[1], ':').second.empty()) {
-		// TODO(GunChleoc): Compatibility, remove this option after v1.0
-		log_warn("'repeatsearch' program without parameter names is deprecated, please use "
-		         "'repeatsearch=<program_name> repetitions:<number> radius:<number>' in %s\n",
-		         worker_.name().c_str());
-		act->iparam1 = read_positive(cmd[0]);
-		act->iparam2 = read_positive(cmd[1]);
-		act->sparam1 = cmd[2];
-	} else {
-		for (const std::string& argument : cmd) {
-			const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
-			if (item.first == "repetitions") {
-				act->iparam1 = read_positive(item.second);
-			} else if (item.first == "radius") {
-				act->iparam2 = read_positive(item.second);
-			} else if (item.second.empty()) {
-				act->sparam1 = item.first;
-			} else {
-				throw GameDataError("Unknown parameter '%s'. Usage: repeatsearch=<program_name> "
-				                    "repetitions:<number> radius:<number>",
-				                    item.first.c_str());
-			}
+	for (const std::string& argument : cmd) {
+		const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
+		if (item.first == "repetitions") {
+			act->iparam1 = read_positive(item.second);
+		} else if (item.first == "radius") {
+			act->iparam2 = read_positive(item.second);
+		} else if (item.second.empty()) {
+			act->sparam1 = item.first;
+		} else {
+			throw GameDataError("Unknown parameter '%s'. Usage: repeatsearch=<program_name> "
+			                    "repetitions:<number> radius:<number>",
+			                    item.first.c_str());
 		}
 	}
 }
@@ -990,25 +962,16 @@ void WorkerProgram::parse_scout(Worker::Action* act, const std::vector<std::stri
 	}
 	act->function = &Worker::run_scout;
 
-	if (read_key_value_pair(cmd[0], ':').second.empty()) {
-		// TODO(GunChleoc): Compatibility, remove this option after v1.0
-		log_warn("'scout' program without parameter names is deprecated, please use "
-		         "'scout=radius:<number> duration:<duration>' in %s\n",
-		         worker_.name().c_str());
-		act->iparam1 = read_positive(cmd[0]);
-		act->iparam2 = read_positive(cmd[1]);
-	} else {
-		for (const std::string& argument : cmd) {
-			const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
-			if (item.first == "radius") {
-				act->iparam1 = read_positive(item.second);
-			} else if (item.first == "duration") {
-				act->iparam2 = read_duration(item.second, worker_).get();
-			} else {
-				throw GameDataError(
-				   "Unknown parameter '%s'. Usage: scout=radius:<number> duration:<duration>",
-				   item.first.c_str());
-			}
+	for (const std::string& argument : cmd) {
+		const std::pair<std::string, std::string> item = read_key_value_pair(argument, ':');
+		if (item.first == "radius") {
+			act->iparam1 = read_positive(item.second);
+		} else if (item.first == "duration") {
+			act->iparam2 = read_duration(item.second).get();
+		} else {
+			throw GameDataError(
+			   "Unknown parameter '%s'. Usage: scout=radius:<number> duration:<duration>",
+			   item.first.c_str());
 		}
 	}
 }
@@ -1020,7 +983,7 @@ Plays a sound effect. See :ref:`map_object_programs_playsound`.
 */
 void WorkerProgram::parse_playsound(Worker::Action* act, const std::vector<std::string>& cmd) {
 	//  50% chance to play, only one instance at a time
-	PlaySoundParameters parameters = MapObjectProgram::parse_act_play_sound(cmd, worker_);
+	PlaySoundParameters parameters = MapObjectProgram::parse_act_play_sound(cmd);
 
 	act->iparam1 = parameters.priority;
 	act->iparam2 = parameters.fx;
