@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -67,15 +67,15 @@ public:
 	~TerrainDescription() = default;
 
 	/// The name used internally for this terrain.
-	const std::string& name() const;
+	[[nodiscard]] const std::string& name() const;
 
 	/// The name showed to users of Widelands. Usually translated.
-	const std::string& descname() const;
+	[[nodiscard]] const std::string& descname() const;
 
-	const std::vector<std::string>& texture_paths() const;
+	[[nodiscard]] const std::vector<std::string>& texture_paths() const;
 
 	/// Returns the texture for the given gametime.
-	const Image& get_texture(uint32_t gametime) const;
+	[[nodiscard]] const Image& get_texture(uint32_t gametime) const;
 	void add_texture(const Image* texture);
 
 	// Sets the base minimap color.
@@ -83,48 +83,48 @@ public:
 
 	// Return the basic terrain colour to be used in the minimap.
 	// 'shade' must be a brightness value, i.e. in [-128, 127].
-	const RGBColor& get_minimap_color(int shade) const;
+	[[nodiscard]] const RGBColor& get_minimap_color(int shade) const;
 
 	/// Returns the type of terrain this is (water, walkable, and so on).
-	Is get_is() const;
+	[[nodiscard]] Is get_is() const;
 	/// Returns a list of the types that match get_is()
-	const std::vector<TerrainDescription::Type> get_types() const;
+	[[nodiscard]] const std::vector<TerrainDescription::Type> get_types() const;
 
 	/// Returns the valid resource with the given index.
-	DescriptionIndex get_valid_resource(DescriptionIndex index) const;
+	[[nodiscard]] DescriptionIndex get_valid_resource(DescriptionIndex index) const;
 
 	/// Returns the number of valid resources.
-	size_t get_num_valid_resources() const;
+	[[nodiscard]] size_t get_num_valid_resources() const;
 
 	/// Returns the the valid resources.
-	std::vector<DescriptionIndex> valid_resources() const;
+	[[nodiscard]] std::vector<DescriptionIndex> valid_resources() const;
 
 	/// Returns true if this resource can be found in this terrain type.
-	bool is_resource_valid(DescriptionIndex res) const;
+	[[nodiscard]] bool is_resource_valid(DescriptionIndex res) const;
 
 	/// Returns the resource index that can by default always be found in this
 	/// terrain.
-	DescriptionIndex get_default_resource() const;
+	[[nodiscard]] DescriptionIndex get_default_resource() const;
 
 	/// Returns the default amount of resources you can find in this terrain.
-	ResourceAmount get_default_resource_amount() const;
+	[[nodiscard]] ResourceAmount get_default_resource_amount() const;
 
 	/// Returns the dither layer, i.e. the information in which zlayer this
 	/// texture should be drawn.
-	int32_t dither_layer() const;
+	[[nodiscard]] int32_t dither_layer() const;
 
 	/// Parameters for terrain affinity of immovables.
 	/// Temperature is in arbitrary units.
-	int temperature() const;
+	[[nodiscard]] int temperature() const;
 
 	/// Humidity, ranging from 0 to 1000.
-	int humidity() const;
+	[[nodiscard]] int humidity() const;
 
 	/// Fertility, ranging from 0 to 1000.
-	int fertility() const;
+	[[nodiscard]] int fertility() const;
 
 	// The terrain which certain workers can transform this terrain into.
-	std::string enhancement(const std::string& category) const;
+	[[nodiscard]] std::string enhancement(const std::string& category) const;
 	void set_enhancement(const std::string& category, const std::string& terrain);
 
 	void replace_textures(const LuaTable&);
