@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,15 +31,17 @@ namespace Widelands {
 /// \note The order in which nodes are returned is not guarantueed.
 template <typename AreaType = Area<>> struct MapDifferenceRegion {
 	MapDifferenceRegion(const Map& map, AreaType area, Direction direction)
-	   : area_(area), remaining_in_edge_(area.radius), passed_corner_(false) {
+	   : area_(area), remaining_in_edge_(area.radius) {
 		assert(1 <= direction);
 		assert(direction <= 6);
 		--direction;
-		if (!direction)
+		if (direction == 0u) {
 			direction = 6;
+		}
 		--direction;
-		if (!direction)
+		if (direction == 0u) {
 			direction = 6;
+		}
 		switch (direction) {
 #define DIRECTION_CASE(dir, neighbour_function)                                                    \
 	case dir:                                                                                       \
@@ -56,15 +58,17 @@ template <typename AreaType = Area<>> struct MapDifferenceRegion {
 #undef DIRECTION_CASE
 		}
 		--direction;
-		if (!direction)
+		if (direction == 0u) {
 			direction = 6;
+		}
 		--direction;
-		if (!direction)
+		if (direction == 0u) {
 			direction = 6;
+		}
 		direction_ = direction;
 	}
 
-	typename AreaType::CoordsType& location() const {
+	[[nodiscard]] typename AreaType::CoordsType& location() const {
 		return area_;
 	}
 
@@ -78,14 +82,14 @@ template <typename AreaType = Area<>> struct MapDifferenceRegion {
 	 */
 	bool advance(const Map& map);
 
-	typename AreaType::RadiusType radius() const {
+	[[nodiscard]] typename AreaType::RadiusType radius() const {
 		return area_.radius;
 	}
 
 private:
 	AreaType area_;
 	typename AreaType::RadiusType remaining_in_edge_;
-	bool passed_corner_;
+	bool passed_corner_{false};
 	Direction direction_;
 };
 }  // namespace Widelands
