@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 #include <memory>
 
 #include "base/macros.h"
-#include "base/multithreading.h"
+#include "base/mutex.h"
 #include "logic/message.h"
 #include "logic/message_id.h"
 
@@ -41,19 +41,18 @@ struct MessageQueue {
 		counts_[static_cast<int>(Message::Status::kArchived)] = 0;
 	}
 
-	~MessageQueue() {
-	}
+	~MessageQueue() = default;
 
 	//  Make some selected inherited members public.
 	//  TODO(sirver): This is weird design. Instead pass out a const ref& to
 	//  'messages_'?
-	MessageMap::const_iterator begin() const {
+	[[nodiscard]] MessageMap::const_iterator begin() const {
 		return messages_.begin();
 	}
-	MessageMap::const_iterator end() const {
+	[[nodiscard]] MessageMap::const_iterator end() const {
 		return messages_.end();
 	}
-	size_t count(uint32_t const i) const {
+	[[nodiscard]] size_t count(uint32_t const i) const {
 		MutexLock m(MutexLock::ID::kMessages);
 		assert_counts();
 		return messages_.count(MessageId(i));
@@ -68,7 +67,7 @@ struct MessageQueue {
 	}
 
 	/// \returns the number of messages with the given status.
-	uint32_t nr_messages(Message::Status const status) const {
+	[[nodiscard]] uint32_t nr_messages(Message::Status const status) const {
 		MutexLock m(MutexLock::ID::kMessages);
 		assert_counts();
 		assert(static_cast<int>(status) < 3);
@@ -124,14 +123,14 @@ struct MessageQueue {
 		assert_counts();
 	}
 
-	MessageId current_message_id() const {
+	[[nodiscard]] MessageId current_message_id() const {
 		return current_message_id_;
 	}
 
 	/// \returns whether all messages with id 1, 2, 3, ..., current_message_id
 	/// exist. This should be the case when messages have been loaded from a map
 	/// file/savegame but the simulation has not started to run yet.
-	bool is_continuous() const {
+	[[nodiscard]] bool is_continuous() const {
 		MutexLock m(MutexLock::ID::kMessages);
 		assert_counts();
 		return current_message_id().value() == messages_.size();
