@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 by the Widelands Development Team
+ * Copyright (C) 2021-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,8 @@
 #include <string>
 
 #include "base/i18n.h"
+#include "base/log.h"
+#include "base/time_string.h"
 #include "base/warning.h"
 #include "base/wexception.h"
 #include "io/fileread.h"
@@ -33,6 +35,7 @@
 #include "logic/filesystem_constants.h"
 #include "logic/map.h"
 #include "map_io/map_elemental_packet.h"
+#include "map_io/map_loader.h"
 
 namespace AddOns {
 
@@ -87,6 +90,10 @@ std::unique_ptr<MutableAddOn> MutableAddOn::create_mutable_addon(const AddOnInfo
 		return std::unique_ptr<ScriptAddon>(new ScriptAddon(a));
 	case AddOnCategory::kMaps:
 		return std::unique_ptr<MapsAddon>(new MapsAddon(a));
+	case AddOnCategory::kMapGenerator:
+		return std::unique_ptr<MapGenAddon>(new MapGenAddon(a));
+	case AddOnCategory::kUIPlugin:
+		return std::unique_ptr<UIPluginAddon>(new UIPluginAddon(a));
 	case AddOnCategory::kCampaign:
 		return std::unique_ptr<CampaignAddon>(new CampaignAddon(a));
 	case AddOnCategory::kWinCondition:
@@ -110,6 +117,7 @@ MutableAddOn::MutableAddOn(const AddOnInfo& a)
      min_wl_version_(a.min_wl_version),
      max_wl_version_(a.max_wl_version),
      category_(a.category),
+     force_sync_safe_(false),
      directory_(kAddOnDir + FileSystem::file_separator() + internal_name_) {
 }
 
@@ -120,11 +128,15 @@ std::string MutableAddOn::profile_path() {
 void MutableAddOn::update_info(const std::string& descname,
                                const std::string& author,
                                const std::string& description,
-                               const std::string& version) {
+                               const std::string& version,
+                               const std::string& min_wl_version,
+                               const std::string& max_wl_version) {
 	descname_ = descname;
 	author_ = author;
 	description_ = description;
 	version_ = version;
+	min_wl_version_ = min_wl_version;
+	max_wl_version_ = max_wl_version;
 }
 
 void MutableAddOn::setup_temp_dir() {
@@ -132,8 +144,8 @@ void MutableAddOn::setup_temp_dir() {
 	// then delete the original add-on directory and move it over.
 	if (g_fs->file_exists(directory_)) {
 		backup_path_ = directory_;
-		directory_ =
-		   kTempFileDir + FileSystem::file_separator() + internal_name_ + kTempFileExtension;
+		directory_ = kTempFileDir + FileSystem::file_separator() + timestring() + ".autogen." +
+		             internal_name_ + kTempFileExtension;
 		if (g_fs->file_exists(directory_)) {
 			g_fs->fs_unlink(directory_);
 		}
@@ -151,7 +163,7 @@ void MutableAddOn::cleanup_temp_dir() {
 }
 
 std::string MutableAddOn::parse_requirements() {
-	// · We need to read the original `addon` file (if it exists) to
+	// • We need to read the original `addon` file (if it exists) to
 	//   determine the requirements. Then write the file, and we are done.
 	const std::string directory = kAddOnDir + FileSystem::file_separator() + internal_name_;
 	bool dir_exists = g_fs->file_exists(directory);
@@ -188,6 +200,7 @@ bool MutableAddOn::write_to_disk() {
 	s.set_string("requires", requirements);
 	s.set_string("min_wl_version", min_wl_version_);
 	s.set_string("max_wl_version", max_wl_version_);
+	s.set_bool("sync_safe", force_sync_safe_);
 
 	p.write(profile_path().c_str(), false);
 
@@ -220,7 +233,7 @@ MapsAddon::MapsAddon(const AddOnInfo& a) : MutableAddOn(a) {
 }
 
 std::string MapsAddon::parse_requirements() {
-	// · For maps, we need to gather the information regarding the maps' required add-ons
+	// • For maps, we need to gather the information regarding the maps' required add-ons
 	//   before writing the profile so we can generate the correct `requires` string.
 	std::string requirements;
 	std::vector<std::string> req;
@@ -262,6 +275,43 @@ void MapsAddon::parse_map_requirements(const DirectoryTree& tree, std::vector<st
 	}
 }
 
+const AddOnVersion MapsAddon::kNoVersionRequirement = {std::numeric_limits<uint32_t>::max()};
+
+AddOnVersion MapsAddon::detect_min_wl_version(const DirectoryTree* start) const {
+	if (start == nullptr) {
+		return detect_min_wl_version(&tree_);
+	}
+
+	AddOnVersion min_version = kNoVersionRequirement;
+
+	for (const auto& pair : start->subdirectories) {
+		AddOnVersion v = detect_min_wl_version(&pair.second);
+		if (is_newer_version(v, min_version)) {
+			min_version = v;
+		}
+	}
+
+	for (const auto& pair : start->maps) {
+		Widelands::Map map;
+		std::unique_ptr<Widelands::MapLoader> ml = map.get_correct_loader(pair.second);
+		if (ml == nullptr) {
+			log_warn("%s: %s (%s) is not a valid map file!", get_internal_name().c_str(),
+			         pair.first.c_str(), pair.second.c_str());
+			continue;
+		}
+
+		map.set_filename(pair.second);
+		ml->preload_map(true, nullptr);
+
+		AddOnVersion v = AddOns::string_to_version(map.version().minimum_required_widelands_version);
+		if (is_newer_version(v, min_version)) {
+			min_version = v;
+		}
+	}
+
+	return min_version;
+}
+
 std::map<std::string, unsigned> MapsAddon::count_all_dirnames(const DirectoryTree* start) const {
 	if (start == nullptr) {
 		return count_all_dirnames(&tree_);
