@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,20 +28,16 @@ namespace Widelands {
 class Objective {
 public:
 	explicit Objective(const std::string& init_name)
-	   : name_(init_name),
-	     descname_(init_name),
-	     descr_(_("This objective has no description.")),
-	     visible_(true),
-	     done_(false) {
+	   : name_(init_name), descname_(init_name), descr_(_("This objective has no description.")) {
 	}
 
 	// Unique internal name of the objective.
-	const std::string& name() const {
+	[[nodiscard]] const std::string& name() const {
 		return name_;
 	}
 
 	// User facing (translated) descriptive name.
-	const std::string& descname() const {
+	[[nodiscard]] const std::string& descname() const {
 		return descname_;
 	}
 	void set_descname(const std::string& new_name) {
@@ -49,7 +45,7 @@ public:
 	}
 
 	// Description text of this name.
-	const std::string& descr() const {
+	[[nodiscard]] const std::string& descr() const {
 		return descr_;
 	}
 	void set_descr(const std::string& new_descr) {
@@ -57,7 +53,7 @@ public:
 	}
 
 	// True, if this objective is fulfilled.
-	bool done() const {
+	[[nodiscard]] bool done() const {
 		return done_;
 	}
 
@@ -66,7 +62,7 @@ public:
 	}
 
 	// True, if this objective is visible to the user.
-	bool visible() const {
+	[[nodiscard]] bool visible() const {
 		return visible_;
 	}
 	void set_visible(const bool t) {
@@ -77,8 +73,8 @@ private:
 	const std::string name_;
 	std::string descname_;
 	std::string descr_;
-	bool visible_;
-	bool done_;
+	bool visible_{true};
+	bool done_{false};
 };
 }  // namespace Widelands
 
