@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,11 +19,16 @@
 #ifndef WL_LOGIC_SAVE_HANDLER_H
 #define WL_LOGIC_SAVE_HANDLER_H
 
+#include <cstdint>
+#include <optional>
+
+#include "base/times.h"
 #include "io/filesystem/filesystem.h"
+#include "logic/filesystem_constants.h"
 
 namespace Widelands {
 class Game;
-}
+}  // namespace Widelands
 
 /**
  * Takes care of manual or autosave via think().
@@ -32,13 +37,17 @@ class Game;
  */
 class SaveHandler {
 public:
-	SaveHandler();
+	SaveHandler() = default;
 
 	void think(Widelands::Game&);
-	std::string create_file_name(const std::string& dir, const std::string& filename) const;
+	[[nodiscard]] std::string create_file_name(const std::string& dir,
+	                                           const std::string& filename) const;
 
 	// Saves the game, overwrites file, handles errors
-	bool save_game(Widelands::Game&, const std::string& filename, std::string* error_str = nullptr);
+	bool save_game(Widelands::Game&,
+	               const std::string& filename,
+	               std::optional<FileSystem::Type> fstype,
+	               std::string* error_str = nullptr);
 
 	const std::string get_cur_filename() {
 		return current_filename_;
@@ -54,7 +63,7 @@ public:
 		allow_saving_ = t;
 	}
 	// Used by lua only
-	bool get_allow_saving() {
+	[[nodiscard]] bool get_allow_saving() const {
 		return allow_saving_;
 	}
 	// Used by lua only
@@ -63,26 +72,29 @@ public:
 		save_filename_ = filename;
 	}
 
-	uint32_t last_save_time() const {
+	[[nodiscard]] uint32_t last_save_time() const {
 		return last_save_realtime_;
 	}
 
 private:
-	uint32_t next_save_realtime_;
-	uint32_t last_save_realtime_;
-	bool initialized_;
-	bool allow_saving_;
-	bool save_requested_;
-	bool saving_next_tick_;
+	uint32_t next_save_realtime_{0U};
+	uint32_t last_save_realtime_{0U};
+	Time next_save_min_gametime_;
+	bool initialized_{false};
+	bool allow_saving_{true};
+	bool save_requested_{false};
+	bool saving_next_tick_{false};
 	std::string save_filename_;
 	std::string current_filename_;
-	std::string autosave_filename_;
+	std::string autosave_filename_{kAutosavePrefix};
 
-	FileSystem::Type fs_type_;
-	int32_t autosave_interval_in_ms_;
-	int32_t number_of_rolls_;  // For rolling file update
+	FileSystem::Type fs_type_{FileSystem::ZIP};
+	int32_t autosave_interval_in_ms_{kDefaultAutosaveInterval * 60 * 1000};
+	Duration autosave_gametime_interval_;
+	int32_t number_of_rolls_{5};  // For rolling file update
+	bool skip_when_inactive_{true};
 
-	void initialize(uint32_t realtime);
+	void initialize(Widelands::Game& game, uint32_t realtime);
 	bool roll_save_files(const std::string& filename, std::string* error) const;
 	bool check_next_tick(Widelands::Game& game, uint32_t realtime) const;
 };
