@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2022 by the Widelands Development Team
+ * Copyright (C) 2015-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -70,20 +70,16 @@ std::string SinglePlayerGameSettingsProvider::get_map() {
 	return s.mapfilename;
 }
 
-bool SinglePlayerGameSettingsProvider::is_peaceful_mode() {
-	return s.peaceful;
+void SinglePlayerGameSettingsProvider::set_flag(GameSettings::Flags flag, bool state) {
+	if (state) {
+		s.flags |= flag;
+	} else {
+		s.flags &= ~flag;
+	}
 }
 
-void SinglePlayerGameSettingsProvider::set_peaceful_mode(bool peace) {
-	s.peaceful = peace;
-}
-
-bool SinglePlayerGameSettingsProvider::get_custom_starting_positions() {
-	return s.custom_starting_positions;
-}
-
-void SinglePlayerGameSettingsProvider::set_custom_starting_positions(bool c) {
-	s.custom_starting_positions = c;
+bool SinglePlayerGameSettingsProvider::get_flag(GameSettings::Flags flag) {
+	return (s.flags & flag) != 0;
 }
 
 void SinglePlayerGameSettingsProvider::set_map(const std::string& mapname,
@@ -268,19 +264,29 @@ void SinglePlayerGameSettingsProvider::set_player_number(uint8_t const number) {
 	}
 	PlayerSettings const position = settings().players.at(number);
 	// Ensure that old player number isn't out of range when we switch to a map with less players
-	PlayerSettings const player = settings().players.at(
-	   settings().playernum < static_cast<int>(settings().players.size()) ? settings().playernum :
-                                                                           0);
+	const uint8_t old_number =
+	   settings().playernum < static_cast<int>(settings().players.size()) ? settings().playernum : 0;
+	PlayerSettings const player = settings().players.at(old_number);
 	if (number < settings().players.size() && (position.state == PlayerSettings::State::kOpen ||
 	                                           position.state == PlayerSettings::State::kClosed ||
 	                                           position.state == PlayerSettings::State::kComputer)) {
 
-		// swap player but keep player name
+		// swap player but keep player name and, if unchanged from the default, colour
+		bool new_uses_default_colour = s.players[old_number].color == kPlayerColors[old_number];
+		bool old_uses_default_colour = s.players[number].color == kPlayerColors[number];
 		set_player(number, player);
 		set_player_name(number, position.name);
 
 		set_player(settings().playernum, position);
 		set_player_name(settings().playernum, player.name);
+
+		if (old_uses_default_colour) {
+			set_player_color(old_number, kPlayerColors[old_number]);
+		}
+		if (new_uses_default_colour) {
+			set_player_color(number, kPlayerColors[number]);
+		}
+
 		s.playernum = number;
 	}
 }
@@ -292,3 +298,11 @@ std::string SinglePlayerGameSettingsProvider::get_win_condition_script() {
 void SinglePlayerGameSettingsProvider::set_win_condition_script(const std::string& wc) {
 	s.win_condition_script = wc;
 }
+
+int32_t SinglePlayerGameSettingsProvider::get_win_condition_duration() {
+	return s.win_condition_duration;
+}
+
+void SinglePlayerGameSettingsProvider::set_win_condition_duration(const int32_t duration) {
+	s.win_condition_duration = duration;
+}
