@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +21,7 @@
 
 #include <cstdint>
 #include <limits>
+#include <string>
 #include <vector>
 
 namespace Widelands {
@@ -28,6 +29,8 @@ namespace Widelands {
 //  Type definitions for the game logic.
 using MilitaryInfluence = uint16_t;
 
+constexpr int32_t kDefaultWinConditionDuration = 4 * 60;
+
 /// 5 bits used, so 0 .. 31
 /// Data type must match kMaxPlayers in graphics/playercolor.h
 using PlayerNumber = uint8_t;
@@ -65,6 +68,8 @@ using ResourceAmount = uint8_t;  /// 4 bits used, so 0 .. 15.
 
 using Quantity = uint32_t;  // e.g. the number of a type of ware in a warehouse.
 
+constexpr Quantity kEconomyTargetInfinity = std::numeric_limits<Quantity>::max();
+
 using Serial = uint32_t;  /// Serial number for MapObject.
 constexpr Serial kInvalidSerial = std::numeric_limits<uint32_t>::max();
 
@@ -85,6 +90,16 @@ struct SoldierStrength {
 	}
 };
 
+// It is assumed elsewhere that enum SoldierPreference fits to uint8_t.
+// These constants are written to savegames.
+enum class SoldierPreference : uint8_t {
+	kRookies = 0,
+	kHeroes = 1,
+	kAny = 2,
+};
+
+std::string soldier_preference_icon(SoldierPreference p);
+
 // For suggested teams info during map preload
 using SuggestedTeam = std::vector<PlayerNumber>;  // Players in a team
 // Recommended teams to play against each other
@@ -92,14 +107,17 @@ using SuggestedTeamLineup = std::vector<SuggestedTeam>;
 
 /** Describes diplomatic relation actions between players. */
 enum class DiplomacyAction : uint8_t {
-	kJoin,          ///< Request to join another player's team.
+	/* Do not change the order, indices are stored in savegames. */
+	kJoin = 0,      ///< Request to join another player's team.
 	kAcceptJoin,    ///< Accept another player's request to join your team.
 	kRefuseJoin,    ///< Refuse another player's request to join your team.
 	kInvite,        ///< Invite another player to join your team.
 	kAcceptInvite,  ///< Accept another player's invitation.
 	kRefuseInvite,  ///< Decline another player's invitation.
 	kLeaveTeam,     ///< Leave the current team and become teamless.
-	kResign         ///< Resign and become a spectator.
+	kResign,        ///< Resign and become a spectator.
+	kRetractJoin,   ///< Retract a previous joining request.
+	kRetractInvite  ///< Retract a previous invitation.
 };
 
 }  // namespace Widelands
