@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +33,7 @@ class Bob;
  */
 class MapObjectLoader {
 public:
-	bool is_object_known(uint32_t) const;
+	[[nodiscard]] bool is_object_known(uint32_t) const;
 
 	/// Registers the object as a new one.
 	///
@@ -62,13 +62,14 @@ public:
 
 	template <typename T> T& get(Serial const serial) {
 		ReverseMapObjectMap::iterator const it = objects_.find(serial);
-		if (it == objects_.end())
+		if (it == objects_.end()) {
 			throw GameDataError("not found");
-		else if (upcast(T, result, it->second))
+		}
+		if (upcast(T, result, it->second)) {
 			return *result;
-		else
-			throw GameDataError("is a %s, expected a %s",
-			                    to_string(it->second->descr().type()).c_str(), typeid(T).name());
+		}
+		throw GameDataError(
+		   "is a %s, expected a %s", to_string(it->second->descr().type()).c_str(), typeid(T).name());
 	}
 
 	int32_t get_nr_unloaded_objects();
