@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,8 +27,10 @@
 #include "logic/editor_game_base.h"
 #include "logic/map.h"
 #include "logic/map_objects/immovable.h"
+#include "logic/map_objects/pinned_note.h"
 #include "logic/map_objects/tribes/battle.h"
 #include "logic/map_objects/tribes/ship.h"
+#include "logic/map_objects/tribes/soldier.h"
 #include "logic/map_objects/tribes/worker.h"
 #include "logic/map_objects/world/critter.h"
 #include "map_io/map_object_loader.h"
@@ -69,6 +71,10 @@ void MapObjectPacket::read(FileSystem& fs, EditorGameBase& egbase, MapObjectLoad
 				loaders.insert(Critter::load(egbase, mol, fr));
 				break;
 
+			case MapObject::HeaderPinnedNote:
+				loaders.insert(PinnedNote::load(egbase, mol, fr));
+				break;
+
 			case MapObject::HeaderWorker:
 				// We can't use the worker's savegame version, because some stuff is loaded before
 				// that
@@ -96,6 +102,18 @@ void MapObjectPacket::read(FileSystem& fs, EditorGameBase& egbase, MapObjectLoad
 				loaders.insert(FerryFleet::load(egbase, mol, fr));
 				break;
 
+			case MapObject::HeaderShipFleetInterface:
+				loaders.insert(ShipFleetYardInterface::load(egbase, mol, fr));
+				break;
+
+			case MapObject::HeaderFerryFleetInterface:
+				loaders.insert(FerryFleetYardInterface::load(egbase, mol, fr));
+				break;
+
+			case MapObject::HeaderNavalInvasionBase:
+				loaders.insert(NavalInvasionBase::load(egbase, mol, fr));
+				break;
+
 			default:
 				throw GameDataError("unknown object header %u", header);
 			}
