@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,21 +29,6 @@
 
 namespace Widelands {
 
-MapObjectSaver::MapObjectSaver()
-   : nr_roads_(0),
-     nr_waterways_(0),
-     nr_flags_(0),
-     nr_buildings_(0),
-     nr_bobs_(0),
-     nr_wares_(0),
-     nr_immovables_(0),
-     nr_battles_(0),
-     nr_ship_fleets_(0),
-     nr_ferry_fleets_(0),
-     nr_portdocks_(0),
-     lastserial_(0) {
-}
-
 /**
  * Return a pointer to the record for the given object.
  * Create a record if that hasn't been done yet.
