@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -108,7 +108,7 @@ public:
 		BufferedConnection* conn_;
 
 		/// The position of the next peek.
-		size_t peek_pointer_;
+		size_t peek_pointer_{0U};
 	};
 
 	/**
@@ -143,7 +143,7 @@ public:
 	 * Returns whether the connection is established.
 	 * \return \c true if the connection is open, \c false otherwise.
 	 */
-	bool is_connected() const;
+	[[nodiscard]] bool is_connected() const;
 
 	/**
 	 * Closes the connection.
@@ -200,7 +200,7 @@ public:
 	 */
 	/*
 	 This method creates a vector to store the data-to-be-send in. Basically this template magic
-	 (called "parameter pack") is similar to the var-arg magic used by printf(). An arbitrary
+	 (called "parameter pack") is similar to the var-arg magic used by printf. An arbitrary
 	 number of arbitrary-typed parameters might be passed as the Fargs parameter. The compiler than
 	 decides which of the send_T_() methods have to be called. Since each of them takes a different
 	 first argument out of Fargs only one of them can match. The matching methods transforms the
@@ -331,7 +331,7 @@ private:
 	/// Protects receive_buffer_
 	std::mutex mutex_receive_;
 	/// Whether we are currently sending something, used within start_sending()
-	bool currently_sending_;
+	bool currently_sending_{false};
 };
 
 #endif  // end of include guard: WL_NETWORK_BUFFEREDCONNECTION_H
