@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +44,7 @@ public:
 	~NetClientProxy() override;
 
 	// Inherited from NetClientInterface
-	bool is_connected() const override;
+	[[nodiscard]] bool is_connected() const override;
 	void close() override;
 	std::unique_ptr<RecvPacket> try_receive() override;
 	void send(const SendPacket& packet, NetPriority priority = NetPriority::kNormal) override;
