@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,7 @@ enum {
 	 * The current version of the in-game network protocol. Client and host
 	 * protocol versions must match.
 	 */
-	NETWORK_PROTOCOL_VERSION = 28,
+	NETWORK_PROTOCOL_VERSION = 32,
 
 	/**
 	 * The default interval (in milliseconds) in which the host issues
@@ -213,6 +213,16 @@ enum : uint8_t {
 
 	/**
 	 * Sent by the host during game setup to indicate that the game starts.
+	 * The payload is:
+	 * \li unsigned_32 Random number generator seed
+	 * \li unsigned_32 Number of enabled add-ons
+	 * \li Each enabled add-on's internal name
+	 * \li Custom naming lists for all players. Each naming list consists of:
+	 *   \li unsigned_8: Player number (0 terminates the list of naming lists).
+	 *   \li unsigned_32: Number `S` of ship names
+	 *   \li `S` × string: Each ship name
+	 *   \li unsigned_32: Number `W` of warehouse names
+	 *   \li `W` × string: Each warehouse name
 	 *
 	 * The client must load the map and setup the game. As soon as the game
 	 * is fully loaded, it must behave as if a \ref NETCMD_WAIT command had
@@ -423,7 +433,7 @@ enum : uint8_t {
 	 * This is sent by the server to generate a clientsided translated system
 	 * chat message. Payload is:
 	 *
-	 * \li string:    Message code \see NetworkGamingMessages::fill_map()
+	 * \li string:    Message code \see src/network/network_gaming_messages.cc
 	 * \li string:    First attached string
 	 * \li string:    Second attached string
 	 * \li string:    Third attached string
@@ -431,20 +441,12 @@ enum : uint8_t {
 	NETCMD_SYSTEM_MESSAGE_CODE = 32,
 
 	/**
-	 * Sent by the host to toggle peaceful mode.
+	 * Sent by the host to set game flags.
 	 *
 	 * Attached data is:
-	 * \li uint8_t: 1 if peaceful mode is enabled, 0 otherwise
+	 * \li uint16_t: Bitset of all enabled game flags.
 	 */
-	NETCMD_PEACEFUL_MODE = 33,
-
-	/**
-	 * Sent by the host to toggle custom_starting_positions mode.
-	 *
-	 * Attached data is:
-	 * \li uint8_t: 1 if custom_starting_positions mode is enabled, 0 otherwise
-	 */
-	NETCMD_CUSTOM_STARTING_POSITIONS = 34,
+	NETCMD_GAMEFLAGS = 33,
 
 	/**
 	 * During game setup, this is sent by the client to indicate that the
@@ -457,6 +459,27 @@ enum : uint8_t {
 	 */
 	NETCMD_SETTING_CHANGECOLOR = 35,
 
+	/**
+	 * Sent by the host to change the win condition duration.
+	 *
+	 * Attached data is:
+	 * \li signed_32: win condition duration in minutes
+	 */
+	NETCMD_WIN_CONDITION_DURATION = 36,
+
+	/**
+	 * Sent by the client to inform the host of the client's custom naming lists for ships and
+	 * warehouses. The lists are distributed by the host to the clients later in the LAUNCH command.
+	 * Zero-size naming lists are ignored and signify to use the defaults.
+	 *
+	 * Attached data is:
+	 * \li unsigned_32: Number `S` of ship names
+	 * \li `S` × string: Each ship name
+	 * \li unsigned_32: Number `W` of warehouse names
+	 * \li `W` × string: Each warehouse name
+	 */
+	NETCMD_CUSTOM_NAMING_LISTS = 37,
+
 	/**
 	 * Sent by the metaserver to a freshly opened game to check connectability
 	 */
