@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,6 +48,9 @@ enum class NoteId : uint32_t {
 	ThreadSafeFunction,
 	ThreadSafeFunctionHandled,
 	Panel,
+	PinnedNoteMoved,
+	QuicknavChangedEvent,
+	Hyperlink,
 	PlayerDetailsEvent
 };
 
