@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@
 #include "base/test.h"
 #include "notifications/notifications.h"
 
-TEST_EXECUTABLE(notifications, false)
+TEST_EXECUTABLE(notifications)
 
 struct SimpleNote {
 	CAN_BE_SENT_AS_NOTE(100)
