@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
 
 #include <memory>
 
-#include "base/multithreading.h"
+#include "base/mutex.h"
 #include "io/fileread.h"
 #include "io/filewrite.h"
 #include "logic/game_data_error.h"
@@ -63,8 +63,7 @@ void unreference_coroutine(lua_State* L, uint32_t idx) {
 
 }  // namespace
 
-LuaCoroutine::LuaCoroutine(lua_State* ms)
-   : lua_state_(ms), idx_(LUA_REFNIL), ninput_args_(0), nreturn_values_(0) {
+LuaCoroutine::LuaCoroutine(lua_State* ms) : lua_state_(ms) {
 	if (lua_state_ != nullptr) {
 		idx_ = reference_coroutine(lua_state_);
 	}
@@ -79,6 +78,8 @@ int LuaCoroutine::get_status() {
 }
 
 int LuaCoroutine::resume() {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
 	MutexLock m(MutexLock::ID::kLua);
 
 	int rv = lua_resume(lua_state_, nullptr, ninput_args_);
@@ -151,7 +152,7 @@ std::unique_ptr<LuaTable> LuaCoroutine::pop_table() {
 	return result;
 }
 
-constexpr uint8_t kCoroutineDataPacketVersion = 5;
+constexpr uint8_t kCoroutineDataPacketVersion = 5;  // since v1.0
 void LuaCoroutine::write(FileWrite& fw) const {
 	fw.unsigned_8(kCoroutineDataPacketVersion);
 
@@ -165,7 +166,7 @@ void LuaCoroutine::write(FileWrite& fw) const {
 void LuaCoroutine::read(lua_State* parent, FileRead& fr) {
 	const uint8_t packet_version = fr.unsigned_8();
 
-	if (packet_version > kCoroutineDataPacketVersion || packet_version < 4) {
+	if (packet_version > kCoroutineDataPacketVersion || packet_version < 5) {
 		throw Widelands::UnhandledVersionError(
 		   "LuaCoroutine", packet_version, kCoroutineDataPacketVersion);
 	}
@@ -179,8 +180,5 @@ void LuaCoroutine::read(lua_State* parent, FileRead& fr) {
 	lua_state_ = luaL_checkthread(parent, -1);
 	lua_pop(parent, 2);
 
-	// TODO(Nordfriese): Savegame compatibility
-	if (packet_version >= 5) {
-		LuaGlobals::read_textdomain_stack(fr, lua_state_);
-	}
+	LuaGlobals::read_textdomain_stack(fr, lua_state_);
 }
