@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,8 +52,7 @@ public:
 
 	LUNA_CLASS_HEAD(LuaPlayer);
 
-	LuaPlayer() : LuaBases::LuaPlayerBase() {
-	}
+	LuaPlayer() = default;
 	explicit LuaPlayer(Widelands::PlayerNumber n) : LuaBases::LuaPlayerBase(n) {
 	}
 	explicit LuaPlayer(lua_State* L) {
@@ -68,6 +67,7 @@ public:
 	int get_objectives(lua_State* L);
 	int get_defeated(lua_State* L);
 	int get_resigned(lua_State* L);
+	int get_end_result(lua_State* L);
 	int get_messages(lua_State* L);
 	int get_inbox(lua_State* L);
 	int get_color(lua_State* L);
@@ -128,8 +128,7 @@ class LuaObjective : public LuaGameModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaObjective);
 
-	~LuaObjective() override {
-	}
+	~LuaObjective() override = default;
 
 	explicit LuaObjective(const Widelands::Objective& o);
 	LuaObjective() = default;
@@ -160,6 +159,7 @@ public:
 	 */
 	int remove(lua_State* L);
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int __eq(lua_State* L);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 
@@ -170,17 +170,15 @@ public:
 };
 
 class LuaInboxMessage : public LuaGameModuleClass {
-	Widelands::PlayerNumber player_number_;
-	Widelands::MessageId message_id_;
+	Widelands::PlayerNumber player_number_{0U};
+	Widelands::MessageId message_id_{0U};
 
 public:
 	LUNA_CLASS_HEAD(LuaInboxMessage);
-	~LuaInboxMessage() override {
-	}
+	~LuaInboxMessage() override = default;
 
 	explicit LuaInboxMessage(uint8_t, Widelands::MessageId);
-	LuaInboxMessage() : player_number_(0), message_id_(0) {
-	}
+	LuaInboxMessage() = default;
 	explicit LuaInboxMessage(lua_State* L) {
 		report_error(L, "Cannot instantiate a '%s' directly!", className);
 	}
@@ -206,6 +204,7 @@ public:
 	 * Lua Methods
 	 */
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int __eq(lua_State* L);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 
@@ -219,4 +218,4 @@ public:
 void luaopen_wlgame(lua_State*);
 
 #endif  // end of include guard: WL_SCRIPTING_LUA_GAME_H
-}
+}  // namespace LuaGame
