@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,9 +20,11 @@
 
 #include <memory>
 
+#include "base/multithreading.h"
 #include "io/filesystem/layered_filesystem.h"
 #include "scripting/lua_globals.h"
 #include "scripting/lua_path.h"
+#include "scripting/lua_styles.h"
 #include "scripting/lua_table.h"
 #include "scripting/lua_ui.h"
 #include "scripting/run_script.h"
@@ -71,6 +73,7 @@ LuaInterface::LuaInterface() {
 
 	// And helper methods.
 	LuaPath::luaopen_path(lua_state_);
+	LuaStyles::luaopen_styles(lua_state_);
 
 	// Also push the "wl" and the "hooks" table.
 	lua_newtable(lua_state_);
@@ -88,10 +91,26 @@ LuaInterface::~LuaInterface() {
 }
 
 void LuaInterface::interpret_string(const std::string& cmd) {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
+	MutexLock m(MutexLock::ID::kLua);
 	int rv = luaL_dostring(lua_state_, cmd.c_str());
 	check_return_value_for_errors(lua_state_, rv);
 }
 
 std::unique_ptr<LuaTable> LuaInterface::run_script(const std::string& path) {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
+	MutexLock m(MutexLock::ID::kLua);
 	return ::run_script(lua_state_, g_fs->fix_cross_file(path), g_fs);
 }
+
+std::unique_ptr<LuaTable> LuaInterface::empty_table() {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
+	MutexLock m(MutexLock::ID::kLua);
+	lua_newtable(lua_state_);
+	std::unique_ptr<LuaTable> rv(new LuaTable(lua_state_));
+	lua_pop(lua_state_, 1);
+	return rv;
+}
