@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,6 +38,9 @@ public:
 	// Runs 'script' and returns the table it returned.
 	virtual std::unique_ptr<LuaTable> run_script(const std::string& path);
 
+	// Returns an empty table.
+	std::unique_ptr<LuaTable> empty_table();
+
 protected:
 	lua_State* lua_state_;
 };
