@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,10 +20,13 @@
 #define WL_SCRIPTING_LUA_MAP_H
 
 #include "economy/economy.h"
+#include "economy/ferry_fleet.h"
 #include "economy/flag.h"
 #include "economy/portdock.h"
 #include "economy/road.h"
+#include "economy/ship_fleet.h"
 #include "logic/game.h"
+#include "logic/map_objects/pinned_note.h"
 #include "logic/map_objects/tribes/constructionsite.h"
 #include "logic/map_objects/tribes/dismantlesite.h"
 #include "logic/map_objects/tribes/market.h"
@@ -65,11 +68,9 @@ class LuaMap : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaMap);
 
-	~LuaMap() override {
-	}
+	~LuaMap() override = default;
 
-	LuaMap() {
-	}
+	LuaMap() = default;
 	explicit LuaMap(lua_State* L) {
 		report_error(L, "Cannot instantiate a 'Map' directly!");
 	}
@@ -89,6 +90,7 @@ public:
 	int get_height(lua_State*);
 	int get_player_slots(lua_State*);
 	int get_waterway_max_length(lua_State*);
+	int set_waterway_max_length(lua_State*);
 
 	/*
 	 * Lua methods
@@ -98,16 +100,18 @@ public:
 	int count_owned_valuable_fields(lua_State*);
 	int place_immovable(lua_State*);
 	int get_field(lua_State*);
+	int wrap_field(lua_State*);
 	int recalculate(lua_State*);
 	int recalculate_seafaring(lua_State*);
 	int set_port_space(lua_State*);
 	int sea_route_exists(lua_State*);
-	int set_waterway_max_length(lua_State*);
 	int find_ocean_fields(lua_State*);
 
 	/*
 	 * C methods
 	 */
+	int do_get_field(lua_State* L, uint32_t x, uint32_t y);
+
 private:
 };
 
@@ -115,11 +119,9 @@ class LuaTribeDescription : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaTribeDescription);
 
-	~LuaTribeDescription() override {
-	}
+	~LuaTribeDescription() override = default;
 
-	LuaTribeDescription() : tribedescr_(nullptr) {
-	}
+	LuaTribeDescription() = default;
 	explicit LuaTribeDescription(const Widelands::TribeDescr* const tribedescr)
 	   : tribedescr_(tribedescr) {
 	}
@@ -165,7 +167,7 @@ public:
 	 * C methods
 	 */
 protected:
-	const Widelands::TribeDescr* get() const {
+	[[nodiscard]] const Widelands::TribeDescr* get() const {
 		assert(tribedescr_ != nullptr);
 		return tribedescr_;
 	}
@@ -175,18 +177,16 @@ protected:
 	}
 
 private:
-	const Widelands::TribeDescr* tribedescr_;
+	const Widelands::TribeDescr* tribedescr_{nullptr};
 };
 
 class LuaMapObjectDescription : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaMapObjectDescription);
 
-	~LuaMapObjectDescription() override {
-	}
+	~LuaMapObjectDescription() override = default;
 
-	LuaMapObjectDescription() : mapobjectdescr_(nullptr) {
-	}
+	LuaMapObjectDescription() = default;
 	explicit LuaMapObjectDescription(const Widelands::MapObjectDescr* const mapobjectdescr)
 	   : mapobjectdescr_(mapobjectdescr) {
 	}
@@ -216,7 +216,7 @@ public:
 	 * C methods
 	 */
 protected:
-	const Widelands::MapObjectDescr* get() const {
+	[[nodiscard]] const Widelands::MapObjectDescr* get() const {
 		assert(mapobjectdescr_ != nullptr);
 		return mapobjectdescr_;
 	}
@@ -226,23 +226,21 @@ protected:
 	}
 
 private:
-	const Widelands::MapObjectDescr* mapobjectdescr_;
+	const Widelands::MapObjectDescr* mapobjectdescr_{nullptr};
 };
 
 #define CASTED_GET_DESCRIPTION(klass)                                                              \
 	const Widelands::klass* get() const {                                                           \
-		return static_cast<const Widelands::klass*>(LuaMapObjectDescription::get());                 \
+		return dynamic_cast<const Widelands::klass*>(LuaMapObjectDescription::get());                \
 	}
 
 class LuaImmovableDescription : public LuaMapObjectDescription {
 public:
 	LUNA_CLASS_HEAD(LuaImmovableDescription);
 
-	~LuaImmovableDescription() override {
-	}
+	~LuaImmovableDescription() override = default;
 
-	LuaImmovableDescription() {
-	}
+	LuaImmovableDescription() = default;
 	explicit LuaImmovableDescription(const Widelands::ImmovableDescr* const immovabledescr)
 	   : LuaMapObjectDescription(immovabledescr) {
 	}
@@ -281,11 +279,9 @@ class LuaBuildingDescription : public LuaMapObjectDescription {
 public:
 	LUNA_CLASS_HEAD(LuaBuildingDescription);
 
-	~LuaBuildingDescription() override {
-	}
+	~LuaBuildingDescription() override = default;
 
-	LuaBuildingDescription() {
-	}
+	LuaBuildingDescription() = default;
 	explicit LuaBuildingDescription(const Widelands::BuildingDescr* const buildingdescr)
 	   : LuaMapObjectDescription(buildingdescr) {
 	}
@@ -333,11 +329,9 @@ class LuaConstructionSiteDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaConstructionSiteDescription);
 
-	~LuaConstructionSiteDescription() override {
-	}
+	~LuaConstructionSiteDescription() override = default;
 
-	LuaConstructionSiteDescription() {
-	}
+	LuaConstructionSiteDescription() = default;
 	explicit LuaConstructionSiteDescription(
 	   const Widelands::ConstructionSiteDescr* const constructionsitedescr)
 	   : LuaBuildingDescription(constructionsitedescr) {
@@ -353,11 +347,9 @@ class LuaDismantleSiteDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaDismantleSiteDescription);
 
-	~LuaDismantleSiteDescription() override {
-	}
+	~LuaDismantleSiteDescription() override = default;
 
-	LuaDismantleSiteDescription() {
-	}
+	LuaDismantleSiteDescription() = default;
 	explicit LuaDismantleSiteDescription(
 	   const Widelands::DismantleSiteDescr* const dismantlesitedescr)
 	   : LuaBuildingDescription(dismantlesitedescr) {
@@ -373,11 +365,9 @@ class LuaProductionSiteDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaProductionSiteDescription);
 
-	~LuaProductionSiteDescription() override {
-	}
+	~LuaProductionSiteDescription() override = default;
 
-	LuaProductionSiteDescription() {
-	}
+	LuaProductionSiteDescription() = default;
 	explicit LuaProductionSiteDescription(
 	   const Widelands::ProductionSiteDescr* const productionsitedescr)
 	   : LuaBuildingDescription(productionsitedescr) {
@@ -422,11 +412,9 @@ class LuaMilitarySiteDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaMilitarySiteDescription);
 
-	~LuaMilitarySiteDescription() override {
-	}
+	~LuaMilitarySiteDescription() override = default;
 
-	LuaMilitarySiteDescription() {
-	}
+	LuaMilitarySiteDescription() = default;
 	explicit LuaMilitarySiteDescription(const Widelands::MilitarySiteDescr* const militarysitedescr)
 	   : LuaBuildingDescription(militarysitedescr) {
 	}
@@ -455,11 +443,9 @@ class LuaTrainingSiteDescription : public LuaProductionSiteDescription {
 public:
 	LUNA_CLASS_HEAD(LuaTrainingSiteDescription);
 
-	~LuaTrainingSiteDescription() override {
-	}
+	~LuaTrainingSiteDescription() override = default;
 
-	LuaTrainingSiteDescription() {
-	}
+	LuaTrainingSiteDescription() = default;
 	explicit LuaTrainingSiteDescription(const Widelands::TrainingSiteDescr* const trainingsitedescr)
 	   : LuaProductionSiteDescription(trainingsitedescr) {
 	}
@@ -469,10 +455,6 @@ public:
 	/*
 	 * Properties
 	 */
-	int get_food_attack(lua_State*);
-	int get_food_defense(lua_State*);
-	int get_food_evade(lua_State*);
-	int get_food_health(lua_State*);
 	int get_max_attack(lua_State*);
 	int get_max_defense(lua_State*);
 	int get_max_evade(lua_State*);
@@ -482,15 +464,13 @@ public:
 	int get_min_defense(lua_State*);
 	int get_min_evade(lua_State*);
 	int get_min_health(lua_State*);
-	int get_weapons_attack(lua_State*);
-	int get_weapons_defense(lua_State*);
-	int get_weapons_evade(lua_State*);
-	int get_weapons_health(lua_State*);
 
 	/*
 	 * Lua methods
 	 */
 
+	int trained_soldiers(lua_State*);
+
 	/*
 	 * C methods
 	 */
@@ -503,11 +483,9 @@ class LuaWarehouseDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaWarehouseDescription);
 
-	~LuaWarehouseDescription() override {
-	}
+	~LuaWarehouseDescription() override = default;
 
-	LuaWarehouseDescription() {
-	}
+	LuaWarehouseDescription() = default;
 	explicit LuaWarehouseDescription(const Widelands::WarehouseDescr* const warehousedescr)
 	   : LuaBuildingDescription(warehousedescr) {
 	}
@@ -535,11 +513,9 @@ class LuaMarketDescription : public LuaBuildingDescription {
 public:
 	LUNA_CLASS_HEAD(LuaMarketDescription);
 
-	~LuaMarketDescription() override {
-	}
+	~LuaMarketDescription() override = default;
 
-	LuaMarketDescription() {
-	}
+	LuaMarketDescription() = default;
 	explicit LuaMarketDescription(const Widelands::MarketDescr* const warehousedescr)
 	   : LuaBuildingDescription(warehousedescr) {
 	}
@@ -566,11 +542,9 @@ class LuaWareDescription : public LuaMapObjectDescription {
 public:
 	LUNA_CLASS_HEAD(LuaWareDescription);
 
-	~LuaWareDescription() override {
-	}
+	~LuaWareDescription() override = default;
 
-	LuaWareDescription() {
-	}
+	LuaWareDescription() = default;
 	explicit LuaWareDescription(const Widelands::WareDescr* const waredescr)
 	   : LuaMapObjectDescription(waredescr) {
 	}
@@ -605,11 +579,9 @@ class LuaWorkerDescription : public LuaMapObjectDescription {
 public:
 	LUNA_CLASS_HEAD(LuaWorkerDescription);
 
-	~LuaWorkerDescription() override {
-	}
+	~LuaWorkerDescription() override = default;
 
-	LuaWorkerDescription() {
-	}
+	LuaWorkerDescription() = default;
 	explicit LuaWorkerDescription(const Widelands::WorkerDescr* const workerdescr)
 	   : LuaMapObjectDescription(workerdescr) {
 	}
@@ -646,11 +618,9 @@ class LuaSoldierDescription : public LuaWorkerDescription {
 public:
 	LUNA_CLASS_HEAD(LuaSoldierDescription);
 
-	~LuaSoldierDescription() override {
-	}
+	~LuaSoldierDescription() override = default;
 
-	LuaSoldierDescription() {
-	}
+	LuaSoldierDescription() = default;
 	explicit LuaSoldierDescription(const Widelands::SoldierDescr* const soldierdescr)
 	   : LuaWorkerDescription(soldierdescr) {
 	}
@@ -690,11 +660,9 @@ class LuaShipDescription : public LuaMapObjectDescription {
 public:
 	LUNA_CLASS_HEAD(LuaShipDescription);
 
-	~LuaShipDescription() override {
-	}
+	~LuaShipDescription() override = default;
 
-	LuaShipDescription() {
-	}
+	LuaShipDescription() = default;
 	explicit LuaShipDescription(const Widelands::ShipDescr* const shipdescr)
 	   : LuaMapObjectDescription(shipdescr) {
 	}
@@ -728,11 +696,9 @@ class LuaResourceDescription : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaResourceDescription);
 
-	~LuaResourceDescription() override {
-	}
+	~LuaResourceDescription() override = default;
 
-	LuaResourceDescription() : resourcedescr_(nullptr) {
-	}
+	LuaResourceDescription() = default;
 	explicit LuaResourceDescription(const Widelands::ResourceDescription* const resourcedescr)
 	   : resourcedescr_(resourcedescr) {
 	}
@@ -764,7 +730,7 @@ public:
 	 * C methods
 	 */
 protected:
-	const Widelands::ResourceDescription* get() const {
+	[[nodiscard]] const Widelands::ResourceDescription* get() const {
 		assert(resourcedescr_ != nullptr);
 		return resourcedescr_;
 	}
@@ -774,18 +740,16 @@ protected:
 	}
 
 private:
-	const Widelands::ResourceDescription* resourcedescr_;
+	const Widelands::ResourceDescription* resourcedescr_{nullptr};
 };
 
 class LuaTerrainDescription : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaTerrainDescription);
 
-	~LuaTerrainDescription() override {
-	}
+	~LuaTerrainDescription() override = default;
 
-	LuaTerrainDescription() : terraindescr_(nullptr) {
-	}
+	LuaTerrainDescription() = default;
 	explicit LuaTerrainDescription(const Widelands::TerrainDescription* const terraindescr)
 	   : terraindescr_(terraindescr) {
 	}
@@ -818,7 +782,7 @@ public:
 	/*
 	 * C methods
 	 */
-	const Widelands::TerrainDescription* get() const {
+	[[nodiscard]] const Widelands::TerrainDescription* get() const {
 		assert(terraindescr_ != nullptr);
 		return terraindescr_;
 	}
@@ -830,18 +794,16 @@ protected:
 	}
 
 private:
-	const Widelands::TerrainDescription* terraindescr_;
+	const Widelands::TerrainDescription* terraindescr_{nullptr};
 };
 
 class LuaEconomy : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaEconomy);
 
-	~LuaEconomy() override {
-	}
+	~LuaEconomy() override = default;
 
-	LuaEconomy() : economy_(nullptr) {
-	}
+	LuaEconomy() = default;
 	explicit LuaEconomy(Widelands::Economy* economy) : economy_(economy) {
 	}
 	explicit LuaEconomy(lua_State* L) : economy_(nullptr) {
@@ -862,13 +824,14 @@ public:
 	 */
 	int target_quantity(lua_State*);
 	int set_target_quantity(lua_State*);
+	int needs(lua_State*);
 
 	/*
 	 * C methods
 	 */
 
 protected:
-	Widelands::Economy* get() const {
+	[[nodiscard]] Widelands::Economy* get() const {
 		assert(economy_ != nullptr);
 		return economy_;
 	}
@@ -878,12 +841,12 @@ protected:
 	}
 
 private:
-	Widelands::Economy* economy_;
+	Widelands::Economy* economy_{nullptr};
 };
 
 #define CASTED_GET(klass)                                                                          \
 	Widelands::klass* get(lua_State* L, Widelands::EditorGameBase& egbase) {                        \
-		return static_cast<Widelands::klass*>(LuaMapObject::get(L, egbase, #klass));                 \
+		return dynamic_cast<Widelands::klass*>(LuaMapObject::get(L, egbase, #klass));                \
 	}
 
 class LuaMapObject : public LuaMapModuleClass {
@@ -912,15 +875,18 @@ public:
 	 * attributes
 	 */
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int get___hash(lua_State*);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 	int get_descr(lua_State*);
 	int get_serial(lua_State*);
+	int get_exists(lua_State*);
 
 	/*
 	 * Lua Methods
 	 */
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int __eq(lua_State* L);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 	int remove(lua_State* L);
@@ -939,14 +905,12 @@ class LuaBaseImmovable : public LuaMapObject {
 public:
 	LUNA_CLASS_HEAD(LuaBaseImmovable);
 
-	LuaBaseImmovable() {
-	}
+	LuaBaseImmovable() = default;
 	explicit LuaBaseImmovable(Widelands::BaseImmovable& mo) : LuaMapObject(mo) {
 	}
 	explicit LuaBaseImmovable(lua_State* L) : LuaMapObject(L) {
 	}
-	~LuaBaseImmovable() override {
-	}
+	~LuaBaseImmovable() override = default;
 
 	/*
 	 * Properties
@@ -967,14 +931,12 @@ class LuaPlayerImmovable : public LuaBaseImmovable {
 public:
 	LUNA_CLASS_HEAD(LuaPlayerImmovable);
 
-	LuaPlayerImmovable() {
-	}
+	LuaPlayerImmovable() = default;
 	explicit LuaPlayerImmovable(Widelands::PlayerImmovable& mo) : LuaBaseImmovable(mo) {
 	}
 	explicit LuaPlayerImmovable(lua_State* L) : LuaBaseImmovable(L) {
 	}
-	~LuaPlayerImmovable() override {
-	}
+	~LuaPlayerImmovable() override = default;
 
 	/*
 	 * Properties
@@ -997,14 +959,12 @@ class LuaPortDock : public LuaPlayerImmovable {
 public:
 	LUNA_CLASS_HEAD(LuaPortDock);
 
-	LuaPortDock() {
-	}
+	LuaPortDock() = default;
 	explicit LuaPortDock(Widelands::PortDock& mo) : LuaPlayerImmovable(mo) {
 	}
 	explicit LuaPortDock(lua_State* L) : LuaPlayerImmovable(L) {
 	}
-	~LuaPortDock() override {
-	}
+	~LuaPortDock() override = default;
 
 	/*
 	 * Properties
@@ -1024,14 +984,12 @@ class LuaBuilding : public LuaPlayerImmovable {
 public:
 	LUNA_CLASS_HEAD(LuaBuilding);
 
-	LuaBuilding() {
-	}
+	LuaBuilding() = default;
 	explicit LuaBuilding(Widelands::Building& mo) : LuaPlayerImmovable(mo) {
 	}
 	explicit LuaBuilding(lua_State* L) : LuaPlayerImmovable(L) {
 	}
-	~LuaBuilding() override {
-	}
+	~LuaBuilding() override = default;
 
 	/*
 	 * Properties
@@ -1056,14 +1014,12 @@ class LuaFlag : public LuaPlayerImmovable {
 public:
 	LUNA_CLASS_HEAD(LuaFlag);
 
-	LuaFlag() {
-	}
+	LuaFlag() = default;
 	explicit LuaFlag(Widelands::Flag& mo) : LuaPlayerImmovable(mo) {
 	}
 	explicit LuaFlag(lua_State* L) : LuaPlayerImmovable(L) {
 	}
-	~LuaFlag() override {
-	}
+	~LuaFlag() override = default;
 
 	/*
 	 * Properties
@@ -1090,14 +1046,12 @@ class LuaRoad : public LuaPlayerImmovable {
 public:
 	LUNA_CLASS_HEAD(LuaRoad);
 
-	LuaRoad() {
-	}
+	LuaRoad() = default;
 	explicit LuaRoad(Widelands::RoadBase& mo) : LuaPlayerImmovable(mo) {
 	}
 	explicit LuaRoad(lua_State* L) : LuaPlayerImmovable(L) {
 	}
-	~LuaRoad() override {
-	}
+	~LuaRoad() override = default;
 
 	/*
 	 * Properties
@@ -1128,14 +1082,12 @@ class LuaConstructionSite : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaConstructionSite);
 
-	LuaConstructionSite() {
-	}
+	LuaConstructionSite() = default;
 	explicit LuaConstructionSite(Widelands::ConstructionSite& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaConstructionSite(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaConstructionSite() override {
-	}
+	~LuaConstructionSite() override = default;
 
 	/*
 	 * Properties
@@ -1172,14 +1124,12 @@ class LuaDismantleSite : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaDismantleSite);
 
-	LuaDismantleSite() {
-	}
+	LuaDismantleSite() = default;
 	explicit LuaDismantleSite(Widelands::DismantleSite& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaDismantleSite(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaDismantleSite() override {
-	}
+	~LuaDismantleSite() override = default;
 
 	/*
 	 * Properties
@@ -1201,20 +1151,20 @@ class LuaWarehouse : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaWarehouse);
 
-	LuaWarehouse() {
-	}
+	LuaWarehouse() = default;
 	explicit LuaWarehouse(Widelands::Warehouse& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaWarehouse(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaWarehouse() override {
-	}
+	~LuaWarehouse() override = default;
 
 	/*
 	 * Properties
 	 */
 	int get_portdock(lua_State* L);
 	int get_expedition_in_progress(lua_State* L);
+	int get_warehousename(lua_State* L);
+	int set_warehousename(lua_State* L);
 
 	/*
 	 * Lua Methods
@@ -1240,14 +1190,12 @@ class LuaMarket : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaMarket);
 
-	LuaMarket() {
-	}
+	LuaMarket() = default;
 	explicit LuaMarket(Widelands::Market& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaMarket(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaMarket() override {
-	}
+	~LuaMarket() override = default;
 
 	/*
 	 * Properties
@@ -1268,14 +1216,12 @@ class LuaProductionSite : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaProductionSite);
 
-	LuaProductionSite() {
-	}
+	LuaProductionSite() = default;
 	explicit LuaProductionSite(Widelands::ProductionSite& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaProductionSite(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaProductionSite() override {
-	}
+	~LuaProductionSite() override = default;
 
 	/*
 	 * Properties
@@ -1312,14 +1258,12 @@ class LuaMilitarySite : public LuaBuilding {
 public:
 	LUNA_CLASS_HEAD(LuaMilitarySite);
 
-	LuaMilitarySite() {
-	}
+	LuaMilitarySite() = default;
 	explicit LuaMilitarySite(Widelands::MilitarySite& mo) : LuaBuilding(mo) {
 	}
 	explicit LuaMilitarySite(lua_State* L) : LuaBuilding(L) {
 	}
-	~LuaMilitarySite() override {
-	}
+	~LuaMilitarySite() override = default;
 
 	/*
 	 * Properties
@@ -1346,14 +1290,12 @@ class LuaTrainingSite : public LuaProductionSite {
 public:
 	LUNA_CLASS_HEAD(LuaTrainingSite);
 
-	LuaTrainingSite() {
-	}
+	LuaTrainingSite() = default;
 	explicit LuaTrainingSite(Widelands::TrainingSite& mo) : LuaProductionSite(mo) {
 	}
 	explicit LuaTrainingSite(lua_State* L) : LuaProductionSite(L) {
 	}
-	~LuaTrainingSite() override {
-	}
+	~LuaTrainingSite() override = default;
 
 	/*
 	 * Properties
@@ -1378,14 +1320,12 @@ class LuaBob : public LuaMapObject {
 public:
 	LUNA_CLASS_HEAD(LuaBob);
 
-	LuaBob() {
-	}
+	LuaBob() = default;
 	explicit LuaBob(Widelands::Bob& mo) : LuaMapObject(mo) {
 	}
 	explicit LuaBob(lua_State* L) : LuaMapObject(L) {
 	}
-	~LuaBob() override {
-	}
+	~LuaBob() override = default;
 
 	/*
 	 * Properties
@@ -1407,14 +1347,12 @@ class LuaWorker : public LuaBob {
 public:
 	LUNA_CLASS_HEAD(LuaWorker);
 
-	LuaWorker() {
-	}
+	LuaWorker() = default;
 	explicit LuaWorker(Widelands::Worker& w) : LuaBob(w) {
 	}
 	explicit LuaWorker(lua_State* L) : LuaBob(L) {
 	}
-	~LuaWorker() override {
-	}
+	~LuaWorker() override = default;
 
 	/*
 	 * Properties
@@ -1425,6 +1363,7 @@ public:
 	/*
 	 * Lua methods
 	 */
+	int evict(lua_State* L);
 
 	/*
 	 * C methods
@@ -1436,14 +1375,12 @@ class LuaSoldier : public LuaWorker {
 public:
 	LUNA_CLASS_HEAD(LuaSoldier);
 
-	LuaSoldier() {
-	}
+	LuaSoldier() = default;
 	explicit LuaSoldier(Widelands::Soldier& w) : LuaWorker(w) {
 	}
 	explicit LuaSoldier(lua_State* L) : LuaWorker(L) {
 	}
-	~LuaSoldier() override {
-	}
+	~LuaSoldier() override = default;
 
 	/*
 	 * Properties
@@ -1469,14 +1406,12 @@ class LuaShip : public LuaBob {
 public:
 	LUNA_CLASS_HEAD(LuaShip);
 
-	LuaShip() {
-	}
+	LuaShip() = default;
 	explicit LuaShip(Widelands::Ship& s) : LuaBob(s) {
 	}
 	explicit LuaShip(lua_State* L) : LuaBob(L) {
 	}
-	~LuaShip() override {
-	}
+	~LuaShip() override = default;
 
 	/*
 	 * Properties
@@ -1486,11 +1421,13 @@ public:
 	int get_last_portdock(lua_State* L);
 	int get_destination(lua_State* L);
 	int get_state(lua_State* L);
+	int get_type(lua_State* L);
 	int get_scouting_direction(lua_State* L);
 	int set_scouting_direction(lua_State* L);
 	int get_island_explore_direction(lua_State* L);
 	int set_island_explore_direction(lua_State* L);
 	int get_shipname(lua_State* L);
+	int set_shipname(lua_State* L);
 	int get_capacity(lua_State* L);
 	int set_capacity(lua_State* L);
 	/*
@@ -1500,12 +1437,125 @@ public:
 	int get_workers(lua_State* L);
 	int build_colonization_port(lua_State* L);
 	int make_expedition(lua_State* L);
+	int refit(lua_State* L);
 
 	/*
 	 * C methods
 	 */
 	CASTED_GET(Ship)
 };
+
+class LuaPinnedNote : public LuaBob {
+public:
+	LUNA_CLASS_HEAD(LuaPinnedNote);
+
+	LuaPinnedNote() = default;
+	explicit LuaPinnedNote(Widelands::PinnedNote& n) : LuaBob(n) {
+	}
+	explicit LuaPinnedNote(lua_State* L) : LuaBob(L) {
+	}
+	~LuaPinnedNote() override = default;
+
+	/*
+	 * Properties
+	 */
+	int get_owner(lua_State* L);
+	int get_text(lua_State*);
+	int set_text(lua_State*);
+	int get_color(lua_State*);
+	int set_color(lua_State*);
+
+	/*
+	 * Lua methods
+	 */
+
+	/*
+	 * C methods
+	 */
+	CASTED_GET(PinnedNote)
+};
+
+class LuaNavalInvasionBase : public LuaBob {
+public:
+	LUNA_CLASS_HEAD(LuaNavalInvasionBase);
+
+	LuaNavalInvasionBase() = default;
+	explicit LuaNavalInvasionBase(Widelands::NavalInvasionBase& n) : LuaBob(n) {
+	}
+	explicit LuaNavalInvasionBase(lua_State* L) : LuaBob(L) {
+	}
+	~LuaNavalInvasionBase() override = default;
+
+	/*
+	 * Properties
+	 */
+	int get_owner(lua_State* L);
+	int get_soldiers(lua_State*);
+
+	/*
+	 * Lua methods
+	 */
+
+	/*
+	 * C methods
+	 */
+	CASTED_GET(NavalInvasionBase)
+};
+
+class LuaShipFleetYardInterface : public LuaBob {
+public:
+	LUNA_CLASS_HEAD(LuaShipFleetYardInterface);
+
+	LuaShipFleetYardInterface() = default;
+	explicit LuaShipFleetYardInterface(Widelands::ShipFleetYardInterface& i) : LuaBob(i) {
+	}
+	explicit LuaShipFleetYardInterface(lua_State* L) : LuaBob(L) {
+	}
+	~LuaShipFleetYardInterface() override = default;
+
+	/*
+	 * Properties
+	 */
+	int get_owner(lua_State* L);
+	int get_building(lua_State*);
+
+	/*
+	 * Lua methods
+	 */
+
+	/*
+	 * C methods
+	 */
+	CASTED_GET(ShipFleetYardInterface)
+};
+
+class LuaFerryFleetYardInterface : public LuaBob {
+public:
+	LUNA_CLASS_HEAD(LuaFerryFleetYardInterface);
+
+	LuaFerryFleetYardInterface() = default;
+	explicit LuaFerryFleetYardInterface(Widelands::FerryFleetYardInterface& i) : LuaBob(i) {
+	}
+	explicit LuaFerryFleetYardInterface(lua_State* L) : LuaBob(L) {
+	}
+	~LuaFerryFleetYardInterface() override = default;
+
+	/*
+	 * Properties
+	 */
+	int get_owner(lua_State* L);
+	int get_building(lua_State*);
+
+	/*
+	 * Lua methods
+	 */
+
+	/*
+	 * C methods
+	 */
+	CASTED_GET(FerryFleetYardInterface)
+};
+
 #undef CASTED_GET
 
 class LuaField : public LuaMapModuleClass {
@@ -1514,8 +1564,7 @@ class LuaField : public LuaMapModuleClass {
 public:
 	LUNA_CLASS_HEAD(LuaField);
 
-	LuaField() {
-	}
+	LuaField() = default;
 	explicit LuaField(int16_t x, int16_t y) : coords_(Widelands::Coords(x, y)) {
 	}
 	explicit LuaField(Widelands::Coords c) : coords_(c) {
@@ -1523,8 +1572,7 @@ public:
 	explicit LuaField(lua_State* L) {
 		report_error(L, "Cannot instantiate a 'Field' directly!");
 	}
-	~LuaField() override {
-	}
+	~LuaField() override = default;
 
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
 	void __persist(lua_State* L) override;
@@ -1535,6 +1583,7 @@ public:
 	 * Properties
 	 */
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int get___hash(lua_State*);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 	int get_x(lua_State* L);
@@ -1562,6 +1611,7 @@ public:
 	int get_resource_amount(lua_State*);
 	int set_resource_amount(lua_State*);
 	int get_initial_resource_amount(lua_State*);
+	int set_initial_resource_amount(lua_State*);
 	int get_claimers(lua_State*);
 	int get_owner(lua_State*);
 	int get_buildable(lua_State*);
@@ -1571,7 +1621,9 @@ public:
 	 * Lua methods
 	 */
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int __tostring(lua_State* L);
+	// NOLINTNEXTLINE(bugprone-reserved-identifier,cert-dcl37-c,cert-dcl51-cpp)
 	int __eq(lua_State* L);
 	CLANG_DIAG_RESERVED_IDENTIFIER_ON
 	int region(lua_State* L);
@@ -1595,20 +1647,18 @@ private:
 };
 
 class LuaPlayerSlot : public LuaMapModuleClass {
-	Widelands::PlayerNumber player_number_;
+	Widelands::PlayerNumber player_number_{0U};
 
 public:
 	LUNA_CLASS_HEAD(LuaPlayerSlot);
 
-	LuaPlayerSlot() : player_number_(0) {
-	}
+	LuaPlayerSlot() = default;
 	explicit LuaPlayerSlot(Widelands::PlayerNumber plr) : player_number_(plr) {
 	}
 	explicit LuaPlayerSlot(lua_State* L) : player_number_(0) {
 		report_error(L, "Cannot instantiate a 'PlayerSlot' directly!");
 	}
-	~LuaPlayerSlot() override {
-	}
+	~LuaPlayerSlot() override = default;
 
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
 	void __persist(lua_State* L) override;
@@ -1619,8 +1669,11 @@ public:
 	 * Properties
 	 */
 	int get_tribe_name(lua_State*);
+	int set_tribe_name(lua_State*);
 	int get_name(lua_State*);
+	int set_name(lua_State*);
 	int get_starting_field(lua_State*);
+	int set_starting_field(lua_State*);
 
 	/*
 	 * Lua methods
