@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,7 +75,7 @@ Game
 
    .. code-block:: lua
 
-      current_speed = wl.Game().real_Speed
+      current_speed = wl.Game().real_speed
 
 */
 const char LuaGame::className[] = "Game";
@@ -89,7 +89,8 @@ const PropertyType<LuaGame> LuaGame::Properties[] = {
    PROP_RW(LuaGame, desired_speed),      PROP_RW(LuaGame, allow_saving),
    PROP_RO(LuaGame, last_save_time),     PROP_RO(LuaGame, type),
    PROP_RO(LuaGame, interactive_player), PROP_RO(LuaGame, scenario_difficulty),
-   PROP_RW(LuaGame, allow_diplomacy),    PROP_RO(LuaGame, win_condition),
+   PROP_RO(LuaGame, win_condition),      PROP_RO(LuaGame, win_condition_duration),
+   PROP_RW(LuaGame, allow_diplomacy),    PROP_RW(LuaGame, allow_naval_warfare),
    {nullptr, nullptr, nullptr},
 };
 
@@ -111,8 +112,12 @@ void LuaGame::__unpersist(lua_State* /* L */) {
 /* RST
    .. attribute:: real_speed
 
-      (RO) The speed that the current game is running at in ms.
+      (RO) The speed that the current game is set to run at in ms.
       For example, for game speed = 2x, this returns 2000.
+
+      In network games this is the speed resulting from the votes of the players, so it can be
+      different from the local player's :attr:`desired_speed`.
+      Else it is the same as :attr:`desired_speed`.
 */
 int LuaGame::get_real_speed(lua_State* L) {
 	lua_pushinteger(L, get_game(L).game_controller()->real_speed());
@@ -133,8 +138,9 @@ int LuaGame::get_time(lua_State* L) {
    .. attribute:: desired_speed
 
       (RW) Sets the desired speed of the game in ms per real second, so a speed of
-      2000 means the game runs at 2x speed. Note that this will not work in
-      network games as expected.
+      2000 means the game runs at 2x speed.
+      Note that in network games this is the speed voted by the current player. The speed resulting
+      from the votes is in :attr:`real_speed`.
 */
 // UNTESTED
 int LuaGame::set_desired_speed(lua_State* L) {
@@ -170,6 +176,8 @@ int LuaGame::get_allow_saving(lua_State* L) {
    .. attribute:: interactive_player
 
       (RO) The player number of the interactive player, or 0 for spectator
+
+      value of :attr:`wl.game.Player.number` of the interactive player
 */
 int LuaGame::get_interactive_player(lua_State* L) {
 	upcast(const InteractivePlayer, p, get_game(L).get_ibase());
@@ -227,6 +235,19 @@ int LuaGame::get_win_condition(lua_State* L) {
 	return 1;
 }
 
+/* RST
+   .. attribute:: win_condition_duration
+
+      .. versionadded:: 1.2
+
+      (RO) The time limit configured for the game's win condition, in minutes.
+      Only valid if the selected win condition allows configuring the time limit.
+*/
+int LuaGame::get_win_condition_duration(lua_State* L) {
+	lua_pushint32(L, get_game(L).get_win_condition_duration());
+	return 1;
+}
+
 /* RST
    .. attribute:: scenario_difficulty
 
@@ -259,6 +280,23 @@ int LuaGame::set_allow_diplomacy(lua_State* L) {
 	return 0;
 }
 
+/* RST
+   .. attribute:: allow_naval_warfare
+
+      .. versionadded:: 1.2
+
+      (RW) Whether players are allowed to refit ships to warships and
+      launch coastal invasions and ship-to-ship battles.
+*/
+int LuaGame::get_allow_naval_warfare(lua_State* L) {
+	lua_pushboolean(L, static_cast<int>(get_game(L).naval_warfare_allowed()));
+	return 1;
+}
+int LuaGame::set_allow_naval_warfare(lua_State* L) {
+	get_game(L).set_naval_warfare_allowed(luaL_checkboolean(L, -1));
+	return 0;
+}
+
 /*
  ==========================================================
  LUA METHODS
@@ -413,6 +451,7 @@ const PropertyType<LuaDescriptions> LuaDescriptions::Properties[] = {
    PROP_RO(LuaDescriptions, immovable_descriptions),
    PROP_RO(LuaDescriptions, terrain_descriptions),
    PROP_RO(LuaDescriptions, worker_descriptions),
+   PROP_RO(LuaDescriptions, building_descriptions),
    {nullptr, nullptr, nullptr},
 };
 
@@ -449,9 +488,8 @@ void LuaDescriptions::__unpersist(lua_State* /* L */) {
 int LuaDescriptions::get_tribes_descriptions(lua_State* L) {
 	const Widelands::Descriptions& descriptions = get_egbase(L).descriptions();
 	lua_newtable(L);
-	int index = 1;
 	for (Widelands::DescriptionIndex i = 0; i < descriptions.nr_tribes(); ++i) {
-		lua_pushint32(L, index++);
+		lua_pushint32(L, i + 1);
 		to_lua<LuaMaps::LuaTribeDescription>(
 		   L, new LuaMaps::LuaTribeDescription(descriptions.get_tribe_descr(i)));
 		lua_settable(L, -3);
@@ -469,9 +507,8 @@ int LuaDescriptions::get_tribes_descriptions(lua_State* L) {
 int LuaDescriptions::get_immovable_descriptions(lua_State* L) {
 	const Widelands::Descriptions& descriptions = get_egbase(L).descriptions();
 	lua_newtable(L);
-	int index = 1;
 	for (Widelands::DescriptionIndex i = 0; i < descriptions.nr_immovables(); ++i) {
-		lua_pushint32(L, index++);
+		lua_pushint32(L, i + 1);
 		to_lua<LuaMaps::LuaImmovableDescription>(
 		   L, new LuaMaps::LuaImmovableDescription(descriptions.get_immovable_descr(i)));
 		lua_settable(L, -3);
@@ -479,6 +516,24 @@ int LuaDescriptions::get_immovable_descriptions(lua_State* L) {
 	return 1;
 }
 
+/* RST
+   .. attribute:: building_descriptions
+
+      .. versionadded:: 1.2
+
+      (RO) An :class:`array` of all :class:`~wl.map.BuildingDescription` objects that are available.
+*/
+int LuaDescriptions::get_building_descriptions(lua_State* L) {
+	const Widelands::Descriptions& descriptions = get_egbase(L).descriptions();
+	lua_newtable(L);
+	for (Widelands::DescriptionIndex i = 0; i < descriptions.nr_buildings(); ++i) {
+		lua_pushint32(L, i + 1);
+		LuaMaps::upcasted_map_object_descr_to_lua(L, descriptions.get_building_descr(i));
+		lua_settable(L, -3);
+	}
+	return 1;
+}
+
 /* RST
    .. attribute:: terrain_descriptions
 
@@ -489,9 +544,8 @@ int LuaDescriptions::get_immovable_descriptions(lua_State* L) {
 int LuaDescriptions::get_terrain_descriptions(lua_State* L) {
 	const Widelands::Descriptions& descriptions = get_egbase(L).descriptions();
 	lua_newtable(L);
-	int index = 1;
 	for (Widelands::DescriptionIndex i = 0; i < descriptions.terrains().size(); ++i) {
-		lua_pushint32(L, index++);
+		lua_pushint32(L, i + 1);
 		to_lua<LuaMaps::LuaTerrainDescription>(
 		   L, new LuaMaps::LuaTerrainDescription(descriptions.get_terrain_descr(i)));
 		lua_settable(L, -3);
@@ -509,11 +563,9 @@ int LuaDescriptions::get_terrain_descriptions(lua_State* L) {
 int LuaDescriptions::get_worker_descriptions(lua_State* L) {
 	const Widelands::Descriptions& descriptions = get_egbase(L).descriptions();
 	lua_newtable(L);
-	int index = 1;
 	for (Widelands::DescriptionIndex i = 0; i < descriptions.workers().size(); ++i) {
-		lua_pushint32(L, index++);
-		to_lua<LuaMaps::LuaWorkerDescription>(
-		   L, new LuaMaps::LuaWorkerDescription(descriptions.get_worker_descr(i)));
+		lua_pushint32(L, i + 1);
+		LuaMaps::upcasted_map_object_descr_to_lua(L, descriptions.get_worker_descr(i));
 		lua_settable(L, -3);
 	}
 	return 1;
@@ -727,6 +779,9 @@ int LuaDescriptions::new_tribe(lua_State* L) {
          :const:`"becomes"`                            **worker_name**    (*string*)            1.0
          :const:`"programs"`, :const:`"set"`           **program_name**   (*string*),           1.0
                                                        **actions_table**  (*table*)
+         :const:`"buildcost"`, :const:`"set"`          **ware_name**      (*string*),           1.2
+                                                       **amount**         (*int*)
+         :const:`"buildcost"`, :const:`"remove"`       **ware_name**      (*string*),           1.2
          ============================================  =======================================  =============
 
       .. table:: ``"building"``
@@ -814,6 +869,7 @@ int LuaDescriptions::new_tribe(lua_State* L) {
          ============================================  =======================================  =============
          :const:`"heal_per_second"`                    **amount**         (*int*)               1.1
          :const:`"conquers"`                           **radius**         (*int*)               1.1
+         :const:`"max_garrison"`                       **amount**         (*int*)               1.2
          ============================================  =======================================  =============
 
       .. table:: ``"tribe"``
@@ -889,42 +945,46 @@ int LuaDescriptions::new_tribe(lua_State* L) {
 */
 // clang-format on
 int LuaDescriptions::modify_unit(lua_State* L) {
-	const std::string type = luaL_checkstring(L, 2);
-	const std::string unit = luaL_checkstring(L, 3);
-	const std::string property = luaL_checkstring(L, 4);
+	if (lua_gettop(L) < 4) {
+		report_error(L, "modify_unit: too few arguments");
+	}
 
-	// Load the unit to modify if it was not loaded yet
-	Notifications::publish(Widelands::NoteMapObjectDescription(
-	   unit, Widelands::NoteMapObjectDescription::LoadType::kObject));
+	try {
+		const std::string type = luaL_checkstring(L, 2);
+		const std::string unit = luaL_checkstring(L, 3);
+		const std::string property = luaL_checkstring(L, 4);
 
-	if (type == "resource") {
-		do_modify_resource(L, unit, property);
-	} else if (type == "tribe") {
-		do_modify_tribe(L, unit, property);
-	} else if (type == "ship") {
-		do_modify_ship(L, unit, property);
-	} else if (type == "critter") {
-		do_modify_critter(L, unit, property);
-	} else if (type == "terrain") {
-		do_modify_terrain(L, unit, property);
-	} else if (type == "immovable") {
-		do_modify_immovable(L, unit, property);
-	} else if (type == "worker") {
-		do_modify_worker(L, unit, property);
-	} else if (type == "ware") {
-		do_modify_ware(L, unit, property);
-	} else if (type == "building") {
-		do_modify_building(L, unit, property);
-	} else if (type == "trainingsite") {
-		do_modify_trainingsite(L, unit, property);
-	} else if (type == "productionsite") {
-		do_modify_productionsite(L, unit, property);
-	} else if (type == "militarysite") {
-		do_modify_militarysite(L, unit, property);
-	} else if (type == "warehouse") {
-		do_modify_warehouse(L, unit, property);
-	} else {
-		report_error(L, "modify_unit: invalid type '%s'", type.c_str());
+		if (type == "resource") {
+			do_modify_resource(L, unit, property);
+		} else if (type == "tribe") {
+			do_modify_tribe(L, unit, property);
+		} else if (type == "ship") {
+			do_modify_ship(L, unit, property);
+		} else if (type == "critter") {
+			do_modify_critter(L, unit, property);
+		} else if (type == "terrain") {
+			do_modify_terrain(L, unit, property);
+		} else if (type == "immovable") {
+			do_modify_immovable(L, unit, property);
+		} else if (type == "worker") {
+			do_modify_worker(L, unit, property);
+		} else if (type == "ware") {
+			do_modify_ware(L, unit, property);
+		} else if (type == "building") {
+			do_modify_building(L, unit, property);
+		} else if (type == "trainingsite") {
+			do_modify_trainingsite(L, unit, property);
+		} else if (type == "productionsite") {
+			do_modify_productionsite(L, unit, property);
+		} else if (type == "militarysite") {
+			do_modify_militarysite(L, unit, property);
+		} else if (type == "warehouse") {
+			do_modify_warehouse(L, unit, property);
+		} else {
+			report_error(L, "modify_unit: invalid type '%s'", type.c_str());
+		}
+	} catch (const std::exception& e) {
+		report_error(L, "modify_unit: error: %s", e.what());
 	}
 
 	return 0;
@@ -942,7 +1002,7 @@ void LuaDescriptions::do_modify_resource(lua_State* L,
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
 	Widelands::ResourceDescription& resource_descr =
-	   *descrs.get_mutable_resource_descr(descrs.safe_resource_index(unit_name));
+	   *descrs.get_mutable_resource_descr(descrs.load_resource(unit_name));
 
 	if (property == "max_amount") {
 		resource_descr.set_max_amount(luaL_checkuint32(L, 5));
@@ -957,7 +1017,7 @@ void LuaDescriptions::do_modify_tribe(lua_State* L,
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
 	Widelands::TribeDescr& tribe_descr =
-	   *descrs.get_mutable_tribe_descr(descrs.safe_tribe_index(unit_name));
+	   *descrs.get_mutable_tribe_descr(descrs.load_tribe(unit_name));
 
 	if (property == "add_ware") {
 		const std::string warename = luaL_checkstring(L, 5);
@@ -965,7 +1025,7 @@ void LuaDescriptions::do_modify_tribe(lua_State* L,
 		   warename, Widelands::NoteMapObjectDescription::LoadType::kObject));
 
 		const size_t column = luaL_checkuint32(L, 6);
-		const Widelands::DescriptionIndex di = descrs.safe_ware_index(warename);
+		const Widelands::DescriptionIndex di = descrs.load_ware(warename);
 		tribe_descr.mutable_wares().insert(di);
 		tribe_descr.mutable_wares_order()[column].push_back(di);
 
@@ -993,7 +1053,7 @@ void LuaDescriptions::do_modify_tribe(lua_State* L,
 		   workername, Widelands::NoteMapObjectDescription::LoadType::kObject));
 
 		const size_t column = luaL_checkuint32(L, 6);
-		const Widelands::DescriptionIndex di = descrs.safe_worker_index(workername);
+		const Widelands::DescriptionIndex di = descrs.load_worker(workername);
 		tribe_descr.mutable_workers().insert(di);
 		tribe_descr.mutable_workers_order()[column].push_back(di);
 
@@ -1023,7 +1083,7 @@ void LuaDescriptions::do_modify_tribe(lua_State* L,
 		Notifications::publish(Widelands::NoteMapObjectDescription(
 		   buildingname, Widelands::NoteMapObjectDescription::LoadType::kObject));
 
-		const Widelands::DescriptionIndex di = descrs.safe_building_index(buildingname);
+		const Widelands::DescriptionIndex di = descrs.load_building(buildingname);
 		tribe_descr.mutable_buildings().insert(di);
 
 		LuaTable t(L);
@@ -1039,11 +1099,11 @@ void LuaDescriptions::do_modify_tribe(lua_State* L,
 		const std::string immo_name = luaL_checkstring(L, 5);
 		Notifications::publish(Widelands::NoteMapObjectDescription(
 		   immo_name, Widelands::NoteMapObjectDescription::LoadType::kObject));
-		tribe_descr.mutable_immovables().insert(descrs.safe_immovable_index(immo_name));
+		tribe_descr.mutable_immovables().insert(descrs.load_immovable(immo_name));
 
 		LuaTable t(L);
 		tribe_descr.load_helptexts(
-		   descrs.get_mutable_immovable_descr(descrs.safe_immovable_index(immo_name)), t);
+		   descrs.get_mutable_immovable_descr(descrs.load_immovable(immo_name)), t);
 	} else {
 		report_error(L, "modify_unit: invalid tribe property '%s'", property.c_str());
 	}
@@ -1055,7 +1115,7 @@ void LuaDescriptions::do_modify_worker(lua_State* L,
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
 	Widelands::WorkerDescr& worker_descr =
-	   *descrs.get_mutable_worker_descr(descrs.safe_worker_index(unit_name));
+	   *descrs.get_mutable_worker_descr(descrs.load_worker(unit_name));
 
 	if (property == "experience") {
 		worker_descr.set_needed_experience(luaL_checkuint32(L, 5));
@@ -1071,6 +1131,17 @@ void LuaDescriptions::do_modify_worker(lua_State* L,
 		} else {
 			report_error(L, "modify_unit - worker - programs: invalid command '%s'", cmd.c_str());
 		}
+	} else if (property == "buildcost") {
+		const std::string cmd = luaL_checkstring(L, 5);
+		const std::string item_name = luaL_checkstring(L, 6);
+		Widelands::WorkerDescr::Buildcost& bc = worker_descr.mutable_buildcost();
+		if (cmd == "remove") {
+			bc.erase(item_name);
+		} else if (cmd == "set") {
+			bc[item_name] = luaL_checkuint32(L, 7);
+		} else {
+			report_error(L, "modify_unit - worker - buildcost: invalid command '%s'", cmd.c_str());
+		}
 	} else {
 		report_error(L, "modify_unit: invalid worker property '%s'", property.c_str());
 	}
@@ -1081,7 +1152,7 @@ void LuaDescriptions::do_modify_building(lua_State* L,
                                          const std::string& property) {
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
-	const Widelands::DescriptionIndex bldindex = descrs.safe_building_index(unit_name);
+	const Widelands::DescriptionIndex bldindex = descrs.load_building(unit_name);
 	Widelands::BuildingDescr& bld = *descrs.get_mutable_building_descr(bldindex);
 
 	if (property == "enhancement") {
@@ -1094,7 +1165,7 @@ void LuaDescriptions::do_modify_building(lua_State* L,
 		Widelands::Buildcost& bc = bld.mutable_buildcost();
 		const std::string cmd = luaL_checkstring(L, 5);
 		const std::string warename = luaL_checkstring(L, 6);
-		const Widelands::DescriptionIndex wi = descrs.safe_ware_index(warename);
+		const Widelands::DescriptionIndex wi = descrs.load_ware(warename);
 		if (cmd == "remove") {
 			bc.erase(wi);
 		} else if (cmd == "set") {
@@ -1106,7 +1177,7 @@ void LuaDescriptions::do_modify_building(lua_State* L,
 		Widelands::Buildcost& bc = bld.mutable_returns_on_dismantle();
 		const std::string cmd = luaL_checkstring(L, 5);
 		const std::string warename = luaL_checkstring(L, 6);
-		const Widelands::DescriptionIndex wi = descrs.safe_ware_index(warename);
+		const Widelands::DescriptionIndex wi = descrs.load_ware(warename);
 		if (cmd == "remove") {
 			bc.erase(wi);
 		} else if (cmd == "set") {
@@ -1119,7 +1190,7 @@ void LuaDescriptions::do_modify_building(lua_State* L,
 		Widelands::Buildcost& bc = bld.mutable_enhancement_cost();
 		const std::string cmd = luaL_checkstring(L, 5);
 		const std::string warename = luaL_checkstring(L, 6);
-		const Widelands::DescriptionIndex wi = descrs.safe_ware_index(warename);
+		const Widelands::DescriptionIndex wi = descrs.load_ware(warename);
 		if (cmd == "remove") {
 			bc.erase(wi);
 		} else if (cmd == "set") {
@@ -1132,7 +1203,7 @@ void LuaDescriptions::do_modify_building(lua_State* L,
 		Widelands::Buildcost& bc = bld.mutable_enhancement_returns_on_dismantle();
 		const std::string cmd = luaL_checkstring(L, 5);
 		const std::string warename = luaL_checkstring(L, 6);
-		const Widelands::DescriptionIndex wi = descrs.safe_ware_index(warename);
+		const Widelands::DescriptionIndex wi = descrs.load_ware(warename);
 		if (cmd == "remove") {
 			bc.erase(wi);
 		} else if (cmd == "set") {
@@ -1152,7 +1223,7 @@ void LuaDescriptions::do_modify_productionsite(lua_State* L,
                                                const std::string& property) {
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
-	const Widelands::DescriptionIndex psindex = descrs.safe_building_index(unit_name);
+	const Widelands::DescriptionIndex psindex = descrs.load_building(unit_name);
 	Widelands::ProductionSiteDescr& psdescr =
 	   dynamic_cast<Widelands::ProductionSiteDescr&>(*descrs.get_mutable_building_descr(psindex));
 
@@ -1163,12 +1234,12 @@ void LuaDescriptions::do_modify_productionsite(lua_State* L,
 		   input_name, Widelands::NoteMapObjectDescription::LoadType::kObject));
 
 		if (cmd == "add_ware") {
-			const Widelands::DescriptionIndex di = descrs.safe_ware_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_ware(input_name);
 			const Widelands::Quantity amount = luaL_checkuint32(L, 7);
 			assert(amount);
 			psdescr.mutable_input_wares().push_back(Widelands::WareAmount(di, amount));
 		} else if (cmd == "modify_ware") {
-			const Widelands::DescriptionIndex di = descrs.safe_ware_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_ware(input_name);
 			const Widelands::Quantity amount = luaL_checkuint32(L, 7);
 			assert(amount);
 			for (Widelands::WareAmount& w : psdescr.mutable_input_wares()) {
@@ -1180,7 +1251,7 @@ void LuaDescriptions::do_modify_productionsite(lua_State* L,
 			report_error(L, "modify_unit - productionsite - input - modify_ware: %s not found",
 			             input_name.c_str());
 		} else if (cmd == "remove_ware") {
-			const Widelands::DescriptionIndex di = descrs.safe_ware_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_ware(input_name);
 			for (auto it = psdescr.mutable_input_wares().begin();
 			     it != psdescr.mutable_input_wares().end(); ++it) {
 				if (it->first == di) {
@@ -1191,12 +1262,12 @@ void LuaDescriptions::do_modify_productionsite(lua_State* L,
 			report_error(L, "modify_unit - productionsite - input - remove_ware: %s not found",
 			             input_name.c_str());
 		} else if (cmd == "add_worker") {
-			const Widelands::DescriptionIndex di = descrs.safe_worker_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_worker(input_name);
 			const Widelands::Quantity amount = luaL_checkuint32(L, 7);
 			assert(amount);
 			psdescr.mutable_input_workers().push_back(Widelands::WareAmount(di, amount));
 		} else if (cmd == "modify_worker") {
-			const Widelands::DescriptionIndex di = descrs.safe_worker_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_worker(input_name);
 			const Widelands::Quantity amount = luaL_checkuint32(L, 7);
 			assert(amount);
 			for (Widelands::WareAmount& w : psdescr.mutable_input_workers()) {
@@ -1208,7 +1279,7 @@ void LuaDescriptions::do_modify_productionsite(lua_State* L,
 			report_error(L, "modify_unit - productionsite - input - modify_worker: %s not found",
 			             input_name.c_str());
 		} else if (cmd == "remove_worker") {
-			const Widelands::DescriptionIndex di = descrs.safe_worker_index(input_name);
+			const Widelands::DescriptionIndex di = descrs.load_worker(input_name);
 			for (auto it = psdescr.mutable_input_workers().begin();
 			     it != psdescr.mutable_input_workers().end(); ++it) {
 				if (it->first == di) {
@@ -1258,7 +1329,7 @@ void LuaDescriptions::do_modify_terrain(lua_State* L,
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
 	Widelands::TerrainDescription& terrain =
-	   *descrs.get_mutable_terrain_descr(descrs.safe_terrain_index(unit_name));
+	   *descrs.get_mutable_terrain_descr(descrs.load_terrain(unit_name));
 
 	if (property == "enhancement") {
 		terrain.set_enhancement(luaL_checkstring(L, 5), luaL_checkstring(L, 6));
@@ -1287,7 +1358,7 @@ void LuaDescriptions::do_modify_trainingsite(lua_State* L,
                                              const std::string& property) {
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
-	const Widelands::DescriptionIndex tsindex = descrs.safe_building_index(unit_name);
+	const Widelands::DescriptionIndex tsindex = descrs.load_building(unit_name);
 	Widelands::TrainingSiteDescr& tsdescr =
 	   dynamic_cast<Widelands::TrainingSiteDescr&>(*descrs.get_mutable_building_descr(tsindex));
 
@@ -1305,7 +1376,7 @@ void LuaDescriptions::do_modify_militarysite(lua_State* L,
                                              const std::string& property) {
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
-	const Widelands::DescriptionIndex msindex = descrs.safe_building_index(unit_name);
+	const Widelands::DescriptionIndex msindex = descrs.load_building(unit_name);
 	Widelands::MilitarySiteDescr& msdescr =
 	   dynamic_cast<Widelands::MilitarySiteDescr&>(*descrs.get_mutable_building_descr(msindex));
 
@@ -1325,7 +1396,7 @@ void LuaDescriptions::do_modify_warehouse(lua_State* L,
                                           const std::string& property) {
 	Widelands::EditorGameBase& egbase = get_egbase(L);
 	Widelands::Descriptions& descrs = *egbase.mutable_descriptions();
-	const Widelands::DescriptionIndex whindex = descrs.safe_building_index(unit_name);
+	const Widelands::DescriptionIndex whindex = descrs.load_building(unit_name);
 	Widelands::WarehouseDescr& whdescr =
 	   dynamic_cast<Widelands::WarehouseDescr&>(*descrs.get_mutable_building_descr(whindex));
 
@@ -1333,6 +1404,8 @@ void LuaDescriptions::do_modify_warehouse(lua_State* L,
 		whdescr.set_conquers(luaL_checkuint32(L, 5));
 	} else if (property == "heal_per_second") {
 		whdescr.set_heal_per_second(luaL_checkuint32(L, 5));
+	} else if (property == "max_garrison") {
+		whdescr.set_max_garrison(luaL_checkuint32(L, 5));
 	} else {
 		report_error(L, "modify_unit: invalid warehouse property '%s'", property.c_str());
 	}
@@ -1353,27 +1426,8 @@ void luaopen_wlroot(lua_State* L, bool in_editor) {
 		register_class<LuaGame>(L, "", true);
 		add_parent<LuaGame, LuaBases::LuaEditorGameBase>(L);
 		lua_pop(L, 1);  // Pop the meta table
-
-		// TODO(GunChleoc): These 2 classes are only here for savegame compatibility
-		register_class<LuaWorld>(L, "", false);
-		register_class<LuaTribes>(L, "", false);
 	}
 	register_class<LuaDescriptions>(L, "", false);
 }
 
-const char LuaWorld::className[] = "World";
-const MethodType<LuaWorld> LuaWorld::Methods[] = {
-   {nullptr, nullptr},
-};
-const PropertyType<LuaWorld> LuaWorld::Properties[] = {
-   {nullptr, nullptr, nullptr},
-};
-const char LuaTribes::className[] = "Tribes";
-const MethodType<LuaTribes> LuaTribes::Methods[] = {
-   {nullptr, nullptr},
-};
-const PropertyType<LuaTribes> LuaTribes::Properties[] = {
-   {nullptr, nullptr, nullptr},
-};
-
 }  // namespace LuaRoot
