@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -42,8 +42,7 @@ public:
 		return "";
 	}
 
-	LuaGame() {
-	}
+	LuaGame() = default;
 	explicit LuaGame(lua_State* L);
 
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
@@ -65,8 +64,11 @@ public:
 	int get_scenario_difficulty(lua_State*);
 	int get_allow_diplomacy(lua_State*);
 	int set_allow_diplomacy(lua_State*);
+	int get_allow_naval_warfare(lua_State*);
+	int set_allow_naval_warfare(lua_State*);
 	int get_interactive_player(lua_State*);
 	int get_win_condition(lua_State*);
+	int get_win_condition_duration(lua_State*);
 
 	/*
 	 * Lua methods
@@ -86,11 +88,9 @@ public:
 		return "";
 	}
 
-	LuaEditor() {
-	}
+	LuaEditor() = default;
 	explicit LuaEditor(lua_State* L);
-	~LuaEditor() override {
-	}
+	~LuaEditor() override = default;
 
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
 	void __persist(lua_State* L) override;
@@ -117,8 +117,7 @@ public:
 		return "";
 	}
 
-	LuaDescriptions() {
-	}
+	LuaDescriptions() = default;
 	explicit LuaDescriptions(lua_State* L);
 
 	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
@@ -131,6 +130,7 @@ public:
 	 */
 	int get_tribes_descriptions(lua_State* L);
 	int get_immovable_descriptions(lua_State* L);
+	int get_building_descriptions(lua_State* L);
 	int get_terrain_descriptions(lua_State* L);
 	int get_worker_descriptions(lua_State*);
 
@@ -177,47 +177,7 @@ public:
 	void do_modify_ship(lua_State* L, const std::string&, const std::string&);
 };
 
-// TODO(GunChleoc): This class is here for saveloading compatibility only. We'll get a SIGABRT from
-// the scripting packet if it's not there.
-class LuaWorld : public LuaRootModuleClass {
-public:
-	LUNA_CLASS_HEAD(LuaWorld);
-	const char* get_modulename() override {
-		return "";
-	}
-	LuaWorld() = default;
-	explicit LuaWorld(lua_State*) {
-	}
-
-	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
-	void __persist(lua_State*) override {
-	}
-	void __unpersist(lua_State*) override {
-	}
-	CLANG_DIAG_RESERVED_IDENTIFIER_ON
-};
-
-// TODO(GunChleoc): This class is here for saveloading compatibility only. We'll get a SIGABRT from
-// the scripting packet if it's not there.
-class LuaTribes : public LuaRootModuleClass {
-public:
-	LUNA_CLASS_HEAD(LuaTribes);
-	const char* get_modulename() override {
-		return "";
-	}
-	LuaTribes() = default;
-	explicit LuaTribes(lua_State*) {
-	}
-
-	CLANG_DIAG_RESERVED_IDENTIFIER_OFF
-	void __persist(lua_State*) override {
-	}
-	void __unpersist(lua_State*) override {
-	}
-	CLANG_DIAG_RESERVED_IDENTIFIER_ON
-};
-
 void luaopen_wlroot(lua_State*, bool in_editor);
 
 #endif  // end of include guard: WL_SCRIPTING_LUA_ROOT_H
-}
+}  // namespace LuaRoot
