@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 #include <memory>
 #include <set>
 
-#include "base/multithreading.h"
+#include "base/mutex.h"
 #include "base/string.h"
 #include "base/vector.h"
 #include "scripting/lua.h"
@@ -131,7 +131,7 @@ public:
 			lua_pop(L_, 1);
 			throw LuaError(as_string(key) + " is not a string value.");
 		}
-		const std::string rv = lua_tostring(L_, -1);
+		std::string rv = lua_tostring(L_, -1);
 		lua_pop(L_, 1);
 		return rv;
 	}
@@ -181,6 +181,13 @@ public:
 		return static_cast<int>(value);
 	}
 
+	/// Returns the corresponding value with the given 'key' if it exists,
+	/// otherwise returns 'default_value'.
+	template <typename KeyType>
+	int get_int_with_default(const KeyType& key, const int default_value) const {
+		return has_key(key) ? get_int(key) : default_value;
+	}
+
 	template <typename KeyType> bool get_bool(const KeyType& key) const {
 		get_existing_table_value(key);
 		if (!lua_isboolean(L_, -1)) {
@@ -192,6 +199,13 @@ public:
 		return rv;
 	}
 
+	/// Returns the corresponding value with the given 'key' if it exists,
+	/// otherwise returns 'default_value'.
+	template <typename KeyType>
+	bool get_bool_with_default(const KeyType& key, const bool default_value) const {
+		return has_key(key) ? get_bool(key) : default_value;
+	}
+
 	template <typename KeyType>
 	std::unique_ptr<LuaCoroutine> get_coroutine(const KeyType& key) const {
 		get_existing_table_value(key);
@@ -223,10 +237,12 @@ private:
 	// Get a lua value of the specific type. See template specializations.
 	template <typename T> T get_value() const;
 
-	MutexLock mutex_lock_;
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock objects_lock_;
+	MutexLock lua_lock_;
 	lua_State* L_;
 	mutable std::set<std::string> accessed_keys_;
-	bool warn_about_unaccessed_keys_;
+	bool warn_about_unaccessed_keys_{true};
 };
 
 template <> std::string LuaTable::get_value<std::string>() const;
