@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,6 +45,8 @@ std::string get_file_content(FileSystem* fs, const std::string& filename) {
 // Runs the 'content' as a lua script identified by 'identifier' in 'L'.
 std::unique_ptr<LuaTable>
 run_string_as_script(lua_State* L, const std::string& identifier, const std::string& content) {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
 	MutexLock m(MutexLock::ID::kLua);
 
 	// Get the current value of __file__
@@ -87,6 +89,9 @@ run_string_as_script(lua_State* L, const std::string& identifier, const std::str
 }  // namespace
 
 int check_return_value_for_errors(lua_State* L, int rv) {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
+	MutexLock m(MutexLock::ID::kLua);
 	if (rv != 0) {
 		const std::string err = luaL_checkstring(L, -1);
 		lua_pop(L, 1);
@@ -96,6 +101,9 @@ int check_return_value_for_errors(lua_State* L, int rv) {
 }
 
 std::unique_ptr<LuaTable> run_script(lua_State* L, const std::string& path, FileSystem* fs) {
+	// TODO(tothxa): kObjects before kLua is needed because of Panel::do_run() and plugin actions
+	MutexLock o(MutexLock::ID::kObjects);
+	MutexLock m(MutexLock::ID::kLua);
 	const std::string content = get_file_content(fs, path);
 	return run_string_as_script(L, path, content);
 }
