@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@ struct FXset {
 	/**
 	 * Number of ticks since this FXSet was last played
 	 */
-	uint32_t ticks_since_last_play() const;
+	[[nodiscard]] uint32_t ticks_since_last_play() const;
 
 	/** Get a sound effect from the fxset. Load the audio on demand.
 	 * \param random A random number for picking a variant
