@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2022 by the Widelands Development Team
+ * Copyright (C) 2010-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,13 +32,14 @@ struct Icon : public Panel {
 	/// Create a new icon with the given dimensions and position offset
 	Icon(Panel* parent,
 	     PanelStyle,
+	     const std::string& name,
 	     int32_t x,
 	     int32_t y,
 	     int32_t w,
 	     int32_t h,
 	     const Image* picture_id);
 	/// Create a new icon with no offset. Dimentions are taken from 'picture_id'.
-	Icon(Panel* parent, PanelStyle, const Image* picture_id);
+	Icon(Panel* parent, PanelStyle, const std::string& name, const Image* picture_id);
 
 	void set_icon(const Image* picture_id);
 	const Image* icon() const {
