@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2022 by the Widelands Development Team
+ * Copyright (C) 2003-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,12 +65,13 @@ private:
  */
 IconGrid::IconGrid(Panel* const parent,
                    PanelStyle s,
+                   const std::string& name,
                    int32_t x,
                    int32_t y,
                    int32_t cellw,
                    int32_t cellh,
                    int32_t cols)
-   : Panel(parent, s, x, y, 0, 0), columns_(cols), cell_width_(cellw), cell_height_(cellh) {
+   : Panel(parent, s, name, x, y, 0, 0), columns_(cols), cell_width_(cellw), cell_height_(cellh) {
 }
 
 /**
