@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,6 +45,7 @@ enum class ListselectLayout {
  */
 struct BaseListselect : public Panel {
 	BaseListselect(Panel* parent,
+	               const std::string& name,
 	               int32_t x,
 	               int32_t y,
 	               uint32_t w,
@@ -57,17 +58,17 @@ struct BaseListselect : public Panel {
 	Notifications::Signal<uint32_t> double_clicked;
 
 	void clear();
-	void sort(const uint32_t Begin = 0, uint32_t End = std::numeric_limits<uint32_t>::max());
+	void sort(uint32_t Begin = 0, uint32_t End = std::numeric_limits<uint32_t>::max());
 	/**
 	 * Text conventions: Title Case for the 'name', Sentence case for the 'tooltip_text'
 	 */
 	void add(const std::string& name,
 	         uint32_t entry,
 	         const Image* pic,
-	         const bool select_this,
+	         bool select_this,
 	         const std::string& tooltip_text,
 	         const std::string& hotkey,
-	         const unsigned indent);
+	         unsigned indent);
 
 	void remove(uint32_t);
 	void remove(const char* str);
@@ -103,6 +104,17 @@ struct BaseListselect : public Panel {
 
 	///  Return the total height (text + spacing) occupied by a single line.
 	int get_lineheight() const;
+	int get_lineheight_without_padding() const;
+	void set_min_lineheight(int minh) {
+		min_lineheight_ = minh;
+	}
+
+	void set_select_with_wheel(bool s) {
+		select_with_wheel_ = s;
+	}
+	[[nodiscard]] bool get_select_with_wheel() const {
+		return select_with_wheel_;
+	}
 
 	uint32_t get_eff_w() const;
 
@@ -118,6 +130,9 @@ struct BaseListselect : public Panel {
 	bool handle_mousewheel(int32_t x, int32_t y, uint16_t modstate) override;
 	bool handle_key(bool down, SDL_Keysym) override;
 
+	/* Ensure the selected entry is visible in the list. */
+	void scroll_to_selection();
+
 	void set_linked_dropdown(UI::BaseDropdown* d) {
 		linked_dropdown = d;
 	}
@@ -134,7 +149,7 @@ private:
 		                     const Image* init_pic,
 		                     const std::string& tooltip_text,
 		                     const std::string& hotkey_text,
-		                     const unsigned indent,
+		                     unsigned indent,
 		                     const UI::TableStyleInfo& style);
 		~EntryRecord();
 
@@ -150,14 +165,14 @@ private:
 	};
 
 	int max_pic_width_;
-	int widest_text_;
-	int widest_hotkey_;
+	int widest_text_{0};
+	int widest_hotkey_{0};
 
 	std::deque<EntryRecord*> entry_records_;
 	Scrollbar scrollbar_;
-	uint32_t scrollpos_;  //  in pixels
+	uint32_t scrollpos_{0U};  //  in pixels
 	uint32_t selection_;
-	uint32_t last_click_time_;
+	uint32_t last_click_time_{std::numeric_limits<uint32_t>::max()};
 	uint32_t last_selection_;  // for double clicks
 	ListselectLayout selection_mode_;
 	const Image* check_pic_;
@@ -166,20 +181,23 @@ private:
 	const UI::PanelStyleInfo* background_style() const;  // Background color and texture
 
 	int lineheight_;
+	int min_lineheight_{0};
 	std::string current_tooltip_;
+	bool select_with_wheel_{true};
 
-	UI::BaseDropdown* linked_dropdown;
+	UI::BaseDropdown* linked_dropdown{nullptr};
 };
 
 template <typename Entry> struct Listselect : public BaseListselect {
 	Listselect(Panel* parent,
+	           const std::string& name,
 	           int32_t x,
 	           int32_t y,
 	           uint32_t w,
 	           uint32_t h,
 	           UI::PanelStyle style,
 	           ListselectLayout selection_mode = ListselectLayout::kPlain)
-	   : BaseListselect(parent, x, y, w, h, style, selection_mode) {
+	   : BaseListselect(parent, name, x, y, w, h, style, selection_mode) {
 	}
 
 	void add(const std::string& name,
@@ -217,13 +235,14 @@ template <typename Entry> struct Listselect<Entry&> : public Listselect<Entry*>
 	using Base = Listselect<Entry*>;
 
 	Listselect(Panel* parent,
+	           const std::string& name,
 	           int32_t x,
 	           int32_t y,
 	           uint32_t w,
 	           uint32_t h,
 	           UI::PanelStyle style,
 	           ListselectLayout selection_mode = ListselectLayout::kPlain)
-	   : Base(parent, x, y, w, h, style, selection_mode) {
+	   : Base(parent, name, x, y, w, h, style, selection_mode) {
 	}
 
 	void add(const std::string& name,
