@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,7 @@
 #define WL_UI_BASIC_MULTILINETEXTAREA_H
 
 #include <memory>
+#include <optional>
 
 #include "graphic/align.h"
 #include "graphic/styles/font_style.h"
@@ -44,20 +45,22 @@ struct MultilineTextarea : public Panel {
 	};
 
 	MultilineTextarea(
-	   Panel* const parent,
-	   const int32_t x,
-	   const int32_t y,
-	   const uint32_t w,
-	   const uint32_t h,
+	   Panel* parent,
+	   const std::string& name,
+	   int32_t x,
+	   int32_t y,
+	   uint32_t w,
+	   uint32_t h,
 	   UI::PanelStyle style,
 	   const std::string& text = std::string(),
-	   const Align = UI::Align::kLeft,
+	   Align = UI::Align::kLeft,
 	   MultilineTextarea::ScrollMode scroll_mode = MultilineTextarea::ScrollMode::kScrollNormal);
 
 	const std::string& get_text() const {
 		return text_;
 	}
 
+	void get_text_size(int* w, int* h);
 	void set_text(const std::string&);
 	// int instead of uint because of overflow situations
 	int32_t get_eff_w() const {
@@ -70,8 +73,11 @@ struct MultilineTextarea : public Panel {
 	// Drawing and event handlers
 	void draw(RenderTarget&) override;
 
+	bool handle_mousepress(uint8_t btn, int32_t x, int32_t y) override;
 	bool handle_mousewheel(int32_t x, int32_t y, uint16_t modstate) override;
 	bool handle_key(bool down, SDL_Keysym code) override;
+	bool
+	handle_mousemove(uint8_t state, int32_t x, int32_t y, int32_t xdiff, int32_t ydiff) override;
 	void scroll_to_top();
 
 	void set_scrollmode(MultilineTextarea::ScrollMode scroll_mode);
@@ -89,12 +95,14 @@ private:
 	 */
 	std::string make_richtext();
 	std::string text_;
+	std::optional<std::string> tooltip_before_hyperlink_tooltip_;
 
 	std::shared_ptr<const UI::RenderedText> rendered_text_;
+	Vector2i render_anchor_;
 
 	FontStyle font_style_;
 	const FontStyleInfo& font_style() const;
-	float font_scale_;
+	float font_scale_{1.0f};
 
 	const Align align_;
 
