@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +33,7 @@
 #include "base/rect.h"
 #include "base/vector.h"
 #include "base/wexception.h"
+#include "graphic/hyperlink.h"
 #include "graphic/styles/panel_styles.h"
 #include "notifications/signal.h"
 #include "sound/constants.h"
@@ -41,7 +42,7 @@ class FileWrite;
 class RenderTarget;
 namespace Widelands {
 struct MapObjectSaver;
-}
+}  // namespace Widelands
 
 namespace UI {
 
@@ -76,8 +77,6 @@ public:
 		pf_child_die = 1 << 4,     ///< a child needs to die
 		pf_visible = 1 << 5,       ///< render the panel
 		pf_can_focus = 1 << 6,     ///< can receive the keyboard focus
-		/// children should snap only when overlapping the snap target
-		pf_snap_windows_only_when_overlapping = 1 << 7,
 		/// children should snap to the edges of this panel
 		pf_dock_windows_to_edges = 1 << 8,
 		/// whether any change in the desired size should propagate to the actual size
@@ -90,31 +89,58 @@ public:
 		pf_logic_think = 1 << 12,
 		// Do not draw any tooltips and stuff
 		pf_hide_all_overlays = 1 << 13,
+		// Other panels will snap to this one.
+		pf_snap_target = 1 << 14,
+		// Layouting hint that this panel is expected to grow to some very large sizes.
+		pf_unlimited_size = 1 << 15,
 	};
 
-	Panel(Panel* const nparent,
+	/** The Z ordering of overlapping panels; highest value is always on top. */
+	enum class ZOrder : uint8_t {
+		kAlwaysInBackground = 0,  ///< Always in the background.
+		kDefault = 8,             ///< No special handling.
+		kPinned = 16,             ///< Pinned by the user.
+		kConfirmation = 24,       ///< A confirmation prompt.
+		kInfoPanel = 32,          ///< The info panel and toolbar.
+		kFullscreenWindow = 64,   ///< A fullscreen window.
+		kDropdown = 128,          ///< Dropdown lists.
+	};
+
+	Panel(Panel* nparent,
 	      UI::PanelStyle,
-	      int32_t const nx,
-	      int32_t const ny,
-	      int const nw,
-	      int const nh,
+	      const std::string& name,
+	      int32_t nx,
+	      int32_t ny,
+	      int nw,
+	      int nh,
 	      const std::string& tooltip_text = std::string());
 	virtual ~Panel();
 
 	Notifications::Signal<> clicked;
 	Notifications::Signal<> position_changed;
 
-	Panel* get_parent() const {
+	[[nodiscard]] Panel* get_parent() const {
 		return parent_;
 	}
 
 	void free_children();
 
+	[[nodiscard]] bool get_flag(unsigned flag) const {
+		return (flags_ & flag) != 0;
+	}
+	void set_flag(unsigned flag, bool on) {
+		if (on) {
+			flags_ |= flag;
+		} else {
+			flags_ &= ~flag;
+		}
+	}
+
 	// Checks whether this panel will be deleted in the next think cycle.
 	// This check is used to stop panels from thinking and performing other
 	// activities to prevent undesired side-effects.
-	bool is_dying() const {
-		return flags_ & pf_die;
+	[[nodiscard]] bool is_dying() const {
+		return get_flag(pf_die);
 	}
 
 	// Modal
@@ -133,7 +159,7 @@ public:
 		return_code_ = static_cast<int>(code);
 	}
 
-	bool is_modal() const;
+	[[nodiscard]] bool is_modal() const;
 
 	virtual void start();
 	virtual void end();
@@ -146,102 +172,118 @@ public:
 	virtual void move_inside_parent();
 	virtual void layout();
 
-	void set_layout_toplevel(bool ltl);
-	bool get_layout_toplevel() const;
+	void set_layout_toplevel(bool ltl) {
+		set_flag(pf_layout_toplevel, ltl);
+	}
+	bool get_layout_toplevel() const {
+		return get_flag(pf_layout_toplevel);
+	}
 
 	void get_desired_size(int* w, int* h) const;
 
-	int32_t get_x() const {
+	[[nodiscard]] const std::string& get_name() const {
+		return name_;
+	}
+
+	[[nodiscard]] int32_t get_x() const {
 		return x_;
 	}
-	int32_t get_y() const {
+	[[nodiscard]] int32_t get_y() const {
 		return y_;
 	}
-	Vector2i get_pos() const {
+	[[nodiscard]] Vector2i get_pos() const {
 		return Vector2i(x_, y_);
 	}
 	// int instead of uint because of overflow situations
-	int32_t get_w() const {
+	[[nodiscard]] int32_t get_w() const {
 		return w_;
 	}
-	int32_t get_h() const {
+	[[nodiscard]] int32_t get_h() const {
 		return h_;
 	}
 
-	Vector2i to_parent(const Vector2i&) const;
+	[[nodiscard]] Vector2i to_parent(const Vector2i&) const;
 
-	virtual bool is_snap_target() const {
-		return false;
+	[[nodiscard]] bool is_snap_target() const {
+		return get_flag(pf_snap_target);
 	}
-	uint16_t get_border_snap_distance() const {
+	void set_snap_target(bool on) {
+		set_flag(pf_snap_target, on);
+	}
+	[[nodiscard]] uint16_t get_border_snap_distance() const {
 		return border_snap_distance_;
 	}
 	void set_border_snap_distance(uint8_t const value) {
 		border_snap_distance_ = value;
 	}
-	uint8_t get_panel_snap_distance() const {
+	[[nodiscard]] uint8_t get_panel_snap_distance() const {
 		return panel_snap_distance_;
 	}
 	void set_panel_snap_distance(uint8_t const value) {
 		panel_snap_distance_ = value;
 	}
-	bool get_snap_windows_only_when_overlapping() const {
-		return flags_ & pf_snap_windows_only_when_overlapping;
+	[[nodiscard]] bool get_dock_windows_to_edges() const {
+		return get_flag(pf_dock_windows_to_edges);
 	}
-	void set_snap_windows_only_when_overlapping(const bool on = true);
-	bool get_dock_windows_to_edges() const {
-		return flags_ & pf_dock_windows_to_edges;
+	inline void set_dock_windows_to_edges(bool on = true) {
+		set_flag(pf_dock_windows_to_edges, on);
 	}
-	void set_dock_windows_to_edges(const bool on = true);
 	void set_inner_size(int nw, int nh);
 	void set_border(int l, int r, int t, int b);
 
-	int get_lborder() const {
+	[[nodiscard]] int get_lborder() const {
 		return lborder_;
 	}
-	int get_rborder() const {
+	[[nodiscard]] int get_rborder() const {
 		return rborder_;
 	}
-	int get_tborder() const {
+	[[nodiscard]] int get_tborder() const {
 		return tborder_;
 	}
-	int get_bborder() const {
+	[[nodiscard]] int get_bborder() const {
 		return bborder_;
 	}
 
-	int get_inner_w() const;
-	int get_inner_h() const;
+	[[nodiscard]] int get_inner_w() const;
+	[[nodiscard]] int get_inner_h() const;
 
-	const Panel* get_next_sibling() const {
+	[[nodiscard]] const Panel* get_next_sibling() const {
 		return next_;
 	}
-	Panel* get_next_sibling() {
+	[[nodiscard]] Panel* get_next_sibling() {
 		return next_;
 	}
-	const Panel* get_prev_sibling() const {
+	[[nodiscard]] const Panel* get_prev_sibling() const {
 		return prev_;
 	}
-	Panel* get_prev_sibling() {
+	[[nodiscard]] Panel* get_prev_sibling() {
 		return prev_;
 	}
-	const Panel* get_first_child() const {
+	[[nodiscard]] const Panel* get_first_child() const {
 		return first_child_;
 	}
-	Panel* get_first_child() {
+	[[nodiscard]] Panel* get_first_child() {
 		return first_child_;
 	}
-	const Panel* get_last_child() const {
+	[[nodiscard]] const Panel* get_last_child() const {
 		return last_child_;
 	}
-	Panel* get_last_child() {
+	[[nodiscard]] Panel* get_last_child() {
 		return last_child_;
 	}
+	Panel* find_child_by_name(const std::string& name, bool recurse);
 
-	void move_to_top();
+	void move_to_top(bool on_top_of_equal_z = true);
+	[[nodiscard]] virtual ZOrder get_z() const {
+		return z_order_;
+	}
+	void set_z(ZOrder z) {
+		z_order_ = z;
+	}
 
 	// Drawing, visibility
-	bool is_visible() const {
-		return flags_ & pf_visible;
+	[[nodiscard]] bool is_visible() const {
+		return get_flag(pf_visible);
 	}
 	void set_visible(bool on);
 
@@ -255,14 +297,14 @@ public:
 		// Overridden only by InteractiveBase
 	}
 
-	void set_logic_think() {
-		flags_ |= pf_logic_think;
+	void set_logic_think(bool on = true) {
+		set_flag(pf_logic_think, on);
 	}
-	void set_hide_all_overlays() {
-		flags_ |= pf_hide_all_overlays;
+	void set_hide_all_overlays(bool on = true) {
+		set_flag(pf_hide_all_overlays, on);
 	}
 
-	Vector2i get_mouse_position() const;
+	[[nodiscard]] Vector2i get_mouse_position() const;
 	void set_mouse_pos(Vector2i);
 	void center_mouse();
 
@@ -285,42 +327,49 @@ public:
 	/// item #1916453). That is "a huge oversight" in SDL 1.2 and a fix is
 	/// promised in SDL 1.3:
 	/// http://lists.libsdl.org/pipermail/sdl-libsdl.org/2008-March/064560.html
-	bool get_key_state(SDL_Scancode) const;
+	[[nodiscard]] bool get_key_state(SDL_Scancode) const;
 
-	void set_handle_mouse(bool yes);
+	void set_handle_mouse(bool yes) {
+		set_flag(pf_handle_mouse, yes);
+	}
 	void grab_mouse(bool grab);
 
 	void set_can_focus(bool yes);
-	bool get_can_focus() const {
-		return flags_ & pf_can_focus;
+	[[nodiscard]] bool get_can_focus() const {
+		return get_flag(pf_can_focus);
 	}
-	bool has_focus() const {
+	[[nodiscard]] bool has_focus() const {
 		return (get_can_focus() && parent_->focus_ == this);
 	}
+	[[nodiscard]] bool has_top_level_focus();
 	virtual void focus(bool topcaller = true);
-	Panel* focused_child() const {
+	[[nodiscard]] Panel* focused_child() const {
 		return focus_;
 	}
 
 	void set_top_on_click(bool const on) {
-		if (on)
-			flags_ |= pf_top_on_click;
-		else
-			flags_ &= ~pf_top_on_click;
+		set_flag(pf_top_on_click, on);
 	}
-	bool get_top_on_click() const {
-		return flags_ & pf_top_on_click;
+	[[nodiscard]] bool get_top_on_click() const {
+		return get_flag(pf_top_on_click);
 	}
 
 	static void set_allow_user_input(bool const t) {
 		allow_user_input_ = t;
 	}
-	static bool allow_user_input() {
+	[[nodiscard]] static bool allow_user_input() {
 		return allow_user_input_;
 	}
 
+	static void set_allow_fastclick(bool const t) {
+		allow_fastclick_ = t;
+	}
+	[[nodiscard]] static bool allow_fastclick() {
+		return allow_fastclick_;
+	}
+
 	void set_tooltip(const std::string&);
-	const std::string& tooltip() const {
+	[[nodiscard]] const std::string& tooltip() const {
 		return tooltip_;
 	}
 
@@ -350,7 +399,7 @@ public:
 
 	void find_all_children_at(int16_t x, int16_t y, std::vector<Panel*>& result) const;
 
-	Panel& get_topmost_forefather();
+	[[nodiscard]] Panel& get_topmost_forefather();
 
 	struct ModalGuard {
 		explicit ModalGuard(Panel& p);
@@ -383,10 +432,23 @@ public:
 		kEncyclopedia,
 		kShipWindow,
 		kAttackWindow,
+		kQuicknav,
+		kFleetOptions,
 	};
+	/*
+	 * Actual save type after initialization.
+	 * Overridden in derived classes
+	 */
 	virtual SaveType save_type() const {
 		return SaveType::kNone;
 	}
+	/*
+	 * Saving partially initialized windows can trigger
+	 * race conditions. Wait until initialization_complete().
+	 */
+	SaveType current_save_type() const {
+		return initialized_ ? save_type() : SaveType::kNone;
+	}
 	virtual void save(FileWrite&, Widelands::MapObjectSaver&) const {
 		NEVER_HERE();
 	}
@@ -395,11 +457,7 @@ protected:
 	// This panel will never receive keypresses (do_key), instead
 	// textinput will be passed on (do_textinput).
 	void set_handle_textinput(bool const on = true) {
-		if (on) {
-			flags_ |= pf_handle_textinput;
-		} else {
-			flags_ &= ~pf_handle_textinput;
-		}
+		set_flag(pf_handle_textinput, on);
 	}
 
 	/*
@@ -412,24 +470,24 @@ protected:
 	// If this is set to 'true', this panel ad its children will never receive keypresses (do_key) or
 	// textinput (do_textinput).
 	void set_handle_keypresses(bool const on) {
-		if (on) {
-			flags_ |= pf_handle_keypresses;
-		} else {
-			flags_ &= ~pf_handle_keypresses;
-		}
+		set_flag(pf_handle_keypresses, on);
 	}
 
 	// Defines if think() should be called repeatedly. This is true on construction.
-	void set_thinks(bool yes);
+	void set_thinks(bool yes) {
+		set_flag(pf_thinks, yes);
+	}
 
-	bool keyboard_free() {
-		return !(focus_);
+	[[nodiscard]] bool keyboard_free() const {
+		return (focus_) == nullptr;
 	}
 
 	virtual void update_desired_size();
 
 	static void play_click();
 
+	virtual void handle_hyperlink(const std::string& action);
+
 	static bool
 	draw_tooltip(const std::string& text, PanelStyle, Vector2i pos = Vector2i::invalid());
 	void draw_background(RenderTarget& dst, const UI::PanelStyleInfo&);
@@ -439,13 +497,14 @@ protected:
 	virtual void update_template() {
 	}
 
-	virtual Panel* get_open_dropdown();
+	[[nodiscard]] virtual Panel* get_open_dropdown();
 
-	virtual bool is_focus_toplevel() const;
+	[[nodiscard]] virtual bool is_focus_toplevel() const;
 
-	virtual std::vector<Recti> focus_overlay_rects();
+	[[nodiscard]] virtual std::vector<Recti> focus_overlay_rects();
 	// Convenience functions for overriding focus_overlay_rects()
-	std::vector<Recti> focus_overlay_rects(int off_x, int off_y, int strength_diff) const;
+	[[nodiscard]] std::vector<Recti>
+	focus_overlay_rects(int off_x, int off_y, int strength_diff) const;
 
 	// Wait until the current logic frame has ended
 	void wait_for_current_logic_frame();
@@ -456,6 +515,7 @@ protected:
 
 	const PanelStyle panel_style_;
 
+public:
 	/** Never call this function, except when you need Widelands to stay responsive
 	 *  during a costly operation and you can guarantee that it will not interfere
 	 *  with the "normal" graphics refreshing done periodically from `Panel::do_run`.
@@ -466,25 +526,29 @@ protected:
 	void do_redraw_now(bool handle_input = true,
 	                   const std::string& message_to_display = std::string());
 
-private:
-	bool initialized_;
-
-	bool handles_mouse() const {
-		return (flags_ & pf_handle_mouse) != 0;
+	virtual bool check_handles_mouse(int32_t /* x */, int32_t /* y */) {
+		return get_flag(pf_handle_mouse);
 	}
 
-	bool handles_keypresses() const {
+	[[nodiscard]] static uint32_t time_of_last_user_activity() {
+		return time_of_last_user_activity_;
+	}
+
+private:
+	bool initialized_{false};
+
+	[[nodiscard]] bool handles_keypresses() const {
 		if (get_parent() != nullptr && !get_parent()->handles_keypresses()) {
 			return false;
 		}
-		return (flags_ & pf_handle_keypresses) != 0;
+		return get_flag(pf_handle_keypresses);
 	}
 
-	bool handles_textinput() const {
-		return (flags_ & pf_handle_textinput) != 0;
+	[[nodiscard]] bool handles_textinput() const {
+		return get_flag(pf_handle_textinput);
 	}
-	bool thinks() const {
-		return (flags_ & pf_thinks) != 0;
+	[[nodiscard]] bool thinks() const {
+		return get_flag(pf_thinks);
 	}
 
 	void check_child_death();
@@ -499,9 +563,9 @@ private:
 
 	Panel* child_at_mouse_cursor(int32_t mouse_x, int32_t mouse_y, Panel* child);
 	void do_mousein(bool inside);
-	bool do_mousepress(const uint8_t btn, int32_t x, int32_t y);
-	bool do_mouserelease(const uint8_t btn, int32_t x, int32_t y);
-	bool do_mousemove(const uint8_t state, int32_t x, int32_t y, int32_t xdiff, int32_t ydiff);
+	bool do_mousepress(uint8_t btn, int32_t x, int32_t y);
+	bool do_mouserelease(uint8_t btn, int32_t x, int32_t y);
+	bool do_mousemove(uint8_t state, int32_t x, int32_t y, int32_t xdiff, int32_t ydiff);
 	bool do_mousewheel(int32_t x, int32_t y, uint16_t modstate, Vector2i rel_mouse_pos);
 	bool do_key(bool down, SDL_Keysym code);
 	bool do_textinput(const std::string& text);
@@ -511,38 +575,48 @@ private:
 	std::deque<Panel*> gather_focusable_children();
 
 	static Panel* ui_trackmouse(int32_t& x, int32_t& y);
-	static bool ui_mousepress(const uint8_t button, int32_t x, int32_t y);
-	static bool ui_mouserelease(const uint8_t button, int32_t x, int32_t y);
-	static bool
-	ui_mousemove(const uint8_t state, int32_t x, int32_t y, int32_t xdiff, int32_t ydiff);
+	static bool ui_mousepress(uint8_t button, int32_t x, int32_t y);
+	static bool ui_mouserelease(uint8_t button, int32_t x, int32_t y);
+	static bool ui_mousemove(uint8_t state, int32_t x, int32_t y, int32_t xdiff, int32_t ydiff);
 	static bool ui_mousewheel(int32_t x, int32_t y, uint16_t modstate);
 	static bool ui_key(bool down, SDL_Keysym code);
 	static bool ui_textinput(const std::string& text);
+	static void register_user_activity();
+	static uint32_t time_of_last_user_activity_;
 
 	Panel* parent_;
 	Panel* next_;
 	Panel* prev_;
-	Panel* first_child_;
-	Panel* last_child_;
-	Panel* mousein_child_;  //  child panel that the mouse is in
-	Panel* focus_;          //  keyboard focus
+	Panel* first_child_{nullptr};
+	Panel* last_child_{nullptr};
+	Panel* mousein_child_{nullptr};  //  child panel that the mouse is in
+	Panel* focus_{nullptr};          //  keyboard focus
 
 	std::atomic<uint32_t> flags_;
+	std::string name_;
 
 	/**
 	 * The outer rectangle is defined by (x_, y_, w_, h_)
 	 */
 	/*@{*/
-	int32_t x_, y_;
-	int w_, h_;
+	int32_t x_;
+	int32_t y_;
+	int w_;
+	int h_;
 	/*@}*/
-	int lborder_, rborder_, tborder_, bborder_;
-	uint8_t border_snap_distance_, panel_snap_distance_;
-	int desired_w_, desired_h_;
+	int lborder_{0};
+	int rborder_{0};
+	int tborder_{0};
+	int bborder_{0};
+	uint8_t border_snap_distance_{0U};
+	uint8_t panel_snap_distance_{0U};
+	int desired_w_;
+	int desired_h_;
+	ZOrder z_order_{ZOrder::kDefault};
 
 	friend struct ModalGuard;
 
-	bool running_;
+	bool running_{false};
 	int return_code_;
 
 	std::string tooltip_;
@@ -553,9 +627,12 @@ private:
 	static Vector2i tooltip_fixed_pos_;
 	static Recti tooltip_fixed_rect_;
 	static bool allow_user_input_;
+	static bool allow_fastclick_;
 
 	static FxId click_fx_;
 
+	std::unique_ptr<Notifications::Subscriber<NoteHyperlink>> hyperlink_subscriber_;
+
 	enum class LogicThreadState { kFree, kLocked, kEndingRequested, kEndingConfirmed };
 	std::atomic<LogicThreadState> logic_thread_locked_;
 	static std::atomic_bool logic_thread_running_;
@@ -569,40 +646,6 @@ private:
 
 	DISALLOW_COPY_AND_ASSIGN(Panel);
 };
-
-inline void Panel::set_snap_windows_only_when_overlapping(const bool on) {
-	flags_ &= ~pf_snap_windows_only_when_overlapping;
-	if (on)
-		flags_ |= pf_snap_windows_only_when_overlapping;
-}
-inline void Panel::set_dock_windows_to_edges(const bool on) {
-	flags_ &= ~pf_dock_windows_to_edges;
-	if (on)
-		flags_ |= pf_dock_windows_to_edges;
-}
-
-/**
- * A Panel with a name. Important for scripting
- */
-struct NamedPanel : public Panel {
-	NamedPanel(Panel* const nparent,
-	           UI::PanelStyle s,
-	           const std::string& name,
-	           int32_t const nx,
-	           int32_t const ny,
-	           int const nw,
-	           int const nh,
-	           const std::string& tooltip_text = std::string())
-	   : Panel(nparent, s, nx, ny, nw, nh, tooltip_text), name_(name) {
-	}
-
-	const std::string& get_name() const {
-		return name_;
-	}
-
-private:
-	std::string name_;
-};
 }  // namespace UI
 
 #endif  // end of include guard: WL_UI_BASIC_PANEL_H
