@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,14 +40,20 @@ struct ProgressBar : public Panel {
 	};
 
 public:
-	ProgressBar(
-	   Panel* parent, PanelStyle, int32_t x, int32_t y, int32_t w, int32_t h, uint32_t orientation);
+	ProgressBar(Panel* parent,
+	            PanelStyle,
+	            const std::string& name,
+	            int32_t x,
+	            int32_t y,
+	            int32_t w,
+	            int32_t h,
+	            uint32_t orientation);
 
-	uint32_t get_state() const {
+	[[nodiscard]] uint32_t get_state() const {
 		return state_;
 	}
 	void set_state(uint32_t);
-	uint32_t get_total() const {
+	[[nodiscard]] uint32_t get_total() const {
 		return total_;
 	}
 	void set_total(uint32_t);
@@ -55,17 +61,20 @@ public:
 	void set_show_percent(bool p) {
 		show_percent_ = p;
 	}
+	[[nodiscard]] bool get_show_percent() const {
+		return show_percent_;
+	}
 
 protected:
 	void draw(RenderTarget&) override;
 
 private:
 	uint32_t orientation_;
-	uint32_t state_;  ///< state_ is [0..total_]
-	uint32_t total_;  ///< maximum progress
+	uint32_t state_{0U};    ///< state_ is [0..total_]
+	uint32_t total_{100U};  ///< maximum progress
 	const UI::PanelStyle progress_style_;
 	const UI::ProgressbarStyleInfo& progress_style() const;
-	bool show_percent_;
+	bool show_percent_{true};
 };
 }  // namespace UI
 
