@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,17 +49,21 @@ std::vector<SDL_Event> ProgressWindow::event_buffer_ = {};
 
 ProgressWindow::ProgressWindow(UI::Panel* parent,
                                const std::string& theme,
-                               const std::string& background)
+                               const std::string& background,
+                               bool crop)
    : UI::Panel(parent,
                PanelStyle::kFsMenu /* unused */,
+               "progresswindow",
                0,
                0,
                parent != nullptr ? parent->get_inner_w() : g_gr->get_xres(),
                parent != nullptr ? parent->get_inner_h() : g_gr->get_yres()),
      label_center_(Vector2i::zero()),
-     theme_(theme) {
+     theme_(theme),
+     crop_(crop) {
 	// As long as this window exists and is visible, no tooltips will be drawn.
 	set_hide_all_overlays();
+	Panel::set_allow_fastclick(false);
 
 	if (parent == nullptr) {
 		graphic_resolution_changed_subscriber_ = Notifications::subscribe<GraphicResolutionChanged>(
@@ -83,6 +87,8 @@ ProgressWindow::~ProgressWindow() {
 	for (SDL_Event event : event_buffer_) {
 		SDL_PushEvent(&event);
 	}
+
+	Panel::set_allow_fastclick(true);
 }
 
 inline const UI::ProgressbarStyleInfo& ProgressWindow::progress_style() const {
@@ -94,8 +100,8 @@ void ProgressWindow::draw(RenderTarget& rt) {
 		const Image& bg = *g_image_cache->get(background_);
 		const float w = bg.width();
 		const float h = bg.height();
-		rt.blitrect_scale(
-		   fit_image(w, h, get_w(), get_h(), true), &bg, Recti(0, 0, w, h), 1.f, BlendMode::UseAlpha);
+		rt.blitrect_scale(fit_image(w, h, get_w(), get_h(), crop_), &bg, Recti(0, 0, w, h), 1.f,
+		                  BlendMode::UseAlpha);
 	}
 
 	// No float division to avoid Texture subsampling.
@@ -133,41 +139,58 @@ void ProgressWindow::draw(RenderTarget& rt) {
 
 /// Set a picture to render in the background
 void ProgressWindow::set_background(const std::string& file_name) {
-	if (file_name.empty() || !g_fs->file_exists(file_name)) {
-		std::string dir = template_dir() + "loadscreens/gameloading/";
-		if (theme_.empty() && g_fs->is_directory(dir)) {
-			// choose random theme
-			const std::set<std::string> dirs = g_fs->list_directory(dir);
-			auto it = dirs.begin();
-			std::advance(it, RNG::static_rand(dirs.size()));
-			dir = *it;
-		} else if (g_fs->is_directory(dir + theme_)) {
-			dir += theme_;
-		} else {
-			log_warn("Theme '%s' not found, using fallback image", theme_.c_str());
-			background_ = "images/logos/wl-ico-128.png";
-			return do_redraw_now();
-		}
-
-		const std::set<std::string> images = g_fs->list_directory(dir);
-		if (images.empty()) {
-			log_warn("No backgrounds found for theme '%s', using fallback image", theme_.c_str());
-			background_ = "images/logos/wl-ico-128.png";
-		} else {
-			auto it = images.begin();
-			std::advance(it, RNG::static_rand(images.size()));
-			background_ = *it;
-		}
-	} else {
+	if (!file_name.empty() && g_fs->file_exists(file_name)) {
 		background_ = file_name;
+		do_redraw_now();
+		return;
 	}
+
+	if (try_set_background(template_dir())) {
+		return;
+	}
+
+	if (!is_using_default_theme() && try_set_background(kDefaultTemplate)) {
+		log_warn("No backgrounds found for theme '%s', using default theme", theme_.c_str());
+		return;
+	}
+
+	log_warn("No backgrounds found for default theme, using fallback image");
+	background_ = "images/logos/wl-ico-128.png";
+	return do_redraw_now();
+}
+
+bool ProgressWindow::try_set_background(const std::string& template_directory) {
+	std::string dir = template_directory + "loadscreens/gameloading/";
+	if (theme_.empty() && g_fs->is_directory(dir)) {
+		// choose random theme
+		const std::set<std::string> dirs = g_fs->list_directory(dir);
+		auto it = dirs.begin();
+		std::advance(it, RNG::static_rand(dirs.size()));
+		dir = *it;
+	} else if (g_fs->is_directory(dir + theme_)) {
+		dir += theme_;
+	} else {
+		log_warn("Theme '%s' not found", theme_.c_str());
+		return false;
+	}
+
+	const std::set<std::string> images = g_fs->list_directory(dir);
+	if (images.empty()) {
+		log_warn("No backgrounds found for theme '%s'", theme_.c_str());
+		return false;
+	}
+
+	auto it = images.begin();
+	std::advance(it, RNG::static_rand(images.size()));
+	background_ = *it;
 	do_redraw_now();
+	return true;
 }
 
 /// Callback function: Buffer keypress events to be replayed after the loading is over.
 bool ProgressWindow::ui_key(bool const down, SDL_Keysym const code) {
 	// WLApplication can handle some keys immediately; don't buffer them.
-	if (WLApplication::get()->handle_key(down, code.sym, code.mod)) {
+	if (WLApplication::get().handle_key(down, code.sym, code.mod)) {
 		return true;
 	}
 	SDL_Event event;
@@ -181,7 +204,7 @@ void ProgressWindow::step(const std::string& description) {
 	// Handle events to respond to window resizing, to buffer keypresses,
 	// and to prevent "not responding" on windows & "beach ball" on macOS.
 	InputCallback input_callback = {nullptr, nullptr, nullptr, ui_key, nullptr, nullptr};
-	WLApplication::get()->handle_input(&input_callback);
+	WLApplication::get().handle_input(&input_callback);
 
 	progress_message_ =
 	   UI::g_fh->render(as_richtext_paragraph(description, progress_style().font()));
