@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,13 +39,15 @@ struct IProgressVisualization {
 	/// Progress Window is closing, unregister and cleanup
 	virtual void stop() = 0;
 
-	virtual ~IProgressVisualization() {
-	}
+	virtual ~IProgressVisualization() = default;
 };
 
 /// Manages a progress window on the screen.
 struct ProgressWindow : public UI::Panel {
-	explicit ProgressWindow(UI::Panel*, const std::string& theme, const std::string& background);
+	explicit ProgressWindow(UI::Panel*,
+	                        const std::string& theme,
+	                        const std::string& background,
+	                        bool crop = true);
 	~ProgressWindow() override;
 
 	/// Register additional visualization (tips/hints, animation, etc)
@@ -61,11 +63,14 @@ struct ProgressWindow : public UI::Panel {
 private:
 	using VisualizationArray = std::vector<IProgressVisualization*>;
 
+	bool try_set_background(const std::string& template_directory);
+
 	Vector2i label_center_;
 	Recti label_rectangle_;
 	VisualizationArray visualizations_;
 	std::string theme_;
 	std::string background_;
+	bool crop_;
 	std::shared_ptr<const UI::RenderedText> progress_message_;
 
 	const UI::ProgressbarStyleInfo& progress_style() const;
