@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,23 +41,18 @@ Scrollbar
 Initialize the scrollbar using default values.
 */
 Scrollbar::Scrollbar(Panel* const parent,
+                     const std::string& name,
                      int32_t const x,
                      int32_t const y,
                      uint32_t const w,
                      uint32_t const h,
                      UI::PanelStyle style,
                      bool const horiz)
-   : Panel(parent, style, x, y, w, h),
+   : Panel(parent, style, name, x, y, w, h),
      horizontal_(horiz),
-     force_draw_(false),
-     pos_(0),
-     singlestepsize_(1),
-     pagesize_(5),
+
      buttonsize_(kSize),
-     steps_(100),
-     pressed_(Area::None),
-     time_nextact_(0),
-     knob_grabdelta_(0),
+
      pic_minus_(g_image_cache->get(horiz ? "images/ui_basic/scrollbar_left.png" :
                                            "images/ui_basic/scrollbar_up.png")),
      pic_plus_(g_image_cache->get(horiz ? "images/ui_basic/scrollbar_right.png" :
