@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,6 +39,7 @@ protected:
 	 * Text conventions: Sentence case for the 'tooltip_text'
 	 */
 	Slider(Panel* parent,
+	       const std::string& name,
 	       int32_t x,
 	       int32_t y,
 	       uint32_t w,
@@ -55,10 +56,6 @@ protected:
 	       int32_t bar_size);
 
 public:
-	bool is_snap_target() const override {
-		return true;
-	}
-
 	int32_t get_value() const {
 		return value_;
 	}
@@ -106,6 +103,7 @@ protected:
 	void bar_pressed(int32_t pointer, int32_t ofs);
 
 private:
+	void calculate_big_step();
 	void send_value_changed() const;
 	void set_highlighted(bool highlighted);
 
@@ -117,11 +115,12 @@ private:
 	int32_t min_value_;  //  cursor values
 	int32_t max_value_;
 	int32_t value_;
-	int32_t relative_move_;
+	int32_t relative_move_{0};
+	int32_t big_step_{0};
 
-	bool highlighted_;  //  mouse over
-	bool pressed_;      //  the cursor is pressed
-	bool enabled_;      //  enabled widget
+	bool highlighted_{false};  //  mouse over
+	bool pressed_{false};      //  the cursor is pressed
+	bool enabled_;             //  enabled widget
 
 	const UI::SliderStyle cursor_style_;  // Cursor color and texture. Not owned.
 	const UI::PanelStyleInfo& cursor_style() const;
@@ -133,7 +132,7 @@ protected:
 
 	int32_t cursor_pos_;   //  cursor position
 	int32_t cursor_size_;  //  cursor width
-	int32_t cursor_fixed_height_;
+	int32_t cursor_fixed_height_{-1};
 };
 
 /**
@@ -141,6 +140,7 @@ protected:
  */
 struct HorizontalSlider : public Slider {
 	HorizontalSlider(Panel* const parent,
+	                 const std::string& name,
 	                 const int32_t x,
 	                 const int32_t y,
 	                 const uint32_t w,
@@ -153,6 +153,7 @@ struct HorizontalSlider : public Slider {
 	                 const uint32_t cursor_size = 20,
 	                 const bool enabled = true)
 	   : Slider(parent,
+	            name,
 	            x,
 	            y,
 	            w,
@@ -181,6 +182,7 @@ protected:
  */
 struct VerticalSlider : public Slider {
 	VerticalSlider(Panel* const parent,
+	               const std::string& name,
 	               const int32_t x,
 	               const int32_t y,
 	               const uint32_t w,
@@ -193,6 +195,7 @@ struct VerticalSlider : public Slider {
 	               const std::string& tooltip_text = std::string(),
 	               const bool enabled = true)
 	   : Slider(parent,
+	            name,
 	            x,
 	            y,
 	            w,
@@ -221,17 +224,18 @@ protected:
  * Slider, but rather embed it, as we need to re-size it and add the labels.
  */
 struct DiscreteSlider : public Panel {
-	DiscreteSlider(Panel* const parent,
-	               const int32_t x,
-	               const int32_t y,
-	               const uint32_t w,
-	               const uint32_t h,
+	DiscreteSlider(Panel* parent,
+	               const std::string& name,
+	               int32_t x,
+	               int32_t y,
+	               uint32_t w,
+	               uint32_t h,
 	               const std::vector<std::string>& labels_in,
 	               uint32_t init_value,
 	               UI::SliderStyle style,
 	               const std::string& tooltip_text = std::string(),
-	               const uint32_t cursor_size = 20,
-	               const bool enabled = true);
+	               uint32_t cursor_size = 20,
+	               bool enabled = true);
 
 	void set_labels(const std::vector<std::string>&);
 
