@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2022 by the Widelands Development Team
+ * Copyright (C) 2009-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,8 @@ struct SpinBoxImpl;
 /// w is the overall width of the SpinBox and must be wide enough to fit 2 labels and the buttons.
 /// unit_w is the width alotted for all buttons and the text between them (the actual spinbox).
 /// label_text is a text that precedes the actual spinbox.
+/// The current implementation does not allow minval or maxval to be near the numeric limits of
+/// int32_t.
 class SpinBox : public Panel {
 public:
 	enum class Type {
@@ -38,12 +40,13 @@ public:
 		kValueList  // Uses the values that are set by set_value_list().
 	};
 
-	enum class Units { kNone, kPixels, kMinutes, kPercent, kFields };
+	enum class Units { kNone, kPixels, kMinutes, kWeeks, kPercent, kFields };
 
 	/**
 	 * Text conventions: Sentence case for the 'label_text' and for all values
 	 */
 	SpinBox(Panel*,
+	        const std::string& name,
 	        int32_t x,
 	        int32_t y,
 	        uint32_t w,
@@ -63,11 +66,11 @@ public:
 
 	Notifications::Signal<> changed;
 
-	void set_value(int32_t);
+	void set_value(int32_t, bool trigger_signal = true);
 	// For spinboxes of type kValueList. The vector needs to be sorted in ascending order,
 	// otherwise you will confuse the user.
 	void set_value_list(const std::vector<int32_t>&);
-	void set_interval(int32_t min, int32_t max);
+	void set_interval(int32_t min, int32_t max, bool trigger_signal_if_changed = true);
 	int32_t get_value() const;
 	void add_replacement(int32_t, const std::string&);
 	const std::vector<UI::Button*>& get_buttons() {
@@ -82,16 +85,19 @@ private:
 	void layout() override;
 	void update();
 	void change_value(int32_t);
-	const std::string unit_text(int32_t value) const;
+	// Format value or change step with unit.
+	const std::string unit_text(int32_t value, bool change = false) const;
+	void calculate_big_step();
 
 	const SpinBox::Type type_;
 	SpinBoxImpl* sbi_;
 	std::vector<UI::Button*> buttons_;
 	UI::Box* box_;
 	uint32_t unit_width_;
-	uint32_t button_height_;
+	uint32_t button_size_;
+	uint32_t big_step_button_width_;
+	uint32_t buttons_width_;
 	uint32_t padding_;
-	uint32_t number_of_paddings_;
 };
 }  // namespace UI
 
