@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,13 +50,14 @@ public:
 	struct EntryRecord {};
 
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle);
-	~Table();
+	~Table() override;
 
 	Notifications::Signal<> cancel;
 	Notifications::Signal<uint32_t> selected;
@@ -77,14 +78,14 @@ public:
 
 	void clear();
 	void set_sort_column(uint8_t col);
-	uint8_t get_sort_colum() const;
+	uint8_t get_sort_column() const;
 	bool get_sort_descending() const;
 
 	void sort(uint32_t lower_bound = 0, uint32_t upper_bound = std::numeric_limits<uint32_t>::max());
 	void remove(uint32_t);
 	void remove_entry(Entry);
 
-	EntryRecord& add(void* const entry, bool const select_this = false);
+	EntryRecord& add(void* entry, bool select_this = false);
 
 	uint32_t size() const;
 	bool empty() const;
@@ -103,7 +104,7 @@ public:
 	uint32_t toggle_entry(uint32_t row);
 	void move_selection(int32_t offset);
 	struct NoSelection : public std::exception {
-		char const* what() const noexcept override {
+		[[nodiscard]] char const* what() const noexcept override {
 			return "UI::Table<Entry>: No selection";
 		}
 	};
@@ -116,7 +117,7 @@ public:
 
 	uint32_t get_eff_w() const;
 
-	std::vector<Recti> focus_overlay_rects();
+	std::vector<Recti> focus_overlay_rects() override;
 
 	// Drawing and event handling
 	void draw(RenderTarget&) override;
@@ -127,6 +128,9 @@ public:
 	bool handle_key(bool down, SDL_Keysym code) override;
 };
 
+// All tables *should* effectively be derived from this template specialization
+using BaseTable = Table<void*>;
+
 template <> class Table<void*> : public Panel {
 public:
 	struct EntryRecord {
@@ -136,9 +140,9 @@ public:
 		void set_picture(uint8_t col, const Image* pic, const std::string& str = std::string());
 		/// Text conventions: Title Case for the 'str'
 		void set_string(uint8_t col, const std::string& str);
-		const Image* get_picture(uint8_t col) const;
-		const std::string& get_string(uint8_t col) const;
-		void* entry() const {
+		[[nodiscard]] const Image* get_picture(uint8_t col) const;
+		[[nodiscard]] const std::string& get_string(uint8_t col) const;
+		[[nodiscard]] void* entry() const {
 			return entry_;
 		}
 
@@ -146,11 +150,11 @@ public:
 			font_style_.reset(new FontStyle(style));
 		}
 
-		const UI::FontStyleInfo* font_style() const {
+		[[nodiscard]] const UI::FontStyleInfo* font_style() const {
 			return font_style_ ? &g_style_manager->font_style(*font_style_) : nullptr;
 		}
 
-		bool is_disabled() const {
+		[[nodiscard]] bool is_disabled() const {
 			return disabled_;
 		}
 		void set_disabled(bool disable) {
@@ -158,7 +162,7 @@ public:
 		}
 
 	private:
-		friend class Table<void*>;
+		friend BaseTable;
 		void* entry_;
 		std::unique_ptr<UI::FontStyle> font_style_;
 		struct Data {
@@ -166,10 +170,11 @@ public:
 			std::string d_string;
 		};
 		std::vector<Data> data_;
-		bool disabled_;
+		bool disabled_{false};
 	};
 
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
@@ -202,11 +207,8 @@ public:
 	size_t number_of_columns() const;
 
 	void clear();
-	void set_sort_column(uint8_t const col) {
-		assert(col < columns_.size());
-		sort_column_ = col;
-	}
-	uint8_t get_sort_colum() const {
+	void set_sort_column(uint8_t col);
+	uint8_t get_sort_column() const {
 		return sort_column_;
 	}
 	bool get_sort_descending() const {
@@ -218,9 +220,9 @@ public:
 
 	void sort(uint32_t lower_bound = 0, uint32_t upper_bound = std::numeric_limits<uint32_t>::max());
 	void remove(uint32_t);
-	void remove_entry(const void* const entry);
+	void remove_entry(const void* entry);
 
-	EntryRecord& add(void* entry = nullptr, bool const do_select = false);
+	EntryRecord& add(void* entry = nullptr, bool do_select = false);
 
 	uint32_t size() const {
 		return entry_records_.size();
@@ -261,14 +263,15 @@ public:
 	uint32_t toggle_entry(uint32_t row);
 	void move_selection(int32_t offset);
 	struct NoSelection : public std::exception {
-		char const* what() const noexcept override {
+		[[nodiscard]] char const* what() const noexcept override {
 			return "UI::Table<void *>: No selection";
 		}
 	};
 	void scroll_to_item(int32_t item);
 	EntryRecord& get_selected_record() const {
-		if (selection_ == no_selection_index())
+		if (selection_ == no_selection_index()) {
 			throw NoSelection();
+		}
 		assert(selection_ < entry_records_.size());
 		return *entry_records_.at(selection_);
 	}
@@ -315,27 +318,30 @@ private:
 		int original_width;
 		Align alignment;
 		CompareFn compare;
+		std::string user_tooltip;
+
+		void update_tooltip(bool sorted) const;
 	};
 	using Columns = std::vector<Column>;
 
 	static const int32_t ms_darken_value = -20;
 
 	Columns columns_;
-	int total_width_;
+	int total_width_{0};
 	int32_t lineheight_;
 	const uint32_t headerheight_;
 	const UI::ButtonStyle button_style_;
-	Scrollbar* scrollbar_;
+	Scrollbar* scrollbar_{nullptr};
 	// A disabled button that will fill the space above the scroll bar
 	UI::Button* scrollbar_filler_button_;
-	int32_t scrollpos_;  //  in pixels
+	int32_t scrollpos_{0};  //  in pixels
 	uint32_t selection_;
 	uint32_t last_multiselect_;  // Remembers last selected element in multiselect mode for keyboard
 	                             // navigation
 	std::set<uint32_t> multiselect_;
-	uint32_t last_click_time_;
+	uint32_t last_click_time_{std::numeric_limits<uint32_t>::max()};
 	uint32_t last_selection_;  // for double clicks
-	Columns::size_type sort_column_;
+	Columns::size_type sort_column_{0};
 	bool sort_descending_;
 	// This column will grow/shrink depending on the scrollbar being present
 	size_t flexible_column_idx_;
@@ -349,29 +355,29 @@ private:
 	FontStyleInfo& get_column_fontstyle(const EntryRecord& er);
 };
 
-template <typename Entry> class Table<const Entry* const> : public Table<void*> {
+template <typename Entry> class Table<const Entry* const> : public BaseTable {
 public:
-	using Base = Table<void*>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : BaseTable(parent, name, x, y, w, h, style, rowtype) {
 	}
 
 	void remove_entry(Entry const* const entry) {
-		Base::remove_entry(const_cast<Entry*>(entry));
+		BaseTable::remove_entry(const_cast<Entry*>(entry));
 	}
 
 	EntryRecord& add(Entry const* const entry = 0, bool const select_this = false) {
-		return Base::add(const_cast<Entry*>(entry), select_this);
+		return BaseTable::add(const_cast<Entry*>(entry), select_this);
 	}
 
 	Entry const* operator[](uint32_t const i) const {
-		return static_cast<Entry const*>(Base::operator[](i));
+		return static_cast<Entry const*>(BaseTable::operator[](i));
 	}
 
 	static Entry const* get(const EntryRecord& er) {
@@ -379,33 +385,33 @@ public:
 	}
 
 	Entry const* get_selected() const {
-		return static_cast<Entry const*>(Base::get_selected());
+		return static_cast<Entry const*>(BaseTable::get_selected());
 	}
 };
 
-template <typename Entry> class Table<Entry* const> : public Table<void*> {
+template <typename Entry> class Table<Entry* const> : public BaseTable {
 public:
-	using Base = Table<void*>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : BaseTable(parent, name, x, y, w, h, style, rowtype) {
 	}
 
 	void remove_entry(Entry const* entry) {
-		Base::remove_entry(entry);
+		BaseTable::remove_entry(entry);
 	}
 
 	EntryRecord& add(Entry* const entry = 0, bool const select_this = false) {
-		return Base::add(entry, select_this);
+		return BaseTable::add(entry, select_this);
 	}
 
 	Entry* operator[](uint32_t const i) const {
-		return static_cast<Entry*>(Base::operator[](i));
+		return static_cast<Entry*>(BaseTable::operator[](i));
 	}
 
 	static Entry* get(const EntryRecord& er) {
@@ -413,33 +419,33 @@ public:
 	}
 
 	Entry* get_selected() const {
-		return static_cast<Entry*>(Base::get_selected());
+		return static_cast<Entry*>(BaseTable::get_selected());
 	}
 };
 
-template <typename Entry> class Table<const Entry&> : public Table<void*> {
+template <typename Entry> class Table<const Entry&> : public BaseTable {
 public:
-	using Base = Table<void*>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : BaseTable(parent, name, x, y, w, h, style, rowtype) {
 	}
 
 	void remove_entry(const Entry& entry) {
-		Base::remove_entry(&const_cast<Entry&>(entry));
+		BaseTable::remove_entry(&const_cast<Entry&>(entry));
 	}
 
 	EntryRecord& add(const Entry& entry, bool const select_this = false) {
-		return Base::add(&const_cast<Entry&>(entry), select_this);
+		return BaseTable::add(&const_cast<Entry&>(entry), select_this);
 	}
 
 	const Entry& operator[](uint32_t const i) const {
-		return *static_cast<Entry const*>(Base::operator[](i));
+		return *static_cast<Entry const*>(BaseTable::operator[](i));
 	}
 
 	static const Entry& get(const EntryRecord& er) {
@@ -447,37 +453,37 @@ public:
 	}
 
 	EntryRecord* find(const Entry& entry) const {
-		return Base::find(&entry);
+		return BaseTable::find(&entry);
 	}
 
 	const Entry& get_selected() const {
-		return *static_cast<Entry const*>(Base::get_selected());
+		return *static_cast<Entry const*>(BaseTable::get_selected());
 	}
 };
 
-template <typename Entry> class Table<Entry&> : public Table<void*> {
+template <typename Entry> class Table<Entry&> : public BaseTable {
 public:
-	using Base = Table<void*>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : BaseTable(parent, name, x, y, w, h, style, rowtype) {
 	}
 
 	void remove_entry(Entry& entry) {
-		Base::remove_entry(&entry);
+		BaseTable::remove_entry(&entry);
 	}
 
 	EntryRecord& add(Entry& entry, bool const select_this = false) {
-		return Base::add(&entry, select_this);
+		return BaseTable::add(&entry, select_this);
 	}
 
 	Entry& operator[](uint32_t const i) const {
-		return *static_cast<Entry*>(Base::operator[](i));
+		return *static_cast<Entry*>(BaseTable::operator[](i));
 	}
 
 	static Entry& get(const EntryRecord& er) {
@@ -485,65 +491,67 @@ public:
 	}
 
 	EntryRecord* find(Entry& entry) const {
-		return Base::find(&entry);
+		return BaseTable::find(&entry);
 	}
 
 	Entry& get_selected() const {
-		return *static_cast<Entry*>(Base::get_selected());
+		return *static_cast<Entry*>(BaseTable::get_selected());
 	}
 };
 
 static_assert(sizeof(void*) == sizeof(uintptr_t),
               "assert(sizeof(void *) == sizeof(uintptr_t)) failed.");
-template <> class Table<uintptr_t> : public Table<void*> {
+template <> class Table<uintptr_t> : public BaseTable {
 public:
-	using Base = Table<void*>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : BaseTable(parent, name, x, y, w, h, style, rowtype) {
 	}
 
 	void remove_entry(uintptr_t const entry) {
-		Base::remove_entry(reinterpret_cast<void*>(entry));
+		BaseTable::remove_entry(reinterpret_cast<void*>(entry));
 	}
 
 	EntryRecord& add(uintptr_t const entry, bool const select_this = false) {
-		return Base::add(reinterpret_cast<void*>(entry), select_this);
+		return BaseTable::add(reinterpret_cast<void*>(entry), select_this);
 	}
 
 	uintptr_t operator[](uint32_t const i) const {
-		return reinterpret_cast<uintptr_t>(Base::operator[](i));
+		return reinterpret_cast<uintptr_t>(BaseTable::operator[](i));
 	}
 	static uintptr_t get(const EntryRecord& er) {
 		return reinterpret_cast<uintptr_t>(er.entry());
 	}
 
 	EntryRecord* find(uintptr_t const entry) const {
-		return Base::find(reinterpret_cast<void const*>(entry));
+		return BaseTable::find(reinterpret_cast<void const*>(entry));
 	}
 
 	uintptr_t get_selected() const {
-		return reinterpret_cast<uintptr_t>(Base::get_selected());
+		return reinterpret_cast<uintptr_t>(BaseTable::get_selected());
 	}
 };
 template <> class Table<uintptr_t const> : public Table<uintptr_t> {
 public:
 	using Base = Table<uintptr_t>;
 	Table(Panel* parent,
+	      const std::string& name,
 	      int32_t x,
 	      int32_t y,
 	      uint32_t w,
 	      uint32_t h,
 	      UI::PanelStyle style,
 	      TableRows rowtype = TableRows::kSingle)
-	   : Base(parent, x, y, w, h, style, rowtype) {
+	   : Base(parent, name, x, y, w, h, style, rowtype) {
 	}
 };
+
 }  // namespace UI
 
 #endif  // end of include guard: WL_UI_BASIC_TABLE_H
