@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2022 by the Widelands Development Team
+ * Copyright (C) 2003-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,7 +37,7 @@ constexpr int kTabPanelButtonHeight = 34;
  * stays the same for all elements
  */
 struct TabPanel;
-struct Tab : public NamedPanel {
+struct Tab : public Panel {
 	friend struct TabPanel;
 	friend class FileViewPanel;
 
@@ -96,7 +96,7 @@ struct TabPanel : public Panel {
 
 	friend struct Tab;
 
-	TabPanel(Panel* parent, UI::TabPanelStyle style);
+	TabPanel(Panel* parent, UI::TabPanelStyle style, const std::string& name);
 
 	/** Add textual tab
 	 *
@@ -105,7 +105,8 @@ struct TabPanel : public Panel {
 	uint32_t add(const std::string& name,
 	             const std::string& title,
 	             Panel* panel,
-	             const std::string& tooltip = std::string());
+	             const std::string& tooltip = std::string(),
+	             int index = -1);
 
 	/** Add pictorial tab
 	 * Text conventions: Sentence case for the 'tooltip'
@@ -113,7 +114,8 @@ struct TabPanel : public Panel {
 	uint32_t add(const std::string& name,
 	             const Image* pic,
 	             Panel* panel,
-	             const std::string& tooltip = std::string());
+	             const std::string& tooltip = std::string(),
+	             int index = -1);
 
 	using TabList = std::vector<Tab*>;
 
@@ -146,7 +148,8 @@ private:
 	                 const std::string& title,
 	                 const Image* pic,
 	                 const std::string& tooltip,
-	                 Panel* panel);
+	                 Panel* panel,
+	                 int index);
 
 	// Drawing and event handlers
 	void draw(RenderTarget&) override;
@@ -159,8 +162,8 @@ private:
 	size_t find_tab(int32_t x, int32_t y) const;
 
 	TabList tabs_;
-	size_t active_;     ///< index of the currently active tab
-	size_t highlight_;  ///< index of the highlighted button
+	size_t active_{0U};  ///< index of the currently active tab
+	size_t highlight_;   ///< index of the highlighted button
 
 	const UI::TabPanelStyle background_style_;  // Background color and texture. Not owned.
 	const UI::PanelStyleInfo& background_style() const;
