@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 by the Widelands Development Team
+ * Copyright (C) 2021-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@
 
 #include "ui_basic/box.h"
 #include "ui_basic/button.h"
-#include "ui_basic/editbox.h"
+#include "ui_basic/textinput.h"
 #include "ui_basic/window.h"
 
 namespace UI {
@@ -35,16 +35,16 @@ public:
 	                    const std::string& text);
 	~TextPrompt() override = default;
 
-	const std::string& text() const {
-		return editbox_.text();
+	[[nodiscard]] const std::string& get_text() const {
+		return editbox_.get_text();
 	}
 
 	/** Add custom content here, if desired. */
-	UI::Box& content_box() {
+	[[nodiscard]] UI::Box& content_box() {
 		return content_box_;
 	}
 
-	bool handle_key(const bool down, const SDL_Keysym code) override;
+	bool handle_key(bool down, SDL_Keysym code) override;
 
 private:
 	UI::Box box_, content_box_, buttonsbox_;
