@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,8 +52,9 @@ namespace UI {
  */
 struct Textarea : public Panel {
 public:
-	explicit Textarea(Panel* const parent,
+	explicit Textarea(Panel* parent,
 	                  PanelStyle,
+	                  const std::string& name,
 	                  FontStyle,
 	                  int32_t x,
 	                  int32_t y,
@@ -63,6 +64,7 @@ public:
 	                  Align align = UI::Align::kLeft);
 	explicit Textarea(Panel* parent,
 	                  PanelStyle,
+	                  const std::string& name,
 	                  FontStyle,
 	                  const std::string& text = std::string(),
 	                  Align align = UI::Align::kLeft);
@@ -91,8 +93,9 @@ protected:
 private:
 	enum class LayoutMode { AutoMove, Layouted };
 
-	Textarea(Panel* const parent,
+	Textarea(Panel* parent,
 	         PanelStyle,
+	         const std::string& name,
 	         FontStyle,
 	         int32_t x,
 	         int32_t y,
