@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ class Panel;
  */
 struct UniqueWindow : public Window {
 	struct Registry {
-		UniqueWindow* window;
+		UniqueWindow* window{nullptr};
 
 		// Whenever Registry::toggle() is called, a window will be created using
 		// 'open_window' or if one is open already, the existing one will be
@@ -48,12 +48,13 @@ struct UniqueWindow : public Window {
 		void destroy() const;
 		void toggle();
 
-		int32_t x, y;
-		bool valid_pos;
+		int32_t x{0};
+		int32_t y{0};
+		bool valid_pos{false};
+		bool pinned{false};
 
-		Registry() : window(nullptr), x(0), y(0), valid_pos(false) {
-		}
-		~Registry();
+		Registry() = default;
+		virtual ~Registry();
 	};
 
 	UniqueWindow(Panel* parent,
@@ -74,12 +75,18 @@ struct UniqueWindow : public Window {
 	             const std::string& title);
 	~UniqueWindow() override;
 
-	bool get_usedefaultpos() {
+	void save_position();
+	void set_pos(Vector2i new_pos) override;
+	void move_inside_parent() override;
+
+	bool get_usedefaultpos() const {
 		return usedefaultpos_;
 	}
 
+protected:
+	Registry* const registry_;
+
 private:
-	Registry* registry_;
 	bool usedefaultpos_;
 };
 }  // namespace UI
