@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,7 @@ namespace UI {
  * Minimize means, that the window is only the caption bar, nothing inside.
  * Another click on this bar resizes the window again
  */
-class Window : public NamedPanel {
+class Window : public Panel {
 public:
 	/// Height the top border must have
 	static constexpr int16_t kTopBorderThickness = 20;
@@ -94,8 +94,12 @@ public:
 	}
 	virtual void restore();
 	virtual void minimize();
-	bool is_snap_target() const override {
-		return true;
+
+	[[nodiscard]] ZOrder get_z() const override {
+		if (is_pinned()) {
+			return std::max(Panel::ZOrder::kPinned, Panel::get_z());
+		}
+		return Panel::get_z();
 	}
 
 	bool is_pinned() const {
@@ -109,6 +113,11 @@ public:
 		return button_pin_;
 	}
 
+	/** Whether the user ever moved the window. */
+	[[nodiscard]] bool moved_by_user() const {
+		return moved_by_user_;
+	}
+
 	// Drawing and event handlers
 	void draw(RenderTarget&) override;
 	void draw_border(RenderTarget&) override;
@@ -156,17 +165,20 @@ protected:
 	virtual void on_resolution_changed_note(const GraphicResolutionChanged& note);
 
 private:
-	bool is_minimal_;
+	bool is_minimal_{false};
 	uint32_t oldh_;  // if it is minimized, this is the old height
-	bool dragging_;
-	int32_t drag_start_win_x_, drag_start_win_y_;
-	int32_t drag_start_mouse_x_, drag_start_mouse_y_;
-	bool pinned_;
+	bool dragging_{false};
+	bool moved_by_user_{false};
+	int32_t drag_start_win_x_{0};
+	int32_t drag_start_win_y_{0};
+	int32_t drag_start_mouse_x_{0};
+	int32_t drag_start_mouse_y_{0};
+	bool pinned_{false};
 
 	std::string title_;
 
-	Panel* center_panel_;
-	Panel* fastclick_panel_;
+	Panel* center_panel_{nullptr};
+	Panel* fastclick_panel_{nullptr};
 
 	Button* button_close_;
 	Button* button_pin_;
