@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 by the Widelands Development Team
+ * Copyright (C) 2021-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,10 +21,9 @@
 
 #include "ui_basic/box.h"
 #include "ui_basic/button.h"
-#include "ui_basic/multilineeditbox.h"
+#include "ui_basic/textinput.h"
 #include "ui_basic/window.h"
 
-namespace FsMenu {
 namespace AddOnsUI {
 
 class AddOnsCtrl;
@@ -46,6 +45,5 @@ private:
 };
 
 }  // namespace AddOnsUI
-}  // namespace FsMenu
 
 #endif  // end of include guard: WL_UI_FSMENU_ADDONS_CONTACT_H
