@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -56,25 +56,39 @@ InternetLobby::InternetLobby(MenuCapsule& fsmm,
      // Left column content
      label_clients_online_(&left_column_box_,
                            UI::PanelStyle::kFsMenu,
+                           "label_clients",
                            UI::FontStyle::kFsMenuLabel,
                            0,
                            0,
                            0,
                            0,
                            _("Clients online:")),
-     clientsonline_table_(&left_column_box_, 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
-     chat_(&left_column_box_, 0, 0, 0, 0, InternetGaming::ref(), UI::PanelStyle::kFsMenu),
+     clientsonline_table_(&left_column_box_, "table", 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     chat_(
+        &left_column_box_,
+        [](int /* unused */) {
+	        return nullptr; /* No ongoing game while still in the lobby. */
+        },
+        0,
+        0,
+        0,
+        0,
+        InternetGaming::ref(),
+        &g_chat_sent_history,
+        UI::PanelStyle::kFsMenu),
 
      // Right column content
      label_opengames_(&right_column_content_box_,
                       UI::PanelStyle::kFsMenu,
+                      "label_opengames",
                       UI::FontStyle::kFsMenuLabel,
                       0,
                       0,
                       0,
                       0,
                       _("Open Games:")),
-     opengames_list_(&right_column_content_box_, 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     opengames_list_(
+        &right_column_content_box_, "list_opengames", 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
      joingame_(&right_column_content_box_,
                "join_game",
                0,
@@ -85,13 +99,14 @@ InternetLobby::InternetLobby(MenuCapsule& fsmm,
                _("Join this game")),
      servername_label_(&right_column_content_box_,
                        UI::PanelStyle::kFsMenu,
+                       "label_servername",
                        UI::FontStyle::kFsMenuLabel,
                        0,
                        0,
                        0,
                        0,
                        _("Name of your server:")),
-     servername_(&right_column_content_box_, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     servername_(&right_column_content_box_, "servername", 0, 0, 0, UI::PanelStyle::kFsMenu),
      hostgame_(&right_column_content_box_,
                "host_game",
                0,
@@ -100,7 +115,7 @@ InternetLobby::InternetLobby(MenuCapsule& fsmm,
                0,
                UI::ButtonStyle::kFsMenuSecondary,
                _("Open a new game")),
-     prev_clientlist_len_(1000),
+
      new_client_fx_(SoundHandler::register_fx(SoundType::kChat, "sound/lobby_freshmen")),
      // Login information
      nickname_(nick),
@@ -125,6 +140,12 @@ InternetLobby::InternetLobby(MenuCapsule& fsmm,
 	right_column_content_box_.add(&servername_, UI::Box::Resizing::kFullSize);
 	right_column_content_box_.add_space(0);
 	right_column_content_box_.add(&hostgame_, UI::Box::Resizing::kFullSize);
+	right_column_content_box_.add_space(0);
+	right_column_content_box_.add(
+	   new UI::MultilineTextarea(&right_column_content_box_, "label_addons", 0, 0, 0, 0,
+	                             UI::PanelStyle::kFsMenu, AddOns::list_game_relevant_addons(),
+	                             UI::Align::kLeft, UI::MultilineTextarea::ScrollMode::kNoScrolling),
+	   UI::Box::Resizing::kFullSize);
 	right_column_content_box_.add_inf_space();
 
 	joingame_.sigclicked.connect([this]() { clicked_joingame(); });
@@ -410,7 +431,7 @@ void InternetLobby::change_servername() {
 	const std::vector<InternetGame>* games = InternetGaming::ref().games();
 	if (games != nullptr) {
 		for (const InternetGame& game : *games) {
-			if (game.name == servername_.text()) {
+			if (game.name == servername_.get_text()) {
 				hostgame_.set_enabled(false);
 				servername_.set_warning(true);
 				servername_.set_tooltip(
@@ -441,6 +462,10 @@ bool InternetLobby::wait_for_ip() {
 
 /// called when the 'join game' button was clicked
 void InternetLobby::clicked_joingame() {
+	if (!joingame_.enabled()) {
+		return;
+	}
+
 	if (opengames_list_.has_selection()) {
 		InternetGaming::ref().join_game(opengames_list_.get_selected().name);
 
@@ -467,9 +492,13 @@ void InternetLobby::clicked_joingame() {
 
 /// called when the 'host game' button was clicked
 void InternetLobby::clicked_hostgame() {
+	if (!hostgame_.enabled()) {
+		return;
+	}
+
 	// Save selected servername as default for next time and during that take care that the name is
 	// not empty.
-	std::string servername_ui = servername_.text();
+	std::string servername_ui = servername_.get_text();
 
 	const std::vector<InternetGame>* games = InternetGaming::ref().games();
 	if (games != nullptr) {
