@@ -450,19 +450,20 @@ bool LaunchGame::init_win_condition_label() {
 /**
  * Fill the dropdown with the available win conditions.
  */
-void LaunchGame::update_win_conditions() {
-	if (!init_win_condition_label()) {
-		std::set<std::string> tags;
-		if (!settings_.settings().mapfilename.empty()) {
-			Widelands::Map map;
-			std::unique_ptr<Widelands::MapLoader> ml =
-			   map.get_correct_loader(settings_.settings().mapfilename);
-			if (ml != nullptr) {
-				ml->preload_map(true, nullptr);
-				tags = map.get_tags();
-			}
+void LaunchGame::update_tags_and_win_conditions() {
+	std::set<std::string> tags;
+	if (!settings_.settings().mapfilename.empty()) {
+		Widelands::Map map;
+		std::unique_ptr<Widelands::MapLoader> ml =
+		   map.get_correct_loader(settings_.settings().mapfilename);
+		if (ml != nullptr) {
+			ml->preload_map(true, nullptr);
+			tags = map.get_tags();
 		}
-		map_is_seafaring_ = tags.count("seafaring") != 0;
+	}
+	map_is_seafaring_ = tags.count("seafaring") != 0;
+
+	if (!init_win_condition_label()) {
 		load_win_conditions(tags);
 	}
 }
