@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ struct ChatProvider;
 struct MapData;
 namespace Widelands {
 class Game;
-}
+}  // namespace Widelands
 
 namespace FsMenu {
 
@@ -48,7 +48,6 @@ public:
 	   GameSettingsProvider&,
 	   GameController&,
 	   ChatProvider&,
-	   Widelands::Game&,
 	   bool game_done_on_cancel,
 	   const std::function<void()>& callback = []() {});
 	~LaunchMPG() override;
@@ -81,7 +80,6 @@ private:
 	std::unique_ptr<HelpWindow> help_;
 	MultiPlayerSetupGroup mpsg_;
 	std::unique_ptr<GameChatPanel> chat_;
-	Widelands::Game& game_;  // Not owned
 
 	std::unique_ptr<Notifications::Subscriber<NoteGameSettings>> subscriber_;
 };
