@@ -679,7 +679,7 @@ bool MainMenu::handle_key(const bool down, const SDL_Keysym code) {
 			// Easter egg: Press Ctrl/Shift+Backspace to exchange the background immediately :-)
 			last_image_exchange_time_ -=
 			   (last_image_exchange_time_ > kImageExchangeInterval ? kImageExchangeInterval :
-                                                                  last_image_exchange_time_);
+			                                                         last_image_exchange_time_);
 			return true;
 		}
 	}
@@ -698,8 +698,8 @@ do_draw_image(RenderTarget& r, const Rectf& dest, const Image& img, const float
 
 inline float MainMenu::calc_opacity(const uint32_t time) const {
 	return last_image_ == draw_image_ ?
-             1.f :
-             std::max(0.f, std::min(1.f, static_cast<float>(time - last_image_exchange_time_) /
+	          1.f :
+	          std::max(0.f, std::min(1.f, static_cast<float>(time - last_image_exchange_time_) /
 	                                         kImageExchangeDuration));
 }
 
@@ -797,9 +797,9 @@ void MainMenu::draw_overlay(RenderTarget& r) {
 
 	if (time - init_time_ < kInitialFadeoutDelay + kInitialFadeoutDuration) {
 		const float opacity = time - init_time_ > kInitialFadeoutDelay ?
-                               1.f - static_cast<float>(time - init_time_ - kInitialFadeoutDelay) /
+		                         1.f - static_cast<float>(time - init_time_ - kInitialFadeoutDelay) /
 		                                  kInitialFadeoutDuration :
-                               1.f;
+		                         1.f;
 		do_draw_image(r, image_pos(*splashscreen_, false), *splashscreen_, opacity);
 	} else {
 		const unsigned opacity =
@@ -921,9 +921,9 @@ void MainMenu::action(const MenuTarget t) {
 		break;
 	case MenuTarget::kReplayLast:
 		if (!filename_for_last_replay_.empty()) {
-			if (Widelands::Game* g = create_safe_game(); g != nullptr) {
-				menu_capsule_.clear_content();
-				g->run_replay(filename_for_last_replay_, "");
+			std::unique_ptr<Widelands::Game> game(create_safe_game(true));
+			if (game != nullptr) {
+				game->run_replay(filename_for_last_replay_, "");
 			}
 		}
 		break;
