@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -146,10 +146,11 @@ static std::string assemble_infotext_for_map(const Widelands::Map& map,
 // MapDetailsBox implementation
 
 MapDetailsBox::MapDetailsBox(Panel* parent, const uint32_t padding)
-   : UI::Box(parent, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Vertical),
+   : UI::Box(parent, UI::PanelStyle::kFsMenu, "map_details_box", 0, 0, UI::Box::Vertical),
      padding_(padding),
      title_(this,
             UI::PanelStyle::kFsMenu,
+            "title",
             UI::FontStyle::kFsGameSetupHeadings,
             0,
             0,
@@ -157,10 +158,10 @@ MapDetailsBox::MapDetailsBox(Panel* parent, const uint32_t padding)
             0,
             _("Map"),
             UI::Align::kCenter),
-     title_box_(this, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Horizontal),
-     content_box_(this, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Vertical),
-     map_name_(&title_box_,
+     content_box_(this, UI::PanelStyle::kFsMenu, "content_box", 0, 0, UI::Box::Vertical),
+     map_name_(this,
                UI::PanelStyle::kFsMenu,
+               "label_name",
                UI::FontStyle::kFsMenuLabel,
                0,
                0,
@@ -169,6 +170,7 @@ MapDetailsBox::MapDetailsBox(Panel* parent, const uint32_t padding)
                _("No map selected"),
                UI::Align::kLeft),
      map_description_(&content_box_,
+                      "description",
                       0,
                       0,
                       UI::Scrollbar::kSize,  // min width must be set to avoid assertion failure...
@@ -182,9 +184,7 @@ MapDetailsBox::MapDetailsBox(Panel* parent, const uint32_t padding)
 	content_box_.set_scrolling(true);
 	add(&title_, Resizing::kAlign, UI::Align::kCenter);
 	add_space(3 * padding);
-	title_box_.add(&map_name_, UI::Box::Resizing::kAlign, UI::Align::kLeft);
-	title_box_.add_inf_space();
-	add(&title_box_, UI::Box::Resizing::kFullSize);
+	add(&map_name_, UI::Box::Resizing::kFullSize);
 	add_space(3 * padding);
 	add(&content_box_, UI::Box::Resizing::kExpandBoth);
 	content_box_.add(&map_description_, UI::Box::Resizing::kExpandBoth);
@@ -222,10 +222,9 @@ void MapDetailsBox::show_map_description(const Widelands::Map& map,
 	set_map_description_text(assemble_infotext_for_map(map, settings->settings()));
 }
 
-void MapDetailsBox::force_new_dimensions(uint32_t width, uint32_t height) {
-	map_name_.set_fixed_width(width - height);
-	content_box_.set_max_size(
-	   width, get_h() - title_.get_h() - title_box_.get_h() - 2 * 3 * padding_);
+void MapDetailsBox::set_max_size(int w, int h) {
+	Box::set_max_size(w, h);
+	content_box_.set_max_size(w, h - title_.get_h() - map_name_.get_h() - 2 * 3 * padding_);
 }
 
 void MapDetailsBox::set_map_description_text(const std::string& text) {
