@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,20 +48,25 @@ MapSelect::MapSelect(MenuCapsule& m,
    : TwoColumnsFullNavigationMenu(m, _("Choose Map")),
      parent_screen_(mpg),
      game_for_preview_(for_preview),
-     checkboxes_(
-        &header_box_, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Vertical, 0, 0, 2 * kPadding),
+     checkboxes_(&header_box_,
+                 UI::PanelStyle::kFsMenu,
+                 "checkboxes_box",
+                 0,
+                 0,
+                 UI::Box::Vertical,
+                 0,
+                 0,
+                 2 * kPadding),
      table_(&left_column_box_, 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
      map_details_(
         &right_column_content_box_, 0, 0, 0, 0, UI::PanelStyle::kFsMenu, *game_for_preview_),
 
-     scenario_types_(settings->settings().multiplayer ? Map::MP_SCENARIO : Map::SP_SCENARIO),
+     scenario_types_(settings->settings().multiplayer ? Widelands::Map::MP_SCENARIO :
+                                                        Widelands::Map::SP_SCENARIO),
      basedir_(kMapsDir),
      settings_(settings),
-     ctrl_(ctrl),
-     has_translated_mapname_(false),
-     unspecified_balancing_found_(false),
-     update_map_details_(false) {
-	curdir_ = basedir_;
+     ctrl_(ctrl) {
+	curdir_ = {basedir_};
 	if (settings_->settings().multiplayer) {
 		back_.set_tooltip(_("Return to the multiplayer game setup"));
 	} else {
@@ -74,13 +79,14 @@ MapSelect::MapSelect(MenuCapsule& m,
 	table_.set_column_compare(1, [this](uint32_t a, uint32_t b) { return compare_mapnames(a, b); });
 	table_.set_column_compare(2, [this](uint32_t a, uint32_t b) { return compare_size(a, b); });
 
-	UI::Box* hbox = new UI::Box(
-	   &checkboxes_, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Horizontal, checkbox_space_, get_w());
+	UI::Box* hbox = new UI::Box(&checkboxes_, UI::PanelStyle::kFsMenu, "hbox", 0, 0,
+	                            UI::Box::Horizontal, checkbox_space_, get_w());
 
 	show_all_maps_ = new UI::Button(
 	   hbox, "show_all_maps", 0, 0, 0, 0, UI::ButtonStyle::kFsMenuSecondary, _("Show all maps"));
-	cb_dont_localize_mapnames_ = new UI::Checkbox(
-	   hbox, UI::PanelStyle::kFsMenu, Vector2i::zero(), _("Show original map names"));
+	cb_dont_localize_mapnames_ =
+	   new UI::Checkbox(hbox, UI::PanelStyle::kFsMenu, "original_map_names", Vector2i::zero(),
+	                    _("Show original map names"));
 	cb_dont_localize_mapnames_->set_state(false);
 
 	hbox->add(show_all_maps_, UI::Box::Resizing::kFullSize);
@@ -91,16 +97,18 @@ MapSelect::MapSelect(MenuCapsule& m,
 
 	// Row with dropdowns
 
-	hbox = new UI::Box(
-	   &checkboxes_, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Horizontal, checkbox_space_, get_w());
+	hbox = new UI::Box(&checkboxes_, UI::PanelStyle::kFsMenu, "tags_box_1", 0, 0,
+	                   UI::Box::Horizontal, checkbox_space_, get_w());
 
 	official_tags_dropdown_ = new UI::Dropdown<std::string>(
 	   hbox, "dropdown_official_tags", 0, 0, 200, 50, 24, "", UI::DropdownType::kTextual,
 	   UI::PanelStyle::kFsMenu, UI::ButtonStyle::kFsMenuMenu);
 	official_tags_dropdown_->set_autoexpand_display_button();
-	official_tags_dropdown_->add(_("Official & Unofficial"), "");
-	official_tags_dropdown_->add(localize_tag("official"), "official");
-	official_tags_dropdown_->add(localize_tag("unofficial"), "unofficial");
+	official_tags_dropdown_->set_tooltip(_("Filter by official status"));
+	official_tags_dropdown_->add(
+	   _("Official & Unofficial"), "", nullptr, false, _("Show both official and unofficial maps"));
+	add_tag_to_dropdown(official_tags_dropdown_, "official");
+	add_tag_to_dropdown(official_tags_dropdown_, "unofficial");
 
 	hbox->add(official_tags_dropdown_, UI::Box::Resizing::kFullSize);
 
@@ -110,14 +118,16 @@ MapSelect::MapSelect(MenuCapsule& m,
 	   hbox, "dropdown_team_tags", 0, 0, 200, 50, 24, "", UI::DropdownType::kTextual,
 	   UI::PanelStyle::kFsMenu, UI::ButtonStyle::kFsMenuMenu);
 	team_tags_dropdown_->set_autoexpand_display_button();
-	/** TRANSLATORS: Filter entry in map selection. Other entries are "Free for all"", "Teams of 2"
-	 * etc. */
-	team_tags_dropdown_->add(_("Any Teams"), "");
-	team_tags_dropdown_->add(localize_tag("ffa"), "ffa");
-	team_tags_dropdown_->add(localize_tag("1v1"), "1v1");
-	team_tags_dropdown_->add(localize_tag("2teams"), "2teams");
-	team_tags_dropdown_->add(localize_tag("3teams"), "3teams");
-	team_tags_dropdown_->add(localize_tag("4teams"), "4teams");
+	team_tags_dropdown_->set_tooltip(_("Filter by desired line-up"));
+	team_tags_dropdown_->add(
+	   /** TRANSLATORS: Filter entry in map selection. Other entries are "Free for all"",
+	    * "Teams of 2" etc. */
+	   _("Any Teams"), "", nullptr, false, _("Do not filter by line-up suggestions"));
+	add_tag_to_dropdown(team_tags_dropdown_, "ffa");
+	add_tag_to_dropdown(team_tags_dropdown_, "1v1");
+	add_tag_to_dropdown(team_tags_dropdown_, "2teams");
+	add_tag_to_dropdown(team_tags_dropdown_, "3teams");
+	add_tag_to_dropdown(team_tags_dropdown_, "4teams");
 
 	hbox->add(team_tags_dropdown_, UI::Box::Resizing::kFullSize);
 
@@ -127,6 +137,7 @@ MapSelect::MapSelect(MenuCapsule& m,
 	   hbox, "dropdown_balancing", 0, 0, 200, 50, 24, "", UI::DropdownType::kTextual,
 	   UI::PanelStyle::kFsMenu, UI::ButtonStyle::kFsMenuMenu);
 	balancing_tags_dropdown_->set_autoexpand_display_button();
+	balancing_tags_dropdown_->set_tooltip(_("Filter by balancing status"));
 	rebuild_balancing_dropdown();
 
 	hbox->add(balancing_tags_dropdown_, UI::Box::Resizing::kFullSize);
@@ -135,12 +146,12 @@ MapSelect::MapSelect(MenuCapsule& m,
 
 	// Row with checkboxes
 
-	hbox = new UI::Box(
-	   &checkboxes_, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Horizontal, checkbox_space_, get_w());
-	add_tag_checkbox(hbox, "seafaring", localize_tag("seafaring"));
-	add_tag_checkbox(hbox, "ferries", localize_tag("ferries"));
-	add_tag_checkbox(hbox, "artifacts", localize_tag("artifacts"));
-	add_tag_checkbox(hbox, "scenario", localize_tag("scenario"));
+	hbox = new UI::Box(&checkboxes_, UI::PanelStyle::kFsMenu, "tags_box_2", 0, 0,
+	                   UI::Box::Horizontal, checkbox_space_, get_w());
+	add_tag_checkbox(hbox, "seafaring");
+	add_tag_checkbox(hbox, "ferries");
+	add_tag_checkbox(hbox, "artifacts");
+	add_tag_checkbox(hbox, "scenario");
 	hbox->add_inf_space();
 	checkboxes_.add(hbox, UI::Box::Resizing::kFullSize);
 
@@ -230,7 +241,7 @@ void MapSelect::clicked_ok() {
 	const MapData& mapdata = maps_data_[table_.get_selected()];
 
 	if (mapdata.width == 0u) {
-		curdir_ = mapdata.filename;
+		curdir_ = mapdata.filenames;
 		fill_table();
 	} else if (!ok_.enabled()) {
 		return;
@@ -293,12 +304,17 @@ void MapSelect::fill_table() {
 	// This is the normal case
 
 	//  Fill it with all files we find in all directories.
-	FilenameSet files = g_fs->list_directory(curdir_);
+	assert(!curdir_.empty());
+	FilenameSet files;
+	for (const std::string& dir : curdir_) {
+		FilenameSet f = g_fs->list_directory(dir);
+		files.insert(f.begin(), f.end());
+	}
 
 	// If we are not at the top of the map directory hierarchy (we're not talking
 	// about the absolute filesystem top!) we manually add ".."
-	if (curdir_ != basedir_) {
-		maps_data_.push_back(MapData::create_parent_dir(curdir_));
+	if (curdir_.at(0) != basedir_) {
+		maps_data_.push_back(MapData::create_parent_dir(curdir_.at(0)));
 	} else {
 		// In the toplevel directory we also need to include add-on maps
 		for (auto& addon : AddOns::g_addons) {
@@ -398,7 +414,20 @@ void MapSelect::fill_table() {
 			if ((strcmp(fs_filename, ".") == 0) || (strcmp(fs_filename, "..") == 0)) {
 				continue;
 			}
-			maps_data_.push_back(MapData::create_directory(mapfilename));
+
+			MapData new_md = MapData::create_directory(mapfilename);
+			bool found = false;
+			for (MapData& md : maps_data_) {
+				if (md.maptype == MapData::MapType::kDirectory &&
+				    md.localized_name == new_md.localized_name) {
+					found = true;
+					md.add(new_md);
+					break;
+				}
+			}
+			if (!found) {
+				maps_data_.push_back(new_md);
+			}
 		}
 	}
 
@@ -418,11 +447,13 @@ void MapSelect::fill_table() {
 /*
  * Add a tag to the checkboxes
  */
-UI::Checkbox*
-MapSelect::add_tag_checkbox(UI::Box* box, const std::string& tag, const std::string& displ_name) {
+UI::Checkbox* MapSelect::add_tag_checkbox(UI::Box* box, const std::string& tag) {
 	tags_ordered_.push_back(tag);
 
-	UI::Checkbox* cb = new UI::Checkbox(box, UI::PanelStyle::kFsMenu, Vector2i::zero(), displ_name);
+	const TagTexts l = localize_tag(tag);
+	UI::Checkbox* cb = new UI::Checkbox(box, UI::PanelStyle::kFsMenu, format("tag_checkbox_%s", tag),
+	                                    Vector2i::zero(), l.displayname);
+	cb->set_tooltip(l.tooltip);
 
 	box->add(cb, UI::Box::Resizing::kFullSize);
 	box->add_space(checkbox_space_);
@@ -460,12 +491,14 @@ void MapSelect::rebuild_balancing_dropdown() {
 	const std::string selected =
 	   balancing_tags_dropdown_->has_selection() ? balancing_tags_dropdown_->get_selected() : "";
 	balancing_tags_dropdown_->clear();
-	balancing_tags_dropdown_->add(_("Balanced & Unbalanced"), "");
-	balancing_tags_dropdown_->add(localize_tag("balanced"), "balanced");
-	balancing_tags_dropdown_->add(localize_tag("unbalanced"), "unbalanced");
+	balancing_tags_dropdown_->add(
+	   _("Balanced & Unbalanced"), "", nullptr, false, _("Show both balanced and unbalanced maps"));
+	add_tag_to_dropdown(balancing_tags_dropdown_, "balanced");
+	add_tag_to_dropdown(balancing_tags_dropdown_, "unbalanced");
 	if (unspecified_balancing_found_) {
 		// Backwards compatibility with old maps
-		balancing_tags_dropdown_->add(pgettext("balancing", "Unspecified"), "unspecified");
+		balancing_tags_dropdown_->add(pgettext("balancing", "Unspecified"), "unspecified", nullptr,
+		                              false, _("The map does not specify whether it is balanced"));
 		balancing_tags_dropdown_->select(selected);
 	} else {
 		balancing_tags_dropdown_->select(selected == "unspecified" ? "" : selected);
