@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -170,7 +170,7 @@ private:
 	UI::Box box_;
 	std::vector<Entry> visible_menus_;
 	MainMenu& fsmm_;
-	bool should_die_;
+	bool should_die_{false};
 };
 
 }  // namespace FsMenu
