@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,26 +37,29 @@ NetSetupLAN::NetSetupLAN(MenuCapsule& fsmm)
      // Left column content
      label_opengames_(&left_column_box_,
                       UI::PanelStyle::kFsMenu,
+                      "label_opengames",
                       UI::FontStyle::kFsMenuLabel,
                       0,
                       0,
                       0,
                       0,
                       _("List of games in your local network:")),
-     table_(&left_column_box_, 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     table_(&left_column_box_, "table", 0, 0, 0, 0, UI::PanelStyle::kFsMenu),
 
      // Right column content
      label_playername_(&right_column_content_box_,
                        UI::PanelStyle::kFsMenu,
+                       "label_playername",
                        UI::FontStyle::kFsMenuLabel,
                        0,
                        0,
                        0,
                        0,
                        _("Your nickname:")),
-     playername_(&right_column_content_box_, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     playername_(&right_column_content_box_, "playername", 0, 0, 0, UI::PanelStyle::kFsMenu),
      label_hostname_(&right_column_content_box_,
                      UI::PanelStyle::kFsMenu,
+                     "label_hostname",
                      UI::FontStyle::kFsMenuLabel,
                      0,
                      0,
@@ -64,8 +67,9 @@ NetSetupLAN::NetSetupLAN(MenuCapsule& fsmm)
                      0,
                      _("Host to connect:")),
 
-     host_box_(&right_column_content_box_, UI::PanelStyle::kFsMenu, 0, 0, UI::Box::Horizontal),
-     hostname_(&host_box_, 0, 0, 0, UI::PanelStyle::kFsMenu),
+     host_box_(
+        &right_column_content_box_, UI::PanelStyle::kFsMenu, "host_box", 0, 0, UI::Box::Horizontal),
+     hostname_(&host_box_, "hostname", 0, 0, 0, UI::PanelStyle::kFsMenu),
      loadlasthost_(&host_box_,
                    "load_previous_host",
                    0,
@@ -109,6 +113,12 @@ NetSetupLAN::NetSetupLAN(MenuCapsule& fsmm)
 	right_column_content_box_.add_inf_space();
 	right_column_content_box_.add(&hostgame_, UI::Box::Resizing::kFullSize);
 	right_column_content_box_.add_inf_space();
+	right_column_content_box_.add(
+	   new UI::MultilineTextarea(&right_column_content_box_, "label_addons", 0, 0, 0, 0,
+	                             UI::PanelStyle::kFsMenu, AddOns::list_game_relevant_addons(),
+	                             UI::Align::kLeft, UI::MultilineTextarea::ScrollMode::kNoScrolling),
+	   UI::Box::Resizing::kFullSize);
+	right_column_content_box_.add_inf_space();
 	right_column_content_box_.add_inf_space();
 	right_column_content_box_.add_inf_space();
 	right_column_content_box_.add_inf_space();
@@ -132,7 +142,6 @@ NetSetupLAN::NetSetupLAN(MenuCapsule& fsmm)
 	table_.add_column(90, _("State"));
 	table_.selected.connect([this](int32_t i) { game_selected(i); });
 	table_.double_clicked.connect([this](int32_t i) { game_doubleclicked(i); });
-	discovery_.set_callback(discovery_callback, this);
 
 	joingame_.set_enabled(false);
 	layout();
@@ -154,11 +163,21 @@ void NetSetupLAN::think() {
 	TwoColumnsBasicNavigationMenu::think();
 	change_playername();
 
-	discovery_.run();
+	try {
+		if (discovery_ == nullptr) {
+			discovery_.reset(new LanGameFinder());
+			discovery_->set_callback(discovery_callback, this);
+		}
+
+		discovery_->run();
+	} catch (...) {
+		return_to_main_menu();
+		throw;
+	}
 }
 
 bool NetSetupLAN::get_host_address(NetAddress* addr) {
-	const std::string& host = hostname_.text();
+	const std::string& host = hostname_.get_text();
 
 	for (uint32_t i = 0; i < table_.size(); ++i) {
 		const NetOpenGame& game = *table_[i];
@@ -180,7 +199,7 @@ bool NetSetupLAN::get_host_address(NetAddress* addr) {
 }
 
 void NetSetupLAN::clicked_ok() {
-	if (hostname_.text().empty()) {
+	if (hostname_.get_text().empty()) {
 		clicked_hostgame();
 	} else {
 		clicked_joingame();
@@ -191,7 +210,7 @@ void NetSetupLAN::game_selected(uint32_t /* index */) {
 	if (table_.has_selection()) {
 		if (const NetOpenGame* const game = table_.get_selected()) {
 			hostname_.set_text(game->info.hostname);
-			joingame_.set_enabled(true);
+			joingame_.set_enabled(valid_playername_);
 		}
 	}
 }
@@ -260,14 +279,14 @@ void NetSetupLAN::discovery_callback(int32_t const type,
 		static_cast<NetSetupLAN*>(userdata)->game_updated(game);
 		break;
 	default:
-		abort();
+		NEVER_HERE();
 	}
 }
 
 void NetSetupLAN::change_hostname() {
 	// Allow user to enter a hostname manually
 	table_.select(UI::Table<const NetOpenGame* const>::no_selection_index());
-	joingame_.set_enabled(!hostname_.text().empty());
+	joingame_.set_enabled(!hostname_.get_text().empty() && valid_playername_);
 }
 
 void NetSetupLAN::change_playername() {
@@ -275,7 +294,8 @@ void NetSetupLAN::change_playername() {
 	playername_.set_tooltip("");
 	hostgame_.set_enabled(true);
 
-	if (!InternetGaming::ref().valid_username(playername_.text())) {
+	valid_playername_ = InternetGaming::ref().valid_username(playername_.get_text());
+	if (!valid_playername_) {
 		playername_.set_warning(true);
 		playername_.set_tooltip(_("Enter a valid nickname. This value may contain only "
 		                          "English letters, numbers, and @ . + - _ characters "
@@ -284,16 +304,20 @@ void NetSetupLAN::change_playername() {
 		hostgame_.set_enabled(false);
 		return;
 	}
-	if (!hostname_.text().empty()) {
+	if (!hostname_.get_text().empty()) {
 		joingame_.set_enabled(true);
 	}
 
-	set_config_string("nickname", playername_.text());
+	set_config_string("nickname", playername_.get_text());
 }
 
 void NetSetupLAN::clicked_joingame() {
+	if (!joingame_.enabled()) {
+		return;
+	}
+
 	// Save selected host so users can reload it for reconnection.
-	set_config_string("lasthost", hostname_.text());
+	set_config_string("lasthost", hostname_.get_text());
 
 	NetAddress addr;
 	if (!get_host_address(&addr)) {
@@ -307,7 +331,7 @@ void NetSetupLAN::clicked_joingame() {
 
 	try {
 		running_game_.reset(new GameClient(
-		   capsule_, running_game_, std::make_pair(addr, NetAddress()), playername_.text()));
+		   capsule_, running_game_, std::make_pair(addr, NetAddress()), playername_.get_text()));
 	} catch (const std::exception& e) {
 		running_game_.reset();
 		UI::WLMessageBox mbox(&capsule_.menu(), UI::WindowStyle::kFsMenu, _("Network Error"),
@@ -318,6 +342,10 @@ void NetSetupLAN::clicked_joingame() {
 }
 
 void NetSetupLAN::clicked_hostgame() {
+	if (!hostgame_.enabled()) {
+		return;
+	}
+
 	std::vector<Widelands::TribeBasicInfo> tribeinfos = Widelands::get_all_tribeinfos(nullptr);
 	if (tribeinfos.empty()) {
 		UI::WLMessageBox mbox(
@@ -329,7 +357,8 @@ void NetSetupLAN::clicked_hostgame() {
 	}
 
 	try {
-		running_game_.reset(new GameHost(&capsule_, running_game_, playername_.text(), tribeinfos));
+		running_game_.reset(
+		   new GameHost(&capsule_, running_game_, playername_.get_text(), tribeinfos));
 	} catch (const std::exception& e) {
 		running_game_.reset();
 		UI::WLMessageBox mbox(&capsule_.menu(), UI::WindowStyle::kFsMenu, _("Network Error"),
@@ -344,7 +373,7 @@ void NetSetupLAN::clicked_lasthost() {
 	std::string const host = s.get_string("lasthost", "");
 	hostname_.set_text(host);
 	if (!host.empty()) {
-		joingame_.set_enabled(true);
+		joingame_.set_enabled(valid_playername_);
 	}
 	table_.select(UI::Table<const NetOpenGame* const>::no_selection_index());
 }
