@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 by the Widelands Development Team
+ * Copyright (C) 2020-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,18 +27,17 @@ namespace FsMenu {
 
 RandomGame::RandomGame(MenuCapsule& m)
    : TwoColumnsFullNavigationMenu(m, _("New Random Game")),
-     menu_(left_column_box_, UI::PanelStyle::kFsMenu, 350, 64, 64),
+     menu_(left_column_box_, UI::PanelStyle::kFsMenu, 350, 64, 64, ok_, back_),
      icon_(&right_column_content_box_,
            UI::PanelStyle::kFsMenu,
-           g_image_cache->get("images/logos/wl-ico-128.png")),
-     progress_window_(nullptr) {
+           "wl_logo",
+           g_image_cache->get("images/logos/wl-ico-128.png")) {
 	m.set_visible(false);
 
 	{  // Do this first to prevent crashes with incompatible add-on types
 		std::vector<AddOns::AddOnState> new_g_addons;
 		for (const AddOns::AddOnState& s : AddOns::g_addons) {
-			if (s.second && s.first->category != AddOns::AddOnCategory::kWorld &&
-			    s.first->category != AddOns::AddOnCategory::kTribes &&
+			if (s.second && s.first->category != AddOns::AddOnCategory::kTribes &&
 			    s.first->category != AddOns::AddOnCategory::kScript) {
 				new_g_addons.push_back(s);
 			}
@@ -52,6 +51,7 @@ RandomGame::RandomGame(MenuCapsule& m)
 		die();
 		return;
 	}
+	game_->logic_rand_seed(RNG::static_rand());
 	m.set_visible(true);
 
 	left_column_box_.add_inf_space();
@@ -66,13 +66,13 @@ RandomGame::RandomGame(MenuCapsule& m)
 	layout();
 	{
 		UI::MultilineTextarea* txt = new UI::MultilineTextarea(
-		   &right_column_content_box_, 0, 0, 100, 100, UI::PanelStyle::kFsMenu, "", UI::Align::kLeft,
-		   UI::MultilineTextarea::ScrollMode::kNoScrolling);
+		   &right_column_content_box_, "beta_message", 0, 0, 100, 100, UI::PanelStyle::kFsMenu, "",
+		   UI::Align::kLeft, UI::MultilineTextarea::ScrollMode::kNoScrolling);
 		txt->set_style(UI::FontStyle::kFsMenuInfoPanelParagraph);
 		txt->set_text(
 		   _("The random map generator is still in beta stage. The maps it generates are usually – "
 		     "but not always – well playable. Seafaring and artifacts are not supported. Add-ons of "
-		     "the World, Tribes, and Script categories are disabled in random matches."));
+		     "the Tribes and Script categories are disabled in random matches."));
 		right_column_content_box_.add(txt, UI::Box::Resizing::kFullSize);
 		right_column_content_box_.add_inf_space();
 	}
@@ -100,7 +100,7 @@ RandomGame::~RandomGame() {
 void RandomGame::reactivated() {
 	if (progress_window_ == nullptr) {
 		progress_window_ =
-		   &game_->create_loader_ui({"general_game", "singleplayer"}, false, "", "", &capsule_);
+		   &game_->create_loader_ui({"general_game", "singleplayer"}, false, "", "", true, &capsule_);
 		progress_window_->set_visible(false);
 	}
 }
