@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -92,6 +92,11 @@ int main(int argc, char** argv) {
 			json->add_string(
 			   "minimum_required_widelands_version", map->minimum_required_widelands_version());
 
+			JSON::Array* tags_array = json->add_array("tags");
+			for (const std::string& tag : map->get_tags()) {
+				tags_array->add_empty(tag);
+			}
+
 			const std::string world_name =
 			   dynamic_cast<Widelands::WidelandsMapLoader*>(ml.get())->old_world_name();
 			json->add_string("world_name", world_name);
