@@ -647,8 +647,8 @@ static void init_one_player_from_template(unsigned p,
 	const Widelands::TribeBasicInfo t = settings->settings().get_tribeinfo(tribe);
 	for (unsigned i = 0; i < t.initializations.size(); ++i) {
 		if (addon.empty() ?
-             init_script_name == FileSystem::fs_filename(t.initializations[i].script.c_str()) :
-             addon == t.initializations[i].script) {
+		       init_script_name == FileSystem::fs_filename(t.initializations[i].script.c_str()) :
+		       addon == t.initializations[i].script) {
 			settings->set_player_init(p, i);
 			found_init = true;
 			break;
@@ -1616,7 +1616,7 @@ void WLApplication::handle_commandline_parameters() {
 		game_type_ = pair.first;
 
 		filename_ = *val;
-		if (filename_.back() == '/') {
+		if (!filename_.empty() && filename_.back() == '/') {
 			// Strip trailing directory separator
 			filename_.erase(filename_.size() - 1);
 		}
@@ -1779,7 +1779,7 @@ void WLApplication::emergency_save(UI::Panel* panel,
 		   panel, UI::WindowStyle::kFsMenu,
 		   ask_for_bug_report ? _("Unexpected error during the game") : _("Game ended unexpectedly"),
 		   ask_for_bug_report ?
-            format(
+		      format(
 		         _("An error occured during the game. The error message is:\n\n%1$s\n\nPlease report "
 		           "this problem to help us improve Widelands. You will find related messages in the "
 		           "standard output (stdout.txt on Windows). You are using version %2$s.\n\n"
@@ -1788,7 +1788,7 @@ void WLApplication::emergency_save(UI::Panel* panel,
 		           "to attempt to create an emergency savegame? It is often – though not always – "
 		           "possible to load it and continue playing."),
 		         error, build_ver_details()) :
-            format(
+		      format(
 		         _("The game ended unexpectedly for the following reason:\n\n%s\n\nWould you like "
 		           "Widelands to attempt to create an emergency savegame? It is often – though not "
 		           "always – possible to load it and continue playing."),
