@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,8 @@
 
 #include <atomic>
 #include <map>
+#include <memory>
+#include <optional>
 #include <stdexcept>
 #include <string>
 #include <vector>
@@ -40,12 +42,15 @@
 #include "base/vector.h"
 #include "wlapplication_messages.h"
 
+namespace FsMenu {
+class MainMenu;
+}  // namespace FsMenu
 namespace UI {
 class Panel;
-}
+}  // namespace UI
 namespace Widelands {
 class Game;
-}
+}  // namespace Widelands
 
 /** Returns the widelands executable path. */
 std::string get_executable_directory(bool logdir = true);
@@ -59,6 +64,8 @@ struct ParameterError : public std::runtime_error {
 	CmdLineVerbosity level_;
 };
 
+using OptionalParameter = std::optional<std::string>;
+
 // Callbacks input events to the UI. All functions return true when the event
 // was handled, false otherwise.
 struct InputCallback {
@@ -122,14 +129,7 @@ struct InputCallback {
 ///
 /// Forking does not work on windows, but nobody cares enough to investigate.
 /// It is only a debugging convenience anyway.
-///
-///
-/// \par The mouse cursor
-///
-/// Ordinarily, relative coordinates break down when the cursor leaves the
-/// window. This means we have to grab the mouse, then relative coords are
-/// always available.
-// TODO(unknown): Actually do grab the mouse when it is locked
+
 // TODO(unknown): Graphics are currently not handled by WLApplication, and it is
 // non essential for playback anyway. Additionally, we will want several
 // rendering backends (software and OpenGL). Maybe the graphics backend loader
@@ -139,7 +139,8 @@ struct InputCallback {
 // TODO(sirver): this class makes no sense for c++ - most of these should be
 // stand alone functions.
 struct WLApplication {
-	static WLApplication* get(int const argc = 0, char const** argv = nullptr);
+
+	static WLApplication& get(int argc = 0, char const** argv = nullptr);
 	~WLApplication();
 
 	void run();
@@ -147,28 +148,27 @@ struct WLApplication {
 	static void initialize_g_addons();
 
 	/// \warning true if an external entity wants us to quit
-	bool should_die() const {
+	[[nodiscard]] bool should_die() const {
 		return should_die_;
 	}
 
 	/// Get the state of the current KeyBoard Button
 	/// \warning This function doesn't check for dumbness
-	bool get_key_state(SDL_Scancode const key) const {
-		return SDL_GetKeyboardState(nullptr)[key];
+	[[nodiscard]] bool get_key_state(SDL_Scancode const key) const {
+		return SDL_GetKeyboardState(nullptr)[key] != 0U;
 	}
 
 	// @{
 	void warp_mouse(Vector2i);
-	void set_input_grab(bool grab);
 
 	/// The mouse's current coordinates
-	Vector2i get_mouse_position() const {
+	[[nodiscard]] Vector2i get_mouse_position() const {
 		return mouse_position_;
 	}
 	//
 	/// Find out whether the mouse is currently pressed
-	bool is_mouse_pressed() const {
-		return SDL_GetMouseState(nullptr, nullptr);
+	[[nodiscard]] bool is_mouse_pressed() const {
+		return SDL_GetMouseState(nullptr, nullptr) != 0U;
 	}
 
 	/// Swap left and right mouse key?
@@ -178,12 +178,12 @@ struct WLApplication {
 
 	/// Lock the mouse cursor into place (e.g., for scrolling the map)
 	void set_mouse_lock(bool locked);
-	bool is_mouse_locked() const {
+	[[nodiscard]] bool is_mouse_locked() const {
 		return mouse_locked_;
 	}
 	// @}
 
-	const std::string& get_datadir() const {
+	[[nodiscard]] const std::string& get_datadir() const {
 		return datadir_;
 	}
 
@@ -204,6 +204,8 @@ struct WLApplication {
 	                           bool replace_ctrl = true,
 	                           bool ask_for_bug_report = true);
 
+	static std::string segfault_backtrace_dir;
+
 private:
 	WLApplication(int argc, char const* const* argv);
 
@@ -217,6 +219,8 @@ private:
 
 	void parse_commandline(int argc, char const* const* argv);
 	void handle_commandline_parameters();
+	bool check_commandline_flag(const std::string& opt);
+	OptionalParameter get_commandline_option_value(const std::string& opt, bool allow_empty = false);
 
 	void setup_homedir();
 
@@ -225,8 +229,9 @@ private:
 	void cleanup_temp_files();
 	void cleanup_temp_backups(const std::string& dir);
 	void cleanup_temp_backups();
+	void check_crash_reports(FsMenu::MainMenu& menu);
 
-	void init_and_run_game_from_template();
+	void init_and_run_game_from_template(FsMenu::MainMenu& mainmenu);
 
 	bool redirect_output(std::string path = "");
 
@@ -242,27 +247,27 @@ private:
 	std::string script_to_run_;
 
 	enum class GameType { kNone, kEditor, kReplay, kScenario, kLoadGame, kFromTemplate };
-	GameType game_type_;
+	GameType game_type_{GameType::kNone};
 
 	/// True if left and right mouse button should be swapped
-	bool mouse_swapped_;
+	bool mouse_swapped_{false};
 
 	/// When apple is involved, the middle mouse button is sometimes send, even
 	/// if it wasn't pressed. We try to revert this and this helps.
-	bool faking_middle_mouse_button_;
+	bool faking_middle_mouse_button_{false};
 
 	/// The current position of the mouse pointer
-	Vector2i mouse_position_;
+	Vector2i mouse_position_{Vector2i::zero()};
 
 	/// If true, the mouse cursor will \e not move with a mousemotion event:
 	/// instead, the map will be scrolled
-	bool mouse_locked_;
+	bool mouse_locked_{false};
 
 	/// Makes it possible to disable the fullscreen and screenshot shortcuts
-	bool handle_key_enabled_;
+	bool handle_key_enabled_{true};
 
 	/// true if an external entity wants us to quit
-	std::atomic_bool should_die_;
+	std::atomic_bool should_die_{false};
 
 	std::string homedir_;
 #ifdef USE_XDG
@@ -270,7 +275,7 @@ private:
 #endif
 
 	/// flag indicating if stdout and stderr have been redirected
-	bool redirected_stdio_;
+	bool redirected_stdio_{false};
 
 	/// Absolute path to the data directory.
 	std::string datadir_;
@@ -280,12 +285,7 @@ private:
 	std::string localedir_;
 
 	/// Prevent toggling fullscreen on and off from flickering
-	uint32_t last_resolution_change_;
-
-	/// Holds this process' one and only instance of WLApplication, if it was
-	/// created already. nullptr otherwise.
-	/// \note This is private on purpose. Read the class documentation.
-	static WLApplication* the_singleton;
+	uint32_t last_resolution_change_{0U};
 
 	void handle_mousebutton(SDL_Event&, InputCallback const*);
 };
