@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 #include "logic/map_objects/tribes/building.h"
 #include "logic/map_objects/tribes/ship.h"
 #include "logic/player.h"
+#include "logic/playersmanager.h"
 #include "ui_basic/box.h"
 #include "ui_basic/checkbox.h"
 #include "ui_basic/multilinetextarea.h"
@@ -34,7 +35,7 @@ struct ActionConfirm : public UI::Window {
 	ActionConfirm(InteractivePlayer& parent,
 	              const std::string& windowtitle,
 	              const std::string& message,
-	              Widelands::MapObject& map_object,
+	              Widelands::MapObject* map_object,
 	              // May be "", in which case no checkbox will be added
 	              const std::string& checkbox = "");
 
@@ -46,7 +47,7 @@ struct ActionConfirm : public UI::Window {
 
 protected:
 	Widelands::ObjectPointer object_;
-	UI::Checkbox* checkbox_;
+	UI::Checkbox* checkbox_{nullptr};
 };
 
 /**
@@ -123,21 +124,32 @@ struct ShipCancelExpeditionConfirm : public ActionConfirm {
 	void ok() override;
 };
 
+/**
+ * Confirmation dialog box for giving up.
+ */
+struct ResignConfirm : public ActionConfirm {
+	explicit ResignConfirm(InteractivePlayer& parent);
+
+	void think() override;
+	void ok() override;
+};
+
 ActionConfirm::ActionConfirm(InteractivePlayer& parent,
                              const std::string& windowtitle,
                              const std::string& message,
-                             Widelands::MapObject& map_object,
+                             Widelands::MapObject* map_object,
                              const std::string& checkbox)
    : UI::Window(
         &parent, UI::WindowStyle::kWui, "building_action_confirm", 0, 0, 200, 120, windowtitle),
-     object_(&map_object),
-     checkbox_(nullptr) {
+     object_(map_object) {
 	const int padding = 6;
-	UI::Box* main_box = new UI::Box(this, UI::PanelStyle::kWui, padding, padding, UI::Box::Vertical);
-	UI::Box* button_box = new UI::Box(main_box, UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal);
+	UI::Box* main_box =
+	   new UI::Box(this, UI::PanelStyle::kWui, "main_box", padding, padding, UI::Box::Vertical);
+	UI::Box* button_box =
+	   new UI::Box(main_box, UI::PanelStyle::kWui, "buttons_box", 0, 0, UI::Box::Horizontal);
 
 	UI::MultilineTextarea* textarea = new UI::MultilineTextarea(
-	   main_box, 0, 0, 200, 74, UI::PanelStyle::kWui, message, UI::Align::kCenter,
+	   main_box, "message", 0, 0, 200, 74, UI::PanelStyle::kWui, message, UI::Align::kCenter,
 	   UI::MultilineTextarea::ScrollMode::kNoScrolling);
 
 	UI::Button* okbtn = new UI::Button(button_box, "ok", 0, 0, 80, 34, UI::ButtonStyle::kWuiMenu,
@@ -156,7 +168,8 @@ ActionConfirm::ActionConfirm(InteractivePlayer& parent,
 	   UI::g_fh->fontset()->is_rtl() ? cancelbtn : okbtn, UI::Box::Resizing::kFillSpace);
 	main_box->add(textarea);
 	if (!checkbox.empty()) {
-		checkbox_ = new UI::Checkbox(main_box, UI::PanelStyle::kWui, Vector2i(0, 0), checkbox);
+		checkbox_ =
+		   new UI::Checkbox(main_box, UI::PanelStyle::kWui, "checkbox", Vector2i(0, 0), checkbox);
 		// tooltip and initial state will be set by the subclass constructor
 		main_box->add_space(padding);
 		main_box->add(checkbox_, UI::Box::Resizing::kFullSize);
@@ -169,6 +182,7 @@ ActionConfirm::ActionConfirm(InteractivePlayer& parent,
 	                         (checkbox_ != nullptr ? checkbox_->get_h() + padding : 0));
 	set_inner_size(main_box->get_w() + 2 * padding, main_box->get_h() + 2 * padding);
 
+	set_z(UI::Panel::ZOrder::kConfirmation);
 	center_to_parent();
 	cancelbtn->center_mouse();
 
@@ -186,7 +200,7 @@ BulldozeConfirm::BulldozeConfirm(InteractivePlayer& parent,
    : ActionConfirm(parent,
                    _("Destroy building?"),
                    _("Do you really want to destroy this building?"),
-                   building),
+                   &building),
      todestroy_(todestroy != nullptr ? todestroy : &building) {
 	// Nothing special to do
 }
@@ -247,7 +261,7 @@ DismantleConfirm::DismantleConfirm(InteractivePlayer& parent, Widelands::Buildin
    : ActionConfirm(parent,
                    _("Dismantle building?"),
                    _("Do you really want to dismantle this building?"),
-                   building,
+                   &building,
                    should_allow_preserving_wares(building.descr()) ? _("Preserve wares") : "") {
 	if (checkbox_ != nullptr) {
 		checkbox_->set_tooltip(_("Any wares left in the building will be dropped out by the builder, "
@@ -307,7 +321,7 @@ EnhanceConfirm::EnhanceConfirm(InteractivePlayer& parent,
               /** TRANSLATORS: Warning message when player wants to enhance a military building */
               _("Be careful if the enemy is near!")) :
            _("Do you really want to enhance this building?"),
-        building,
+        &building,
         should_allow_preserving_wares(building.descr()) ? _("Preserve wares") : ""),
      id_(id),
      still_under_construction_(still_under_construction) {
@@ -366,7 +380,7 @@ ShipSinkConfirm::ShipSinkConfirm(InteractivePlayer& parent, Widelands::Ship& shi
                    _("Sink the ship?"),
                    /** TRANSLATORS: %s is a ship name */
                    format(_("Do you really want to sink %s?"), ship.get_shipname()),
-                   ship) {
+                   &ship) {
 	// Nothing special to do
 }
 
@@ -404,7 +418,7 @@ ShipCancelExpeditionConfirm::ShipCancelExpeditionConfirm(InteractivePlayer& pare
    : ActionConfirm(parent,
                    _("Cancel expedition?"),
                    _("Do you really want to cancel the active expedition?"),
-                   ship) {
+                   &ship) {
 	// Nothing special to do
 }
 
@@ -428,15 +442,43 @@ void ShipCancelExpeditionConfirm::ok() {
 	Widelands::Game& game = iaplayer().game();
 	upcast(Widelands::Ship, ship, object_.get(game));
 
-	if ((ship != nullptr) && iaplayer().can_act(ship->get_owner()->player_number()) &&
-	    ship->get_ship_state() != Widelands::Ship::ShipStates::kTransport &&
-	    ship->get_ship_state() != Widelands::Ship::ShipStates::kExpeditionColonizing) {
+	if (ship != nullptr && iaplayer().can_act(ship->get_owner()->player_number()) &&
+	    ship->get_ship_state() != Widelands::ShipStates::kTransport &&
+	    ship->get_ship_state() != Widelands::ShipStates::kExpeditionColonizing) {
 		game.send_player_cancel_expedition_ship(*ship);
 	}
 
 	die();
 }
 
+/**
+ * Create the panels for confirmation.
+ */
+ResignConfirm::ResignConfirm(InteractivePlayer& parent)
+   : ActionConfirm(
+        parent, _("Resign?"), _("Do you really want to give up and become a spectator?"), nullptr) {
+	// Nothing special to do
+}
+
+/**
+ * Make sure the player is still in the game.
+ */
+void ResignConfirm::think() {
+	if (iaplayer().egbase().player_manager()->get_player_end_status(iaplayer().player_number()) !=
+	    nullptr) {
+		die();
+	}
+}
+
+/**
+ * The "Ok" button was clicked, so issue the command for resigning.
+ */
+void ResignConfirm::ok() {
+	iaplayer().game().send_player_diplomacy(
+	   iaplayer().player_number(), Widelands::DiplomacyAction::kResign, 0 /* ignored */);
+	die();
+}
+
 /**
  * Create a BulldozeConfirm window.
  * No further action is required by the caller: any action necessary to actually
@@ -501,3 +543,7 @@ void show_ship_sink_confirm(InteractivePlayer& player, Widelands::Ship& ship) {
 void show_ship_cancel_expedition_confirm(InteractivePlayer& player, Widelands::Ship& ship) {
 	new ShipCancelExpeditionConfirm(player, ship);
 }
+
+void show_resign_confirm(InteractivePlayer& player) {
+	new ResignConfirm(player);
+}
