@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,18 @@ struct BuildingWindow : public UI::UniqueWindow {
 		Width = 4 * 34  //  4 normally sized buttons
 	};
 
+	enum class CollapsedState : uint8_t { kExpanded, kCollapsed };
+
+	struct Registry : public UI::UniqueWindow::Registry {
+		CollapsedState priority_collapsed{CollapsedState::kExpanded};
+	};
+	void set_priority_collapsed(CollapsedState collapse) {
+		*priority_collapsed_ = collapse;
+	}
+	CollapsedState* priority_collapsed() const {
+		return priority_collapsed_;
+	}
+
 	UI::Panel::SaveType save_type() const override {
 		return UI::Panel::SaveType::kBuildingWindow;
 	}
@@ -51,14 +63,14 @@ protected:
 	// This constructor allows setting a building description for the help button independent of the
 	// base building
 	BuildingWindow(InteractiveBase& parent,
-	               UI::UniqueWindow::Registry& reg,
+	               Registry& reg,
 	               Widelands::Building&,
 	               const Widelands::BuildingDescr&,
 	               bool avoid_fastclick);
 
 public:
 	BuildingWindow(InteractiveBase& parent,
-	               UI::UniqueWindow::Registry& reg,
+	               Registry& reg,
 	               Widelands::Building&,
 	               bool avoid_fastclick);
 
@@ -75,10 +87,15 @@ protected:
 	virtual void init(bool avoid_fastclick, bool workarea_preview_wanted);
 	void die() override;
 
+	// Actions performed when a NoteBuilding is received.
+	virtual void on_building_note(const Widelands::NoteBuilding& note);
+
 	UI::TabPanel* get_tabs() {
 		return tabs_;
 	}
 
+	virtual void setup_name_field_editbox(UI::Box& /* vbox */) {
+	}
 	void act_bulldoze();
 	void act_dismantle();
 	void act_debug();
@@ -87,6 +104,7 @@ protected:
 	void toggle_workarea();
 	void configure_workarea_button();
 	void act_start_stop();
+	void act_produce_infinite();
 	void act_start_or_cancel_expedition();
 	void act_enhance(Widelands::DescriptionIndex, bool is_csite);
 	void clicked_goto();
@@ -109,9 +127,6 @@ protected:
 private:
 	void create_capsbuttons(UI::Box* buttons, Widelands::Building* building);
 
-	// Actions performed when a NoteBuilding is received.
-	void on_building_note(const Widelands::NoteBuilding& note);
-
 	// For ports only.
 	void update_expedition_button(bool expedition_was_canceled);
 
@@ -142,6 +157,7 @@ private:
 
 	bool showing_workarea_;
 	bool avoid_fastclick_;
+	CollapsedState* priority_collapsed_;  ///< Owned by the BuildingWindow::Registry
 
 	UI::Button* expeditionbtn_;
 	UI::Button* mute_this_;
