@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -63,13 +63,17 @@ ConstructionSiteWindow::FakeWaresDisplay::FakeWaresDisplay(UI::Panel* parent,
 			warelist_->add(w->descr().worker_index(), 1);
 		}
 	}
-	add_warelist(*warelist_);
 }
 
 ConstructionSiteWindow::FakeWaresDisplay::~FakeWaresDisplay() {
 	warelist_->clear();  // Avoid annoying warnings
 }
 
+uint32_t
+ConstructionSiteWindow::FakeWaresDisplay::amount_of(const Widelands::DescriptionIndex ware) {
+	return warelist_->stock(ware);
+}
+
 void ConstructionSiteWindow::FakeWaresDisplay::draw_ware(RenderTarget& dst,
                                                          Widelands::DescriptionIndex ware) {
 	if (get_type() == Widelands::wwWORKER &&
@@ -106,19 +110,14 @@ void ConstructionSiteWindow::FakeWaresDisplay::draw_ware(RenderTarget& dst,
 }
 
 ConstructionSiteWindow::ConstructionSiteWindow(InteractiveBase& parent,
-                                               UI::UniqueWindow::Registry& reg,
+                                               BuildingWindow::Registry& reg,
                                                Widelands::ConstructionSite& cs,
                                                bool avoid_fastclick,
                                                bool workarea_preview_wanted)
    : BuildingWindow(parent, reg, cs, cs.building(), avoid_fastclick),
      construction_site_(&cs),
-     progress_(nullptr),
-     cs_launch_expedition_(nullptr),
-     cs_prefer_heroes_rookies_(nullptr),
-     cs_soldier_capacity_(nullptr),
-     cs_stopped_(nullptr),
-     cs_warehouse_wares_(nullptr),
-     cs_warehouse_workers_(nullptr) {
+
+     cs_prefer_heroes_rookies_(nullptr) {
 	init(avoid_fastclick, workarea_preview_wanted);
 }
 
@@ -142,7 +141,8 @@ void ConstructionSiteWindow::init(bool avoid_fastclick, bool workarea_preview_wa
 }
 
 void ConstructionSiteWindow::build_wares_tab(Widelands::ConstructionSite* construction_site) {
-	UI::Box& box = *new UI::Box(get_tabs(), UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical);
+	UI::Box& box =
+	   *new UI::Box(get_tabs(), UI::PanelStyle::kWui, "input_box", 0, 0, UI::Box::Vertical);
 
 	add_progress_bar(box);
 
@@ -155,8 +155,9 @@ void ConstructionSiteWindow::build_wares_tab(Widelands::ConstructionSite* constr
 }
 
 void ConstructionSiteWindow::add_progress_bar(UI::Box& box) {
-	progress_ = new UI::ProgressBar(&box, UI::PanelStyle::kWui, 0, 0, UI::ProgressBar::DefaultWidth,
-	                                UI::ProgressBar::DefaultHeight, UI::ProgressBar::Horizontal);
+	progress_ = new UI::ProgressBar(&box, UI::PanelStyle::kWui, "progress", 0, 0,
+	                                UI::ProgressBar::DefaultWidth, UI::ProgressBar::DefaultHeight,
+	                                UI::ProgressBar::Horizontal);
 	progress_->set_total(1 << 16);
 	box.add(progress_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
 }
@@ -165,14 +166,16 @@ void ConstructionSiteWindow::add_wares_queues(Widelands::ConstructionSite* const
                                               UI::Box& box) const {  // Add the wares queue
 	for (uint32_t i = 0; i < construction_site->nr_dropout_waresqueues(); ++i) {
 		box.add(new InputQueueDisplay(&box, *ibase(), *construction_site,
-		                              *construction_site->get_dropout_waresqueue(i), true, false),
+		                              *construction_site->get_dropout_waresqueue(i), true, false,
+		                              priority_collapsed()),
 		        UI::Box::Resizing::kFullSize);
 	}
 	for (uint32_t i = 0; i < construction_site->nr_consume_waresqueues(); ++i) {
 		Widelands::WaresQueue* ware = construction_site->get_consume_waresqueue(i);
 		// only display the queue if it requests at least one item and is not yet completed
 		if (ware->get_max_size() > 0 && ware->get_filled() <= ware->get_max_size()) {
-			box.add(new InputQueueDisplay(&box, *ibase(), *construction_site, *ware, false, true),
+			box.add(new InputQueueDisplay(
+			           &box, *ibase(), *construction_site, *ware, false, true, priority_collapsed()),
 			        UI::Box::Resizing::kFullSize);
 		}
 	}
@@ -184,7 +187,7 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 	// the relevant options.
 	bool nothing_added = false;
 	std::unique_ptr<UI::Box> settings_box(
-	   new UI::Box(get_tabs(), UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical));
+	   new UI::Box(get_tabs(), UI::PanelStyle::kWui, "settings_box", 0, 0, UI::Box::Vertical));
 	switch (construction_site->building().type()) {
 	case Widelands::MapObjectType::PRODUCTIONSITE:
 	case Widelands::MapObjectType::TRAININGSITE: {
@@ -195,15 +198,17 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 		assert(ps->ware_queues.size() == prodsite->input_wares().size());
 		ensure_box_can_hold_input_queues(*settings_box);
 		for (const auto& pair : prodsite->input_wares()) {
-			InputQueueDisplay* queue = new InputQueueDisplay(
-			   settings_box.get(), *ibase(), *construction_site, Widelands::wwWARE, pair.first);
+			InputQueueDisplay* queue =
+			   new InputQueueDisplay(settings_box.get(), *ibase(), *construction_site,
+			                         Widelands::wwWARE, pair.first, priority_collapsed());
 			settings_box->add(queue, UI::Box::Resizing::kFullSize);
 			cs_ware_queues_.push_back(queue);
 		}
 		assert(ps->worker_queues.size() == prodsite->input_workers().size());
 		for (const auto& pair : prodsite->input_workers()) {
-			InputQueueDisplay* queue = new InputQueueDisplay(
-			   settings_box.get(), *ibase(), *construction_site, Widelands::wwWORKER, pair.first);
+			InputQueueDisplay* queue =
+			   new InputQueueDisplay(settings_box.get(), *ibase(), *construction_site,
+			                         Widelands::wwWORKER, pair.first, priority_collapsed());
 			settings_box->add(queue, UI::Box::Resizing::kFullSize);
 			cs_ware_queues_.push_back(queue);
 		}
@@ -221,8 +226,9 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 				}
 			});
 		}
-		cs_stopped_ = new UI::Checkbox(settings_box.get(), UI::PanelStyle::kWui, Vector2i::zero(),
-		                               _("Stopped"), _("Stop this building’s work after completion"));
+		cs_stopped_ = new UI::Checkbox(settings_box.get(), UI::PanelStyle::kWui, "setting_stop",
+		                               Vector2i::zero(), _("Stopped"),
+		                               _("Stop this building’s work after completion"));
 		cs_stopped_->clickedto.connect([this, ps](bool stop) {
 			if (stop != ps->stopped) {
 				if (game_ != nullptr) {
@@ -236,58 +242,17 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 		settings_box->add_space(6);
 		cs_stopped_->set_enabled(can_act);
 	} break;
-	case Widelands::MapObjectType::MILITARYSITE: {
-		upcast(Widelands::MilitarysiteSettings, ms, construction_site->get_settings());
-		cs_soldier_capacity_ = new ConstructionSoldierCapacityBox(
-		   settings_box.get(), ms->desired_capacity, 1, ms->max_capacity, can_act);
-		settings_box->add(cs_soldier_capacity_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
-		settings_box->add_space(8);
-		cs_soldier_capacity_->changed.connect([this]() {
-			if (game_ != nullptr) {
-				game_->send_player_change_soldier_capacity(
-				   *construction_site_.get(ibase()->egbase()), cs_soldier_capacity_->get_current());
-			} else {
-				NEVER_HERE();  // TODO(Nordfriese / Scenario Editor): implement
-			}
-		});
-
-		UI::Box& soldier_preference_box =
-		   *new UI::Box(settings_box.get(), UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal);
-		settings_box->add(&soldier_preference_box, UI::Box::Resizing::kAlign, UI::Align::kCenter);
-		Panel& soldier_preference_panel =
-		   *new Panel(&soldier_preference_box, UI::PanelStyle::kWui, 0, 0, 64, 32);
-		soldier_preference_box.add(&soldier_preference_panel);
-		cs_prefer_heroes_rookies_.reset(new UI::Radiogroup());
-		cs_prefer_heroes_rookies_->add_button(
-		   &soldier_preference_panel, UI::PanelStyle::kWui, Vector2i::zero(),
-		   g_image_cache->get("images/wui/buildings/prefer_heroes.png"), _("Prefer heroes"));
-		cs_prefer_heroes_rookies_->add_button(
-		   &soldier_preference_panel, UI::PanelStyle::kWui, Vector2i(32, 0),
-		   g_image_cache->get("images/wui/buildings/prefer_rookies.png"), _("Prefer rookies"));
-		cs_prefer_heroes_rookies_->set_state(ms->prefer_heroes ? 0 : 1, false);
-		if (can_act) {
-			cs_prefer_heroes_rookies_->changedto.connect([this](int32_t state) {
-				if (game_ != nullptr) {
-					game_->send_player_militarysite_set_soldier_preference(
-					   *construction_site_.get(ibase()->egbase()),
-					   state != 0 ? Widelands::SoldierPreference::kRookies :
-                               Widelands::SoldierPreference::kHeroes);
-				} else {
-					NEVER_HERE();  // TODO(Nordfriese / Scenario Editor): implement
-				}
-			});
-		}
-		settings_box->add_space(8);
-	} break;
 	case Widelands::MapObjectType::WAREHOUSE: {
 		upcast(Widelands::WarehouseSettings, ws, construction_site->get_settings());
 		auto add_tab = [this, construction_site, can_act](
 		                  Widelands::WareWorker ww, FakeWaresDisplay** display) {
-			UI::Box& mainbox = *new UI::Box(get_tabs(), UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical);
+			UI::Box& mainbox = *new UI::Box(get_tabs(), UI::PanelStyle::kWui,
+			                                "warehouse_settings_main_box", 0, 0, UI::Box::Vertical);
 			*display = new FakeWaresDisplay(&mainbox, can_act, *construction_site, ww);
 			mainbox.add(*display, UI::Box::Resizing::kFullSize);
 			UI::Box& buttonsbox =
-			   *new UI::Box(&mainbox, UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal);
+			   *new UI::Box(&mainbox, UI::PanelStyle::kWui, "warehouse_settings_buttons_box", 0, 0,
+			                UI::Box::Horizontal);
 			mainbox.add(&buttonsbox, UI::Box::Resizing::kAlign, UI::Align::kCenter);
 			mainbox.add_space(15);
 			UI::Button& sp_normal = *new UI::Button(
@@ -333,8 +298,8 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 		add_tab(Widelands::wwWORKER, &cs_warehouse_workers_);
 		if (construction_site->get_info().becomes->get_isport()) {
 			cs_launch_expedition_ = new UI::Checkbox(
-			   settings_box.get(), UI::PanelStyle::kWui, Vector2i::zero(), _("Start an expedition"),
-			   _("Start an expedition from this port after completion"));
+			   settings_box.get(), UI::PanelStyle::kWui, "launch_expedition", Vector2i::zero(),
+			   _("Start an expedition"), _("Start an expedition from this port after completion"));
 			cs_launch_expedition_->clickedto.connect([this, ws](bool launch) {
 				if (launch != ws->launch_expedition) {
 					if (game_ != nullptr) {
@@ -348,9 +313,78 @@ void ConstructionSiteWindow::build_settings_tab(Widelands::ConstructionSite* con
 			settings_box->add(cs_launch_expedition_, UI::Box::Resizing::kFullSize);
 			settings_box->add_space(6);
 			cs_launch_expedition_->set_enabled(can_act);
-		} else {
-			nothing_added = true;
 		}
+	}
+		if (construction_site->get_info().becomes->get_conquers() == 0) {
+			nothing_added = true;
+			break;
+		}
+		FALLS_THROUGH;
+	case Widelands::MapObjectType::MILITARYSITE: {
+		upcast(Widelands::MilitarysiteSettings, ms, construction_site->get_settings());
+		upcast(Widelands::WarehouseSettings, wh, construction_site->get_settings());
+		assert((ms != nullptr) ^ (wh != nullptr));
+		cs_soldier_capacity_ = new ConstructionSoldierCapacityBox(
+		   settings_box.get(), ms != nullptr ? ms->desired_capacity : wh->desired_capacity,
+		   ms != nullptr ? 1 : 0, ms != nullptr ? ms->max_capacity : wh->max_garrison, can_act);
+		settings_box->add(cs_soldier_capacity_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
+		settings_box->add_space(8);
+		cs_soldier_capacity_->changed.connect([this]() {
+			if (game_ != nullptr) {
+				game_->send_player_change_soldier_capacity(
+				   *construction_site_.get(ibase()->egbase()), cs_soldier_capacity_->get_current());
+			} else {
+				NEVER_HERE();  // TODO(Nordfriese / Scenario Editor): implement
+			}
+		});
+
+		UI::Box& soldier_preference_box =
+		   *new UI::Box(settings_box.get(), UI::PanelStyle::kWui, "soldier_preference_box", 0, 0,
+		                UI::Box::Horizontal);
+		settings_box->add(&soldier_preference_box, UI::Box::Resizing::kAlign, UI::Align::kCenter);
+		// TODO(Nordfriese): Use box layout
+		constexpr int kButtonSize = 32;
+		Panel& soldier_preference_panel =
+		   *new Panel(&soldier_preference_box, UI::PanelStyle::kWui, "soldier_preference_panel", 0, 0,
+		              kButtonSize * 3, kButtonSize);
+		soldier_preference_box.add(&soldier_preference_panel);
+		cs_prefer_heroes_rookies_.reset(new UI::Radiogroup());
+		// Make sure the creation order is consistent with enum SoldierPreference!
+		cs_prefer_heroes_rookies_->add_button(
+		   &soldier_preference_panel, UI::PanelStyle::kWui, "prefer_rookies",
+		   Vector2i(kButtonSize * 2, 0),
+		   g_image_cache->get("images/wui/buildings/prefer_rookies.png"), _("Prefer rookies"));
+		cs_prefer_heroes_rookies_->add_button(
+		   &soldier_preference_panel, UI::PanelStyle::kWui, "prefer_heroes",
+		   Vector2i(kButtonSize * 1, 0), g_image_cache->get("images/wui/buildings/prefer_heroes.png"),
+		   _("Prefer heroes"));
+		cs_prefer_heroes_rookies_->add_button(
+		   &soldier_preference_panel, UI::PanelStyle::kWui, "prefer_any",
+		   Vector2i(kButtonSize * 0, 0), g_image_cache->get("images/wui/buildings/prefer_any.png"),
+		   _("No preference"));
+		cs_prefer_heroes_rookies_->set_state(
+		   static_cast<uint8_t>(ms != nullptr ? ms->soldier_preference : wh->soldier_preference),
+		   false);
+		if (can_act) {
+			cs_prefer_heroes_rookies_->changedto.connect([this](int32_t state) {
+				if (game_ != nullptr) {
+					game_->send_player_set_soldier_preference(
+					   *construction_site_.get(ibase()->egbase()),
+					   static_cast<Widelands::SoldierPreference>(state));
+				} else {
+					if (upcast(Widelands::MilitarysiteSettings, ms_settings,
+					           construction_site_.get(ibase()->egbase())->get_settings())) {
+						ms_settings->soldier_preference =
+						   static_cast<Widelands::SoldierPreference>(state);
+					} else if (upcast(Widelands::WarehouseSettings, wh_settings,
+					                  construction_site_.get(ibase()->egbase())->get_settings())) {
+						wh_settings->soldier_preference =
+						   static_cast<Widelands::SoldierPreference>(state);
+					}
+				}
+			});
+		}
+		settings_box->add_space(8);
 	} break;
 	default:
 		NEVER_HERE();
@@ -413,17 +447,17 @@ void ConstructionSiteWindow::think() {
 	// InputQueueDisplay and FakeWaresDisplay update themselves – we need to refresh the other
 	// settings
 	if (upcast(Widelands::ProductionsiteSettings, ps, construction_site->get_settings())) {
-		assert(cs_stopped_);
+		assert(cs_stopped_ != nullptr);
 		cs_stopped_->set_state(ps->stopped);
 	}
 	if (upcast(Widelands::TrainingsiteSettings, ts, construction_site->get_settings())) {
-		assert(cs_soldier_capacity_);
+		assert(cs_soldier_capacity_ != nullptr);
 		cs_soldier_capacity_->refresh(ts->desired_capacity, ts->max_capacity, can_act);
 	} else if (upcast(Widelands::MilitarysiteSettings, ms, construction_site->get_settings())) {
-		assert(cs_soldier_capacity_);
-		assert(cs_prefer_heroes_rookies_);
+		assert(cs_soldier_capacity_ != nullptr);
+		assert(cs_prefer_heroes_rookies_ != nullptr);
 		cs_soldier_capacity_->refresh(ms->desired_capacity, ms->max_capacity, can_act);
-		cs_prefer_heroes_rookies_->set_state(ms->prefer_heroes ? 0 : 1, false);
+		cs_prefer_heroes_rookies_->set_state(static_cast<uint8_t>(ms->soldier_preference), false);
 	} else if (upcast(Widelands::WarehouseSettings, ws, construction_site->get_settings())) {
 		if (cs_launch_expedition_ != nullptr) {
 			cs_launch_expedition_->set_state(ws->launch_expedition);
@@ -433,12 +467,16 @@ void ConstructionSiteWindow::think() {
 			assert(!ws->launch_expedition);
 		}
 #endif
+		if (cs_soldier_capacity_ != nullptr) {
+			cs_soldier_capacity_->refresh(ws->desired_capacity, ws->max_garrison, can_act);
+			cs_prefer_heroes_rookies_->set_state(static_cast<uint8_t>(ws->soldier_preference), false);
+		}
 	}
 }
 
 ConstructionSoldierCapacityBox::ConstructionSoldierCapacityBox(
    Panel* parent, uint32_t current, uint32_t min, uint32_t max, bool enabled)
-   : Box(parent, UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal),
+   : Box(parent, UI::PanelStyle::kWui, "soldier_capacity_box", 0, 0, UI::Box::Horizontal),
      current_(current),
      min_(min),
      max_(max),
@@ -463,8 +501,12 @@ ConstructionSoldierCapacityBox::ConstructionSoldierCapacityBox(
         UI::ButtonStyle::kWuiMenu,
         g_image_cache->get(pic_increase_capacity),
         _("Increase capacity. Hold down Ctrl to set the capacity to the highest value")),
-     cs_soldier_capacity_display_(
-        this, UI::PanelStyle::kWui, UI::FontStyle::kWuiLabel, "", UI::Align::kCenter) {
+     cs_soldier_capacity_display_(this,
+                                  UI::PanelStyle::kWui,
+                                  "soldier_capacity",
+                                  UI::FontStyle::kWuiLabel,
+                                  "",
+                                  UI::Align::kCenter) {
 	cs_soldier_capacity_decrease_.set_repeating(true);
 	cs_soldier_capacity_increase_.set_repeating(true);
 	add(&cs_soldier_capacity_decrease_);
@@ -537,17 +579,21 @@ bool ConstructionSoldierCapacityBox::handle_key(bool down, SDL_Keysym code) {
 		case ChangeType::kMinus:
 			change_current(-1);
 			return true;
+		case ChangeType::kBigPlus:
+			change_current(ChangeBigStep::kSmallRange);
+			return true;
+		case ChangeType::kBigMinus:
+			change_current(-ChangeBigStep::kSmallRange);
+			return true;
 		case ChangeType::kSetMax:
 			set_current(max_);
 			return true;
 		case ChangeType::kSetMin:
 			set_current(min_);
 			return true;
-		default:
-			break;
 		}
 	}
-	return false;
+	return UI::Box::handle_key(down, code);
 }
 bool ConstructionSoldierCapacityBox::handle_mousewheel(int32_t x, int32_t y, uint16_t modstate) {
 	if (!enabled_) {
@@ -555,7 +601,12 @@ bool ConstructionSoldierCapacityBox::handle_mousewheel(int32_t x, int32_t y, uin
 	}
 	int32_t change = get_mousewheel_change(MousewheelHandlerConfigID::kChangeValue, x, y, modstate);
 	if (change == 0) {
-		return false;
+		// Try big step
+		change = get_mousewheel_change(MousewheelHandlerConfigID::kChangeValueBig, x, y, modstate);
+		if (change == 0) {
+			return false;
+		}
+		change *= ChangeBigStep::kSmallRange;
 	}
 	change_current(change);
 	return true;
