@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,10 +23,10 @@
 static const char pic_tab_wares[] = "images/wui/buildings/menu_tab_wares.png";
 
 DismantleSiteWindow::DismantleSiteWindow(InteractiveBase& parent,
-                                         UI::UniqueWindow::Registry& reg,
+                                         BuildingWindow::Registry& reg,
                                          Widelands::DismantleSite& ds,
                                          bool avoid_fastclick)
-   : BuildingWindow(parent, reg, ds, avoid_fastclick), dismantle_site_(&ds), progress_(nullptr) {
+   : BuildingWindow(parent, reg, ds, avoid_fastclick), dismantle_site_(&ds) {
 	init(avoid_fastclick, false);
 }
 
@@ -35,13 +35,15 @@ void DismantleSiteWindow::init(bool avoid_fastclick, bool workarea_preview_wante
 	assert(dismantle_site != nullptr);
 
 	BuildingWindow::init(avoid_fastclick, workarea_preview_wanted);
-	UI::Box& box = *new UI::Box(get_tabs(), UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical);
-	UI::Box& subbox = *new UI::Box(&box, UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical);
+	UI::Box& box =
+	   *new UI::Box(get_tabs(), UI::PanelStyle::kWui, "main_box", 0, 0, UI::Box::Vertical);
+	UI::Box& subbox = *new UI::Box(&box, UI::PanelStyle::kWui, "sub_box", 0, 0, UI::Box::Vertical);
 	ensure_box_can_hold_input_queues(subbox);
 
 	// Add the progress bar
-	progress_ = new UI::ProgressBar(&box, UI::PanelStyle::kWui, 0, 0, UI::ProgressBar::DefaultWidth,
-	                                UI::ProgressBar::DefaultHeight, UI::ProgressBar::Horizontal);
+	progress_ = new UI::ProgressBar(&box, UI::PanelStyle::kWui, "progress", 0, 0,
+	                                UI::ProgressBar::DefaultWidth, UI::ProgressBar::DefaultHeight,
+	                                UI::ProgressBar::Horizontal);
 	progress_->set_total(1 << 16);
 	box.add(progress_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
 
@@ -50,12 +52,14 @@ void DismantleSiteWindow::init(bool avoid_fastclick, bool workarea_preview_wante
 	// Add the wares queue
 	for (uint32_t i = 0; i < dismantle_site->nr_dropout_waresqueues(); ++i) {
 		subbox.add(new InputQueueDisplay(&subbox, *ibase(), *dismantle_site,
-		                                 *dismantle_site->get_dropout_waresqueue(i), true, false),
+		                                 *dismantle_site->get_dropout_waresqueue(i), true, false,
+		                                 priority_collapsed()),
 		           UI::Box::Resizing::kFullSize);
 	}
 	for (uint32_t i = 0; i < dismantle_site->nr_consume_waresqueues(); ++i) {
 		subbox.add(new InputQueueDisplay(&subbox, *ibase(), *dismantle_site,
-		                                 *dismantle_site->get_consume_waresqueue(i), true, false),
+		                                 *dismantle_site->get_consume_waresqueue(i), true, false,
+		                                 priority_collapsed()),
 		           UI::Box::Resizing::kFullSize);
 	}
 
