@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,6 @@
 #include "ui_basic/box.h"
 #include "ui_basic/listselect.h"
 #include "ui_basic/multilinetextarea.h"
-#include "ui_basic/table.h"
 #include "ui_basic/tabpanel.h"
 #include "ui_basic/unique_window.h"
 
@@ -35,7 +34,7 @@ class InteractiveBase;
 namespace UI {
 
 struct EncyclopediaWindow : public UI::UniqueWindow {
-	EncyclopediaWindow(InteractiveBase&, UI::UniqueWindow::Registry&, LuaInterface* const lua);
+	EncyclopediaWindow(InteractiveBase&, UI::UniqueWindow::Registry&, LuaInterface* lua);
 
 	UI::Panel::SaveType save_type() const override {
 		return UI::Panel::SaveType::kEncyclopedia;
@@ -44,16 +43,22 @@ struct EncyclopediaWindow : public UI::UniqueWindow {
 	static UI::Window& load(FileRead&, InteractiveBase&);
 
 protected:
-	void init(InteractiveBase& parent, std::unique_ptr<LuaTable> table);
+	void init(std::unique_ptr<LuaTable> table);
+	void handle_hyperlink(const std::string& action) override;
 
+	InteractiveBase& parent_;
 	LuaInterface* const lua_;
 
 private:
 	struct EncyclopediaEntry {
-		EncyclopediaEntry(const std::string& init_script_path,
+		EncyclopediaEntry(const std::string& init_name,
+		                  const std::string& init_script_path,
 		                  const std::vector<std::string>& init_script_parameters)
-		   : script_path(init_script_path), script_parameters(init_script_parameters) {
+		   : name(init_name),
+		     script_path(init_script_path),
+		     script_parameters(init_script_parameters) {
 		}
+		const std::string name;
 		const std::string script_path;
 		const std::vector<std::string> script_parameters;
 	};
