@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,9 @@
 #include "ui_basic/unique_window.h"
 
 namespace Widelands {
+struct Coords;
 class Player;
+struct Ship;
 }  // namespace Widelands
 
 class InteractiveBase;
@@ -32,4 +34,10 @@ void show_field_action(InteractiveBase* ibase,
                        Widelands::Player* player,
                        UI::UniqueWindow::Registry* registry);
 
+void show_ship_selection_window(InteractiveBase* ibase,
+                                UI::UniqueWindow::Registry* registry,
+                                const Widelands::Coords& node,
+                                const std::vector<Widelands::Ship*>& manageable,
+                                const std::vector<Widelands::Ship*>& attackable);
+
 #endif  // end of include guard: WL_WUI_FIELDACTION_H
