@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,20 +29,27 @@
 #include "ui_basic/mouse_constants.h"
 #include "wui/chat_msg_layout.h"
 
+UI::EditBoxHistory g_chat_sent_history(32);
+UI::EditBoxHistory g_script_console_history(64);
+
 /**
  * Create a game chat panel
  */
 GameChatPanel::GameChatPanel(UI::Panel* parent,
+                             ChatColorForPlayer fn,
                              int32_t const x,
                              int32_t const y,
                              uint32_t const w,
                              uint32_t const h,
                              ChatProvider& chat,
+                             UI::EditBoxHistory* history,
                              UI::PanelStyle style)
-   : UI::Panel(parent, style, x, y, w, h),
+   : UI::Panel(parent, style, "chat_panel", x, y, w, h),
+     color_functor_(fn),
      chat_(chat),
-     vbox_(this, style, 0, 0, UI::Box::Vertical),
+     vbox_(this, style, "vbox", 0, 0, UI::Box::Vertical),
      chatbox(&vbox_,
+             "chat",
              0,
              0,
              0,
@@ -51,7 +58,7 @@ GameChatPanel::GameChatPanel(UI::Panel* parent,
              "",
              UI::Align::kLeft,
              UI::MultilineTextarea::ScrollMode::kScrollLog),
-     hbox_(&vbox_, style, 0, 0, UI::Box::Horizontal),
+     hbox_(&vbox_, style, "hbox", 0, 0, UI::Box::Horizontal),
      recipient_dropdown_(&hbox_,
                          "chat_recipient_dropdown",
                          0,
@@ -63,10 +70,9 @@ GameChatPanel::GameChatPanel(UI::Panel* parent,
                          UI::DropdownType::kPictorial,
                          UI::PanelStyle::kFsMenu,
                          UI::ButtonStyle::kFsMenuSecondary),
-     editbox(&hbox_, 28, 0, w - 28, style),
-     chat_message_counter(0),
-     chat_sound(SoundHandler::register_fx(SoundType::kChat, "sound/lobby_chat")),
-     has_team_(false) {
+     editbox(&hbox_, "input", 28, 0, w - 28, style),
+
+     chat_sound(SoundHandler::register_fx(SoundType::kChat, "sound/lobby_chat")) {
 
 	vbox_.add(&chatbox, UI::Box::Resizing::kExpandBoth);
 	vbox_.add_space(4);
@@ -74,10 +80,11 @@ GameChatPanel::GameChatPanel(UI::Panel* parent,
 
 	editbox.ok.connect([this]() { key_enter(); });
 	editbox.cancel.connect([this]() { key_escape(); });
-	editbox.activate_history(true);
+	editbox.activate_history(history);
 
 	set_handle_mouse(true);
 	set_can_focus(true);
+	set_handle_textinput(true);
 
 	if (chat_.participants_ == nullptr) {
 		// No access to participant list. Hide the dropdown
@@ -133,13 +140,13 @@ bool GameChatPanel::handle_key(const bool down, const SDL_Keysym code) {
 		return false;
 	}
 
-	if (!down || code.sym != SDLK_SPACE || ((SDL_GetModState() & KMOD_CTRL) == 0)) {
+	if (!down || code.sym != SDLK_SPACE || ((code.mod & KMOD_CTRL) == 0)) {
 		return false;
 	}
 
 	// User is pressing Ctrl+Space, try autocomplete
 
-	if (editbox.text().empty()) {
+	if (editbox.get_text().empty()) {
 		return false;
 	}
 
@@ -147,6 +154,11 @@ bool GameChatPanel::handle_key(const bool down, const SDL_Keysym code) {
 	return try_autocomplete();
 }
 
+bool GameChatPanel::handle_textinput(const std::string& text) {
+	focus_edit();
+	return editbox.handle_textinput(text);
+}
+
 /**
  * If doubled space is entered pressed, try to autocomplete the player name.
  * Also keep dropdown selection in sync with entered "@name" text
@@ -157,14 +169,14 @@ void GameChatPanel::key_changed() {
 		return;
 	}
 	// Check if last entered two characters are space
-	std::string str = editbox.text();
-	const size_t cursor_pos = editbox.caret_pos();
+	std::string str = editbox.get_text();
+	const size_t cursor_pos = editbox.get_caret_pos();
 	if (cursor_pos < 2 || str[cursor_pos - 1] != ' ' || str[cursor_pos - 2] != ' ') {
 		// Update state of dropdown, we might have no valid recipient now
 		select_recipient();
 		return;
 	}
-	assert(!editbox.text().empty());
+	assert(!editbox.get_text().empty());
 	// Go back two chars since try_autocomplete() assumes that the cursor is in/at the name part
 	editbox.set_caret_pos(cursor_pos - 2);
 	if (!try_autocomplete()) {
@@ -173,8 +185,8 @@ void GameChatPanel::key_changed() {
 		select_recipient();
 	} else {
 		// It worked and we replaced something. Remove the two spaces
-		str = editbox.text();
-		const size_t end_of_replacement = editbox.caret_pos();
+		str = editbox.get_text();
+		const size_t end_of_replacement = editbox.get_caret_pos();
 		str.erase(end_of_replacement, 2);
 		editbox.set_text(str);
 	}
@@ -188,8 +200,9 @@ bool GameChatPanel::try_autocomplete() {
 
 	// Extract the name to complete
 	// rfind starts at the given pos and goes forward until it finds a space
-	std::string str = editbox.text();
-	size_t namepart_start = str.rfind(' ', (editbox.caret_pos() > 1 ? editbox.caret_pos() - 1 : 0));
+	std::string str = editbox.get_text();
+	size_t namepart_start =
+	   str.rfind(' ', (editbox.get_caret_pos() > 1 ? editbox.get_caret_pos() - 1 : 0));
 	if (namepart_start == std::string::npos) {
 		// Not found, meaning the input only contains the name
 		namepart_start = 0;
@@ -202,7 +215,7 @@ bool GameChatPanel::try_autocomplete() {
 		// assume it is the whisper-sign and ignore the @
 		++namepart_start;
 	}
-	size_t namepart_end = str.find(' ', editbox.caret_pos());
+	size_t namepart_end = str.find(' ', editbox.get_caret_pos());
 
 	if (namepart_end <= namepart_start || namepart_start == str.size()) {
 		// Nothing to complete
@@ -298,7 +311,7 @@ void GameChatPanel::recalculate(bool has_new_message) {
 	const size_t msgs_size = msgs.size();
 	std::string str = "<rt>";
 	for (uint32_t i = 0; i < msgs_size; ++i) {
-		str += format_as_richtext(msgs[i]);
+		str += format_as_richtext(msgs[i], color_functor_);
 	}
 	str += "</rt>";
 
@@ -334,7 +347,7 @@ void GameChatPanel::unfocus_edit() {
 
 void GameChatPanel::key_enter() {
 
-	const std::string& str = editbox.text();
+	const std::string& str = editbox.get_text();
 	if (!str.empty()) {
 		if (chat_.participants_ != nullptr) {
 			const size_t pos_first_space = str.find(' ');
@@ -371,7 +384,7 @@ void GameChatPanel::key_enter() {
 }
 
 void GameChatPanel::key_escape() {
-	if (editbox.text().empty()) {
+	if (editbox.get_text().empty()) {
 		unfocus_edit();
 	}
 	editbox.set_text("");
@@ -394,7 +407,7 @@ void GameChatPanel::set_recipient() {
 	// Replace the old recipient, if any
 
 	const std::string& recipient = recipient_dropdown_.get_selected();
-	std::string str = editbox.text();
+	std::string str = editbox.get_text();
 
 	// We have a recipient already
 	if (str[0] == '@') {
@@ -466,7 +479,7 @@ void GameChatPanel::prepare_recipients() {
 bool GameChatPanel::select_recipient() {
 	// Get the current recipient
 	std::string recipient;
-	const std::string& text = editbox.text();
+	const std::string& text = editbox.get_text();
 	if (!text.empty() && text[0] == '@') {
 		// Get the recipient string including the first space
 		// If there is no space, return the whole string
