@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2022 by the Widelands Development Team
+ * Copyright (C) 2008-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,8 +24,14 @@
 #include "chat/chat.h"
 #include "ui_basic/box.h"
 #include "ui_basic/dropdown.h"
-#include "ui_basic/editbox.h"
 #include "ui_basic/multilinetextarea.h"
+#include "ui_basic/textinput.h"
+
+// Global input histories
+extern UI::EditBoxHistory g_chat_sent_history;
+extern UI::EditBoxHistory g_script_console_history;
+const std::string kChatSentHistoryFile = "sent_messages_history";
+const std::string kScriptConsoleHistoryFile = "script_console_history";
 
 /**
  * Provides a panel that contains chat message scrollbar and a chat message
@@ -33,11 +39,13 @@
  */
 struct GameChatPanel : public UI::Panel {
 	GameChatPanel(UI::Panel*,
+	              ChatColorForPlayer fn,
 	              int32_t x,
 	              int32_t y,
 	              uint32_t w,
 	              uint32_t h,
 	              ChatProvider&,
+	              UI::EditBoxHistory*,
 	              UI::PanelStyle style);
 
 	// Signal is called when a message has been sent by the user.
@@ -47,13 +55,14 @@ struct GameChatPanel : public UI::Panel {
 	Notifications::Signal<> aborted;
 
 	const std::string& get_edit_text() const {
-		return editbox.text();
+		return editbox.get_text();
 	}
 	void set_edit_text(const std::string& text) {
 		editbox.set_text(text);
 	}
 
 	bool handle_key(bool down, SDL_Keysym code) override;
+	bool handle_textinput(const std::string& text) override;
 	bool handle_mousepress(uint8_t btn, int32_t x, int32_t y) override;
 	void focus_edit();
 	void unfocus_edit();
@@ -70,15 +79,16 @@ private:
 	void key_changed();
 	bool try_autocomplete();
 
+	ChatColorForPlayer color_functor_;
 	ChatProvider& chat_;
 	UI::Box vbox_;
 	UI::MultilineTextarea chatbox;
 	UI::Box hbox_;
 	UI::Dropdown<std::string> recipient_dropdown_;
 	UI::EditBox editbox;
-	size_t chat_message_counter;
+	size_t chat_message_counter{0U};
 	FxId chat_sound;
-	bool has_team_;
+	bool has_team_{false};
 	std::unique_ptr<Notifications::Subscriber<ChatMessage>> chat_message_subscriber_;
 	std::unique_ptr<Notifications::Signal<>::SignalSubscriber> update_signal_connection_;
 };
