@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,10 +39,11 @@
 MapObjectDebugPanel::MapObjectDebugPanel(UI::Panel& parent,
                                          const Widelands::EditorGameBase& egbase,
                                          Widelands::MapObject& obj)
-   : UI::Panel(&parent, UI::PanelStyle::kWui, 0, 0, 350, 200),
+   : UI::Panel(&parent, UI::PanelStyle::kWui, "map_object_debug_panel", 0, 0, 350, 200),
      egbase_(egbase),
      object_(&obj),
      log_(this,
+          "log",
           0,
           0,
           350,
@@ -80,9 +81,9 @@ MapObjectDebugWindow
 */
 MapObjectDebugWindow::MapObjectDebugWindow(InteractiveBase& parent, Widelands::MapObject& obj)
    : UI::Window(&parent, UI::WindowStyle::kWui, "map_object_debug", 0, 0, 100, 100, ""),
-     log_general_info_(true),
+
      object_(&obj),
-     tabs_(this, UI::TabPanelStyle::kWuiLight) {
+     tabs_(this, UI::TabPanelStyle::kWuiLight, "tabs") {
 	serial_ = obj.serial();
 	set_title(std::to_string(serial_));
 
@@ -137,11 +138,11 @@ FieldDebugWindow::FieldDebugWindow(InteractiveBase& parent, Widelands::Coords co
      coords_(map_.get_fcoords(coords)),
 
      //  setup child panels
-     ui_field_(this, 0, 0, 300, 280, UI::PanelStyle::kWui, ""),
+     ui_field_(this, "field", 0, 0, 300, 280, UI::PanelStyle::kWui, ""),
 
      ui_immovable_(this, "immovable", 0, 280, 300, 24, UI::ButtonStyle::kWuiMenu, ""),
 
-     ui_bobs_(this, 0, 304, 300, 96, UI::PanelStyle::kWui) {
+     ui_bobs_(this, "bobs", 0, 304, 300, 96, UI::PanelStyle::kWui) {
 	ui_immovable_.sigclicked.connect([this]() { open_immovable(); });
 
 	assert(0 <= coords_.x);
@@ -210,30 +211,6 @@ void FieldDebugWindow::think() {
 
 		Widelands::Vision const vision = player_field.vision;
 		str += format("  vision: %u\n", vision.value());
-		{
-			Time const time_last_surveyed =
-			   player_field.time_triangle_last_surveyed[static_cast<int>(Widelands::TriangleIndex::D)];
-
-			if (time_last_surveyed.is_valid()) {
-				str += format("  D triangle last surveyed at %u: amount %u\n", time_last_surveyed.get(),
-				              static_cast<unsigned int>(player_field.resource_amounts.d));
-
-			} else {
-				str += "  D triangle never surveyed\n";
-			}
-		}
-		{
-			Time const time_last_surveyed =
-			   player_field.time_triangle_last_surveyed[static_cast<int>(Widelands::TriangleIndex::R)];
-
-			if (time_last_surveyed.is_valid()) {
-				str += format("  R triangle last surveyed at %u: amount %u\n", time_last_surveyed.get(),
-				              static_cast<unsigned int>(player_field.resource_amounts.r));
-
-			} else {
-				str += "  R triangle never surveyed\n";
-			}
-		}
 
 		if (!vision.is_explored()) {
 			str += "  never seen\n";
