@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2022 by the Widelands Development Team
+ * Copyright (C) 2004-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -62,7 +62,7 @@ public:
 	void think() override;
 
 private:
-	bool log_general_info_;
+	bool log_general_info_{true};
 	Widelands::ObjectPointer object_;
 	uint32_t serial_;
 	UI::TabPanel tabs_;
