@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,6 +36,19 @@
 #include "wlapplication_options.h"
 #include "wui/interactive_gamebase.h"
 
+struct TypeInfo {
+	std::string window_name;
+	std::string window_title;
+	LoadOrSaveGame::FileType file_type;
+};
+static const std::map<GameMainMenuSaveGame::Type, TypeInfo> kTypes = {
+   {GameMainMenuSaveGame::Type::kLoadReplay,
+    {"load_replay", gettext_noop("Load Replay"), LoadOrSaveGame::FileType::kReplay}},
+   {GameMainMenuSaveGame::Type::kLoadSavegame,
+    {"load_game", gettext_noop("Load Game"), LoadOrSaveGame::FileType::kGameSinglePlayer}},
+   {GameMainMenuSaveGame::Type::kSave,
+    {"save_game", gettext_noop("Save Game"), LoadOrSaveGame::FileType::kShowAll}}};
+
 InteractiveGameBase& GameMainMenuSaveGame::igbase() {
 	return dynamic_cast<InteractiveGameBase&>(*get_parent());
 }
@@ -45,29 +58,29 @@ GameMainMenuSaveGame::GameMainMenuSaveGame(InteractiveGameBase& parent,
                                            const Type type)
    : UI::UniqueWindow(&parent,
                       UI::WindowStyle::kWui,
-                      type == Type::kSave ? "save_game" : "load_game",
+                      kTypes.at(type).window_name,
                       &registry,
                       parent.get_inner_w() - 40,
                       parent.get_inner_h() - 40,
-                      type == Type::kSave ? _("Save Game") : _("Load Game")),
-     // Values for alignment and size
-     padding_(4),
+                      _(kTypes.at(type).window_title)),
+
      type_(type),
 
-     main_box_(this, UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical),
-     info_box_(&main_box_, UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal),
+     main_box_(this, UI::PanelStyle::kWui, "main_box", 0, 0, UI::Box::Vertical),
+     info_box_(&main_box_, UI::PanelStyle::kWui, "info_box", 0, 0, UI::Box::Horizontal),
 
      load_or_save_(&info_box_,
                    igbase().game(),
-                   type == Type::kSave ? LoadOrSaveGame::FileType::kShowAll :
-                                         LoadOrSaveGame::FileType::kGameSinglePlayer,
+                   kTypes.at(type).file_type,
                    UI::PanelStyle::kWui,
                    UI::WindowStyle::kWui,
                    false),
 
-     filename_box_(load_or_save_.table_box(), UI::PanelStyle::kWui, 0, 0, UI::Box::Horizontal),
+     filename_box_(
+        load_or_save_.table_box(), UI::PanelStyle::kWui, "filename_box", 0, 0, UI::Box::Horizontal),
      filename_label_(&filename_box_,
                      UI::PanelStyle::kWui,
+                     "label_filename",
                      UI::FontStyle::kWuiLabel,
                      0,
                      0,
@@ -75,10 +88,11 @@ GameMainMenuSaveGame::GameMainMenuSaveGame(InteractiveGameBase& parent,
                      0,
                      _("Filename:"),
                      UI::Align::kLeft),
-     filename_editbox_(&filename_box_, 0, 0, 0, UI::PanelStyle::kWui),
+     filename_editbox_(&filename_box_, "filename", 0, 0, 0, UI::PanelStyle::kWui),
 
      buttons_box_(load_or_save_.game_details()->button_box(),
                   UI::PanelStyle::kWui,
+                  "buttons_box",
                   0,
                   0,
                   UI::Box::Horizontal),
@@ -131,7 +145,7 @@ GameMainMenuSaveGame::GameMainMenuSaveGame(InteractiveGameBase& parent,
 	load_or_save_.select_by_name(parent.game().save_handler().get_cur_filename());
 
 	center_to_parent();
-	move_to_top();
+	set_z(UI::Panel::ZOrder::kFullscreenWindow);
 
 	if (type_ == Type::kSave) {
 		filename_editbox_.focus();
@@ -139,7 +153,6 @@ GameMainMenuSaveGame::GameMainMenuSaveGame(InteractiveGameBase& parent,
 		load_or_save_.table().focus();
 	}
 	pause_game(true);
-	set_thinks(false);
 	layout();
 
 	initialization_complete();
@@ -169,7 +182,7 @@ void GameMainMenuSaveGame::entry_selected() {
 
 void GameMainMenuSaveGame::edit_box_changed() {
 	// Prevent the user from creating nonsense directory names, like e.g. ".." or "...".
-	const bool is_legal_filename = FileSystemHelper::is_legal_filename(filename_editbox_.text());
+	const bool is_legal_filename = FileSystemHelper::is_legal_filename(filename_editbox_.get_text());
 	ok_.set_enabled(is_legal_filename);
 	filename_editbox_.set_tooltip(is_legal_filename ? "" : illegal_filename_tooltip_);
 	load_or_save_.delete_button()->set_enabled(false);
@@ -177,7 +190,7 @@ void GameMainMenuSaveGame::edit_box_changed() {
 }
 
 void GameMainMenuSaveGame::reset_editbox_or_die(const std::string& current_filename) {
-	if (filename_editbox_.text() == current_filename) {
+	if (filename_editbox_.get_text() == current_filename) {
 		die();
 	} else {
 		filename_editbox_.set_text(current_filename);
@@ -189,28 +202,30 @@ void GameMainMenuSaveGame::ok() {
 	if (!ok_.enabled()) {
 		return;
 	}
-	if (load_or_save_.has_selection() && load_or_save_.entry_selected()->is_directory()) {
+
+	if (load_or_save_.has_selection()) {
 		std::unique_ptr<SavegameData> gamedata = load_or_save_.entry_selected();
-		load_or_save_.change_directory_to(gamedata->filename);
-		curdir_ = gamedata->filename;
-		filename_editbox_.focus();
-	} else {
-		switch (type_) {
-		case Type::kSave: {
-			std::string filename = filename_editbox_.text();
-			if (save_game(filename, !get_config_bool("nozip", false))) {
-				die();
-			} else {
-				load_or_save_.table().focus();
-			}
-		} break;
-		case Type::kLoad: {
-			if (load_or_save_.has_selection()) {
-				igbase().game().set_next_game_to_load(load_or_save_.entry_selected()->filename);
+		if (gamedata->is_directory()) {
+			load_or_save_.change_directory_to(gamedata->filename);
+			curdir_ = gamedata->filename;
+			filename_editbox_.focus();
+			return;
+		}
+		if (type_ == Type::kLoadSavegame || type_ == Type::kLoadReplay) {
+			if (load_or_save_.check_replay_compatibility(*gamedata)) {
+				igbase().game().set_next_game_to_load(gamedata->filename);
 				end_modal<UI::Panel::Returncodes>(UI::Panel::Returncodes::kBack);
 				igbase().end_modal<UI::Panel::Returncodes>(UI::Panel::Returncodes::kBack);
 			}
-		} break;
+			return;
+		}
+	}
+	if (type_ == Type::kSave) {
+		std::string filename = filename_editbox_.get_text();
+		if (save_game(filename, !get_config_bool("nozip", false))) {
+			die();
+		} else {
+			load_or_save_.table().focus();
 		}
 	}
 }
@@ -281,7 +296,7 @@ bool GameMainMenuSaveGame::save_game(std::string filename, bool binary) {
 	Widelands::Game& game = igbase().game();
 
 	game.create_loader_ui(
-	   {"general_game"}, true, game.map().get_background_theme(), game.map().get_background());
+	   {"general_game"}, true, game.map().get_background_theme(), game.map().get_background(), true);
 
 	GenericSaveHandler gsh(
 	   [&game](FileSystem& fs) {
@@ -291,7 +306,7 @@ bool GameMainMenuSaveGame::save_game(std::string filename, bool binary) {
 	   complete_filename, binary ? FileSystem::ZIP : FileSystem::DIR);
 	GenericSaveHandler::Error error;
 	{
-		MutexLock m(MutexLock::ID::kLogicFrame, [this]() { stay_responsive(); });
+		MutexLock m(MutexLock::ID::kLogicFrame);
 		error = gsh.save();
 	}
 
