@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,6 +52,7 @@ GameMessageMenu::GameMessageMenu(InteractivePlayer& plr, UI::UniqueWindow::Regis
                       kWindowHeight,
                       _("Messages: Inbox")),
      message_body(this,
+                  "body",
                   kPadding,
                   kMessageBodyY,
                   kWindowWidth - 2 * kPadding,
@@ -59,10 +60,9 @@ GameMessageMenu::GameMessageMenu(InteractivePlayer& plr, UI::UniqueWindow::Regis
                   UI::PanelStyle::kWui,
                   "",
                   UI::Align::kLeft,
-                  UI::MultilineTextarea::ScrollMode::kScrollNormalForced),
-     mode(Mode::kInbox) {
+                  UI::MultilineTextarea::ScrollMode::kScrollNormalForced) {
 
-	list = new UI::Table<uintptr_t>(this, kPadding, kButtonSize + 2 * kPadding,
+	list = new UI::Table<uintptr_t>(this, "list", kPadding, kButtonSize + 2 * kPadding,
 	                                kWindowWidth - 2 * kPadding, kTableHeight, UI::PanelStyle::kWui,
 	                                UI::TableRows::kMulti);
 	list->add_column(kWindowWidth - 2 * kPadding - 60 - 60 - 75, _("Title"));
