@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,9 +29,10 @@ GameObjectivesMenu::GameObjectivesMenu(InteractivePlayer& parent,
    : UI::UniqueWindow(
         &parent, UI::WindowStyle::kWui, "objectives", &registry, 300, 200, _("Objectives")),
      iplayer_(parent),
-     objective_box_(this, UI::PanelStyle::kWui, 0, 0, UI::Box::Vertical),
-     objective_list_(&objective_box_, 0, 0, 550, 180, UI::PanelStyle::kWui),
+     objective_box_(this, UI::PanelStyle::kWui, "main_box", 0, 0, UI::Box::Vertical),
+     objective_list_(&objective_box_, "list", 0, 0, 550, 180, UI::PanelStyle::kWui),
      objective_text_(&objective_box_,
+                     "text",
                      0,
                      0,
                      100,
