@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@
 
 namespace Widelands {
 class Objective;
-}
+}  // namespace Widelands
 class InteractiveBase;
 
 ///  Shows the not already fulfilled objectives.
