@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,7 +30,8 @@
 class InteractiveGameBase;
 namespace Widelands {
 class Game;
-}
+struct PlayerEndStatus;
+}  // namespace Widelands
 
 /// Shows an ingame summary window on game end
 class GameSummaryScreen : public UI::UniqueWindow {
@@ -43,7 +44,7 @@ private:
 	void fill_data();
 	void stop_clicked();
 	void continue_clicked();
-	void player_selected(uint32_t entry_index);
+	void update_selection();
 	std::string parse_player_info(const std::string& info);
 	bool compare_status(uint32_t, uint32_t) const;
 
@@ -58,7 +59,7 @@ private:
 	UI::Icon* widelands_icon_;
 	UI::Button* continue_button_;
 	UI::Button* stop_button_;
-	UI::Table<uintptr_t const>* players_table_;
+	UI::Table<const Widelands::PlayerEndStatus&>* players_table_;
 };
 
 #endif  // end of include guard: WL_WUI_GAME_SUMMARY_H
