@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,15 +36,14 @@ struct GeneralStatisticsMenu : public UI::UniqueWindow {
 	// Custom registry, to store the selected_information as well.
 	struct Registry : public UI::UniqueWindow::Registry {
 		Registry()
-		   : UI::UniqueWindow::Registry(),
-		     selected_information(0),
-		     selected_players(kMaxPlayers, true),
-		     time(WuiPlotArea::TIME_GAME) {
+		   :
+
+		     selected_players(kMaxPlayers, true) {
 		}
 
-		int32_t selected_information;
+		int32_t selected_information{0};
 		std::vector<bool> selected_players;
-		WuiPlotArea::TIME time;
+		WuiPlotArea::TIME time{WuiPlotArea::TIME_GAME};
 	};
 
 	GeneralStatisticsMenu(InteractiveGameBase&, Registry&);
@@ -61,7 +60,7 @@ private:
 	UI::Box box_, player_buttons_box_;
 	WuiPlotArea plot_;
 	UI::Radiogroup radiogroup_;
-	int32_t selected_information_;
+	int32_t selected_information_{0};
 	UI::Button* cbs_[kMaxPlayers];
 	WuiPlotAreaSlider* slider_;
 	uint32_t ndatasets_;
