@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +23,9 @@
 
 #include "logic/map_objects/tribes/tribe_descr.h"
 #include "ui_basic/multilinetextarea.h"
+#include "ui_basic/textarea.h"
 #include "ui_basic/unique_window.h"
+#include "wui/interactive_base.h"
 
 class LuaInterface;
 
@@ -35,16 +37,31 @@ namespace UI {
  */
 class BuildingHelpWindow : public UI::UniqueWindow {
 public:
-	BuildingHelpWindow(Panel* parent,
+	BuildingHelpWindow(InteractiveBase* parent,
 	                   UI::UniqueWindow::Registry& reg,
 	                   const Widelands::BuildingDescr& building_description,
 	                   const Widelands::TribeDescr& tribe,
-	                   LuaInterface* const lua,
+	                   LuaInterface* lua,
 	                   uint32_t width = 300,
 	                   uint32_t height = 400);
 
+protected:
+	void handle_hyperlink(const std::string& action) override;
+
+	InteractiveBase* const parent_;
+
 private:
-	std::unique_ptr<MultilineTextarea> textarea_;
+	bool load_help(const std::string& type, const std::string& item, bool forward = true);
+	void clicked_back();
+
+	uint32_t height_;
+	Box vbox_, hbox_;
+	Textarea* titlearea_;
+	Button* b_back_;
+	MultilineTextarea* textarea_;
+	LuaInterface* const lua_;
+	const Widelands::TribeDescr& tribe_;
+	std::vector<std::pair<std::string, std::string>> history_;
 };
 
 }  // namespace UI
