@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,9 @@
 #ifndef WL_WUI_INTERACTIVE_BASE_H
 #define WL_WUI_INTERACTIVE_BASE_H
 
+#include <map>
 #include <memory>
+#include <optional>
 
 #include "io/profile.h"
 #include "logic/editor_game_base.h"
@@ -40,12 +42,22 @@ class MainToolbar;
 class UniqueWindowHandler;
 namespace Widelands {
 class MapObjectLoader;
-}
+}  // namespace Widelands
 
 struct WorkareaPreview {
+	using ExtraDataMap = std::map<Widelands::TCoords<>, uint32_t>;
+
+	WorkareaPreview(const Widelands::Coords& c,
+	                const WorkareaInfo* wi,
+	                const ExtraDataMap& d,
+	                const std::set<Widelands::Coords>& sc)
+	   : coords(c), info(wi), data(d), special_coords(sc) {
+	}
+
 	Widelands::Coords coords;
 	const WorkareaInfo* info;
-	std::map<Widelands::TCoords<>, uint32_t> data;
+	ExtraDataMap data;
+	std::set<Widelands::Coords> special_coords;
 };
 
 enum class RoadBuildingType { kRoad, kWaterway };
@@ -80,6 +92,7 @@ public:
 	struct BuildhelpOverlay {
 		const Image* pic = nullptr;
 		Vector2i hotspot = Vector2i::zero();
+		float scale = 0.f;
 	};
 
 	// Manages all UniqueWindows.
@@ -92,10 +105,13 @@ public:
 		return egbase_;
 	}
 
-	void show_workarea(const WorkareaInfo& workarea_info, Widelands::Coords coords);
 	void show_workarea(const WorkareaInfo& workarea_info,
 	                   Widelands::Coords coords,
-	                   std::map<Widelands::TCoords<>, uint32_t>& extra_data);
+	                   const std::set<Widelands::Coords>& special_coords);
+	void show_workarea(const WorkareaInfo& workarea_info,
+	                   Widelands::Coords coords,
+	                   const WorkareaPreview::ExtraDataMap& extra_data,
+	                   const std::set<Widelands::Coords>& special_coords);
 	void hide_workarea(const Widelands::Coords& coords, bool is_additional);
 
 	//  point of view for drawing
@@ -104,6 +120,7 @@ public:
 	void game_logic_think() override;
 	void think() override;
 	double average_fps() const;
+	uint64_t average_real_gamespeed() const;
 	bool handle_key(bool down, SDL_Keysym code) override;
 	virtual void postload();
 
@@ -134,11 +151,17 @@ public:
 	uint32_t get_sel_radius() const {
 		return sel_.radius;
 	}
+	uint16_t get_sel_gap_percent() const {
+		return sel_.gap_percent;
+	}
 	virtual void set_sel_pos(Widelands::NodeAndTriangle<>);
 	void set_sel_freeze(const bool yes) {
 		sel_.freeze = yes;
 	}
-	virtual void set_sel_radius(uint32_t);
+	void set_sel_radius(uint32_t);
+	void set_sel_gap_percent(uint16_t gap) {
+		sel_.gap_percent = gap;
+	}
 
 	//  display flags
 	uint32_t get_display_flags() const;
@@ -156,7 +179,9 @@ public:
 	void start_build_road(Widelands::Coords start, Widelands::PlayerNumber player, RoadBuildingType);
 	void abort_build_road();
 	void finish_build_road();
-	bool append_build_road(Widelands::Coords field);
+	bool append_build_road(Widelands::Coords field, bool is_preview);
+	[[nodiscard]] std::optional<Widelands::CoordPath>
+	try_append_build_road(Widelands::Coords field) const;
 	Widelands::Coords get_build_road_start() const;
 	Widelands::Coords get_build_road_end() const;
 	Widelands::CoordPath get_build_road_path() const;
@@ -166,29 +191,33 @@ public:
 	/**
 	 * Log a message to be displayed on screen
 	 */
-	void log_message(const std::string& message) const;
-	void log_message(const char* message) const {
-		log_message(std::string(message));
+	void log_message(const std::string& message, const std::string& tooltip = std::string()) const;
+	void log_message(const char* message, const char* tt = nullptr) const {
+		log_message(std::string(message), tt == nullptr ? std::string() : std::string(tt));
 	}
 
 	void toggle_minimap();
+	void toggle_quicknav();
 	// Toggles the buildhelp and calls rebuild_showhide_menu
 	void toggle_buildhelp();
 
-	// Returns the list of landmarks that have been mapped to the keys 0-9
-	const QuickNavigation::Landmark* landmarks();
-
-	// Sets the landmark for the keyboard 'key' to 'point'
-	void set_landmark(size_t key, const MapView::View& view);
+	QuickNavigation& quick_navigation() {
+		return quick_navigation_;
+	}
 
 	void add_wanted_building_window(const Widelands::Coords& coords,
-	                                const Vector2i point,
+	                                Vector2i point,
 	                                bool was_minimal,
 	                                bool was_pinned);
 	UI::UniqueWindow* show_building_window(const Widelands::Coords& coords,
 	                                       bool avoid_fastclick,
 	                                       bool workarea_preview_wanted);
 	UI::UniqueWindow& show_ship_window(Widelands::Ship* ship);
+	virtual UI::Window* show_attack_window(const Widelands::Coords& /* coords */,
+	                                       Widelands::MapObject* /* object */,
+	                                       bool /* fastclick */) {
+		NEVER_HERE();  // Overridden in InteractivePlayer
+	}
 
 	MapView* map_view() {
 		return &map_view_;
@@ -222,9 +251,23 @@ public:
 		return true;
 	}
 
+	void add_toolbar_plugin(const std::string& action,
+	                        const std::string& icon,
+	                        const std::string& label,
+	                        const std::string& tt);
+	void add_plugin_timer(const std::string& action, uint32_t interval, bool failsafe);
+
+	UI::Box* toolbar();
+	// Sets the toolbar's position to the bottom middle and configures its background images
+	void finalize_toolbar();
+
+	// arg1 is always the real user's name
+	void broadcast_cheating_message(const std::string& code = "CHEAT",
+	                                const std::string& arg2 = "") const;
+
 protected:
 	// For referencing the items in mapviewmenu_
-	enum class MapviewMenuEntry { kMinimap, kIncreaseZoom, kDecreaseZoom, kResetZoom };
+	enum class MapviewMenuEntry { kMinimap, kIncreaseZoom, kDecreaseZoom, kResetZoom, kQuicknav };
 
 	// Adds the mapviewmenu_ to the toolbar
 	void add_mapview_menu(MiniMapType minimap_type);
@@ -233,6 +276,9 @@ protected:
 	// Takes the appropriate action when an item in the mapviewmenu_ is selected
 	void mapview_menu_selected(MapviewMenuEntry entry);
 
+	void add_plugin_menu();
+	bool plugin_action(const std::string& action, bool failsafe);
+
 	/// Adds a toolbar button to the toolbar
 	/// \param image_basename:      File path for button image starting from 'images' and without
 	///                             file extension
@@ -277,22 +323,22 @@ protected:
 	                  const FieldsToDraw::Field* f,
 	                  const Time& gametime,
 	                  float scale) const;
-	void draw_road_building(FieldsToDraw::Field&);
+	void draw_road_building(RenderTarget* dst,
+	                        FieldsToDraw::Field& field,
+	                        const Time& gametime,
+	                        float scale) const;
 
 	void unset_sel_picture();
 	void set_sel_picture(const Image* image);
-	const Image* get_sel_picture() {
+	const Image* get_sel_picture() const {
 		return sel_.pic;
 	}
 
-	// Sets the toolbar's position to the bottom middle and configures its background images
-	void finalize_toolbar();
-
 	ChatOverlay* chat_overlay() {
 		return chat_overlay_;
 	}
 
-	UI::Box* toolbar();
+	ChatColorForPlayer color_functor() const;
 
 	// Returns the information which overlay text should currently be drawn.
 	// Returns InfoToDraw::kNone if not 'show'
@@ -304,7 +350,7 @@ protected:
 
 	// Returns the 'BuildhelpOverlay' for 'caps' or nullptr if there is no help
 	// to be displayed on this field.
-	const BuildhelpOverlay* get_buildhelp_overlay(Widelands::NodeCaps caps) const;
+	const BuildhelpOverlay* get_buildhelp_overlay(Widelands::NodeCaps caps, float scale) const;
 
 	// Overlays displayed while a road or waterway is under construction.
 	struct RoadBuildingMode {
@@ -313,12 +359,16 @@ protected:
 		}
 		const Widelands::PlayerNumber player;
 		Widelands::CoordPath path;
+		std::optional<Widelands::CoordPath> preview_path;
 		const RoadBuildingType type;
 		std::unique_ptr<WorkareaInfo> work_area;
-		std::map<Widelands::Coords, std::vector<uint8_t>> overlay_road_previews;
+		using PreviewPathMap = std::map<Widelands::Coords, std::vector<uint8_t>>;
+		PreviewPathMap overlay_road_previews;
+		PreviewPathMap overlay_roadpreview_previews;
 		std::map<Widelands::Coords, const Image*> overlay_steepness_indicators;
 	};
-	std::map<Widelands::Coords, std::vector<uint8_t>> road_building_preview_overlays() const;
+	RoadBuildingMode::PreviewPathMap road_building_preview_overlays() const;
+	RoadBuildingMode::PreviewPathMap road_building_preview_preview_overlays() const;
 	std::map<Widelands::Coords, const Image*> road_building_steepness_overlays() const;
 
 	/// Returns true if there is a workarea preview being shown at the given coordinates.
@@ -326,6 +376,7 @@ protected:
 	/// otherwise checks if the coords are within any workarea.
 	bool has_workarea_preview(const Widelands::Coords& coords,
 	                          const Widelands::Map* map = nullptr) const;
+	bool has_workarea_special_coords(const Widelands::Coords& coords) const;
 
 	/// Returns true if the current player is allowed to hear sounds from map objects on this field
 	virtual bool player_hears_field(const Widelands::Coords& coords) const = 0;
@@ -334,11 +385,7 @@ protected:
 
 	ChatProvider* chat_provider_;
 
-	void broadcast_cheating_message() const;
-
-#ifndef NDEBUG  //  only in debug builds
 	UI::UniqueWindow::Registry debugconsole_;
-#endif
 
 	InfoPanel& info_panel_;
 
@@ -346,28 +393,39 @@ private:
 	void play_sound_effect(const NoteSound& note) const;
 	void resize_chat_overlay();
 	void road_building_add_overlay();
+	void road_building_add_overlay(const Widelands::CoordPath& path,
+	                               RoadBuildingMode::PreviewPathMap& target,
+	                               bool steepness);
 	void road_building_remove_overlay();
 	void cmd_map_object(const std::vector<std::string>& args);
-	void cmd_lua(const std::vector<std::string>& args);
+	void cmd_lua(const std::vector<std::string>& args) const;
 
 	// Rebuilds the subclass' showhidemenu_ according to current map settings
 	virtual void rebuild_showhide_menu() = 0;
 
 	struct SelData {
-		SelData(const bool Freeze = false,
-		        const bool Triangles = false,
-		        const Widelands::NodeAndTriangle<>& Pos =
-		           Widelands::NodeAndTriangle<>{
-		              Widelands::Coords(0, 0),
-		              Widelands::TCoords<>(Widelands::Coords(0, 0), Widelands::TriangleIndex::D)},
-		        const uint32_t Radius = 0,
-		        const Image* Pic = nullptr)
-		   : freeze(Freeze), triangles(Triangles), pos(Pos), radius(Radius), pic(Pic) {
+		explicit SelData(const bool Freeze = false,
+		                 const bool Triangles = false,
+		                 const Widelands::NodeAndTriangle<>& Pos =
+		                    Widelands::NodeAndTriangle<>{
+		                       Widelands::Coords(0, 0),
+		                       Widelands::TCoords<>(Widelands::Coords(0, 0),
+		                                            Widelands::TriangleIndex::D)},
+		                 const uint32_t Radius = 0,
+		                 const uint16_t Gap = 0,
+		                 const Image* Pic = nullptr)
+		   : freeze(Freeze),
+		     triangles(Triangles),
+		     pos(Pos),
+		     radius(Radius),
+		     gap_percent(Gap),
+		     pic(Pic) {
 		}
 		bool freeze;     // don't change sel, even if mouse moves
 		bool triangles;  //  otherwise nodes
 		Widelands::NodeAndTriangle<> pos;
 		uint32_t radius;
+		uint16_t gap_percent;
 		const Image* pic;
 	} sel_;
 
@@ -388,20 +446,37 @@ private:
 		const bool minimize;
 		const bool pin;
 		const bool show_workarea;
+
+		bool warp_done{false};
 	};
 
 	// Building coordinates, window position, whether the window was minimized
-	std::map<uint32_t, std::unique_ptr<const WantedBuildingWindow>> wanted_building_windows_;
+	std::map<uint32_t, std::unique_ptr<WantedBuildingWindow>> wanted_building_windows_;
 	std::unique_ptr<Notifications::Subscriber<Widelands::NoteBuilding>> buildingnotes_subscriber_;
 
 	MainToolbar& toolbar_;
 
 	// Map View menu on the toolbar
 	UI::Dropdown<MapviewMenuEntry> mapviewmenu_;
+	UI::Dropdown<std::string> plugins_dropdown_;
 	QuickNavigation quick_navigation_;
 
+	struct PluginTimer {
+		PluginTimer() = default;
+		explicit PluginTimer(const std::string& a, uint32_t i, bool f)
+		   : action(a), interval(i), failsafe(f) {
+		}
+
+		std::string action;
+		uint32_t interval{0U};
+		uint32_t next_run{0U};
+		bool failsafe{false};
+	};
+	std::vector<PluginTimer> plugin_timers_;
+
 public:
 	MiniMap::Registry minimap_registry_;
+	UI::UniqueWindow::Registry quicknav_registry_;
 
 private:
 	// The currently enabled work area previews
@@ -413,21 +488,27 @@ private:
 	std::unique_ptr<Notifications::Subscriber<NoteSound>> sound_subscriber_;
 	Widelands::EditorGameBase& egbase_;
 	uint32_t display_flags_;
-	uint32_t lastframe_;        //  system time (milliseconds)
-	uint32_t frametime_;        //  in millseconds
-	uint32_t avg_usframetime_;  //  in microseconds!
+	uint64_t lastframe_;            //  system time (milliseconds)
+	uint64_t frametime_{0U};        //  in millseconds
+	uint64_t avg_usframetime_{0U};  //  in microseconds!
 
 	// For measuring actual game speed and how smoothly the game logic runs
-	uint32_t last_frame_realtime_, previous_frame_realtime_;
-	Time last_frame_gametime_, previous_frame_gametime_;
+	uint64_t last_frame_realtime_{0U};
+	uint64_t previous_frame_realtime_{0U};
+	Time last_frame_gametime_{0U};
+	Time previous_frame_gametime_{0U};
+	uint64_t avg_actual_gamespeed_{0U};  // in microseconds gametime per second realtime
+	uint64_t last_target_gamespeed_{0U};
+	uint64_t gamespeed_last_change_time_{0U};
 
 	std::unique_ptr<RoadBuildingMode> road_building_mode_;
 
 	std::unique_ptr<UniqueWindowHandler> unique_window_handler_;
-	BuildhelpOverlay buildhelp_overlays_[Widelands::Field::Buildhelp_None];
+	BuildhelpOverlay
+	   buildhelp_overlays_[Widelands::Field::Buildhelp_None * ImageCache::kScalesCount];
 
-	bool cheat_mode_enabled_;
-	bool screenshot_failed_;
+	bool cheat_mode_enabled_{false};
+	bool screenshot_failed_{false};
 };
 
 #endif  // end of include guard: WL_WUI_INTERACTIVE_BASE_H
