@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2022 by the Widelands Development Team
+ * Copyright (C) 2007-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
 #include "chat/chat.h"
 #include "graphic/game_renderer.h"
 #include "graphic/mouse_cursor.h"
+#include "graphic/text_layout.h"
 #include "logic/game_controller.h"
 #include "logic/player.h"
 #include "ui_basic/textarea.h"
@@ -39,26 +40,36 @@ InteractiveSpectator::InteractiveSpectator(Widelands::Game& g,
                                            bool const multiplayer,
                                            ChatProvider* chat_provider)
    : InteractiveGameBase(g, global_s, multiplayer, chat_provider) {
+	constexpr int kSpacing = 15;
 	add_main_menu();
 
-	add_toolbar_button("wui/menus/statistics_general", "general_stats", _("Statistics"),
-	                   &menu_windows_.stats_general, true);
+	add_toolbar_button(
+	   "wui/menus/statistics_general", "general_stats",
+	   as_tooltip_text_with_hotkey(_("Statistics"),
+	                               shortcut_string_for(KeyboardShortcut::kInGameStatsGeneral, false),
+	                               UI::PanelStyle::kWui),
+	   &menu_windows_.stats_general, true);
 	menu_windows_.stats_general.open_window = [this] {
 		new GeneralStatisticsMenu(*this, menu_windows_.stats_general);
 	};
 
-	toolbar()->add_space(15);
+	toolbar()->add_space(kSpacing);
 
 	add_mapview_menu(MiniMapType::kStaticViewWindow);
 	add_showhide_menu();
 	add_gamespeed_menu();
 
-	toolbar()->add_space(15);
+	toolbar()->add_space(kSpacing);
 
 	if (is_multiplayer()) {
 		add_chat_ui();
+		toolbar()->add_space(kSpacing);
 	}
 
+	add_diplomacy_menu();
+
+	add_plugin_menu();
+
 	finalize_toolbar();
 
 	// Setup all screen elements
@@ -93,6 +104,9 @@ void InteractiveSpectator::draw_map_view(MapView* given_map_view, RenderTarget*
 	const auto info_to_draw = get_info_to_draw(!given_map_view->is_animating());
 	for (size_t idx = 0; idx < fields_to_draw->size(); ++idx) {
 		const FieldsToDraw::Field& field = fields_to_draw->at(idx);
+		if (field.obscured_by_slope) {
+			continue;
+		}
 
 		draw_bridges(dst, &field, gametime, scale);
 		draw_border_markers(field, scale, *fields_to_draw, dst);
@@ -117,6 +131,13 @@ void InteractiveSpectator::draw_map_view(MapView* given_map_view, RenderTarget*
 			}
 		}
 
+		if (has_workarea_special_coords(field.fcoords)) {
+			blit_field_overlay(dst, field, special_coords_marker_pic_,
+			                   Vector2i(special_coords_marker_pic_->width() / 2,
+			                            special_coords_marker_pic_->height() / 2),
+			                   scale);
+		}
+
 		// Draw build help.
 		if (buildhelp()) {
 			auto caps = Widelands::NodeCaps::CAPS_NONE;
@@ -128,9 +149,9 @@ void InteractiveSpectator::draw_map_view(MapView* given_map_view, RenderTarget*
 					break;
 				}
 			}
-			const auto* overlay = get_buildhelp_overlay(caps);
+			const auto* overlay = get_buildhelp_overlay(caps, scale);
 			if (overlay != nullptr) {
-				blit_field_overlay(dst, field, overlay->pic, overlay->hotspot, scale);
+				blit_field_overlay(dst, field, overlay->pic, overlay->hotspot, scale / overlay->scale);
 			}
 		}
 
@@ -185,7 +206,7 @@ void InteractiveSpectator::node_action(const Widelands::NodeAndTriangle<>& node_
 		return;
 	}
 
-	if (try_show_ship_window()) {
+	if (try_show_ship_windows()) {
 		return;
 	}
 
