@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,10 +27,10 @@
  * Author data for a map or scenario.
  */
 struct MapAuthorData {
-	const std::string& get_names() const {
+	[[nodiscard]] const std::string& get_names() const {
 		return names_;
 	}
-	size_t get_number() const {
+	[[nodiscard]] size_t get_number() const {
 		return number_;
 	}
 
