@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,7 +48,10 @@ public:
 	        const MapData::DisplayType& init_displaytype);
 
 	/// For directories
-	MapData(const std::string& init_filename, const std::string& init_localized_name);
+	MapData(const std::string& init_filenames, const std::string& init_localized_name);
+
+	/// Add a second directory path to this directory entry.
+	void add(const MapData& md);
 
 	/// The localized name of the parent directory
 	static std::string parent_name();
@@ -63,11 +66,11 @@ public:
 	static MapData create_directory(const std::string& directory);
 
 	// Sorting functions to order by different categories.
-	bool compare_names(const MapData& other) const;
-	bool compare_players(const MapData& other) const;
-	bool compare_size(const MapData& other) const;
+	[[nodiscard]] bool compare_names(const MapData& other) const;
+	[[nodiscard]] bool compare_players(const MapData& other) const;
+	[[nodiscard]] bool compare_size(const MapData& other) const;
 
-	std::string filename;
+	std::vector<std::string> filenames;
 	std::string name;
 	std::string localized_name;
 	MapAuthorData authors;
@@ -83,6 +86,7 @@ public:
 	MapData::MapType maptype;
 	MapData::DisplayType displaytype;
 	AddOns::AddOnRequirements required_addons;
+	std::string minimum_required_widelands_version;
 };
 
 #endif  // end of include guard: WL_WUI_MAPDATA_H
