@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,6 +51,7 @@ struct WuiPlotArea : public UI::Panel {
 
 	// sample_rate is in in milliseconds
 	WuiPlotArea(UI::Panel* parent,
+	            const std::string& name,
 	            int32_t x,
 	            int32_t y,
 	            int32_t w,
@@ -69,20 +70,21 @@ struct WuiPlotArea : public UI::Panel {
 	}
 
 	void set_time_id(uint32_t time) {
-		if (time == game_time_id_)
+		if (time == game_time_id_) {
 			set_time(TIME_GAME);
-		else
+		} else {
 			set_time(static_cast<TIME>(time));
+		}
 		needs_update_ = true;
 	}
 	TIME get_time() const {
 		return static_cast<TIME>(time_);
 	}
 	int32_t get_time_id() const {
-		if (time_ == TIME_GAME)
+		if (time_ == TIME_GAME) {
 			return game_time_id_;
-		else
-			return time_;
+		}
+		return time_;
 	}
 
 	uint32_t get_game_time_id();
@@ -101,8 +103,8 @@ protected:
 	               uint32_t highest_scale);
 	void draw_plot_line(RenderTarget& dst,
 	                    std::vector<uint32_t> const* dataset,
-	                    uint32_t const highest_scale,
-	                    float const sub,
+	                    uint32_t highest_scale,
+	                    float sub,
 	                    const RGBColor& color,
 	                    int32_t yoffset);
 	uint32_t get_plot_time() const;
@@ -124,22 +126,22 @@ protected:
 	uint32_t sample_rate_;
 
 	/// Whether there has ben a data update since the last time that think() was executed
-	bool needs_update_;
+	bool needs_update_{true};
 	/// The last time the information in this Panel got updated
-	uint32_t lastupdate_;
+	uint32_t lastupdate_{0U};
 
 	/// For first updating and then plotting the data
 	float const xline_length_;
 	float const yline_length_;
-	uint32_t time_ms_;
-	uint32_t highest_scale_;
-	float sub_;
+	uint32_t time_ms_{0U};
+	uint32_t highest_scale_{0U};
+	float sub_{0.f};
 
 private:
 	uint32_t get_game_time() const;
 
-	TIME time_;              // How much do you want to list
-	uint32_t game_time_id_;  // what label is used for TIME_GAME
+	TIME time_{TIME_GAME};       // How much do you want to list
+	uint32_t game_time_id_{0U};  // what label is used for TIME_GAME
 };
 
 /**
@@ -148,6 +150,7 @@ private:
  */
 struct WuiPlotAreaSlider : public UI::DiscreteSlider {
 	WuiPlotAreaSlider(Panel* const parent,
+	                  const std::string& name,
 	                  WuiPlotArea& plot_area,
 	                  const int32_t x,
 	                  const int32_t y,
@@ -157,6 +160,7 @@ struct WuiPlotAreaSlider : public UI::DiscreteSlider {
 	                  const uint32_t cursor_size = 20,
 	                  const bool enabled = true)
 	   : DiscreteSlider(parent,
+	                    name,
 	                    x,
 	                    y,
 	                    w,
@@ -167,8 +171,7 @@ struct WuiPlotAreaSlider : public UI::DiscreteSlider {
 	                    tooltip_text,
 	                    cursor_size,
 	                    enabled),
-	     plot_area_(plot_area),
-	     last_game_time_id_(0) {
+	     plot_area_(plot_area) {
 	}
 
 protected:
@@ -176,7 +179,7 @@ protected:
 
 private:
 	WuiPlotArea& plot_area_;
-	uint32_t last_game_time_id_;
+	uint32_t last_game_time_id_{0U};
 };
 
 /**
@@ -187,6 +190,7 @@ private:
 struct DifferentialPlotArea : public WuiPlotArea {
 public:
 	DifferentialPlotArea(UI::Panel* parent,
+	                     const std::string& name,
 	                     int32_t x,
 	                     int32_t y,
 	                     int32_t w,
