@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2022 by the Widelands Development Team
+ * Copyright (C) 2011-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,12 +20,13 @@
 #define WL_WUI_PORTDOCKWARESDISPLAY_H
 
 #include "ui_basic/box.h"
+#include "wui/buildingwindow.h"
 #include "wui/interactive_gamebase.h"
 #include "wui/waresdisplay.h"
 
 namespace Widelands {
 class PortDock;
-}
+}  // namespace Widelands
 
 AbstractWaresDisplay* create_portdock_wares_display(UI::Panel* parent,
                                                     uint32_t width,
@@ -34,6 +35,7 @@ AbstractWaresDisplay* create_portdock_wares_display(UI::Panel* parent,
 
 UI::Box* create_portdock_expedition_display(UI::Panel* parent,
                                             Widelands::Warehouse& wh,
-                                            InteractiveGameBase&);
+                                            InteractiveGameBase&,
+                                            BuildingWindow::CollapsedState* priority_collapsed);
 
 #endif  // end of include guard: WL_WUI_PORTDOCKWARESDISPLAY_H
