@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,7 @@
 
 struct ProductionSiteWindow : public BuildingWindow {
 	ProductionSiteWindow(InteractiveBase& parent,
-	                     UI::UniqueWindow::Registry& reg,
+	                     BuildingWindow::Registry& reg,
 	                     Widelands::ProductionSite&,
 	                     bool avoid_fastclick,
 	                     bool workarea_preview_wanted);
@@ -37,24 +37,23 @@ protected:
 	void init(bool avoid_fastclick, bool workarea_preview_wanted) override;
 	void evict_worker();
 	void clicked_watch() override;
+	void on_building_note(const Widelands::NoteBuilding& note) override;
 
 private:
 	void update_worker_table(Widelands::ProductionSite* production_site);
 
 	Widelands::OPtr<Widelands::ProductionSite> production_site_;
-	UI::Table<uintptr_t>* worker_table_;
-	UI::Box* worker_caps_;
-	std::unique_ptr<Notifications::Subscriber<Widelands::NoteBuilding>>
-	   productionsitenotes_subscriber_;
+	UI::Table<uintptr_t>* worker_table_{nullptr};
+	UI::Box* worker_caps_{nullptr};
 
 	void worker_table_selection_changed();
 	void worker_table_dropdown_clicked();
 	void worker_table_xp_clicked(int8_t);
 	void update_worker_xp_buttons(const Widelands::Worker*);
 
-	UI::Dropdown<Widelands::DescriptionIndex>* worker_type_;
-	UI::Button* worker_xp_decrease_;
-	UI::Button* worker_xp_increase_;
+	UI::Dropdown<Widelands::DescriptionIndex>* worker_type_{nullptr};
+	UI::Button* worker_xp_decrease_{nullptr};
+	UI::Button* worker_xp_increase_{nullptr};
 
 	DISALLOW_COPY_AND_ASSIGN(ProductionSiteWindow);
 };
