@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,13 +23,6 @@
 #include "base/time_string.h"
 #include "graphic/text_layout.h"
 
-SavegameData::SavegameData()
-   : nrplayers("0"),
-     savetimestamp(0),
-     gametype(GameController::GameType::kSingleplayer),
-     type_(SavegameType::kSavegame) {
-}
-
 SavegameData::SavegameData(const std::string& fname)
    : SavegameData(fname, SavegameType::kSavegame) {
 }
