@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,22 +34,22 @@ public:
 
 	/// attempt to delete the passed savegames. Returns true, if deletion was actually attempted
 	/// (because deletion can be aborted by user via "cancel" in confirmation window)
-	bool delete_savegames(const std::vector<SavegameData>& to_be_deleted) const;
+	[[nodiscard]] bool delete_savegames(const std::vector<SavegameData>& to_be_deleted) const;
 
-	virtual ~SavegameDeleter() {
-	}
+	virtual ~SavegameDeleter() = default;
 
 private:
-	bool show_confirmation_window(const std::vector<SavegameData>& selections) const;
-	virtual const std::string
-	create_header_for_confirmation_window(const size_t no_selections) const;
+	[[nodiscard]] bool show_confirmation_window(const std::vector<SavegameData>& selections) const;
+	[[nodiscard]] virtual const std::string
+	create_header_for_confirmation_window(size_t no_selections) const;
 	void delete_and_count_failures(const std::vector<SavegameData>& to_be_deleted) const;
-	virtual uint32_t try_to_delete(const std::vector<SavegameData>& to_be_deleted) const;
+	[[nodiscard]] virtual uint32_t
+	try_to_delete(const std::vector<SavegameData>& to_be_deleted) const;
 
 	void notify_deletion_failed(const std::vector<SavegameData>& to_be_deleted,
-	                            const uint32_t no_failed) const;
-	virtual std::string create_header_for_deletion_failed_window(size_t no_to_be_deleted,
-	                                                             size_t no_failed) const;
+	                            uint32_t no_failed) const;
+	[[nodiscard]] virtual std::string
+	create_header_for_deletion_failed_window(size_t no_to_be_deleted, size_t no_failed) const;
 
 	UI::Panel* parent_;
 	UI::WindowStyle style_;
@@ -60,11 +60,13 @@ public:
 	ReplayDeleter(UI::Panel* parent, UI::WindowStyle);
 
 private:
-	const std::string
-	create_header_for_confirmation_window(const size_t no_selections) const override;
-	std::string create_header_for_deletion_failed_window(size_t no_to_be_deleted,
-	                                                     size_t no_failed) const override;
-	uint32_t try_to_delete(const std::vector<SavegameData>& to_be_deleted) const override;
+	[[nodiscard]] const std::string
+	create_header_for_confirmation_window(size_t no_selections) const override;
+	[[nodiscard]] std::string
+	create_header_for_deletion_failed_window(size_t no_to_be_deleted,
+	                                         size_t no_failed) const override;
+	[[nodiscard]] uint32_t
+	try_to_delete(const std::vector<SavegameData>& to_be_deleted) const override;
 };
 
 #endif  // WL_WUI_SAVEGAMEDELETER_H
