@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 by the Widelands Development Team
+ * Copyright (C) 2017-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,15 +40,10 @@ constexpr int kButtonSize = 34;
 
 SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
                                                  UI::UniqueWindow::Registry& registry)
-   : UI::UniqueWindow(&plr,
-                      UI::WindowStyle::kWui,
-                      "seafaring_statistics",
-                      &registry,
-                      375,
-                      375,
-                      _("Seafaring Statistics")),
+   : UI::UniqueWindow(&plr, UI::WindowStyle::kWui, "seafaring_statistics", &registry, 375, 375, ""),
      main_box_(this,
                UI::PanelStyle::kWui,
+               "main_box",
                kPadding,
                kPadding,
                UI::Box::Vertical,
@@ -57,6 +52,7 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
                kPadding),
      filter_box_(&main_box_,
                  UI::PanelStyle::kWui,
+                 "filter_box",
                  0,
                  0,
                  UI::Box::Horizontal,
@@ -103,9 +99,25 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
                    kButtonSize,
                    UI::ButtonStyle::kWuiSecondary,
                    status_to_image(ShipFilterStatus::kShipping)),
-     ship_filter_(ShipFilterStatus::kAll),
+     warship_btn_(&filter_box_,
+                  "filter_ship_warship",
+                  0,
+                  0,
+                  kButtonSize,
+                  kButtonSize,
+                  UI::ButtonStyle::kWuiSecondary,
+                  status_to_image(ShipFilterStatus::kWarship)),
+     refitting_btn_(&filter_box_,
+                    "filter_ship_refitting",
+                    0,
+                    0,
+                    kButtonSize,
+                    kButtonSize,
+                    UI::ButtonStyle::kWuiSecondary,
+                    status_to_image(ShipFilterStatus::kRefitting)),
      navigation_box_(&main_box_,
                      UI::PanelStyle::kWui,
+                     "navigation_box",
                      0,
                      0,
                      UI::Box::Horizontal,
@@ -127,25 +139,32 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
                   UI::PanelStyle::kWui)),
      openwindowbtn_(
         &navigation_box_,
-        "seafaring_stats_watch_button",
+        "seafaring_stats_open_ship_window_button",
         0,
         0,
         kButtonSize,
         kButtonSize,
         UI::ButtonStyle::kWuiPrimary,
         g_image_cache->get("images/ui_basic/fsel.png"),
-        format("%s<br>%s",
-               as_tooltip_text_with_hotkey(
-                  /** TRANSLATORS: Tooltip in the seafaring statistics window */
-                  _("Open the selected ship’s window"),
-                  shortcut_string_for(KeyboardShortcut::kInGameSeafaringstatsOpenShipWindow, true),
-                  UI::PanelStyle::kWui),
-               as_tooltip_text_with_hotkey(
-                  /** TRANSLATORS: Tooltip in the seafaring statistics window */
-                  _("Go to the selected ship and open its window"),
-                  shortcut_string_for(
-                     KeyboardShortcut::kInGameSeafaringstatsOpenShipWindowAndGoto, true),
-                  UI::PanelStyle::kWui))),
+        format("<rt><p>%s %s<br>%s</p></rt>",
+               g_style_manager->font_style(UI::FontStyle::kWuiTooltip)
+                  .as_font_tag(
+                     /** TRANSLATORS: Tooltip in the seafaring statistics window */
+                     _("Open the selected ship’s window")),
+               g_style_manager->font_style(UI::FontStyle::kWuiTooltipHotkey)
+                  .as_font_tag("(" +
+                               shortcut_string_for(
+                                  KeyboardShortcut::kInGameSeafaringstatsOpenShipWindow, true) +
+                               ")"),
+               g_style_manager->font_style(UI::FontStyle::kWuiTooltip)
+                  .as_font_tag(
+                     /** TRANSLATORS: Tooltip in the seafaring statistics window, placeholder is a
+                         hotkey */
+                     format(_("(You can use %s to go to the selected ship and open its window.)"),
+                            g_style_manager->font_style(UI::FontStyle::kWuiTooltipHotkey)
+                               .as_font_tag(shortcut_string_for(
+                                  KeyboardShortcut::kInGameSeafaringstatsOpenShipWindowAndGoto,
+                                  true)))))),
      centerviewbtn_(&navigation_box_,
                     "seafaring_stats_center_main_mapview_button",
                     0,
@@ -159,7 +178,7 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
                        _("Center the map on the selected ship"),
                        shortcut_string_for(KeyboardShortcut::kInGameSeafaringstatsGotoShip, true),
                        UI::PanelStyle::kWui)),
-     table_(&main_box_, 0, 0, get_inner_w() - 2 * kPadding, 100, UI::PanelStyle::kWui) {
+     table_(&main_box_, "table", 0, 0, get_inner_w() - 2 * kPadding, 100, UI::PanelStyle::kWui) {
 
 	// Buttons for ship states
 	main_box_.add(&filter_box_, UI::Box::Resizing::kAlign, UI::Align::kCenter);
@@ -168,6 +187,8 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
 	filter_box_.add(&waiting_btn_);
 	filter_box_.add(&scouting_btn_);
 	filter_box_.add(&portspace_btn_);
+	filter_box_.add(&warship_btn_);
+	filter_box_.add(&refitting_btn_);
 
 	main_box_.add(&table_, UI::Box::Resizing::kExpandBoth);
 
@@ -188,6 +209,8 @@ SeafaringStatisticsMenu::SeafaringStatisticsMenu(InteractivePlayer& plr,
 	   [this]() { filter_ships(ShipFilterStatus::kExpeditionScouting); });
 	portspace_btn_.sigclicked.connect(
 	   [this]() { filter_ships(ShipFilterStatus::kExpeditionPortspaceFound); });
+	warship_btn_.sigclicked.connect([this]() { filter_ships(ShipFilterStatus::kWarship); });
+	refitting_btn_.sigclicked.connect([this]() { filter_ships(ShipFilterStatus::kRefitting); });
 	ship_filter_ = ShipFilterStatus::kAll;
 	set_filter_ships_tooltips();
 
@@ -243,6 +266,10 @@ SeafaringStatisticsMenu::status_to_string(SeafaringStatisticsMenu::ShipFilterSta
 		return pgettext("ship_state", "Scouting");
 	case SeafaringStatisticsMenu::ShipFilterStatus::kExpeditionPortspaceFound:
 		return pgettext("ship_state", "Port Space Found");
+	case SeafaringStatisticsMenu::ShipFilterStatus::kWarship:
+		return pgettext("ship_state", "Warship");
+	case SeafaringStatisticsMenu::ShipFilterStatus::kRefitting:
+		return pgettext("ship_state", "Being Refitted");
 	case SeafaringStatisticsMenu::ShipFilterStatus::kAll:
 		return "All";  // The user shouldn't see this, so we don't localize
 	}
@@ -268,6 +295,12 @@ SeafaringStatisticsMenu::status_to_image(SeafaringStatisticsMenu::ShipFilterStat
 	case SeafaringStatisticsMenu::ShipFilterStatus::kExpeditionPortspaceFound:
 		filename = "images/wui/ship/ship_construct_port_space.png";
 		break;
+	case SeafaringStatisticsMenu::ShipFilterStatus::kWarship:
+		filename = "images/wui/ship/ship_refit_warship.png";
+		break;
+	case SeafaringStatisticsMenu::ShipFilterStatus::kRefitting:
+		filename = "images/wui/ship/ship_refit_transport.png";
+		break;
 	case SeafaringStatisticsMenu::ShipFilterStatus::kAll:
 		filename = "images/wui/ship/ship_scout_ne.png";
 		break;
@@ -277,30 +310,42 @@ SeafaringStatisticsMenu::status_to_image(SeafaringStatisticsMenu::ShipFilterStat
 
 std::unique_ptr<const SeafaringStatisticsMenu::ShipInfo>
 SeafaringStatisticsMenu::create_shipinfo(const Widelands::Ship& ship) const {
-	const Widelands::Ship::ShipStates state = ship.get_ship_state();
+	const Widelands::ShipStates state = ship.get_ship_state();
 	ShipFilterStatus status = ShipFilterStatus::kAll;
-	switch (state) {
-	case Widelands::Ship::ShipStates::kTransport:
-		if ((ship.get_destination() != nullptr) && ship.get_fleet()->get_schedule().is_busy(ship)) {
-			status = ShipFilterStatus::kShipping;
-		} else {
-			status = ShipFilterStatus::kIdle;
+	if (ship.is_refitting()) {
+		status = ShipFilterStatus::kRefitting;
+	} else {
+		switch (ship.get_ship_type()) {
+		case Widelands::ShipType::kWarship:
+			status = ShipFilterStatus::kWarship;
+			break;
+		case Widelands::ShipType::kTransport:
+			switch (state) {
+			case Widelands::ShipStates::kTransport:
+				if (ship.has_destination() && ship.get_fleet()->get_schedule().is_busy(ship)) {
+					status = ShipFilterStatus::kShipping;
+				} else {
+					status = ShipFilterStatus::kIdle;
+				}
+				break;
+			case Widelands::ShipStates::kExpeditionWaiting:
+				status = ShipFilterStatus::kExpeditionWaiting;
+				break;
+			case Widelands::ShipStates::kExpeditionScouting:
+				status = ShipFilterStatus::kExpeditionScouting;
+				break;
+			case Widelands::ShipStates::kExpeditionPortspaceFound:
+			case Widelands::ShipStates::kExpeditionColonizing:
+				// We're grouping the "colonizing" status with the port space.
+				status = ShipFilterStatus::kExpeditionPortspaceFound;
+				break;
+			case Widelands::ShipStates::kSinkRequest:
+			case Widelands::ShipStates::kSinkAnimation:
+				status = ShipFilterStatus::kAll;
+				break;
+			}
+			break;
 		}
-		break;
-	case Widelands::Ship::ShipStates::kExpeditionWaiting:
-		status = ShipFilterStatus::kExpeditionWaiting;
-		break;
-	case Widelands::Ship::ShipStates::kExpeditionScouting:
-		status = ShipFilterStatus::kExpeditionScouting;
-		break;
-	case Widelands::Ship::ShipStates::kExpeditionPortspaceFound:
-	case Widelands::Ship::ShipStates::kExpeditionColonizing:
-		// We're grouping the "colonizing" status with the port space.
-		status = ShipFilterStatus::kExpeditionPortspaceFound;
-		break;
-	case Widelands::Ship::ShipStates::kSinkRequest:
-	case Widelands::Ship::ShipStates::kSinkAnimation:
-		status = ShipFilterStatus::kAll;
 	}
 	return std::unique_ptr<const ShipInfo>(new ShipInfo(ship.get_shipname(), status, ship.serial()));
 }
@@ -377,6 +422,10 @@ void SeafaringStatisticsMenu::update_button_states() {
 	centerviewbtn_.set_enabled(table_.has_selection());
 	openwindowbtn_.set_enabled(table_.has_selection());
 	watchbtn_.set_enabled(table_.has_selection());
+
+	set_title(format(ngettext("Seafaring Statistics (%u Ship)", "Seafaring Statistics (%u Ships)",
+	                          iplayer().player().ships().size()),
+	                 iplayer().player().ships().size()));
 }
 
 bool SeafaringStatisticsMenu::handle_key(bool down, SDL_Keysym code) {
@@ -418,6 +467,14 @@ bool SeafaringStatisticsMenu::handle_key(bool down, SDL_Keysym code) {
 			filter_ships(ShipFilterStatus::kExpeditionScouting);
 			return true;
 		}
+		if (matches_shortcut(KeyboardShortcut::kInGameSeafaringstatsFilterWarship, code)) {
+			filter_ships(ShipFilterStatus::kWarship);
+			return true;
+		}
+		if (matches_shortcut(KeyboardShortcut::kInGameSeafaringstatsFilterRefitting, code)) {
+			filter_ships(ShipFilterStatus::kRefitting);
+			return true;
+		}
 		if (matches_shortcut(KeyboardShortcut::kInGameSeafaringstatsFilterExpPortspace, code)) {
 			filter_ships(ShipFilterStatus::kExpeditionPortspaceFound);
 			return true;
@@ -468,6 +525,12 @@ void SeafaringStatisticsMenu::filter_ships(ShipFilterStatus status) {
 	case ShipFilterStatus::kIdle:
 		toggle_filter_ships_button(idle_btn_, status);
 		break;
+	case ShipFilterStatus::kWarship:
+		toggle_filter_ships_button(warship_btn_, status);
+		break;
+	case ShipFilterStatus::kRefitting:
+		toggle_filter_ships_button(refitting_btn_, status);
+		break;
 	case ShipFilterStatus::kAll:
 		set_filter_ships_tooltips();
 		ship_filter_ = ShipFilterStatus::kAll;
@@ -476,6 +539,8 @@ void SeafaringStatisticsMenu::filter_ships(ShipFilterStatus status) {
 		portspace_btn_.set_perm_pressed(false);
 		shipping_btn_.set_perm_pressed(false);
 		idle_btn_.set_perm_pressed(false);
+		warship_btn_.set_perm_pressed(false);
+		refitting_btn_.set_perm_pressed(false);
 		break;
 	}
 	fill_table();
@@ -493,6 +558,8 @@ void SeafaringStatisticsMenu::toggle_filter_ships_button(UI::Button& button,
 		portspace_btn_.set_perm_pressed(false);
 		shipping_btn_.set_perm_pressed(false);
 		idle_btn_.set_perm_pressed(false);
+		warship_btn_.set_perm_pressed(false);
+		refitting_btn_.set_perm_pressed(false);
 		button.set_perm_pressed(true);
 		ship_filter_ = status;
 
@@ -531,6 +598,16 @@ void SeafaringStatisticsMenu::set_filter_ships_tooltips() {
 	   _("Show expeditions that have found a port space or are founding a colony"),
 	   shortcut_string_for(KeyboardShortcut::kInGameSeafaringstatsFilterExpPortspace, true),
 	   UI::PanelStyle::kWui));
+	warship_btn_.set_tooltip(as_tooltip_text_with_hotkey(
+	   /** TRANSLATORS: Tooltip in the ship statistics window */
+	   _("Show warships"),
+	   shortcut_string_for(KeyboardShortcut::kInGameSeafaringstatsFilterWarship, true),
+	   UI::PanelStyle::kWui));
+	refitting_btn_.set_tooltip(as_tooltip_text_with_hotkey(
+	   /** TRANSLATORS: Tooltip in the ship statistics window */
+	   _("Show ships being refitted"),
+	   shortcut_string_for(KeyboardShortcut::kInGameSeafaringstatsFilterRefitting, true),
+	   UI::PanelStyle::kWui));
 }
 
 inline bool SeafaringStatisticsMenu::satisfies_filter(const ShipInfo& info,
