@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@
  */
 struct StoryMessageBox : public UI::Window {
 	StoryMessageBox(Widelands::Game* game,
-	                const Widelands::Coords coords,
+	                Widelands::Coords coords,
 	                const std::string& title,
 	                const std::string& body,
 	                int32_t x,
@@ -69,7 +69,8 @@ private:
 	UI::Button ok_, next_scenario_, main_menu_;
 
 	const uint32_t desired_speed_;  // Remember the previous game speed
-	Widelands::Game* game_;         // For controlling the game speed
+	const bool modal_;
+	Widelands::Game* game_;  // For controlling the game speed
 };
 
 #endif  // end of include guard: WL_WUI_STORY_MESSAGE_BOX_H
