@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +27,7 @@ static char const* pic_tab_military = "images/wui/buildings/menu_tab_military.pn
  * Create the \ref TrainingSite specific soldier list tab.
  */
 TrainingSiteWindow::TrainingSiteWindow(InteractiveBase& parent,
-                                       UI::UniqueWindow::Registry& reg,
+                                       BuildingWindow::Registry& reg,
                                        Widelands::TrainingSite& ts,
                                        bool avoid_fastclick,
                                        bool workarea_preview_wanted)
