@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2022 by the Widelands Development Team
+ * Copyright (C) 2006-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,3 +21,7 @@
 UI::UniqueWindow::Registry& UniqueWindowHandler::get_registry(const std::string& name) {
 	return registries_[name];
 }
+BuildingWindow::Registry&
+UniqueWindowHandler::get_building_window_registry(const std::string& name) {
+	return building_window_registries_[name];
+}
