@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2022 by the Widelands Development Team
+ * Copyright (C) 2002-2024 by the Widelands Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,13 +27,14 @@
  */
 struct WarehouseWindow : public BuildingWindow {
 	WarehouseWindow(InteractiveBase& parent,
-	                UI::UniqueWindow::Registry& reg,
+	                BuildingWindow::Registry& reg,
 	                Widelands::Warehouse&,
 	                bool avoid_fastclick,
 	                bool workarea_preview_wanted);
 
 private:
 	void init(bool avoid_fastclick, bool workarea_preview_wanted) override;
+	void setup_name_field_editbox(UI::Box& vbox) override;
 
 	Widelands::OPtr<Widelands::Warehouse> warehouse_;
 
