@@ -34,9 +34,9 @@ wl.Descriptions():new_worker_type {
       harvest = {
          "findobject=attrib:tree radius:10",
          "walk=object",
-         "playsound=sound/woodcutting/woodcutting 255",
+         "playsound=sound/woodcutting/woodcutting priority:100%",
          "animate=hacking duration:15s",
-         "playsound=sound/woodcutting/tree_falling 130",
+         "playsound=sound/woodcutting/tree_falling priority:50%",
          "callobject=fall",
          "animate=idle duration:2s",
          "createware=custom_ware",
