@@ -4,6 +4,7 @@
 """Script to find unused includes.
 
 Call from src directory.
+
 """
 
 import copy
@@ -39,9 +40,9 @@ FILE_EXCLUDES = {'graphic/gl/system_headers.h', 'scripting/lua.h',
                  'base/format/abstract_node.h'}
 
 # Headers files with contents that need to be detected by functions
-DIFFICULT_FILES = {'graphic/build_texture_atlas.h', 'base/string.h',
+DIFFICULT_FILES = {'graphic/build_texture_atlas.h', 'base/string.h', 'wlapplication_options.h',
                    'scripting/report_error.h', 'editor/tools/set_resources_tool.h',
-                   'wlapplication_options.h'}
+                   'third_party/libmd/include/sha2.h'}
 
 # Remove overgenerated symbols
 FUNCTION_EXCLUDES = {'_Pragma',
@@ -213,6 +214,7 @@ def main():
     """Script to find unused includes and print them to console.
 
     Call from src directory.
+
     """
 
     error_count = 0
