@@ -25,17 +25,22 @@ tempfile="$(mktemp -d)/image.png"
 
 i=0
 skipped=0
+saved=0
 for image in $(find "$dir" -name '*.png')
 do
   ((++i))
   printf "\r[%5d] %-100s " "$i" "$image"
   pngquant 256 < "$image" > "$tempfile"
-  if [ $(wc -c < "$tempfile") -lt $(wc -c < "$image") ]
+
+  oldsize=$(wc -c < "$image")
+  newsize=$(wc -c < "$tempfile")
+  if [ $newsize -lt $((oldsize * 95 / 100)) ]  # Only accept images that have shrunk by at least 5%
   then
     mv "$tempfile" "$image"
+    ((saved += oldsize - newsize))
   else
     ((++skipped))
   fi
 done
 
-printf "\n%d images converted, %d images skipped.\n" $((i-skipped)) $skipped
+printf "\n%d images converted, %d images skipped, %d bytes saved.\n" $((i - skipped)) $skipped $saved
